@@ -1,6 +1,6 @@
 /* airpcap_loader.c
  *
- * $Id: airpcap_loader.c 31539 2010-01-16 01:02:51Z gerald $
+ * $Id: airpcap_loader.c 33935 2010-08-26 17:35:28Z gerald $
  *
  * Giorgio Tino <giorgio.tino@cacetech.com>
  * Copyright (c) CACE Technologies, LLC 2006
@@ -47,6 +47,7 @@
 #include <epan/strutil.h>
 #include <epan/frequency-utils.h>
 #include "capture_ui_utils.h"
+#include <wsutil/file_util.h>
 
 #include "simple_dialog.h"
 
@@ -2450,7 +2451,7 @@ int load_airpcap(void)
     gboolean base_functions = TRUE;
     gboolean eleven_n_functions = TRUE;
 
-    if((AirpcapLib =  LoadLibrary(TEXT("airpcap.dll"))) == NULL)
+    if((AirpcapLib = ws_load_library("airpcap.dll")) == NULL)
     {
   		/* Report the error but go on */
   		AirpcapVersion = AIRPCAP_DLL_NOT_FOUND;
