@@ -2,7 +2,7 @@
  * Written by Shaun Jackman <sjackman@gmail.com>.
  * Copyright 2007 Shaun Jackman
  *
- * $Id: packet-mpeg-audio-template.c 25330 2008-05-20 21:51:01Z morriss $
+ * $Id: packet-mpeg-audio-template.c 27882 2009-03-29 14:37:57Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -32,7 +32,6 @@
 #include <glib.h>
 
 #include <epan/packet.h>
-#include <epan/prefs.h>
 #include <epan/asn1.h>
 
 #include <wsutil/mpeg-audio.h>
@@ -56,7 +55,7 @@ dissect_mpeg_audio_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	guint32 h;
 	struct mpa mpa;
-	size_t data_size = 0;
+	int data_size = 0;
 	asn1_ctx_t asn1_ctx;
 	int offset = 0;
 
@@ -81,7 +80,7 @@ dissect_mpeg_audio_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		col_add_fstr(pinfo->cinfo, COL_INFO,
 				"Audio Layer %d", mpa_layer(&mpa) + 1);
 	if (MPA_BITRATE_VALID(&mpa) && MPA_FREQUENCY_VALID(&mpa)) {
-		data_size = MPA_DATA_BYTES(&mpa) - sizeof mpa;
+		data_size = (int)(MPA_DATA_BYTES(&mpa) - sizeof mpa);
 		if (check_col(pinfo->cinfo, COL_DEF_SRC)) {
 			SET_ADDRESS(&pinfo->src, AT_NONE, 0, NULL);
 			col_add_fstr(pinfo->cinfo, COL_DEF_SRC,
