@@ -3,7 +3,7 @@
  *
  * Copyright 2008, Anders Broman <anders.broman@ericsson.com>
  *
- * $Id: packet-pcap-template.c 26728 2008-11-07 17:13:25Z wmeier $
+ * $Id: packet-pcap-template.c 27390 2009-02-07 14:33:47Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -35,11 +35,9 @@
 #include <glib.h>
 #include <epan/packet.h>
 #include <epan/prefs.h>
-#include <epan/conversation.h>
 
 #include <stdio.h>
 #include <string.h>
-#include <epan/emem.h>
 #include <epan/strutil.h>
 #include <epan/asn1.h>
 
