@@ -17,7 +17,7 @@
  * See RFC 2578 for Structure of Management Information Version 2 (SMIv2)
  * Copyright (C) 2007 Luis E. Garcia Ontanon <luis@ontanon.org>
  *
- * $Id: packet-snmp-template.c 32223 2010-03-17 19:14:44Z gerald $
+ * $Id: packet-snmp-template.c 33586 2010-07-19 23:41:57Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1036,12 +1036,12 @@ static snmp_ue_assoc_t* ue_se_dup(snmp_ue_assoc_t* o) {
 #define CACHE_INSERT(c,a) if (c) { snmp_ue_assoc_t* t = c; c = a; c->next = t; } else { c = a; a->next = NULL; }
 
 static void renew_ue_cache(void) {
-	if (num_ueas) {
-		guint i;
-
 		localized_ues = NULL;
 		unlocalized_ues = NULL;
 
+	if (num_ueas) {
+		guint i;
+
 		for(i = 0; i < num_ueas; i++) {
 			snmp_ue_assoc_t* a = ue_se_dup(&(ueas[i]));
 
@@ -1053,9 +1053,6 @@ static void renew_ue_cache(void) {
 			}
 
 		}
-	} else {
-		localized_ues = NULL;
-		unlocalized_ues = NULL;
 	}
 }
 
@@ -1825,6 +1822,10 @@ static void snmp_users_update_cb(void* p _U_, const char** err) {
 
 	*err = NULL;
 
+	if (num_ueas == 0)
+		/* Nothing to update */
+		return;
+
 	if (! ue->user.userName.len)
 		g_string_append_printf(es,"no userName\n");
 
