@@ -3,7 +3,7 @@
  * time, so that we only need one Wireshark binary and one TShark binary
  * for Windows, regardless of whether WinPcap is installed or not.
  *
- * $Id: capture-wpcap.c 31539 2010-01-16 01:02:51Z gerald $
+ * $Id: capture-wpcap.c 33935 2010-08-26 17:35:28Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -39,6 +39,8 @@
 #include "capture-pcap-util.h"
 #include "capture-pcap-util-int.h"
 
+#include <wsutil/file_util.h>
+
 /* XXX - yes, I know, I should move cppmagic.h to a generic location. */
 #include "tools/lemon/cppmagic.h"
 
@@ -193,7 +195,7 @@ load_wpcap(void)
 	GModule		*wh; /* wpcap handle */
 	const symbol_table_t	*sym;
 
-	wh = g_module_open("wpcap", 0);
+	wh = ws_module_open("wpcap.dll", 0);
 
 	if (!wh) {
 		return;
@@ -867,7 +869,7 @@ get_runtime_pcap_version(GString *str)
 			 */
 			if (packetVer == NULL) {
 				packetVer = "version unknown";
-				handle = g_module_open("Packet.dll", 0);
+				handle = ws_module_open("packet.dll", 0);
 				if (handle != NULL) {
 					if (g_module_symbol(handle,
 					    "PacketLibraryVersion",
