@@ -1,7 +1,7 @@
 /* capture_info.c
  * capture info functions
  *
- * $Id: capture_info.c 23077 2007-10-05 22:39:06Z morriss $
+ * $Id: capture_info.c 25986 2008-08-12 04:44:35Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -54,11 +54,10 @@
 #include <epan/dissectors/packet-ieee80211.h>
 #include <epan/dissectors/packet-radiotap.h>
 #include <epan/dissectors/packet-chdlc.h>
-#include <epan/dissectors/packet-prism.h>
 #include <epan/dissectors/packet-ipfc.h>
 #include <epan/dissectors/packet-arcnet.h>
 #include <epan/dissectors/packet-enc.h>
-#include <epan/dissectors/packet-wlancap.h>
+#include <epan/dissectors/packet-i2c.h>
 
 static void capture_info_packet(
 packet_counts *counts, gint wtap_linktype, const guchar *pd, guint32 caplen, union wtap_pseudo_header *pseudo_header);
@@ -76,7 +75,7 @@ info_data_t info_data;
 
 
 /* open the info */
-void capture_info_open(const char *iface)
+void capture_info_open(capture_options *capture_opts)
 {
     info_data.counts.total      = 0;
     info_data.counts.sctp       = 0;
@@ -90,11 +89,13 @@ void capture_info_open(const char *iface)
     info_data.counts.vines      = 0;
     info_data.counts.other      = 0;
     info_data.counts.arp        = 0;
+    info_data.counts.i2c_event  = 0;
+    info_data.counts.i2c_data   = 0;
 
     info_data.wtap = NULL;
     info_data.ui.counts = &info_data.counts;
 
-    capture_info_ui_create(&info_data.ui, iface);
+    capture_info_ui_create(&info_data.ui, capture_opts);
 }
 
 
@@ -336,6 +337,9 @@ capture_info_packet(packet_counts *counts, gint wtap_linktype, const guchar *pd,
     case WTAP_ENCAP_PPI:
       capture_ppi(pd, caplen, counts);
       break;
+    case WTAP_ENCAP_I2C:
+      capture_i2c(pseudo_header, counts);
+      break;
     /* XXX - some ATM drivers on FreeBSD might prepend a 4-byte ATM
        pseudo-header to DLT_ATM_RFC1483, with LLC header following;
        we might have to implement that at some point. */
