@@ -1,7 +1,7 @@
 /* capture_ui_utils.c
  * Utilities for capture user interfaces
  *
- * $Id: capture_ui_utils.c 25418 2008-06-03 23:51:39Z guy $
+ * $Id: capture_ui_utils.c 32655 2010-05-04 00:20:39Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -33,7 +33,8 @@
 #include <string.h>
 #include <glib.h>
 
-#include <epan/prefs.h>
+#include "epan/prefs.h"
+#include "epan/ex-opt.h"
 #include "capture-pcap-util.h"
 #include "capture_ui_utils.h"
 
@@ -154,6 +155,17 @@ get_interface_descriptive_name(const char *if_name)
   if (descr != NULL) {
     /* Yes - make a copy of that. */
     descr = g_strdup(descr);
+  } else if (strcmp(if_name, "-") == 0) {
+    /*
+     * Strictly speaking, -X (extension) options are for modules, e.g. Lua
+     * and using one here stretches that definition. However, this doesn't
+     * waste a single-letter option on something that might be rarely used
+     * and is backward-compatible to 1.0.
+     */
+    descr = g_strdup(ex_opt_get_nth("stdin_descr", 0));
+    if (!descr) {
+      descr = g_strdup("Standard input");
+    }
   } else {
     /* No, we don't have a user-supplied description; did we get
        one from the OS or libpcap? */
