@@ -4,7 +4,7 @@
  * time, so that we only need one Wireshark binary and one TShark binary
  * for Windows, regardless of whether WinPcap is installed or not.
  *
- * $Id: capture_wpcap_packet.c 33940 2010-08-26 20:10:28Z gerald $
+ * $Id: capture_wpcap_packet.c 33935 2010-08-26 17:35:28Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,7 +34,6 @@
 #include <glib.h>
 #include <gmodule.h>
 
-#include <wtap.h>
 #include <pcap.h>
 
 /* XXX - yes, I know, I should move cppmagic.h to a generic location. */
@@ -42,16 +41,26 @@
 
 #include <epan/value_string.h>
 
-#include <wiretap/file_util.h>
+#include <winsock2.h>    /* Needed here to force a definition of WINVER           */
+                         /* for some (all ?) Microsoft compilers newer than vc6.  */
+                         /* (If windows.h were used instead, there might be       */
+                         /*  issues re winsock.h included before winsock2.h )     */
+#include <windowsx.h>
+#include <Ntddndis.h>
 
+#include "capture_wpcap_packet.h"
+#include <wsutil/file_util.h>
 
 /* packet32.h requires sockaddr_storage 
- * wether sockaddr_storage is defined or not depends on the Platform SDK 
+ * whether sockaddr_storage is defined or not depends on the Platform SDK 
  * version installed. The only one not defining it is the SDK that comes
  * with MSVC 6.0 (WINVER 0x0400).
  *
  * copied from RFC2553 (and slightly modified because of datatypes) ...
  * XXX - defined more than once, move this to a header file */
+#ifndef WINVER
+#error WINVER not defined ....
+#endif
 #if (WINVER <= 0x0400) && defined(_MSC_VER)
 typedef unsigned short eth_sa_family_t;
 
@@ -85,13 +94,7 @@ struct sockaddr_storage {
 /* ... copied from RFC2553 */
 #endif /* WINVER */
 
-
 #include <Packet32.h>
-#include <windows.h>
-#include <windowsx.h>
-#include <Ntddndis.h>
-
-#include "capture_wpcap_packet.h"
 
 gboolean has_wpacket = FALSE;
 
@@ -317,3 +320,16 @@ wpcap_packet_load(void)
 }
 
 #endif /* HAVE_LIBPCAP */
+
+/*
+ * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ *
+ * Local variables:
+ * c-basic-offset: 4
+ * tab-width: 4
+ * indent-tabs-mode: tabs
+ * End:
+ *
+ * ex: set shiftwidth=4 tabstop=4 noexpandtab
+ * :indentSize=4:tabSize=4:noTabs=false:
+ */
\ No newline at end of file
