@@ -1,7 +1,7 @@
 /* column-utils.h
  * Definitions for column utility structures and routines
  *
- * $Id: column-utils.h 27452 2009-02-15 15:02:55Z stig $
+ * $Id: column-utils.h 33652 2010-07-28 18:49:19Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -81,7 +81,7 @@ extern void	col_fill_in(packet_info *pinfo);
  */
 extern gboolean	col_get_writable(column_info *cinfo);
 
-/** Set the columns writable. 
+/** Set the columns writable.
  *
  * @param cinfo the current packet row
  * @param writable TRUE if it's writable, FALSE if not
@@ -95,8 +95,8 @@ extern void	col_set_writable(column_info *cinfo, gboolean writable);
  */
 extern gint	check_col(column_info *cinfo, gint col);
 
-/** Sets a fence for the current column content, 
- * so this content won't be affected by further col_... function calls. 
+/** Sets a fence for the current column content,
+ * so this content won't be affected by further col_... function calls.
  *
  * This can be useful if a protocol is more than once in a single packet,
  * e.g. multiple HTTP calls in a single TCP packet.
@@ -171,7 +171,7 @@ extern void	col_append_str(column_info *cinfo, gint col, const gchar *str);
  * @param format the format string
  * @param ... the variable number of parameters
  */
-extern void	col_append_fstr(column_info *cinfo, gint col, const gchar *format, ...)
+extern void	col_append_fstr(column_info *cinfo, const gint col, const gchar *format, ...)
     GNUC_FORMAT_CHECK(printf, 3, 4);
 
 /** Prepend the given text to a column element, the text will be formatted and copied.
@@ -217,7 +217,7 @@ extern void	col_append_sep_str(column_info *cinfo, gint col, const gchar *sep,
  * @param format the format string
  * @param ... the variable number of parameters
  */
-extern void	col_append_sep_fstr(column_info *cinfo, gint col, const gchar *sep,
+extern void	col_append_sep_fstr(column_info *cinfo, const gint col, const gchar *sep,
 		const gchar *format, ...)
     GNUC_FORMAT_CHECK(printf, 4, 5);
 
@@ -225,11 +225,11 @@ extern void	col_append_sep_fstr(column_info *cinfo, gint col, const gchar *sep,
  *
  * Used by multiple dissectors to set the time in the columns
  * COL_REL_CONV_TIME and COL_DELTA_CONV_TIME
- * 
+ *
  * @param cinfo		the current packet row
  * @param col		the column to use, e.g. COL_INFO
  * @param ts		the time to set in the column
- * @param fieldname	the fieldname to use for creating a filter (when 
+ * @param fieldname	the fieldname to use for creating a filter (when
  *			  applying/preparing/copying as filter)
  */
 extern void 	col_set_time(column_info *cinfo, int col,
