@@ -1,7 +1,7 @@
 /**
  * airpdcap_rijndael.h
  *
- * $Id: airpdcap_rijndael.h 20932 2007-02-25 23:25:23Z guy $
+ * $Id: airpdcap_rijndael.h 25879 2008-07-30 22:32:21Z gerald $
  *
  * @version 3.0 (December 2000)
  *
@@ -52,7 +52,6 @@
 /*																										*/
 /* Note: copied AirPDcap/rijndael/rijndael.h												*/
 typedef struct s_rijndael_ctx {
-	INT     decrypt;
 	INT     Nr;             /* key-length-dependent number of rounds */
 	UINT32 ek[4 * (RIJNDAEL_MAXNR + 1)];  /* encrypt key schedule */
 	UINT32 dk[4 * (RIJNDAEL_MAXNR + 1)];  /* decrypt key schedule */
@@ -75,6 +74,9 @@ void rijndael_set_key(
 	const UCHAR *key,
 	INT bits)
 	;
+
+UCHAR AES_unwrap(UCHAR *kek, UINT16 key_len, UCHAR *cipher_text, UINT16 cipher_len, UCHAR *output);
+
 /*																										*/
 /******************************************************************************/
 
@@ -82,10 +84,10 @@ void rijndael_set_key(
 /*	Block XOR macro definition																*/
 /*																										*/
 #define XOR_BLOCK(b, a, len) \
-	{						\
-		INT i;					\
-		for (i = 0; i < (INT)(len); i++)	\
-			(b)[i] ^= (a)[i];		\
+	{							\
+		INT __i__;					\
+		for (__i__ = 0; __i__ < (INT)(len); __i__++)	\
+			(b)[__i__] ^= (a)[__i__];		\
 	}
 /*																										*/
 /******************************************************************************/
