@@ -1,7 +1,7 @@
 /* packet-3com-njack.c
  * Routines for the disassembly of the 3com NetworkJack management protocol
  *
- * $Id: packet-3com-njack.c 23623 2007-11-27 18:52:51Z guy $
+ * $Id: packet-3com-njack.c 27854 2009-03-26 18:33:50Z jmayer $
  *
  * Copyright 2005 Joerg Mayer (see AUTHORS file)
  *
@@ -59,9 +59,6 @@ Specs:
 #include <epan/packet.h>
 #include <epan/emem.h>
 
-#ifdef NEED_G_ASCII_STRCASECMP_H
-#include "g_ascii_strcasecmp.h"
-#endif
 
 /* protocol handles */
 static int proto_njack = -1;
@@ -554,7 +551,7 @@ verify_password(tvbuff_t *tvb, const char *password)
 	md5_append(&md_ctx, digest, 16);
 	md5_append(&md_ctx, packetdata + 28, length - 28);
 	md5_finish(&md_ctx, digest);
-	fprintf(stderr, "Calclulated digest: "); /* debugging */
+	fprintf(stderr, "Calculated digest: "); /* debugging */
 	for (i = 0; i < 16; i++) {
 		fprintf(stderr, "%02X", digest[i]); /* debugging */
 		if (digest[i] != *(packetdata + 12 + i)) {
@@ -679,8 +676,6 @@ dissect_njack_static(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	return dissect_njack(tvb, pinfo, tree);
 }
 
-void proto_register_njack(void);
-
 void
 proto_register_njack(void)
 {
@@ -689,99 +684,99 @@ proto_register_njack(void)
 	/* NJACK header */
 		{ &hf_njack_magic,
 		{ "Magic",	"njack.magic", FT_STRING, BASE_DEC, NULL,
-			0x0, "", HFILL }},
+			0x0, NULL, HFILL }},
 
 		{ &hf_njack_type,
 		{ "Type",	"njack.type", FT_UINT8, BASE_HEX, NULL,
-			0x0, "", HFILL }},
+			0x0, NULL, HFILL }},
 
 	/* TLV fields */
 		{ &hf_njack_tlv_type,
 		{ "TlvType",	"njack.tlv.type", FT_UINT8, BASE_HEX, VALS(njack_cmd_vals),
-			0x0, "", HFILL }},
+			0x0, NULL, HFILL }},
 
 		{ &hf_njack_tlv_length,
 		{ "TlvLength",	"njack.tlv.length", FT_UINT8, BASE_HEX, NULL,
-			0x0, "", HFILL }},
+			0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_data,
                 { "TlvData",   "njack.tlv.data", FT_BYTES, BASE_NONE, NULL,
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_version,
                 { "TlvFwVersion",   "njack.tlv.version", FT_IPv4, BASE_NONE, NULL,
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_snmpwrite,
                 { "TlvTypeSnmpwrite",   "njack.tlv.snmpwrite", FT_UINT8, BASE_DEC, VALS(&njack_snmpwrite),
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_dhcpcontrol,
                 { "TlvTypeDhcpControl",   "njack.tlv.dhcpcontrol", FT_UINT8, BASE_DEC, VALS(&njack_dhcpcontrol),
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_devicemac,
                 { "TlvTypeDeviceMAC",   "njack.tlv.devicemac", FT_ETHER, BASE_NONE, NULL,
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
 		/* XXX dummy entries, to be replaced */
                 { &hf_njack_tlv_typeip,
                 { "TlvTypeIP",   "njack.tlv.typeip", FT_IPv4, BASE_NONE, NULL,
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_typestring,
                 { "TlvTypeString",   "njack.tlv.typestring", FT_STRING, BASE_DEC, NULL,
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
 		/* 1st tab */
                 { &hf_njack_tlv_scheduling,
                 { "TlvTypeScheduling",   "njack.tlv.scheduling", FT_UINT8, BASE_DEC, VALS(&njack_scheduling),
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_addtagscheme,
                 { "TlvAddTagScheme",   "njack.tlv.addtagscheme", FT_UINT8, BASE_DEC, VALS(&njack_addtagscheme),
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_portingressmode,
                 { "TlvTypePortingressmode",   "njack.tlv.portingressmode", FT_UINT8, BASE_DEC, VALS(&njack_portingressmode),
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_maxframesize,
                 { "TlvTypeMaxframesize",   "njack.tlv.maxframesize", FT_UINT8, BASE_DEC, VALS(&njack_maxframesize),
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_countermode,
-                { "TlvTypeCountermode",   "njack.tlv.contermode", FT_UINT8, BASE_DEC, VALS(&njack_countermode),
-                        0x0, "", HFILL }},
+                { "TlvTypeCountermode",   "njack.tlv.countermode", FT_UINT8, BASE_DEC, VALS(&njack_countermode),
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_powerforwarding,
                 { "TlvTypePowerforwarding",   "njack.tlv.powerforwarding", FT_UINT8, BASE_DEC, VALS(&njack_powerforwarding),
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
 	/* Type 0x07: set */
 		{ &hf_njack_set_length,
 		{ "SetLength",	"njack.set.length", FT_UINT16, BASE_HEX, NULL,
-			0x0, "", HFILL }},
+			0x0, NULL, HFILL }},
 
 		{ &hf_njack_set_salt,
 		{ "Salt",	"njack.set.salt", FT_UINT32, BASE_HEX, NULL,
-			0x0, "", HFILL }},
+			0x0, NULL, HFILL }},
 
                 { &hf_njack_set_authdata,
                 { "Authdata",   "njack.tlv.authdata", FT_BYTES, BASE_NONE, NULL,
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
 	/* Type 0x08: set result */
                 { &hf_njack_setresult,
                 { "SetResult",   "njack.setresult", FT_UINT8, BASE_HEX, VALS(njack_setresult_vals),
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
 	/* Type 0x0b get */
 
 	/* Type 0x0c get response */
 		{ &hf_njack_getresp_unknown1,
 		{ "Unknown1",	"njack.getresp.unknown1", FT_UINT8, BASE_HEX, NULL,
-			0x0, "", HFILL }},
+			0x0, NULL, HFILL }},
 
         };
 	static gint *ett[] = {
@@ -789,14 +784,11 @@ proto_register_njack(void)
 		&ett_njack_tlv_header,
 	};
 
-        proto_njack = proto_register_protocol(PROTO_LONG_NAME,
-	    PROTO_SHORT_NAME, "njack");
+        proto_njack = proto_register_protocol(PROTO_LONG_NAME, PROTO_SHORT_NAME, "njack");
         proto_register_field_array(proto_njack, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
 }
 
-void proto_reg_handoff_njack(void);
-
 void
 proto_reg_handoff_njack(void)
 {
