@@ -12,7 +12,7 @@
  * Copyright 2007, Michael Lum <michael.lum [AT] utstar.com>
  * In association with UTStarcom Inc.
  *
- * $Id: packet-ansi_801.c 24181 2008-01-24 21:57:13Z morriss $
+ * $Id: packet-ansi_801.c 28488 2009-05-26 16:01:12Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -82,7 +82,7 @@ static proto_tree *g_tree;
 
 /* FUNCTIONS */
 
-static const guint8 bit_mask[] = {
+static const guint8 global_bit_mask[] = {
     0x01,
     0x03,
     0x07,
@@ -93,7 +93,7 @@ static const guint8 bit_mask[] = {
     0xff
 };
 
-guint64
+static guint64
 ansi_801_tvb_get_bits(tvbuff_t *tvb, guint32 *offset_p, guint8 *bit_offset_p, guint8 num_bits)
 {
     guint64	bits;
@@ -106,7 +106,7 @@ ansi_801_tvb_get_bits(tvbuff_t *tvb, guint32 *offset_p, guint8 *bit_offset_p, gu
     {
 	shift_bits = (*bit_offset_p) - num_bits;
 
-	bits = (tvb_get_guint8(tvb, *offset_p) & bit_mask[(*bit_offset_p)-1]) >> shift_bits;
+	bits = (tvb_get_guint8(tvb, *offset_p) & global_bit_mask[(*bit_offset_p)-1]) >> shift_bits;
 
 	if (shift_bits == 0)
 	{
@@ -124,7 +124,7 @@ ansi_801_tvb_get_bits(tvbuff_t *tvb, guint32 *offset_p, guint8 *bit_offset_p, gu
 
     shift_bits = (num_bits - *bit_offset_p);
 
-    bits = (tvb_get_guint8(tvb, *offset_p) & bit_mask[(*bit_offset_p)-1]) << shift_bits;
+    bits = (tvb_get_guint8(tvb, *offset_p) & global_bit_mask[(*bit_offset_p)-1]) << shift_bits;
 
     num_octs = (shift_bits / 8) + 1;
     remaining_bits = shift_bits % 8;
@@ -954,7 +954,7 @@ pr_loc_response(tvbuff_t *tvb, proto_tree *tree, guint len, guint32 offset)
 
     other_decode_bitfield_value(bigbuf, value, 0x003e, 16);
     proto_tree_add_text(tree, tvb, offset, 2,
-	"%s :  LOC_UNCRTNTY_P: Standard deviation of axis perpindicular to angle specified for position uncertainty (meters): %s",
+	"%s :  LOC_UNCRTNTY_P: Standard deviation of axis perpendicular to angle specified for position uncertainty (meters): %s",
 	bigbuf,
 	str);
 
@@ -1316,7 +1316,7 @@ rev_req_gps_loc_ass(tvbuff_t *tvb, proto_tree *tree, guint len, guint32 offset)
     proto_tree_add_text(tree, tvb, offset, 1,
 	"%s :  Coordinate type requested: %s coordinates",
 	bigbuf,
-	(oct & 0x80) ? "Sperical" : "Cartesian");
+	(oct & 0x80) ? "Spherical" : "Cartesian");
 
     other_decode_bitfield_value(bigbuf, oct, 0x7f, 8);
     proto_tree_add_text(tree, tvb, offset, 1,
@@ -2080,6 +2080,7 @@ dissect_ansi_801_for_message(tvbuff_t *tvb, proto_tree *tree)
     guint8	oct, num_req, num_rsp, pd_msg_type;
     guint	rem_len;
     const gchar	*str = NULL;
+	proto_item *hidden_item;
 
     offset = 0;
     oct = tvb_get_guint8(tvb, offset);
@@ -2106,8 +2107,9 @@ dissect_ansi_801_for_message(tvbuff_t *tvb, proto_tree *tree)
 	bigbuf,
 	oct & 0x1f);
 
-    proto_tree_add_uint_hidden(tree, hf_ansi_801_sess_tag, tvb, offset,
+    hidden_item = proto_tree_add_uint(tree, hf_ansi_801_sess_tag, tvb, offset,
 	1, oct & 0x1f);
+	PROTO_ITEM_SET_HIDDEN(hidden_item);
 
     offset++;
     oct = tvb_get_guint8(tvb, offset);
@@ -2265,6 +2267,7 @@ dissect_ansi_801_rev_message(tvbuff_t *tvb, proto_tree *tree)
     guint8	oct, num_req, num_rsp, pd_msg_type;
     guint	rem_len;
     const gchar	*str = NULL;
+	proto_item *hidden_item;
 
     offset = 0;
     oct = tvb_get_guint8(tvb, offset);
@@ -2291,8 +2294,9 @@ dissect_ansi_801_rev_message(tvbuff_t *tvb, proto_tree *tree)
 	bigbuf,
 	oct & 0x1f);
 
-    proto_tree_add_uint_hidden(tree, hf_ansi_801_sess_tag, tvb, offset,
+    hidden_item = proto_tree_add_uint(tree, hf_ansi_801_sess_tag, tvb, offset,
 	1, oct & 0x1f);
+	PROTO_ITEM_SET_HIDDEN(hidden_item);
 
     offset++;
     oct = tvb_get_guint8(tvb, offset);
@@ -2500,37 +2504,37 @@ proto_register_ansi_801(void)
 	{ &hf_ansi_801_for_req_type,
 	    { "Forward Request Type",		"ansi_801.for_req_type",
 	    FT_UINT8, BASE_DEC, NULL, 0,
-	    "", HFILL }
+	    NULL, HFILL }
 	},
 	{ &hf_ansi_801_for_rsp_type,
 	    { "Forward Response Type",		"ansi_801.for_rsp_type",
 	    FT_UINT8, BASE_DEC, NULL, 0,
-	    "", HFILL }
+	    NULL, HFILL }
 	},
 	{ &hf_ansi_801_rev_req_type,
 	    { "Reverse Request Type",		"ansi_801.rev_req_type",
 	    FT_UINT8, BASE_DEC, NULL, 0,
-	    "", HFILL }
+	    NULL, HFILL }
 	},
 	{ &hf_ansi_801_rev_rsp_type,
 	    { "Reverse Response Type",		"ansi_801.rev_rsp_type",
 	    FT_UINT8, BASE_DEC, NULL, 0,
-	    "", HFILL }
+	    NULL, HFILL }
 	},
 	{ &hf_ansi_801_for_sess_tag,
 	    { "Forward Session Tag",		"ansi_801.for_sess_tag",
 	    FT_UINT8, BASE_DEC, NULL, 0,
-	    "", HFILL }
+	    NULL, HFILL }
 	},
 	{ &hf_ansi_801_rev_sess_tag,
 	    { "Reverse Session Tag",		"ansi_801.rev_sess_tag",
 	    FT_UINT8, BASE_DEC, NULL, 0,
-	    "", HFILL }
+	    NULL, HFILL }
 	},
 	{ &hf_ansi_801_sess_tag,
 	    { "Session Tag",			"ansi_801.sess_tag",
 	    FT_UINT8, BASE_DEC, NULL, 0,
-	    "", HFILL }
+	    NULL, HFILL }
 	},
     };
 
