@@ -2,7 +2,7 @@
  * Routines for BACnet (APDU) dissection
  * Copyright 2004, Herbert Lischka <lischka@kieback-peter.de>, Berlin
  *
- * $Id: packet-bacapp.h 22262 2007-07-06 22:36:58Z jake $
+ * $Id: packet-bacapp.h 25758 2008-07-17 13:53:26Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,9 +30,6 @@
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
-#if HAVE_ICONV
-#include <iconv.h>
-#endif
 #endif
 
 #include <stdio.h>
@@ -1846,7 +1843,7 @@ fVTSession (tvbuff_t *tvb, proto_tree *tree, guint offset);
  * -- 4 = days numbered 22-28
  * -- 5 = days numbered 29-31
  * -- 6 = last 7 days of this month
- * -- XFF = any week of this month
+ * -- X'FF' = any week of this month
  * -- third octet dayOfWeek (1..7) where 1 = Monday
  * -- 7 = Sunday
  * -- X'FF' = any day of week
@@ -1964,6 +1961,20 @@ fTimeSpan (tvbuff_t *tvb, proto_tree *tree, guint offset, const gchar *label);
 static guint
 fPropertyIdentifier (tvbuff_t *tvb, proto_tree *tree, guint offset);
 
+/**
+ * BACnet Application PDUs chapter 21
+ * BACnetPropertyArrayIndex::= ENUMERATED {
+ * 	 @see bacapp_property_array_index
+ * }
+ * @param tvb
+ * @param tree
+ * @param offset
+ * @param tt returnvalue of this item
+ * @return modified offset
+ */
+static guint
+fPropertyArrayIndex (tvbuff_t *tvb, proto_tree *tree, guint offset);
+
 /**
  * listOfEventSummaries ::= SEQUENCE OF SEQUENCE {
  * 	objectIdentifier	[0] BACnetObjectIdentifier,
@@ -2060,7 +2071,7 @@ void
 proto_reg_handoff_bacapp(void);
 
 /**
- * converts XXX coded strings to UTF-8 if iconv is allowed
+ * converts XXX coded strings to UTF-8
  * else 'in' is copied to 'out'
  * @param in  -- pointer to string
  * @param inbytesleft
@@ -2070,7 +2081,7 @@ proto_reg_handoff_bacapp(void);
  * @return count of modified characters of returned string, -1 for errors
  */
 guint32
-fConvertXXXtoUTF8(const guint8 *in, size_t *inbytesleft,guint8 *out, size_t *outbytesleft, const gchar *fromcoding);
+fConvertXXXtoUTF8(gchar *in, size_t *inbytesleft, gchar *out, size_t *outbytesleft, const gchar *fromcoding);
 
 #endif /* __BACAPP_H__ */
 
