@@ -5,7 +5,7 @@
  * Copyright 2006, Balint Reczey <Balint.Reczey@ericsson.com>
  * Copyright 2007, Todd J Martin <todd.martin@acm.org>
  *
- * $Id: packet-bfd.c 24286 2008-02-07 15:44:45Z stig $
+ * $Id: packet-bfd.c 27890 2009-03-29 22:16:26Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -239,7 +239,7 @@ static gint ett_bfd_auth = -1;
 /* Given the type of authentication being used, return the required length of
  * the authentication header
  */
-guint8 get_bfd_required_auth_len(guint8 auth_type) 
+static guint8 get_bfd_required_auth_len(guint8 auth_type) 
 {
     guint8 auth_len = 0;
     switch (auth_type) {
@@ -260,7 +260,7 @@ guint8 get_bfd_required_auth_len(guint8 auth_type)
 /* Given the type of authentication being used, return the length of
  * checksum field
  */
-guint8 get_bfd_checksum_len(guint8 auth_type) 
+static guint8 get_bfd_checksum_len(guint8 auth_type) 
 {
     guint8 checksum_len = 0;
     switch (auth_type) {
