@@ -2,7 +2,7 @@
  * Routines for decoding MDS Port Analyzer Adapter (FC in Eth) Header
  * Copyright 2001, Dinesh G Dutt <ddutt@andiamo.com>
  *
- * $Id: packet-brdwlk.c 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-brdwlk.c 28317 2009-05-08 20:35:57Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -222,7 +222,7 @@ dissect_brdwlk (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 
 /* Set up structures needed to add the protocol subtree and manage it */
-    proto_item *ti;
+    proto_item *ti, *hidden_item;
     proto_tree *brdwlk_tree = NULL;
     tvbuff_t *next_tvb;
     guint8 error, eof, sof;
@@ -334,8 +334,9 @@ dissect_brdwlk (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             }
 
             if (tree) {
-                proto_tree_add_boolean_hidden (brdwlk_tree, hf_brdwlk_drop,
+                hidden_item = proto_tree_add_boolean (brdwlk_tree, hf_brdwlk_drop,
                                                tvb, offset, 0, dropped_packets);
+                PROTO_ITEM_SET_HIDDEN(hidden_item);
             }
         }
         packet_count = pkt_cnt;
@@ -415,7 +416,7 @@ proto_register_brdwlk (void)
           {"Packet Count", "brdwlk.pktcnt", FT_UINT16, BASE_DEC, NULL, 0x0,
            "", HFILL}},
         { &hf_brdwlk_drop,
-          {"Packet Dropped", "brdwlk.drop", FT_BOOLEAN, BASE_DEC, NULL, 0x0,
+          {"Packet Dropped", "brdwlk.drop", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
            "", HFILL}},
         { &hf_brdwlk_vsan,
           {"VSAN", "brdwlk.vsan", FT_UINT16, BASE_DEC, NULL, 0xFFF, "",
