@@ -2,7 +2,7 @@
  * Routines for BACnet/IP (BVLL, BVLC) dissection
  * Copyright 2001, Hartmut Mueller <hartmut@abmlinux.org>, FH Dortmund
  *
- * $Id: packet-bvlc.c 24286 2008-02-07 15:44:45Z stig $
+ * $Id: packet-bvlc.c 26914 2008-12-04 20:10:16Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -48,7 +48,7 @@
  * configured locally to a different value without it being considered
  * a violation of this protocol.
  */
-static guint additional_bvlc_udp_port = 0;
+static guint global_additional_bvlc_udp_port = 0;
 
 static int proto_bvlc = -1;
 static int hf_bvlc_type = -1;
@@ -203,7 +203,7 @@ dissect_bvlc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		 	* packet to dissect, see README.developer, 1.6.2, FID */
 			proto_tree_add_uint_format_value(bvlc_tree, hf_bvlc_result, tvb,
 				offset, 2, bvlc_result,"0x%04x (%s)",
-				bvlc_result, val_to_str(bvlc_result << 4,
+				bvlc_result, val_to_str(bvlc_result,
 					bvlc_result_names, "Unknown"));
 			offset += 2;
 			break;
@@ -342,7 +342,7 @@ proto_register_bvlc(void)
 		 * packet to dissect */
 		{ &hf_bvlc_result,
 			{ "Result",           "bvlc.result",
-			FT_UINT16, BASE_HEX, NULL, 0xffff,
+			FT_UINT16, BASE_HEX, NULL, 0,
 			"Result Code", HFILL }
 		},
 		{ &hf_bvlc_bdt_ip,
@@ -415,7 +415,7 @@ proto_register_bvlc(void)
 	prefs_register_uint_preference(bvlc_module, "additional_udp_port",
 					"Additional UDP port", "Set an additional UDP port, "
 					"besides the standard X'BAC0' (47808) port.",
-					10, &additional_bvlc_udp_port);
+					10, &global_additional_bvlc_udp_port);
 
 	new_register_dissector("bvlc", dissect_bvlc, proto_bvlc);
 
@@ -426,23 +426,26 @@ proto_register_bvlc(void)
 void
 proto_reg_handoff_bvlc(void)
 {
-	static int bvlc_initialized = FALSE;
+	static gboolean bvlc_initialized = FALSE;
 	static dissector_handle_t bvlc_handle;
-	static guint bvlc_udp_port;
+	static guint additional_bvlc_udp_port;
 	
 	if (!bvlc_initialized)
 	{
 		bvlc_handle = find_dissector("bvlc");
 		dissector_add("udp.port", 0xBAC0, bvlc_handle);
+		data_handle = find_dissector("data");
 		bvlc_initialized = TRUE;
 	}
 	else
 	{
-		dissector_delete("udp.port", bvlc_udp_port, bvlc_handle);
+		if (additional_bvlc_udp_port != 0) {
+			dissector_delete("udp.port", additional_bvlc_udp_port, bvlc_handle);
+		}
 	}
 
-	bvlc_udp_port = additional_bvlc_udp_port;
-	dissector_add("udp.port", bvlc_udp_port, bvlc_handle);
-
-	data_handle = find_dissector("data");
+	if (global_additional_bvlc_udp_port != 0) {
+		dissector_add("udp.port", global_additional_bvlc_udp_port, bvlc_handle);
+	}
+	additional_bvlc_udp_port = global_additional_bvlc_udp_port;
 }
