@@ -2,7 +2,7 @@
  * Routines for the disassembly of the "Cisco Discovery Protocol"
  * (c) Copyright Hannes R. Boehm <hannes@boehm.org>
  *
- * $Id: packet-cdp.c 27698 2009-03-11 07:54:40Z jake $
+ * $Id: packet-cdp.c 28091 2009-04-20 05:49:26Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -879,7 +879,7 @@ dissect_cdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	/* Move offset to where the list of Power Available Values Exist */
 	offset += 8;
 	while(power_avail_len) {
-	  if (power_avail_len > 4) {
+	  if (power_avail_len >= 4) {
 	    power_avail = tvb_get_ntohl(tvb, offset);
 	    if (tree) {
 	      proto_tree_add_text(tlv_tree, tvb, offset,
@@ -889,14 +889,6 @@ dissect_cdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	    power_avail_len -= 4;
 	    offset += 4;
 	  } else {
-	    if (power_avail_len == 4) {
-	      power_avail = tvb_get_ntohl(tvb, offset);
-	      if (tree) {
-		proto_tree_add_text(tlv_tree, tvb, offset,
-				    4, "Power Available: %u mW", power_avail);
-		proto_item_append_text(tlvi, "%u mW", power_avail);
-	      }
-	    }
 	    offset += power_avail_len;
 	    break;
 	  }
@@ -1237,7 +1229,7 @@ add_multi_line_string_to_tree(proto_tree *tree, tvbuff_t *tvb, gint start,
     int line_len;
     int data_len;
 
-    prefix_len = strlen(prefix);
+    prefix_len = (int)strlen(prefix);
     if (prefix_len > 64)
 	prefix_len = 64;
     for (i = 0; i < prefix_len; i++)
