@@ -2,7 +2,7 @@
  * Routines for CFM EOAM (IEEE 802.1ag) dissection
  * Copyright 2007, Keith Mercer <keith.mercer@alcatel-lucent.com>
  *
- * $Id: packet-cfm.c 23631 2007-11-28 00:08:20Z gerald $
+ * $Id: packet-cfm.c 27050 2008-12-18 19:08:49Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -35,7 +35,6 @@
 #endif
 
 #include <epan/packet.h>
-#include <epan/prefs.h>
 #include <stdio.h>
 #include <glib.h>
 #include <string.h>
@@ -46,11 +45,9 @@
 static void dissect_cfm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
 
 static int proto_cfm = -1;
-static dissector_handle_t cfm_handle;
-
 
 static const value_string opcodetypenames[] = {
-	{ IEE8021, 	"Reserved for IEE 802.1" },
+	{ IEEE8021, 	"Reserved for IEEE 802.1" },
 	{ CCM, 		"Continuity Check Message (CCM)" },
 	{ LBR, 		"Loopback Reply (LBR)" },
 	{ LBM, 		"Loopback Message (LBM)" },
@@ -77,7 +74,7 @@ static const value_string CCM_IntervalFieldEncoding[] = {
 	{ 1, "Trans Int 3.33ms, max Lifetime 11.66ms, min Lifetime 10.83ms" },
 	{ 2, "Trans Int 10ms, max Lifetime 35ms, min Lifetime 32.5ms" },
 	{ 3, "Trans Int 100ms, max Lifetime 350ms, min Lifetime 325ms" },
-	{ 4, "Trans Int 1ms, max Lifetime 3.5s, min Lifetime 3.25s" },
+	{ 4, "Trans Int 1s, max Lifetime 3.5s, min Lifetime 3.25s" },
 	{ 5, "Trans Int 10s, max Lifetime 35s, min Lifetime 32.5s" },
 	{ 6, "Trans Int 1min, max Lifetime 3.5min, min Lifetime 3.25min" },
 	{ 7, "Trans Int 10min, max Lifetime 35min, min Lifetime 32.5min" },
@@ -441,7 +438,7 @@ void proto_register_cfm(void)
 			BASE_NONE, NULL, 0x0, NULL, HFILL	}
 		},
 		{ &hf_cfm_flags_UseFDBonly,
-			{ "RDI", "cfm.flags.usefdbonly", FT_UINT8,
+			{ "UseFDBonly", "cfm.flags.usefdbonly", FT_UINT8,
 			BASE_DEC, NULL, 0x80, NULL, HFILL }
 		},
 		{ &hf_cfm_flags_ltm_Reserved,
@@ -809,11 +806,9 @@ void proto_register_cfm(void)
 /* Register CFM OEAM protocol handler */
 void proto_reg_handoff_cfm(void)
 {
-	static int initialized=FALSE;
-	if (!initialized) {
-		cfm_handle = create_dissector_handle(dissect_cfm, proto_cfm);
-		dissector_add("ethertype", ETHERTYPE_CFM, cfm_handle);
-	}
+	dissector_handle_t cfm_handle;
+	cfm_handle = create_dissector_handle(dissect_cfm, proto_cfm);
+	dissector_add("ethertype", ETHERTYPE_CFM, cfm_handle);
 }
 
 /* CFM EOAM sub-protocol dissectors: CCM, LBM, LBR, LTM, LTR */
