@@ -3,7 +3,7 @@
  * Copyright 2003, Brad Hards <bradh@frogmouth.net>
  * Copyright 2003, Ronnie Sahlberg, added TCP desegmentation.
  *
- * $Id: packet-distcc.c 21253 2007-03-28 21:55:11Z sfisher $
+ * $Id: packet-distcc.c 26124 2008-09-02 21:40:46Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -71,7 +71,7 @@ extern void proto_reg_handoff_distcc(void);
 	if(parameter>tvb_length_remaining(tvb, offset) || parameter < 1){\
 		len=tvb_length_remaining(tvb, offset);\
 		if (check_col(pinfo->cinfo, COL_INFO)) {\
-			col_append_fstr(pinfo->cinfo, COL_INFO, "[Short" x " PDU]");\
+			col_append_str(pinfo->cinfo, COL_INFO, "[Short" x " PDU]");\
 		}\
 	} \
 	tvb_ensure_bytes_exist(tvb, offset, len);
@@ -248,7 +248,7 @@ dissect_distcc_doti(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int off
 	DESEGMENT_TCP("DOTI");
 
 	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_append_fstr(pinfo->cinfo, COL_INFO, "DOTI source ");
+		col_append_str(pinfo->cinfo, COL_INFO, "DOTI source ");
 	}
 
 	proto_tree_add_item(tree, hf_distcc_doti_source, tvb, offset, len, FALSE);
@@ -270,7 +270,7 @@ dissect_distcc_doto(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int off
 	DESEGMENT_TCP("DOTO");
 
 	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_append_fstr(pinfo->cinfo, COL_INFO, "DOTO object ");
+		col_append_str(pinfo->cinfo, COL_INFO, "DOTO object ");
 	}
 
 	proto_tree_add_item(tree, hf_distcc_doto_object, tvb, offset, len, FALSE);
@@ -419,24 +419,23 @@ proto_reg_handoff_distcc(void)
 	static int distcc_tcp_port;
 	static dissector_handle_t distcc_handle;
 
-	if (registered_dissector) {
-		/*
-		 * We've registered the dissector with a TCP port number
-		 * of "distcc_tcp_port"; we might be changing the TCP port
-		 * number, so remove that registration.
-		 */
-		dissector_delete("tcp.port", distcc_tcp_port, distcc_handle);
-	} else {
+	if (!registered_dissector) {
 		/*
 		 * We haven't registered the dissector yet; get a handle
 		 * for it.
 		 */
 		distcc_handle = create_dissector_handle(dissect_distcc,
 		    proto_distcc);
+		data_handle = find_dissector("data");
 		registered_dissector = TRUE;
+	} else {
+		/*
+		 * We've registered the dissector with a TCP port number
+		 * of "distcc_tcp_port"; we might be changing the TCP port
+		 * number, so remove that registration.
+		 */
+		dissector_delete("tcp.port", distcc_tcp_port, distcc_handle);
 	}
 	distcc_tcp_port = glb_distcc_tcp_port;
 	dissector_add("tcp.port", distcc_tcp_port, distcc_handle);
-
-	data_handle = find_dissector("data");
 }
