@@ -2,7 +2,7 @@
  * Routines for DNS packet disassembly
  * Copyright 2004, Nicolas DICHTEL - 6WIND - <nicolas.dichtel@6wind.com>
  *
- * $Id: packet-dns.c 27050 2008-12-18 19:08:49Z wmeier $
+ * $Id: packet-dns.c 29662 2009-09-01 22:36:30Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,6 +28,7 @@
  * RFC 2136 for dynamic DNS
  * http://files.multicastdns.org/draft-cheshire-dnsext-multicastdns.txt
  *  for multicast DNS
+ * RFC 4795 for link-local multicast name resolution (LLMNR)
  */
 
 #ifdef HAVE_CONFIG_H
@@ -55,8 +56,11 @@ static int hf_dns_flags = -1;
 static int hf_dns_flags_response = -1;
 static int hf_dns_flags_opcode = -1;
 static int hf_dns_flags_authoritative = -1;
+static int hf_dns_flags_conflict_query = -1;
+static int hf_dns_flags_conflict_response = -1;
 static int hf_dns_flags_truncated = -1;
 static int hf_dns_flags_recdesired = -1;
+static int hf_dns_flags_tentative = -1;
 static int hf_dns_flags_recavail = -1;
 static int hf_dns_flags_z = -1;
 static int hf_dns_flags_authenticated = -1;
@@ -141,6 +145,7 @@ typedef struct _dns_conv_info_t {
 #define TCP_PORT_DNS     53
 #define UDP_PORT_MDNS    5353
 #define TCP_PORT_MDNS    5353
+#define UDP_PORT_LLMNR   5355
 
 /* Offsets of fields in the DNS header. */
 #define	DNS_ID		0
@@ -222,10 +227,12 @@ typedef struct _dns_conv_info_t {
 #define F_OPCODE        (0xF<<11)       /* query opcode */
 #define OPCODE_SHIFT	11
 #define F_AUTHORITATIVE (1<<10)         /* response is authoritative */
+#define F_CONFLICT      (1<<10)         /* conflict detected */
 #define F_TRUNCATED     (1<<9)          /* response is truncated */
 #define F_RECDESIRED    (1<<8)          /* recursion desired */
+#define F_TENTATIVE     (1<<8)          /* response is tentative */
 #define F_RECAVAIL      (1<<7)          /* recursion available */
-#define F_Z		(1<<6)		/* Z */
+#define F_Z             (1<<6)          /* Z */
 #define F_AUTHENTIC     (1<<5)          /* authentic data (RFC2535) */
 #define F_CHECKDISABLE  (1<<4)          /* checking disabled (RFC2535) */
 #define F_RCODE         (0xF<<0)        /* reply code */
@@ -240,6 +247,16 @@ static const true_false_string tfs_flags_authoritative = {
 	"Server is not an authority for domain"
 };
 
+static const true_false_string tfs_flags_conflict_query = {
+	"The sender received multiple responses",
+	"None"
+};
+
+static const true_false_string tfs_flags_conflict_response = {
+	"The name is not considered unique",
+	"The name is considered unique"
+};
+
 static const true_false_string tfs_flags_truncated = {
 	"Message is truncated",
 	"Message is not truncated"
@@ -250,6 +267,11 @@ static const true_false_string tfs_flags_recdesired = {
 	"Don't do query recursively"
 };
 
+static const true_false_string tfs_flags_tentative = {
+	"Tentative",
+	"Not tentative"
+};
+
 static const true_false_string tfs_flags_recavail = {
 	"Server can do recursive queries",
 	"Server can't do recursive queries"
@@ -500,7 +522,7 @@ dns_type_description (guint type)
     "DNS public key",                   /* future RFC 2535bis */
     NULL,
     "Next secured hash",                /* RFC 5155 */
-    "NSEC3 parameters"                  /* RFC 5155 */       
+    "NSEC3 parameters"                  /* RFC 5155 */
   };
   const char *short_name;
   const char *long_name;
@@ -578,10 +600,10 @@ dns_class_name(int class)
  */
 int
 get_dns_name(tvbuff_t *tvb, int offset, int max_len, int dns_data_offset,
-    const char **name)
+    const guchar **name)
 {
   int start_offset = offset;
-  char *np;
+  guchar *np;
   int len = -1;
   int chars_processed = 0;
   int data_size = tvb_reported_length_remaining(tvb, dns_data_offset);
@@ -750,7 +772,7 @@ get_dns_name(tvbuff_t *tvb, int offset, int max_len, int dns_data_offset,
 
 static int
 get_dns_name_type_class(tvbuff_t *tvb, int offset, int dns_data_offset,
-    const char **name_ret, int *name_len_ret, int *type_ret, int *class_ret)
+    const guchar **name_ret, int *name_len_ret, int *type_ret, int *class_ret)
 {
   int len;
   int name_len;
@@ -827,8 +849,8 @@ dissect_dns_query(tvbuff_t *tvb, int offset, int dns_data_offset,
   column_info *cinfo, proto_tree *dns_tree, gboolean is_mdns)
 {
   int len;
-  const char *name;
-  char *name_out;
+  const guchar *name;
+  gchar *name_out;
   int name_len;
   int type;
   int class;
@@ -883,7 +905,7 @@ dissect_dns_query(tvbuff_t *tvb, int offset, int dns_data_offset,
       proto_tree_add_boolean(q_tree, hf_dns_qry_qu, tvb, offset, 2, qu);
     } else
       proto_tree_add_uint(q_tree, hf_dns_qry_class, tvb, offset, 2, class);
-    
+
     offset += 2;
   }
 
@@ -893,7 +915,7 @@ dissect_dns_query(tvbuff_t *tvb, int offset, int dns_data_offset,
 
 static proto_tree *
 add_rr_to_tree(proto_item *trr, int rr_type, tvbuff_t *tvb, int offset,
-  const char *name, int namelen, int type, int class, int flush,
+  const guchar *name, int namelen, int type, int class, int flush,
   guint ttl, gushort data_len, gboolean is_mdns)
 {
   proto_tree *rr_tree;
@@ -962,7 +984,7 @@ add_opt_rr_to_tree(proto_item *trr, int rr_type, tvbuff_t *tvb, int offset,
 
 static int
 dissect_type_bitmap(proto_tree *rr_tree, tvbuff_t *tvb, int cur_offset, int rr_len)
-{   
+{
   int mask, blockbase, blocksize;
   int i, initial_offset, rr_type;
   guint8 bits;
@@ -974,7 +996,7 @@ dissect_type_bitmap(proto_tree *rr_tree, tvbuff_t *tvb, int cur_offset, int rr_l
     cur_offset += 2;
     rr_len -= 2;
     rr_type = blockbase * 256;
-    for( ; blocksize; blocksize-- ) {	    
+    for( ; blocksize; blocksize-- ) {
       bits = tvb_get_guint8(tvb, cur_offset);
       mask = 1<<7;
       for (i = 0; i < 8; i++) {
@@ -1042,13 +1064,13 @@ static const value_string cert_vals[] = {
  *   Compute the key id of a KEY RR depending of the algorithm used.
  */
 static guint16
-compute_key_id(tvbuff_t *tvb, int offset, int size, guint8 algo) 
+compute_key_id(tvbuff_t *tvb, int offset, int size, guint8 algo)
 {
   guint32 ac;
   guint8 c1, c2;
 
   DISSECTOR_ASSERT(size >= 4);
-  
+
   switch( algo ) {
      case DNS_ALGO_RSAMD5:
        return (guint16)(tvb_get_guint8(tvb, offset + size - 3) << 8) + tvb_get_guint8( tvb, offset + size - 2 );
@@ -1074,8 +1096,8 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
   gboolean is_mdns)
 {
   int len;
-  const char *name;
-  char *name_out;
+  const guchar *name;
+  gchar *name_out;
   int name_len;
   int type;
   int class;
@@ -1171,7 +1193,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
 
   case T_NS:
     {
-      const char *ns_name;
+      const guchar *ns_name;
       int ns_name_len;
 
       /* XXX Fix data length */
@@ -1189,7 +1211,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
 
   case T_CNAME:
     {
-      const char *cname;
+      const guchar *cname;
       int cname_len;
 
       /* XXX Fix data length */
@@ -1207,9 +1229,9 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
 
   case T_SOA:
     {
-      const char *mname;
+      const guchar *mname;
       int mname_len;
-      const char *rname;
+      const guchar *rname;
       int rname_len;
       guint32 serial;
       guint32 refresh;
@@ -1264,7 +1286,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
 
   case T_PTR:
     {
-      const char *pname;
+      const guchar *pname;
       int pname_len;
 
       /* XXX Fix data length */
@@ -1289,12 +1311,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
       int mask;
       int port_num;
       int i;
-      char *bitnames, *strptr;
-
-#define MAX_STR_LEN 128
-      bitnames=ep_alloc(MAX_STR_LEN);
-      bitnames[0]=0;
-      strptr=bitnames;
+      emem_strbuf_t *bitnames = ep_strbuf_new_label(NULL);
 
       if (rr_len < 4) {
 	if (dns_tree != NULL)
@@ -1324,28 +1341,24 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
 	  bits = tvb_get_guint8(tvb, cur_offset);
 	  if (bits != 0) {
 	    mask = 1<<7;
-            bitnames[0]=0;
-            strptr=bitnames;
+            ep_strbuf_truncate(bitnames, 0);
 	    for (i = 0; i < 8; i++) {
 	      if (bits & mask) {
-		if (strptr!=bitnames)
-		  strptr += MIN(MAX_STR_LEN-(strptr-bitnames),
-				g_snprintf(strptr, MAX_STR_LEN-(strptr-bitnames), ", "));
+		if (bitnames->len > 0) {
+		  ep_strbuf_append(bitnames, ", ");
+		}
 		switch (protocol) {
 
 		case IP_PROTO_TCP:
-		  strptr += MIN(MAX_STR_LEN-(strptr-bitnames),
-				g_snprintf(strptr, MAX_STR_LEN-(strptr-bitnames), "%s", get_tcp_port(port_num)));
+		  ep_strbuf_append(bitnames, get_tcp_port(port_num));
 		  break;
 
 		case IP_PROTO_UDP:
-		  strptr += MIN(MAX_STR_LEN-(strptr-bitnames),
-				g_snprintf(strptr, MAX_STR_LEN-(strptr-bitnames), "%s", get_udp_port(port_num)));
+		  ep_strbuf_append(bitnames, get_udp_port(port_num));
 		  break;
 
 		default:
-		  strptr += MIN(MAX_STR_LEN-(strptr-bitnames),
-				g_snprintf(strptr, MAX_STR_LEN-(strptr-bitnames), "%u", port_num));
+		  ep_strbuf_append_printf(bitnames, "%u", port_num);
 		  break;
 	        }
 	      }
@@ -1353,7 +1366,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
 	      port_num++;
 	    }
 	    proto_tree_add_text(rr_tree, tvb, cur_offset, 1,
-		"Bits: 0x%02x (%s)", bits, bitnames);
+		"Bits: 0x%02x (%s)", bits, bitnames->str);
 	  } else
 	    port_num += 8;
 	  cur_offset += 1;
@@ -1395,7 +1408,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
   case T_MX:
     {
       guint16 preference = 0;
-      const char *mx_name;
+      const guchar *mx_name;
       int mx_name_len;
 
       preference = tvb_get_ntohs(tvb, cur_offset);
@@ -1439,7 +1452,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
       int rr_len = data_len;
       guint16 type_covered;
       nstime_t nstime;
-      const char *signer_name;
+      const guchar *signer_name;
       int signer_name_len;
 
       if (dns_tree != NULL) {
@@ -1512,7 +1525,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
     }
     break;
 
-  case T_DNSKEY:  
+  case T_DNSKEY:
     {
       int rr_len = data_len;
       guint16 flags;
@@ -1532,14 +1545,14 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
 		  2*8, "This is the zone key for the specified zone",
 		       "This is not a zone key"));
 	proto_tree_add_text(flags_tree, tvb, cur_offset, 2, "%s",
-		decode_boolean_bitfield(flags, 0x0080, 
+		decode_boolean_bitfield(flags, 0x0080,
 		  2*8, "Key is revoked",
 		       "Key is not revoked"));
 	proto_tree_add_text(flags_tree, tvb, cur_offset, 2, "%s",
-		decode_boolean_bitfield(flags, 0x0001, 
+		decode_boolean_bitfield(flags, 0x0001,
 		  2*8, "Key is a Key Signing Key",
 		       "Key is a Zone Signing Key"));
-	
+
 	cur_offset += 2;
 	rr_len -= 2;
 
@@ -1647,17 +1660,17 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
       int rr_len = data_len;
       guint8 gw_type, algo;
       const guint8 *addr;
-      const char *gw;
+      const guchar *gw;
       int gw_name_len;
       static const value_string gw_algo[] = {
 	  { 1,     "DSA" },
 	  { 2,     "RSA" },
 	  { 0,      NULL }
       };
-      
+
 
       if( dns_tree != NULL ) {
-	if(rr_len < 3) 
+	if(rr_len < 3)
 	  goto bad_rr;
 
 	proto_tree_add_text(rr_tree, tvb, cur_offset, 1, "Gateway precedence: %u",
@@ -1688,7 +1701,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
 	     break;
 	   case 2:
 	     addr = tvb_get_ptr(tvb, cur_offset, 16);
-	     proto_tree_add_text(rr_tree, tvb, cur_offset, 16, "Gateway: %s", 
+	     proto_tree_add_text(rr_tree, tvb, cur_offset, 16, "Gateway: %s",
 				 ip6_to_str((const struct e_in6_addr *)addr));
 
 	     cur_offset += 16;
@@ -1701,14 +1714,14 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
 				 "Gateway: %s", format_text(gw, strlen(gw)));
 
 	     cur_offset += gw_name_len;
-	     rr_len -= gw_name_len;	     
+	     rr_len -= gw_name_len;
 	     break;
 	   default:
 	     proto_tree_add_text(rr_tree, tvb, cur_offset, 0, "Gateway: Unknown gateway type(%u)", gw_type);
 	     break;
 	}
 	if (rr_len != 0)
-	  proto_tree_add_text(rr_tree, tvb, cur_offset, rr_len, "Public key");	
+	  proto_tree_add_text(rr_tree, tvb, cur_offset, rr_len, "Public key");
       }
     }
     break;
@@ -1741,7 +1754,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
       unsigned short pre_len;
       unsigned short suf_len;
       unsigned short suf_octet_count;
-      const char *pname;
+      const guchar *pname;
       int pname_len;
       int a6_offset;
       int suf_offset;
@@ -1801,7 +1814,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
 
   case T_DNAME:
     {
-      const char *dname;
+      const guchar *dname;
       int dname_len;
 
       /* XXX Fix data length */
@@ -1860,7 +1873,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
   case T_NSEC:
     {
       int rr_len = data_len;
-      const char *next_domain_name;
+      const guchar *next_domain_name;
       int next_domain_name_len;
 
       /* XXX Fix data length */
@@ -1901,7 +1914,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
         cur_offset += salt_len;
         hash_len = tvb_get_guint8(tvb, cur_offset);
         proto_tree_add_item(rr_tree, hf_dns_nsec3_hash_length, tvb, cur_offset++, 1, FALSE);
-        proto_tree_add_item(rr_tree, hf_dns_nsec3_hash_value, tvb, cur_offset, hash_len, FALSE);   
+        proto_tree_add_item(rr_tree, hf_dns_nsec3_hash_value, tvb, cur_offset, hash_len, FALSE);
         cur_offset += hash_len;
         rr_len = data_len - (cur_offset - initial_offset);
         cur_offset += dissect_type_bitmap(rr_tree, tvb, cur_offset, rr_len);
@@ -1912,7 +1925,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
   case T_NXT:
     {
       int rr_len = data_len;
-      const char *next_domain_name;
+      const guchar *next_domain_name;
       int next_domain_name_len;
       int rr_type;
       guint8 bits;
@@ -1954,7 +1967,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
   case T_KX:
     {
       guint16 preference = 0;
-      const char *kx_name;
+      const guchar *kx_name;
       int kx_name_len;
 
       /* XXX Fix data length */
@@ -2018,7 +2031,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
 
   case T_DS:
     {
-      guint16 keytag, digest_data_size = -1;
+      guint16 keytag, digest_data_size;
       guint8  ds_algorithm, ds_digest;
       int rr_len = data_len;
 
@@ -2050,12 +2063,11 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
 	cur_offset += 1;
 	rr_len -= 1;
 
-	if (ds_digest == TDSDIGEST_SHA1)
+	if (ds_digest == TDSDIGEST_SHA1) {
 	  digest_data_size = 20; /* SHA1 key is always 20 bytes long */
-	if (digest_data_size > 0) {
 	  if (rr_len < digest_data_size)
 	    goto bad_rr;
-	  proto_tree_add_text(rr_tree, tvb, cur_offset, digest_data_size, "Public key"); 
+	  proto_tree_add_text(rr_tree, tvb, cur_offset, digest_data_size, "Public key");
 	}
       }
     }
@@ -2063,7 +2075,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
 
   case T_TKEY:
     {
-      const char *tkey_algname;
+      const guchar *tkey_algname;
       int tkey_algname_len;
       guint16 tkey_mode, tkey_error, tkey_keylen, tkey_otherlen;
       int rr_len = data_len;
@@ -2200,7 +2212,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
     {
       guint16 tsig_error, tsig_timehi, tsig_siglen, tsig_otherlen;
       guint32 tsig_timelo;
-      const char *tsig_raw_algname;
+      const guchar *tsig_raw_algname;
       char *tsig_algname;
       int tsig_algname_len;
       nstime_t nstime;
@@ -2363,7 +2375,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
       guint32 local_flag;
       guint32 lookup_timeout;
       guint32 cache_timeout;
-      const char *dname;
+      const guchar *dname;
       int dname_len;
 
       if (rr_len < 4)
@@ -2414,7 +2426,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
       guint16 priority = 0;
       guint16 weight = 0;
       guint16 port = 0;
-      const char *target;
+      const guchar *target;
       int target_len;
 
       priority = tvb_get_ntohs(tvb, cur_offset);
@@ -2450,8 +2462,8 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
       guint8 service_len;
       guchar *regex;
       guint8 regex_len;
-      guchar *replacement;
-      guint8 replacement_len;
+      const guchar *replacement;
+      int replacement_len;
 
       order = tvb_get_ntohs(tvb, offset);
       offset += 2;
@@ -2469,11 +2481,11 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
       offset++;
       regex = tvb_get_ephemeral_string(tvb, offset, regex_len);
       offset += regex_len;
-      replacement_len = tvb_get_guint8(tvb, offset);
+      replacement_len = get_dns_name(tvb, offset, 0, dns_data_offset, &replacement);
       offset++;
-      replacement = tvb_get_ephemeral_string(tvb, offset, replacement_len);
+      name_out = format_text(replacement, strlen(replacement));
 
-      if (cinfo != NULL) 
+      if (cinfo != NULL)
 	col_append_fstr(cinfo, COL_INFO, " %u %u %s", order, preference, flags);
 
       if (dns_tree != NULL) {
@@ -2498,7 +2510,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offsetx, int dns_data_offset,
 	offset += regex_len;
 	proto_tree_add_text(rr_tree, tvb, offset, 1, "Replacement length: %u", replacement_len);
 	offset++;
-	proto_tree_add_text(rr_tree, tvb, offset, replacement_len, "Replacement: \"%s\"", replacement);
+	proto_tree_add_text(rr_tree, tvb, offset, replacement_len, "Replacement: %s", name_out);
       }
     }
     break;
@@ -2579,7 +2591,7 @@ dissect_answer_records(tvbuff_t *tvb, int cur_off, int dns_data_offset,
 
 static void
 dissect_dns_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
-    gboolean is_tcp, gboolean is_mdns)
+    gboolean is_tcp, gboolean is_mdns, gboolean is_llmnr)
 {
   int offset = is_tcp ? 2 : 0;
   int dns_data_offset;
@@ -2617,7 +2629,7 @@ dissect_dns_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		g_snprintf(buf+bufpos, MAX_BUF_SIZE-bufpos, "%s%s",
 		val_to_str(opcode, opcode_vals, "Unknown operation (%u)"),
 		(flags&F_RESPONSE)?" response":""));
-		
+
     if (flags & F_RESPONSE) {
       if ((flags & F_RCODE) != RCODE_NOERROR) {
 	bufpos+=MIN(MAX_BUF_SIZE-bufpos,
@@ -2640,8 +2652,13 @@ dissect_dns_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     isupdate = FALSE;
 
   if (tree) {
-    ti = proto_tree_add_protocol_format(tree, proto_dns, tvb, 0, -1,
-      "Domain Name System (%s)", (flags & F_RESPONSE) ? "response" : "query");
+    if (is_llmnr) {
+      ti = proto_tree_add_protocol_format(tree, proto_dns, tvb, 0, -1,
+        "Link-local Multicast Name Resolution (%s)", (flags & F_RESPONSE) ? "response" : "query");
+    } else {
+      ti = proto_tree_add_protocol_format(tree, proto_dns, tvb, 0, -1,
+        "Domain Name System (%s)", (flags & F_RESPONSE) ? "response" : "query");
+    }
 
     dns_tree = proto_item_add_subtree(ti, ett_dns);
   }
@@ -2649,13 +2666,13 @@ dissect_dns_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
   /*
    * Do we have a conversation for this connection?
    */
-  conversation = find_conversation(pinfo->fd->num, 
+  conversation = find_conversation(pinfo->fd->num,
 			&pinfo->src, &pinfo->dst,
-			pinfo->ptype, 
+			pinfo->ptype,
 			pinfo->srcport, pinfo->destport, 0);
   if (conversation == NULL) {
     /* We don't yet have a conversation, so create one. */
-    conversation = conversation_new(pinfo->fd->num, 
+    conversation = conversation_new(pinfo->fd->num,
 			&pinfo->src, &pinfo->dst,
 			pinfo->ptype,
 			pinfo->srcport, pinfo->destport, 0);
@@ -2719,7 +2736,7 @@ dissect_dns_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
       it=proto_tree_add_time(dns_tree, hf_dns_time, tvb, 0, 0, &ns);
       PROTO_ITEM_SET_GENERATED(it);
     }
-  }              
+  }
 
   if (is_tcp) {
     /* Put the length indication into the tree. */
@@ -2748,28 +2765,46 @@ dissect_dns_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		tvb, offset + DNS_FLAGS, 2, FALSE);
   proto_tree_add_item(field_tree, hf_dns_flags_opcode,
 		tvb, offset + DNS_FLAGS, 2, FALSE);
-  if (flags & F_RESPONSE) {
-    proto_tree_add_item(field_tree, hf_dns_flags_authoritative,
+  if (is_llmnr) {
+    if (flags & F_RESPONSE) {
+      proto_tree_add_item(field_tree, hf_dns_flags_conflict_response,
 		tvb, offset + DNS_FLAGS, 2, FALSE);
-  }
-  proto_tree_add_item(field_tree, hf_dns_flags_truncated,
+    } else {
+      proto_tree_add_item(field_tree, hf_dns_flags_conflict_query,
 		tvb, offset + DNS_FLAGS, 2, FALSE);
-  proto_tree_add_item(field_tree, hf_dns_flags_recdesired,
+    }
+    proto_tree_add_item(field_tree, hf_dns_flags_truncated,
 		tvb, offset + DNS_FLAGS, 2, FALSE);
-  if (flags & F_RESPONSE) {
-    proto_tree_add_item(field_tree, hf_dns_flags_recavail,
+    proto_tree_add_item(field_tree, hf_dns_flags_tentative,
 		tvb, offset + DNS_FLAGS, 2, FALSE);
-    proto_tree_add_item(field_tree, hf_dns_flags_z,
-		tvb, offset + DNS_FLAGS, 2, FALSE);
-    proto_tree_add_item(field_tree, hf_dns_flags_authenticated,
-		tvb, offset + DNS_FLAGS, 2, FALSE);
-    proto_tree_add_item(field_tree, hf_dns_flags_rcode,
+    if (flags & F_RESPONSE) {
+      proto_tree_add_item(field_tree, hf_dns_flags_rcode,
 		tvb, offset + DNS_FLAGS, 2, FALSE);
+    }
   } else {
-    proto_tree_add_item(field_tree, hf_dns_flags_z,
+    if (flags & F_RESPONSE) {
+      proto_tree_add_item(field_tree, hf_dns_flags_authoritative,
+ 		tvb, offset + DNS_FLAGS, 2, FALSE);
+    }
+    proto_tree_add_item(field_tree, hf_dns_flags_truncated,
 		tvb, offset + DNS_FLAGS, 2, FALSE);
-    proto_tree_add_item(field_tree, hf_dns_flags_checkdisable,
+    proto_tree_add_item(field_tree, hf_dns_flags_recdesired,
 		tvb, offset + DNS_FLAGS, 2, FALSE);
+    if (flags & F_RESPONSE) {
+      proto_tree_add_item(field_tree, hf_dns_flags_recavail,
+		tvb, offset + DNS_FLAGS, 2, FALSE);
+      proto_tree_add_item(field_tree, hf_dns_flags_z,
+		tvb, offset + DNS_FLAGS, 2, FALSE);
+      proto_tree_add_item(field_tree, hf_dns_flags_authenticated,
+		tvb, offset + DNS_FLAGS, 2, FALSE);
+      proto_tree_add_item(field_tree, hf_dns_flags_rcode,
+		tvb, offset + DNS_FLAGS, 2, FALSE);
+    } else {
+      proto_tree_add_item(field_tree, hf_dns_flags_z,
+		tvb, offset + DNS_FLAGS, 2, FALSE);
+      proto_tree_add_item(field_tree, hf_dns_flags_checkdisable,
+		tvb, offset + DNS_FLAGS, 2, FALSE);
+    }
   }
 
   quest = tvb_get_ntohs(tvb, offset + DNS_QUEST);
@@ -2833,7 +2868,7 @@ dissect_dns_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
   if (auth > 0) {
     cur_off += dissect_answer_records(tvb, cur_off, dns_data_offset, auth,
 				      NULL, dns_tree,
-				      (isupdate ? "Updates" : 
+				      (isupdate ? "Updates" :
 				       "Authoritative nameservers"),
 				      pinfo, is_mdns);
   }
@@ -2851,7 +2886,7 @@ dissect_dns_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   if (check_col(pinfo->cinfo, COL_PROTOCOL))
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "DNS");
 
-  dissect_dns_common(tvb, pinfo, tree, FALSE, FALSE);
+  dissect_dns_common(tvb, pinfo, tree, FALSE, FALSE, FALSE);
 }
 
 static void
@@ -2860,9 +2895,17 @@ dissect_mdns_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   if (check_col(pinfo->cinfo, COL_PROTOCOL))
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "MDNS");
 
-  dissect_dns_common(tvb, pinfo, tree, FALSE, TRUE);
+  dissect_dns_common(tvb, pinfo, tree, FALSE, TRUE, FALSE);
 }
 
+static void
+dissect_llmnr_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+{
+  if (check_col(pinfo->cinfo, COL_PROTOCOL))
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "LLMNR");
+
+  dissect_dns_common(tvb, pinfo, tree, FALSE, FALSE, TRUE);
+}
 
 static guint
 get_dns_pdu_len(packet_info *pinfo _U_, tvbuff_t *tvb, int offset)
@@ -2886,7 +2929,7 @@ dissect_dns_tcp_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   if (check_col(pinfo->cinfo, COL_PROTOCOL))
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "DNS");
 
-  dissect_dns_common(tvb, pinfo, tree, TRUE, FALSE);
+  dissect_dns_common(tvb, pinfo, tree, TRUE, FALSE, FALSE);
 }
 
 static void
@@ -2920,6 +2963,14 @@ proto_register_dns(void)
       { "Authoritative",	"dns.flags.authoritative",
 	FT_BOOLEAN, 16, TFS(&tfs_flags_authoritative), F_AUTHORITATIVE,
 	"Is the server is an authority for the domain?", HFILL }},
+    { &hf_dns_flags_conflict_query,
+      { "Conflict",	"dns.flags.conflict",
+	FT_BOOLEAN, 16, TFS(&tfs_flags_conflict_query), F_CONFLICT,
+	"Did we receive multiple responses to a query?", HFILL }},
+    { &hf_dns_flags_conflict_response,
+      { "Conflict",	"dns.flags.conflict",
+	FT_BOOLEAN, 16, TFS(&tfs_flags_conflict_response), F_CONFLICT,
+	"Is the name considered unique?", HFILL }},
     { &hf_dns_flags_truncated,
       { "Truncated",	"dns.flags.truncated",
 	FT_BOOLEAN, 16, TFS(&tfs_flags_truncated), F_TRUNCATED,
@@ -2928,6 +2979,10 @@ proto_register_dns(void)
       { "Recursion desired",	"dns.flags.recdesired",
 	FT_BOOLEAN, 16, TFS(&tfs_flags_recdesired), F_RECDESIRED,
 	"Do query recursively?", HFILL }},
+    { &hf_dns_flags_tentative,
+      { "Tentative",	"dns.flags.tentative",
+	FT_BOOLEAN, 16, TFS(&tfs_flags_tentative), F_TENTATIVE,
+	"Is the responder authoritative for the name, but not yet verified the uniqueness?", HFILL }},
     { &hf_dns_flags_recavail,
       { "Recursion available",	"dns.flags.recavail",
 	FT_BOOLEAN, 16, TFS(&tfs_flags_recavail), F_RECAVAIL,
@@ -2991,7 +3046,7 @@ proto_register_dns(void)
     { &hf_dns_rr_name,
       { "Name",      	"dns.resp.name",
 	FT_STRING, BASE_NONE, NULL, 0x0,
-	"Response Name", HFILL }},  
+	"Response Name", HFILL }},
     { &hf_dns_rr_ttl,
       { "Time to live", "dns.resp.ttl",
 	FT_UINT32, BASE_DEC, NULL, 0x0,
@@ -3139,15 +3194,18 @@ proto_reg_handoff_dns(void)
   dissector_handle_t dns_udp_handle;
   dissector_handle_t dns_tcp_handle;
   dissector_handle_t mdns_udp_handle;
+  dissector_handle_t llmnr_udp_handle;
 
   dns_udp_handle = create_dissector_handle(dissect_dns_udp, proto_dns);
   dns_tcp_handle = create_dissector_handle(dissect_dns_tcp, proto_dns);
   mdns_udp_handle = create_dissector_handle(dissect_mdns_udp, proto_dns);
+  llmnr_udp_handle = create_dissector_handle(dissect_llmnr_udp, proto_dns);
 
   dissector_add("udp.port", UDP_PORT_DNS, dns_udp_handle);
   dissector_add("tcp.port", TCP_PORT_DNS, dns_tcp_handle);
   dissector_add("udp.port", UDP_PORT_MDNS, mdns_udp_handle);
   dissector_add("tcp.port", TCP_PORT_MDNS, dns_tcp_handle);
+  dissector_add("udp.port", UDP_PORT_LLMNR, llmnr_udp_handle);
 
   gssapi_handle = find_dissector("gssapi");
   ntlmssp_handle = find_dissector("ntlmssp");
