@@ -2,7 +2,7 @@
  * This is a dissector for the DirectPlay protocol.
  * Copyright 2006 - 2008 by Kai Blin
  *
- * $Id: packet-dplay.c 24535 2008-03-03 19:57:09Z etxrab $
+ * $Id: packet-dplay.c 27826 2009-03-23 12:44:50Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,23 +30,21 @@
 #endif
 
 #include <epan/packet.h>
-#include <epan/prefs.h>
 #include <epan/emem.h>
+#include <epan/aftypes.h>
 #include <string.h>
 
 /* function declarations */
-void proto_reg_handoff_dplay(void);
 static gboolean heur_dissect_dplay(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
 static void dissect_dplay(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
 static gint dissect_type1a_message(proto_tree *tree, tvbuff_t *tvb, gint offset);
 
 static int proto_dplay = -1;
-static dissector_handle_t dplay_handle;
 
 /* Common data fields */
 static int hf_dplay_size = -1;              /* Size of the whole data */
 static int hf_dplay_token = -1;
-static int hf_dplay_saddr_af = -1;          /* AF_INET, as this dissector does not handle IPX yet */
+static int hf_dplay_saddr_af = -1;          /* WINSOCK_AF_INET, as this dissector does not handle IPX yet */
 static int hf_dplay_saddr_port = -1;        /* port to use for the reply to this packet */
 static int hf_dplay_saddr_ip = -1;          /* IP to use for the reply to this packet, or 0.0.0.0,
                                                then use the same IP as this packet used. */
@@ -355,8 +353,8 @@ static const value_string dplay_command_val[] = {
 };
 
 static const value_string dplay_af_val[] = {
-    { 0x0002, "AF_INET" },
-    { 0x0006, "AF_IPX" },
+    { WINSOCK_AF_INET, "AF_INET" },
+    { WINSOCK_AF_IPX, "AF_IPX" },
     { 0     , NULL},
 };
 
@@ -1013,7 +1011,7 @@ static gint dissect_type2f_message(proto_tree *tree, tvbuff_t *tvb, gint offset)
 static void dissect_dplay(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
     guint16 message_type;
-    guint16 second_message_type = -1;
+    guint16 second_message_type = G_MAXUINT16;
     guint16 proto_version;
     guint16 packet_size;
     guint32 dplay_id;
@@ -1197,14 +1195,22 @@ static gboolean heur_dissect_dplay(tvbuff_t *tvb, packet_info *pinfo, proto_tree
     token = tvb_get_letohl(tvb, 0);
     token = (token & 0xfff00000) >> 20;
     if (token == 0xfab || token == 0xbab || token == 0xcab) {
+      /* Check the s_addr_in structure */
+      if (tvb_get_letohs(tvb, 4) == WINSOCK_AF_INET) {
+        int offset;
+        for (offset = 12; offset <= 20; offset++)
+          if (tvb_get_guint8(tvb, offset) != 0)
+            return FALSE;
+
         dissect_dplay_player_msg(tvb, pinfo, tree);
         return TRUE;
+      }
     }
 
     return FALSE;
 }
 
-void proto_register_dplay()
+void proto_register_dplay(void)
 {
     static hf_register_info hf [] = {
     /* Common data fields */
@@ -1750,31 +1756,19 @@ void proto_register_dplay()
         &ett_dplay_type05_flags,
         &ett_dplay_type29_spp,
     };
-    module_t *dplay_module;
 
-    if(proto_dplay == -1)
-    {
-        proto_dplay = proto_register_protocol (
-                "DirectPlay Protocol",
-                "DPLAY",
-                "dplay"
-                );
-        proto_register_field_array(proto_dplay, hf, array_length(hf));
-        proto_register_subtree_array(ett, array_length(ett));
-        dplay_module = prefs_register_protocol(proto_dplay, proto_reg_handoff_dplay);
-    }
+    proto_dplay = proto_register_protocol (
+        "DirectPlay Protocol",
+        "DPLAY",
+        "dplay"
+        );
+    proto_register_field_array(proto_dplay, hf, array_length(hf));
+    proto_register_subtree_array(ett, array_length(ett));
 }
 
 void proto_reg_handoff_dplay(void)
 {
-    static int initialized = FALSE;
-
-    if(!initialized)
-    {
-        initialized = TRUE;
-        heur_dissector_add("udp", heur_dissect_dplay, proto_dplay);
-        heur_dissector_add("tcp", heur_dissect_dplay, proto_dplay);
-        dplay_handle = create_dissector_handle(dissect_dplay, proto_dplay);
-    }
+    heur_dissector_add("udp", heur_dissect_dplay, proto_dplay);
+    heur_dissector_add("tcp", heur_dissect_dplay, proto_dplay);
 }
 
