@@ -1,7 +1,7 @@
 /* packet-dua.c
  * Routines for DPNSS/DASS2-User Adaptation Layer dissection
  *
- * It is hopefully (needs testing) compilant to
+ * It is hopefully (needs testing) compliant to
  *   http://www.ietf.org/internet-drafts/draft-ietf-sigtran-dua-08.txt
  *   http://www.ietf.org/internet-drafts/draft-ietf-sigtran-rfc3057bis-02.txt
  *
@@ -9,7 +9,7 @@
  *
  * Copyright 2005, Michael Tuexen <tuexen [AT] fh-muenster.de>
  *
- * $Id: packet-dua.c 22543 2007-08-17 21:31:22Z etxrab $
+ * $Id: packet-dua.c 27050 2008-12-18 19:08:49Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -37,7 +37,6 @@
 #endif
 
 #include <epan/packet.h>
-#include <epan/prefs.h>
 #include <epan/sctpppids.h>
 
 #define NETWORK_BYTE_ORDER          FALSE
@@ -236,7 +235,7 @@ dissect_traffic_mode_type_parameter(tvbuff_t *parameter_tvb, proto_tree *paramet
 static const value_string error_code_values[] = {
   { INVALID_VERSION_ERROR,                       "Invalid version" },
   { INVALID_INTERFACE_IDENTIFIER_ERROR,          "Invalid interface identifier" },
-  { UNSUPPORTED_MESSAGE_CLASS_ERROR,             "Unsuported message class" },
+  { UNSUPPORTED_MESSAGE_CLASS_ERROR,             "Unsupported message class" },
   { UNSUPPORTED_MESSAGE_TYPE_ERROR,              "Unsupported message type" },
   { UNSUPPORTED_TRAFFIC_HANDLING_MODE_ERROR,     "Unsupported traffic handling mode" },
   { UNEXPECTED_MESSAGE_ERROR,                    "Unexpected message" },
@@ -324,7 +323,7 @@ dissect_protocol_data_parameter(tvbuff_t *parameter_tvb, proto_item *parameter_i
   }
 
   call_dissector(data_handle, protocol_data_tvb, pinfo, tree);
-  
+
   proto_item_append_text(parameter_item, " (%u byte%s)", protocol_data_length, plurality(protocol_data_length, "", "s"));
 }
 
@@ -426,7 +425,7 @@ static const value_string parameter_tag_values[] = {
   { DLCI_PARAMETER_TAG,                                    "DLCI" },
   { DIAGNOSTIC_INFORMATION_PARAMETER_TAG,                  "Diagnostic information" },
   { INTEGER_RANGE_INTERFACE_IDENTIFIER_PARAMETER_TAG,      "Integer range interface identifier" },
-  { HEARTBEAT_DATA_PARAMETER_TAG,                          "Hearbeat data" },
+  { HEARTBEAT_DATA_PARAMETER_TAG,                          "Heartbeat data" },
   { TRAFFIC_MODE_TYPE_PARAMETER_TAG,                       "Traffic mode type" },
   { ERROR_CODE_PARAMETER_TAG,                              "Error code" },
   { STATUS_TYPE_INDENTIFICATION_PARAMETER_TAG,             "Status type/identification" },
@@ -450,7 +449,7 @@ dissect_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo, proto_tree *tree,
   padding_length = tvb_length(parameter_tvb) - length;
 
   /* create proto_tree stuff */
-  parameter_item   = proto_tree_add_text(dua_tree, parameter_tvb, PARAMETER_HEADER_OFFSET, tvb_length(parameter_tvb),
+  parameter_item   = proto_tree_add_text(dua_tree, parameter_tvb, PARAMETER_HEADER_OFFSET, tvb_length(parameter_tvb), "%s",
                                          val_to_str(tag, parameter_tag_values, "Unknown parameter"));
   parameter_tree   = proto_item_add_subtree(parameter_item, ett_dua_parameter);
 
@@ -716,7 +715,7 @@ proto_register_dua(void)
 
   /* Setup list of header fields */
   static hf_register_info hf[] = {
-    { &hf_int_interface_id,      { "Integer interface identifier", "dua.int_interface_identifier",  FT_INT32,   BASE_HEX,  NULL,                           0x0,               "", HFILL } },
+    { &hf_int_interface_id,      { "Integer interface identifier", "dua.int_interface_identifier",  FT_UINT32,   BASE_HEX,  NULL,                           0x0,               "", HFILL } },
     { &hf_text_interface_id,     { "Text interface identifier",    "dua.text_interface_identifier", FT_STRING,  BASE_NONE, NULL,                           0x0,               "", HFILL } },
     { &hf_info_string,           { "Info string",                  "dua.info_string",               FT_STRING,  BASE_NONE, NULL,                           0x0,               "", HFILL } },
     { &hf_dlci_reserved,         { "Reserved",                     "dua.dlci_reserved",             FT_UINT16,  BASE_DEC,  NULL,                           RESERVED_BIT_MASK, "", HFILL } },
@@ -769,7 +768,7 @@ proto_reg_handoff_dua(void)
 {
   dissector_handle_t dua_handle;
 
-  dua_handle  = create_dissector_handle(dissect_dua, proto_dua);
+  dua_handle  = find_dissector("dua");
   data_handle = find_dissector("data");
   dpnss_handle = find_dissector("dpnss");
   dissector_add("sctp.ppi", DUA_PAYLOAD_PROTOCOL_ID, dua_handle);
