@@ -1,6 +1,6 @@
 /* packet-epl.c
- * Routines for "Ethernet Powerlink 2.0" dissection
- * (ETHERNET Powerlink V2.0 Communication Profile Specification Draft Standard Version 1.0.0)
+ * Routines for "Ethernet POWERLINK 2.0" dissection
+ * (Ethernet POWERLINK V2.0 Communication Profile Specification Draft Standard Version 1.0.0)
  *
  * Copyright (c) 2006: Zurich University of Applied Sciences Winterthur (ZHW)
  *                     Institute of Embedded Systems (InES)
@@ -14,7 +14,7 @@
  *                     http://www.systec-electronic.com
  *                     - Daniel Krueger <daniel.krueger[AT]systec-electronic.com>
  *
- * $Id: packet-epl.c 24557 2008-03-04 21:05:21Z morriss $
+ * $Id: packet-epl.c 27050 2008-12-18 19:08:49Z wmeier $
  *
  * A plugin for:
  * Wireshark - Network traffic analyzer
@@ -44,7 +44,6 @@
 #include <gmodule.h>
 #include <epan/packet.h>
 #include <epan/etypes.h>
-#include <epan/emem.h>
 #include <epan/prefs.h>
 
 #include "packet-epl.h"
@@ -344,11 +343,11 @@ dissect_epl(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     if (tree && !udpencap)
     {
         epl_dest_item = proto_tree_add_item(epl_tree, hf_epl_dest, tvb, offset, 1, TRUE);
-        proto_item_append_text (epl_dest_item, dest_str);
+        proto_item_append_text (epl_dest_item, "%s", dest_str);
         offset += 1;
 
         epl_src_item = proto_tree_add_item(epl_tree, hf_epl_src, tvb, offset, 1, TRUE);
-        proto_item_append_text (epl_src_item, src_str);
+        proto_item_append_text (epl_src_item, "%s", src_str);
         offset += 1;
     }
     else
@@ -854,7 +853,7 @@ dissect_epl_asnd_ires(proto_tree *epl_tree, tvbuff_t *tvb, packet_info *pinfo, g
         additional = tvb_get_letohs(tvb, offset+2);
         proto_tree_add_string_format(epl_tree, hf_epl_asnd_identresponse_dt, tvb, offset,
             4, "", "Device Type: Profil %d (%s), Additional Information: 0x%4.4X",
-            profile, val_to_str(profile, epl_device_profiles, "Unkown Profile"), additional);
+            profile, val_to_str(profile, epl_device_profiles, "Unknown Profile"), additional);
 
         proto_tree_add_item(epl_tree, hf_epl_asnd_identresponse_profile, tvb, offset, 2, TRUE);
         offset += 4;
@@ -970,8 +969,8 @@ dissect_epl_asnd_sres(proto_tree *epl_tree, tvbuff_t *tvb, packet_info *pinfo, g
         proto_tree_add_item(epl_seb_tree, hf_epl_asnd_statusresponse_seb_err_errorregister_u8_bit7, tvb, offset, 1, TRUE);
         offset += 2;
 
-        proto_tree_add_item(epl_seb_tree, hf_epl_asnd_statusresponse_seb_devicespecific_err, tvb,offset, 8, TRUE);
-        offset += 8;
+        proto_tree_add_item(epl_seb_tree, hf_epl_asnd_statusresponse_seb_devicespecific_err, tvb,offset, 6, TRUE);
+        offset += 6;
 
         /* List of errors / events */
         /* get the number of entries in the error code list*/
@@ -1090,7 +1089,7 @@ gint
 dissect_epl_sdo_command(proto_tree *epl_tree, tvbuff_t *tvb, packet_info *pinfo, gint offset)
 {
     guint8  segmented, command_id;
-    gboolean response, abort;
+    gboolean response, abort_flag;
     guint32 abort_code;
     guint16 segment_size;
 
@@ -1099,10 +1098,10 @@ dissect_epl_sdo_command(proto_tree *epl_tree, tvbuff_t *tvb, packet_info *pinfo,
 
     command_id = tvb_get_guint8(tvb, offset + 2);
 
-    abort      = tvb_get_guint8(tvb, offset + 1) & EPL_ASND_SDO_CMD_ABORT_FILTER;
+    abort_flag      = tvb_get_guint8(tvb, offset + 1) & EPL_ASND_SDO_CMD_ABORT_FILTER;
 
     /* test if CommandField == empty */
-    if (command_id != 0 || abort)
+    if (command_id != 0 || abort_flag)
     {
         segmented  = (tvb_get_guint8(tvb, offset + 1) & EPL_ASND_SDO_CMD_SEGMENTATION_FILTER) >> 4;
         response   = tvb_get_guint8(tvb, offset + 1) & EPL_ASND_SDO_CMD_RESPONSE_FILTER;
@@ -1144,7 +1143,7 @@ dissect_epl_sdo_command(proto_tree *epl_tree, tvbuff_t *tvb, packet_info *pinfo,
             offset += 4;
         }
 
-        if (abort)
+        if (abort_flag)
         {
             abort_code = tvb_get_letohl(tvb, offset);
             /* if AbortBit is set then print AbortMessage */
@@ -1437,7 +1436,7 @@ static hf_register_info hf[] = {
 { &hf_epl_asnd_statusresponse_seb_err_errorregister_u8_bit7,    { "Manufacturer specific",      "epl.asnd.res.seb.bit7",                FT_UINT8, BASE_DEC, NULL, 0x80, "", HFILL }},
 { &hf_epl_asnd_statusresponse_seb_devicespecific_err,           { "Device profile specific",    "epl.asnd.res.seb.devicespecific_err",FT_BYTES, BASE_DEC,NULL, 0x00, "", HFILL }},
 
-{ &hf_epl_asnd_statusresponse_el,                               { "ErrorsCodeList",             "epl.asnd.sres.el",                     FT_BYTES, BASE_DEC, NULL, 0x00, "", HFILL }},
+{ &hf_epl_asnd_statusresponse_el,                               { "ErrorCodesList",             "epl.asnd.sres.el",                     FT_BYTES, BASE_DEC, NULL, 0x00, "", HFILL }},
 { &hf_epl_asnd_statusresponse_el_entry,                         { "Entry",                      "epl.asnd.sres.el.entry",               FT_BYTES, BASE_DEC, NULL, 0x00, "", HFILL }},
 
 /*List of Errors/Events*/
@@ -1501,7 +1500,7 @@ static hf_register_info hf[] = {
     module_t *epl_module;
 
     /* Register the protocol name and description */
-    proto_epl = proto_register_protocol("ETHERNET Powerlink v2", "EPL", "epl");
+    proto_epl = proto_register_protocol("Ethernet POWERLINK V2", "EPL", "epl");
 
     /* Required function calls to register the header fields and subtrees used */
     proto_register_field_array(proto_epl, hf, array_length(hf));
