@@ -4,7 +4,7 @@
  *   Copyright 2003  Ronnie Sahlberg, exchange first/last matching and 
  *                                    tap listener and misc updates
  *
- * $Id: packet-fc.c 27037 2008-12-17 17:23:37Z wmeier $
+ * $Id: packet-fc.c 28356 2009-05-13 19:46:11Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1124,10 +1124,9 @@ dissect_fc_helper (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
                                          !is_lastframe_inseq);
              
              if (fcfrag_head) {
-                  next_tvb = tvb_new_real_data (fcfrag_head->data,
+                  next_tvb = tvb_new_child_real_data(tvb, fcfrag_head->data,
                                                 fcfrag_head->datalen,
                                                 fcfrag_head->datalen);
-                  tvb_set_child_real_data_tvbuff(tvb, next_tvb);
                   
                   /* Add the defragmented data to the data source list. */
                   add_new_data_source(pinfo, next_tvb, "Reassembled FC");
@@ -1255,7 +1254,7 @@ proto_register_fc(void)
            HFILL}},
 
         { &hf_fc_reassembled,
-          {"Reassembled Frame", "fc.reassembled", FT_BOOLEAN, BASE_HEX, NULL,
+          {"Reassembled Frame", "fc.reassembled", FT_BOOLEAN, BASE_NONE, NULL,
            0x0, "", HFILL}},
         { &hf_fc_nh_da,
           {"Network DA", "fc.nethdr.da", FT_STRING, BASE_HEX, NULL,
