@@ -3,7 +3,7 @@
  * This decoder is for FC-SP version 1.1
  * Copyright 2003, Dinesh G Dutt <ddutt@cisco.com>
  *
- * $Id: packet-fcsp.c 23406 2007-11-08 22:49:03Z etxrab $
+ * $Id: packet-fcsp.c 26265 2008-09-25 02:21:04Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -48,7 +48,6 @@
 
 #include <glib.h>
 
-#include <epan/prefs.h>
 #include <epan/packet.h>
 #include <epan/conversation.h>
 #include <epan/etypes.h>
@@ -575,8 +574,6 @@ proto_register_fcsp (void)
     /* Required function calls to register the header fields and subtrees used */
     proto_register_field_array(proto_fcsp, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
-
-    data_handle = find_dissector("data");
 }
 
 /* If this dissector uses sub-dissector registration add a registration routine.
@@ -586,10 +583,6 @@ proto_register_fcsp (void)
 void
 proto_reg_handoff_fcsp (void)
 {
-    dissector_handle_t fcsp_handle;
-
-    fcsp_handle = create_dissector_handle (dissect_fcsp, proto_fcsp);
-
     data_handle = find_dissector ("data");
 }
 
