@@ -3,7 +3,7 @@
  * Copyright 1999, Richard Sharpe <rsharpe@ns.aus.com>
  * Copyright 2001, Juan Toledo <toledo@users.sourceforge.net> (Passive FTP)
  *
- * $Id: packet-ftp.c 29702 2009-09-04 21:26:50Z gerald $
+ * $Id: packet-ftp.c 27896 2009-03-30 17:53:41Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -298,7 +298,7 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	gboolean        is_request;
 	proto_tree      *ftp_tree = NULL;
 	proto_tree      *reqresp_tree = NULL;
-	proto_item	*ti;
+	proto_item	*ti, *hidden_item;
 	gint		offset = 0;
 	const guchar	*line;
 	guint32		code;
@@ -353,15 +353,19 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		ftp_tree = proto_item_add_subtree(ti, ett_ftp);
 
 		if (is_request) {
-			proto_tree_add_boolean_hidden(ftp_tree,
+			hidden_item = proto_tree_add_boolean(ftp_tree,
 			    hf_ftp_request, tvb, 0, 0, TRUE);
-			proto_tree_add_boolean_hidden(ftp_tree,
+			PROTO_ITEM_SET_HIDDEN(hidden_item);
+			hidden_item = proto_tree_add_boolean(ftp_tree,
 			    hf_ftp_response, tvb, 0, 0, FALSE);
+			PROTO_ITEM_SET_HIDDEN(hidden_item);
 		} else {
-			proto_tree_add_boolean_hidden(ftp_tree,
+			hidden_item = proto_tree_add_boolean(ftp_tree,
 			    hf_ftp_request, tvb, 0, 0, FALSE);
-			proto_tree_add_boolean_hidden(ftp_tree,
+			PROTO_ITEM_SET_HIDDEN(hidden_item);
+			hidden_item = proto_tree_add_boolean(ftp_tree,
 			    hf_ftp_response, tvb, 0, 0, TRUE);
+			PROTO_ITEM_SET_HIDDEN(hidden_item);
 		}
 
 		/*
@@ -447,8 +451,8 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			next_token = line;
 		}
 	}
-	offset += next_token - line;
-	linelen -= next_token - line;
+	offset += (gint) (next_token - line);
+	linelen -= (int) (next_token - line);
 	line = next_token;
 
 	if (tree) {
@@ -731,17 +735,15 @@ proto_register_ftp(void)
   register_dissector("ftp-data", dissect_ftpdata, proto_ftp_data);
   proto_register_field_array(proto_ftp, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
-
-  ftpdata_handle = create_dissector_handle(dissect_ftpdata, proto_ftp_data);
 }
 
 void
 proto_reg_handoff_ftp(void)
 {
-  dissector_handle_t ftpdata_handle, ftp_handle;
+  dissector_handle_t ftp_handle;
 
-  ftpdata_handle = create_dissector_handle(dissect_ftpdata, proto_ftp_data);
+  ftpdata_handle = find_dissector("ftp-data");
   dissector_add("tcp.port", TCP_PORT_FTPDATA, ftpdata_handle);
-  ftp_handle = create_dissector_handle(dissect_ftp, proto_ftp);
+  ftp_handle = find_dissector("ftp");
   dissector_add("tcp.port", TCP_PORT_FTP, ftp_handle);
 }
