@@ -1,6 +1,6 @@
 /* packet-gsm_a_common.h
  *
- * $Id: packet-gsm_a_common.h 27147 2009-01-01 22:54:30Z etxrab $
+ * $Id: packet-gsm_a_common.h 29703 2009-09-04 21:35:02Z gerald $
  *
  *   Reference [3]
  *   Mobile radio interface Layer 3 specification;
@@ -131,9 +131,14 @@ extern elem_fcn nas_eps_common_elem_fcn[];
 extern int hf_nas_eps_common_elem_id;
 
 extern const value_string nas_emm_elem_strings[];
-extern gint ett_nas_emm_elem[];
+extern gint ett_nas_eps_emm_elem[];
 extern elem_fcn emm_elem_fcn[];
-extern int hf_nas_emm_elem_id;
+extern int hf_nas_eps_emm_elem_id;
+
+extern const value_string nas_esm_elem_strings[];
+extern gint ett_nas_eps_esm_elem[];
+extern elem_fcn esm_elem_fcn[];
+extern int hf_nas_eps_esm_elem_id;
 
 extern sccp_msg_info_t* sccp_msg;
 extern sccp_assoc_info_t* sccp_assoc;
@@ -159,17 +164,18 @@ extern int hf_gsm_a_rr_chnl_needed_ch1;
 #define GSM_BSSMAP_APDU_IE	0x49
 
 /* flags for the packet-gsm_a_common routines */
-#define GSM_A_PDU_TYPE_BSSMAP	0 /* BSSAP_PDU_TYPE_BSSMAP i.e. 0 - until split complete at least! */
-#define GSM_A_PDU_TYPE_DTAP		1  /*BSSAP_PDU_TYPE_DTAP i.e. 1 - until split complete at least! */
+#define GSM_A_PDU_TYPE_BSSMAP		0  /* BSSAP_PDU_TYPE_BSSMAP i.e. 0 - until split complete at least! */
+#define GSM_A_PDU_TYPE_DTAP		1  /* BSSAP_PDU_TYPE_DTAP i.e. 1   - until split complete at least! */
 #define GSM_A_PDU_TYPE_RP		2
 #define GSM_A_PDU_TYPE_RR		3
-#define GSM_A_PDU_TYPE_COMMON	4
+#define GSM_A_PDU_TYPE_COMMON		4
 #define GSM_A_PDU_TYPE_GM		5
-#define GSM_A_PDU_TYPE_BSSLAP	6
-#define GSM_A_PDU_TYPE_SACCH	7
-#define GSM_PDU_TYPE_BSSMAP_LE	8
+#define GSM_A_PDU_TYPE_BSSLAP		6
+#define GSM_A_PDU_TYPE_SACCH		7
+#define GSM_PDU_TYPE_BSSMAP_LE		8
 #define NAS_PDU_TYPE_COMMON		9
 #define NAS_PDU_TYPE_EMM		10
+#define NAS_PDU_TYPE_ESM		11
 
 extern const char* get_gsm_a_msg_string(int pdu_type, int idx);
 
@@ -181,9 +187,9 @@ extern const char* get_gsm_a_msg_string(int pdu_type, int idx);
 #define	IS_UPLINK_UNKNOWN	2
 
 /* Defines and nasty static for handling half octet mandatory V IEs 
- * TODO: Note origimally UPPER_NIBBLE was -2 and LOWER_NIBBLE was -1
+ * TODO: Note originally UPPER_NIBBLE was -2 and LOWER_NIBBLE was -1
  * changed here to unsigned integer as it wouldn't compile (Warnings on Ubuntu)
- * uggly hack...
+ * ugly hack...
  */
 #define UPPER_NIBBLE	(2)
 #define LOWER_NIBBLE	(1)
@@ -271,9 +277,14 @@ extern const char* get_gsm_a_msg_string(int pdu_type, int idx);
 		break; \
 	case NAS_PDU_TYPE_EMM: \
 		SEV_elem_names = nas_emm_elem_strings; \
-		SEV_elem_ett = ett_nas_emm_elem; \
+		SEV_elem_ett = ett_nas_eps_emm_elem; \
 		SEV_elem_funcs = emm_elem_fcn; \
 		break; \
+	case NAS_PDU_TYPE_ESM: \
+		SEV_elem_names = nas_esm_elem_strings; \
+		SEV_elem_ett = ett_nas_eps_esm_elem; \
+		SEV_elem_funcs = esm_elem_fcn; \
+		break; \
 	default: \
 		proto_tree_add_text(tree, \
 			tvb, curr_offset, -1, \
@@ -342,6 +353,14 @@ extern guint16 elem_v(tvbuff_t *tvb, proto_tree *tree, gint pdu_type, int idx, g
 extern guint16 elem_v_short(tvbuff_t *tvb, proto_tree *tree, gint pdu_type, int idx, guint32 offset);
 
 
+/* XXX: Most (if not all) the functions which make use of the following macros have the variables 'consumed',
+ *      'curr_offset', and 'cur_len' declared as *unsigned*.  This means that the 'if (curr_len <= 0)' statement
+ *      originally at the end of each of the macros would always be FALSE since an unsigned cannot be less than 0.
+ *      I've chosen to change the statement to 'if ((signed)curr_len <= 0)'. (Although this may be a bit of a
+ *      hack, it seems simpler than changing declarations to signed in all the places these macros are used).
+ *      Is there a better approach ?
+ */
+
 #define ELEM_MAND_TLV(EMT_iei, EMT_pdu_type, EMT_elem_idx, EMT_elem_name_addition) \
 {\
 	if ((consumed = elem_tlv(tvb, tree, (guint8) EMT_iei, EMT_pdu_type, EMT_elem_idx, curr_offset, curr_len, EMT_elem_name_addition)) > 0) \
@@ -379,7 +398,7 @@ extern guint16 elem_v_short(tvbuff_t *tvb, proto_tree *tree, gint pdu_type, int
 			(EMT_elem_name_addition == NULL) || (EMT_elem_name_addition[0] == '\0') ? "" : EMT_elem_name_addition \
 			); \
 	} \
-	if (curr_len <= 0) return; \
+	if ((signed)curr_len <= 0) return; \
 }
 #define ELEM_OPT_TLV(EOT_iei, EOT_pdu_type, EOT_elem_idx, EOT_elem_name_addition) \
 {\
@@ -388,7 +407,7 @@ extern guint16 elem_v_short(tvbuff_t *tvb, proto_tree *tree, gint pdu_type, int
 		curr_offset += consumed; \
 		curr_len -= consumed; \
 	} \
-	if (curr_len <= 0) return; \
+	if ((signed)curr_len <= 0) return; \
 }
 
 #define ELEM_OPT_TLV_E(EOT_iei, EOT_pdu_type, EOT_elem_idx, EOT_elem_name_addition) \
@@ -398,7 +417,7 @@ extern guint16 elem_v_short(tvbuff_t *tvb, proto_tree *tree, gint pdu_type, int
 		curr_offset += consumed; \
 		curr_len -= consumed; \
 	} \
-	if (curr_len <= 0) return; \
+	if ((signed)curr_len <= 0) return; \
 }
 
 #define ELEM_MAND_TV(EMT_iei, EMT_pdu_type, EMT_elem_idx, EMT_elem_name_addition) \
@@ -418,7 +437,7 @@ extern guint16 elem_v_short(tvbuff_t *tvb, proto_tree *tree, gint pdu_type, int
 			(EMT_elem_name_addition == NULL) || (EMT_elem_name_addition[0] == '\0') ? "" : EMT_elem_name_addition \
 		); \
 	} \
-	if (curr_len <= 0) return; \
+	if ((signed)curr_len <= 0) return; \
 }
 
 #define ELEM_OPT_TV(EOT_iei, EOT_pdu_type, EOT_elem_idx, EOT_elem_name_addition) \
@@ -428,7 +447,7 @@ extern guint16 elem_v_short(tvbuff_t *tvb, proto_tree *tree, gint pdu_type, int
 		curr_offset += consumed; \
 		curr_len -= consumed; \
 	} \
-	if (curr_len <= 0) return; \
+	if ((signed)curr_len <= 0) return; \
 }
 
 #define ELEM_OPT_TV_SHORT(EOT_iei, EOT_pdu_type, EOT_elem_idx, EOT_elem_name_addition) \
@@ -438,7 +457,7 @@ extern guint16 elem_v_short(tvbuff_t *tvb, proto_tree *tree, gint pdu_type, int
 		curr_offset += consumed; \
 		curr_len -= consumed; \
 	} \
-	if (curr_len <= 0) return; \
+	if ((signed)curr_len <= 0) return; \
 }
 
 #define ELEM_OPT_T(EOT_iei, EOT_pdu_type, EOT_elem_idx, EOT_elem_name_addition) \
@@ -448,7 +467,7 @@ extern guint16 elem_v_short(tvbuff_t *tvb, proto_tree *tree, gint pdu_type, int
 		curr_offset += consumed; \
 		curr_len -= consumed; \
 	} \
-	if (curr_len <= 0) return; \
+	if ((signed)curr_len <= 0) return; \
 }
 
 #define ELEM_MAND_LV(EML_pdu_type, EML_elem_idx, EML_elem_name_addition) \
@@ -462,7 +481,7 @@ extern guint16 elem_v_short(tvbuff_t *tvb, proto_tree *tree, gint pdu_type, int
 	{ \
 		/* Mandatory, but nothing we can do */ \
 	} \
-	if (curr_len <= 0) return; \
+	if ((signed)curr_len <= 0) return;      \
 }
 
 #define ELEM_MAND_LV_E(EML_pdu_type, EML_elem_idx, EML_elem_name_addition) \
@@ -476,7 +495,7 @@ extern guint16 elem_v_short(tvbuff_t *tvb, proto_tree *tree, gint pdu_type, int
 	{ \
 		/* Mandatory, but nothing we can do */ \
 	} \
-	if (curr_len <= 0) return; \
+	if ((signed)curr_len <= 0) return;      \
 }
 
 #define ELEM_MAND_V(EMV_pdu_type, EMV_elem_idx) \
@@ -490,7 +509,7 @@ extern guint16 elem_v_short(tvbuff_t *tvb, proto_tree *tree, gint pdu_type, int
 	{ \
 		/* Mandatory, but nothing we can do */ \
 	} \
-	if (curr_len <= 0) return; \
+	if ((signed)curr_len <= 0) return;      \
 }
 
 #define ELEM_MAND_V_SHORT(EMV_pdu_type, EMV_elem_idx) \
@@ -504,7 +523,7 @@ extern guint16 elem_v_short(tvbuff_t *tvb, proto_tree *tree, gint pdu_type, int
 	{ \
 		/* Mandatory, but nothing we can do */ \
 	} \
-	if (curr_len <= 0) return; \
+	if ((signed)curr_len <= 0) return;      \
 }
 
 /*
@@ -563,8 +582,9 @@ guint16 de_plmn_list(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len,
 guint16 de_ms_cm_1(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len, gchar *add_string _U_, int string_len _U_);
 guint16 de_ms_cm_2(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len, gchar *add_string, int string_len);
 guint16 de_ms_cm_3(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len, gchar *add_string, int string_len);
-
+guint16 de_serv_cat(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len, gchar *add_string, int string_len);
 guint16 de_sm_apn(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len, gchar *add_string, int string_len);
+guint16 de_sm_pco(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len, gchar *add_string _U_, int string_len _U_);
 guint16 de_sm_qos(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len, gchar *add_string, int string_len);
 guint16 de_sm_pflow_id(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len, gchar *add_string, int string_len);
 
@@ -631,7 +651,7 @@ typedef enum
 	DE_MS_CM_1,				/* Mobile Station Classmark 1 */
 	DE_MS_CM_2,				/* Mobile Station Classmark 2 */
 	DE_MS_CM_3,				/* Mobile Station Classmark 3 */
-	DE_SPARE_NIBBLE,			/* Spare Half Octet */
+	DE_SPARE_NIBBLE,		/* Spare Half Octet */
 	DE_D_GB_CALL_REF,		/* Descriptive group or broadcast call reference */
 	DE_G_CIPH_KEY_NUM,		/* Group Cipher Key Number */
 	DE_PD_SAPI,				/* PD and SAPI $(CCBS)$ */
@@ -894,7 +914,7 @@ typedef enum
 	DE_CAUSE_NO_CLI,				/* Cause of No CLI */
 	DE_IMM_MOD_IND,					/* Immediate Modification Indicator */
 	DE_SUP_CODEC_LIST,				/* Supported Codec List */
-	DE_SRVC_CAT,					/* Service Category */
+	DE_SERV_CAT,					/* Service Category */
 	DE_REDIAL,						/* 10.5.4.34 Redial */
 	/* Short Message Service Information Elements [5] 8.1.4 */
 	DE_CP_USER_DATA,				/* CP-User Data */
@@ -1081,9 +1101,9 @@ typedef enum
 	DE_RR_EXT_MEAS_RESULT,     	/* [3] 10.5.2.45 Extended Measurement Results */
 	DE_RR_EXT_MEAS_FREQ_LIST,		/* [3] 10.5.2.46 Extended Measurement Frequency List */
 	DE_RR_SUS_CAU,					/* [3] 10.5.2.47 Suspension Cause				*/
-/* [3] 10.5.2.48 APDU ID
- * [3] 10.5.2.49 APDU Flags
- * [3] 10.5.2.50 APDU Data */
+	DE_RR_APDU_ID,					/* [3] 10.5.2.48 APDU ID */
+	DE_RR_APDU_FLAGS,				/* [3] 10.5.2.49 APDU Flags */
+	DE_RR_APDU_DATA,				/* [3] 10.5.2.50 APDU Data */
 	DE_RR_HO_TO_UTRAN_CMD,			/* [3] 10.5.2.51 Handover To UTRAN Command */
 /* [3] 10.5.2.52 Handover To cdma2000 Command
  * [3] 10.5.2.53 (void)
