@@ -14,7 +14,7 @@
  * Header field support for TPDU Parameters added by
  * Abhik Sarkar.
  *
- * $Id: packet-gsm_sms.c 27718 2009-03-13 22:06:48Z stig $
+ * $Id: packet-gsm_sms.c 32215 2010-03-16 23:22:42Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -277,11 +277,12 @@ static const value_string msg_type_strings_ms_to_sc[] = {
     { 0, NULL },
 };
 
+/* 9.2.3.3 TP-Validity-Period-Format (TP-VPF) */
 static const value_string vp_type_strings[] = {
-    { 0,	"TP VP field not present"},
-    { 1,	"TP VP field present - relative format"},
-    { 2,	"TP-VP field present - enhanced format"},
-    { 3,	"TP VP field present - absolute format"},
+    { 0,	"TP-VP field not present"},
+    { 2,	"TP-VP field present - relative format"},
+    { 1,	"TP-VP field present - enhanced format"},
+    { 3,	"TP-VP field present - absolute format"},
     { 0, NULL },
 };
 
@@ -1566,7 +1567,7 @@ gsm_sms_char_7bit_unpack(unsigned int offset, unsigned int in_length, unsigned i
 	}
     }
 
-    return out_num - output;
+    return (int)(out_num - output);
 }
 
 #define GN_CHAR_ALPHABET_SIZE 128
@@ -2713,7 +2714,7 @@ dis_field_ud(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint32 length, gb
 						utf8_text = g_convert_with_iconv(sm_tvb->real_data, sm_tvb->reported_length , cd , NULL , NULL , &l_conv_error);
 						if(!l_conv_error)
 						{
-							len_sms = strlen(utf8_text);
+							len_sms = (int)strlen(utf8_text);
 							num_labels = len_sms / MAX_SMS_FRAG_LEN;
 							num_labels += len_sms % MAX_SMS_FRAG_LEN ? 1 : 0;
 							for(i = 0; i < num_labels;i++)
