@@ -4,7 +4,7 @@
  * Copyright 2002, Richard Sharpe <rsharpe@samba.org> Added a few 
  *		   bits and pieces ...
  *
- * $Id: packet-gssapi.c 19119 2006-09-02 11:46:15Z sahlberg $
+ * $Id: packet-gssapi.c 28356 2009-05-13 19:46:11Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -45,6 +45,7 @@
 #include "epan/emem.h"
 #include "epan/prefs.h"
 #include "epan/reassemble.h"
+#include <epan/asn1.h>
 #include "packet-ber.h"
 #include "to_str.h"
 
@@ -110,7 +111,8 @@ gssapi_reassembly_init(void)
  * Subdissectors
  */
 
-static dissector_handle_t ntlmssp_handle = NULL;
+static dissector_handle_t ntlmssp_handle;
+static dissector_handle_t spnego_krb5_wrap_handle;
 
 static GHashTable *gssapi_oids;
 
@@ -170,15 +172,16 @@ static int
 dissect_gssapi_work(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     gboolean is_verifier)
 {
-	proto_item *item;
-	proto_tree *subtree;
-	int return_offset = 0;
-	gssapi_conv_info_t *gss_info;
+	proto_item *volatile item;
+	proto_tree *volatile subtree;
+	volatile int return_offset = 0;
+	gssapi_conv_info_t *volatile gss_info;
 	gssapi_oid_value *oidvalue;
 	dissector_handle_t handle;
 	conversation_t *conversation;
 	tvbuff_t *oid_tvb;
-	int len, offset, start_offset, oid_start_offset;
+	int len, start_offset, oid_start_offset;
+	volatile int offset;
 	gint8 class;
 	gboolean pc, ind_field;
 	gint32 tag;
@@ -186,11 +189,12 @@ dissect_gssapi_work(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	const char *oid;
 	fragment_data *fd_head=NULL;
 	gssapi_frag_info_t *fi;
-	tvbuff_t *gss_tvb=NULL;
+	tvbuff_t *volatile gss_tvb=NULL;
+	asn1_ctx_t asn1_ctx;
 
 	start_offset=0;
 	offset=0;
-
+	asn1_ctx_init(&asn1_ctx, ASN1_ENC_BER, TRUE, pinfo);
 	/*
 	 * We don't know whether the data is encrypted, so say it's
 	 * not, for now.  The subdissector must set gssapi_data_encrypted
@@ -222,7 +226,6 @@ dissect_gssapi_work(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		conversation_add_proto_data(conversation, proto_gssapi, gss_info);
 	}
 
-
 	item = proto_tree_add_item(
 		tree, proto_gssapi, tvb, offset, -1, FALSE);
 
@@ -269,8 +272,7 @@ dissect_gssapi_work(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 			gss_info->do_reassembly=FALSE;
 			fi->reassembled_in=pinfo->fd->num;
 
-			gss_tvb=tvb_new_real_data(fd_head->data, fd_head->datalen, fd_head->datalen);
-			tvb_set_child_real_data_tvbuff(tvb, gss_tvb);
+			gss_tvb=tvb_new_child_real_data(tvb, fd_head->data, fd_head->datalen, fd_head->datalen);
 			add_new_data_source(pinfo, gss_tvb, "Reassembled GSSAPI");
 		}
 		/* We have seen this packet before.
@@ -284,8 +286,7 @@ dissect_gssapi_work(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 				if(fd_head && (fd_head->flags&FD_DEFRAGMENTED)){
 					if(pinfo->fd->num==fi->reassembled_in){
 					        proto_item *frag_tree_item;
-						gss_tvb=tvb_new_real_data(fd_head->data, fd_head->datalen, fd_head->datalen);
-						tvb_set_child_real_data_tvbuff(tvb, gss_tvb);
+						gss_tvb=tvb_new_child_real_data(tvb, fd_head->data, fd_head->datalen, fd_head->datalen);
 						add_new_data_source(pinfo, gss_tvb, "Reassembled GSSAPI");
 						show_fragment_tree(fd_head, &gssapi_frag_items, tree, pinfo, tvb, &frag_tree_item);
 					} else {
@@ -300,10 +301,29 @@ dissect_gssapi_work(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 		/* Read header */
 		offset = get_ber_identifier(gss_tvb, offset, &class, &pc, &tag);
-		offset = get_ber_length(tree, gss_tvb, offset, &len1, &ind_field);
+		offset = get_ber_length(gss_tvb, offset, &len1, &ind_field);
 
 
 		if (!(class == BER_CLASS_APP && pc && tag == 0)) {
+		  /* It could be NTLMSSP, with no OID.  This can happen 
+		     for anything that microsoft calls 'Negotiate' or GSS-SPNEGO */
+		  if ((tvb_length_remaining(gss_tvb, start_offset)>7) && (tvb_strneql(gss_tvb, start_offset, "NTLMSSP", 7) == 0)) {
+		    return_offset = call_dissector(ntlmssp_handle,
+						   tvb_new_subset(gss_tvb, start_offset, -1, -1),
+						   pinfo, subtree);
+		    goto done;
+		  }
+
+		  /* Maybe it's new GSSKRB5 CFX Wrapping */
+		  if ((tvb_length_remaining(gss_tvb, start_offset)>2) &&
+		      ((tvb_memeql(gss_tvb, start_offset, "\04\x04", 2) == 0) ||
+		       (tvb_memeql(gss_tvb, start_offset, "\05\x04", 2) == 0))) {
+		    return_offset = call_dissector(spnego_krb5_wrap_handle,
+						   tvb_new_subset(gss_tvb, start_offset, -1, -1),
+						   pinfo, subtree);
+		    goto done;
+		  }
+
 		  /* 
 		   * If we do not recognise an Application class,
 		   * then we are probably dealing with an inner context
@@ -334,27 +354,20 @@ dissect_gssapi_work(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		  }
 		  if (!oidvalue)
 		  {
-		    /* It could be NTLMSSP, with no OID.  This can happen 
-		       for anything that microsoft calls 'Negotiate' or GSS-SPNEGO */
-		    if (tvb_strneql(gss_tvb, start_offset, "NTLMSSP", 7) == 0) {
-		      call_dissector(ntlmssp_handle, tvb_new_subset(gss_tvb, start_offset, -1, -1), pinfo, subtree);
-		    } else {
-		      proto_tree_add_text(subtree, gss_tvb, start_offset, 0,
+                    proto_tree_add_text(subtree, gss_tvb, start_offset, 0,
 					  "Unknown header (class=%d, pc=%d, tag=%d)",
 					  class, pc, tag);
-		    }
 		    return_offset = tvb_length(gss_tvb);
 		    goto done;
-
 		  } else {
-		    tvbuff_t *oid_tvb;
+		    tvbuff_t *oid_tvb_local;
 
-		    oid_tvb = tvb_new_subset(gss_tvb, start_offset, -1, -1);
+		    oid_tvb_local = tvb_new_subset(gss_tvb, start_offset, -1, -1);
 		    if (is_verifier)
 			handle = oidvalue->wrap_handle;
 		    else
 			handle = oidvalue->handle;
-		    len = call_dissector(handle, oid_tvb, pinfo, subtree);
+		    len = call_dissector(handle, oid_tvb_local, pinfo, subtree);
 		    if (len == 0)
 			return_offset = tvb_length(gss_tvb);
 		    else
@@ -365,7 +378,7 @@ dissect_gssapi_work(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 		/* Read oid */
 		oid_start_offset=offset;
-		offset=dissect_ber_object_identifier_str(FALSE, pinfo, subtree, gss_tvb, offset, hf_gssapi_oid, &oid);
+		offset=dissect_ber_object_identifier_str(FALSE, &asn1_ctx, subtree, gss_tvb, offset, hf_gssapi_oid, &oid);
 		oidvalue = gssapi_lookup_oid_str(oid);
 
 
@@ -489,31 +502,31 @@ proto_register_gssapi(void)
 {
 	static hf_register_info hf[] = {
 	{ &hf_gssapi_oid, 
-	    	{ "OID", "gssapi.OID", FT_STRING, BASE_NONE,
+	    	{ "OID", "gss-api.OID", FT_STRING, BASE_NONE,
 		  NULL, 0, "This is a GSS-API Object Identifier", HFILL }},
 	{ &hf_gssapi_segment,
-		{ "GSSAPI Segment", "gssapi.segment", FT_FRAMENUM, BASE_NONE, 
+		{ "GSSAPI Segment", "gss-api.segment", FT_FRAMENUM, BASE_NONE, 
 		  NULL, 0x0, "GSSAPI Segment", HFILL }},
 	{ &hf_gssapi_segments,
-		{ "GSSAPI Segments", "gssapi.segment.segments", FT_NONE, BASE_NONE, 
+		{ "GSSAPI Segments", "gss-api.segment.segments", FT_NONE, BASE_NONE, 
 		  NULL, 0x0, "GSSAPI Segments", HFILL }},
 	{ &hf_gssapi_segment_overlap,
-		{ "Fragment overlap",	"gssapi.segment.overlap", FT_BOOLEAN, BASE_NONE, 
+		{ "Fragment overlap",	"gss-api.segment.overlap", FT_BOOLEAN, BASE_NONE, 
 		   NULL, 0x0, "Fragment overlaps with other fragments", HFILL }},
 	{ &hf_gssapi_segment_overlap_conflict,
-		{ "Conflicting data in fragment overlap",	"gssapi.segment.overlap.conflict", FT_BOOLEAN, BASE_NONE, 
+		{ "Conflicting data in fragment overlap",	"gss-api.segment.overlap.conflict", FT_BOOLEAN, BASE_NONE, 
 		  NULL, 0x0, "Overlapping fragments contained conflicting data", HFILL }},
 	{ &hf_gssapi_segment_multiple_tails,
-		{ "Multiple tail fragments found",	"gssapi.segment.multipletails", FT_BOOLEAN, BASE_NONE, 
+		{ "Multiple tail fragments found",	"gss-api.segment.multipletails", FT_BOOLEAN, BASE_NONE, 
 		  NULL, 0x0, "Several tails were found when defragmenting the packet", HFILL }},
 	{ &hf_gssapi_segment_too_long_fragment,
-		{ "Fragment too long",	"gssapi.segment.toolongfragment", FT_BOOLEAN, BASE_NONE, 
+		{ "Fragment too long",	"gss-api.segment.toolongfragment", FT_BOOLEAN, BASE_NONE, 
 		  NULL, 0x0, "Fragment contained data past end of packet", HFILL }},
 	{ &hf_gssapi_segment_error,
-		{ "Defragmentation error", "gssapi.segment.error", FT_FRAMENUM, BASE_NONE, 
+		{ "Defragmentation error", "gss-api.segment.error", FT_FRAMENUM, BASE_NONE, 
 		  NULL, 0x0, "Defragmentation error due to illegal fragments", HFILL }},
 	{ &hf_gssapi_reassembled_in,
-		{ "Reassembled In", "gssapi.reassembled_in", FT_FRAMENUM, BASE_DEC, 
+		{ "Reassembled In", "gss-api.reassembled_in", FT_FRAMENUM, BASE_DEC, 
 		  NULL, 0x0, "The frame where this pdu is reassembled", HFILL }},
 
 	};
@@ -615,6 +628,7 @@ proto_reg_handoff_gssapi(void)
 	dissector_handle_t gssapi_handle;
 
 	ntlmssp_handle = find_dissector("ntlmssp");
+	spnego_krb5_wrap_handle = find_dissector("spnego-krb5-wrap");
 
 	register_dcerpc_auth_subdissector(DCE_C_AUTHN_LEVEL_CONNECT,
 					  DCE_C_RPC_AUTHN_PROTOCOL_SPNEGO,
@@ -626,6 +640,6 @@ proto_reg_handoff_gssapi(void)
 					  DCE_C_RPC_AUTHN_PROTOCOL_SPNEGO,
 					  &gssapi_auth_fns);
 
-	gssapi_handle = create_dissector_handle(dissect_gssapi,	proto_gssapi);
+	gssapi_handle = find_dissector("gssapi");
 	dissector_add_string("dns.tsig.mac", "gss.microsoft.com", gssapi_handle);
 }
