@@ -2,7 +2,7 @@
  * Routines for H.223 packet dissection
  * Copyright (c) 2004-5 MX Telecom Ltd <richardv@mxtelecom.com>
  *
- * $Id: packet-h223.c 22635 2007-08-24 13:44:59Z richardv $
+ * $Id: packet-h223.c 28356 2009-05-13 19:46:11Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -122,9 +122,8 @@ static gint ett_h223_al2 = -1;
 static gint ett_h223_al_payload = -1;
 
 /* These are the handles of our subdissectors */
-static dissector_handle_t data_handle=NULL;
-static dissector_handle_t srp_handle=NULL;
-static dissector_handle_t h245dg_handle=NULL;
+static dissector_handle_t data_handle;
+static dissector_handle_t srp_handle;
 
 static const fragment_items h223_mux_frag_items _U_ = {
 	&ett_h223_mux_fragment,
@@ -183,7 +182,7 @@ static gint circuit_chain_equal(gconstpointer v, gconstpointer w)
     gint result;
     result = ( v1->call == v2->call &&
 	       v1->vc == v2 -> vc );
-    return result;;
+    return result;
 }
 
 static guint circuit_chain_hash (gconstpointer v)
@@ -412,32 +411,32 @@ static void init_logical_channel( guint32 start_frame, h223_call_info* call_info
 /* create a brand-new h223_call_info structure */
 static h223_call_info *create_call_info( guint32 start_frame )
 {
-    h223_call_info *data;
+    h223_call_info *datax;
     h223_lc_params *vc0_params;
 
-    data = se_alloc(sizeof(h223_call_info));
+    datax = se_alloc(sizeof(h223_call_info));
 
     /* initialise the call info */
-    init_direction_data(&data -> direction_data[0]);
-    init_direction_data(&data -> direction_data[1]);
+    init_direction_data(&datax -> direction_data[0]);
+    init_direction_data(&datax -> direction_data[1]);
         
     /* FIXME shouldn't this be figured out dynamically? */
-    data -> h223_level = 2;
+    datax -> h223_level = 2;
 
     vc0_params = se_alloc(sizeof(h223_lc_params));
     vc0_params->al_type = al1Framed;
     vc0_params->al_params = NULL;
     vc0_params->segmentable = TRUE;
     vc0_params->subdissector = srp_handle;
-    init_logical_channel( start_frame, data, 0, P2P_DIR_SENT, vc0_params );
-    init_logical_channel( start_frame, data, 0, P2P_DIR_RECV, vc0_params );
-    return data;
+    init_logical_channel( start_frame, datax, 0, P2P_DIR_SENT, vc0_params );
+    init_logical_channel( start_frame, datax, 0, P2P_DIR_RECV, vc0_params );
+    return datax;
 }
 
 /* find or create call_info struct for calls over circuits (eg, IAX) */
 static h223_call_info *find_or_create_call_info_circ(packet_info * pinfo)
 {
-    h223_call_info *data;
+    h223_call_info *datax;
     circuit_t *circ = NULL;
 
     if(pinfo->ctype != CT_NONE)
@@ -445,29 +444,29 @@ static h223_call_info *find_or_create_call_info_circ(packet_info * pinfo)
     if(circ == NULL)
         return NULL;
 
-    data = (h223_call_info *)circuit_get_proto_data(circ, proto_h223);
+    datax = (h223_call_info *)circuit_get_proto_data(circ, proto_h223);
     
-    if( data == NULL ) {
-        data = create_call_info(pinfo->fd->num);
+    if( datax == NULL ) {
+        datax = create_call_info(pinfo->fd->num);
 
 #ifdef DEBUG_H223
         g_debug("%u: Created new call %p for circuit %p ctype %d, id %u",
-                pinfo->fd->num, data, circ, pinfo->ctype, pinfo->circuit_id);
+                pinfo->fd->num, datax, circ, pinfo->ctype, pinfo->circuit_id);
 #endif
-        circuit_add_proto_data(circ, proto_h223, data);
+        circuit_add_proto_data(circ, proto_h223, datax);
     }
     
     /* work out what direction we're really going in */
     if( pinfo->p2p_dir < 0 || pinfo->p2p_dir > 1)
         pinfo->p2p_dir = P2P_DIR_SENT;
     
-    return data;
+    return datax;
 }
 
 /* find or create call_info struct for calls over conversations (eg, RTP) */
 static h223_call_info *find_or_create_call_info_conv(packet_info * pinfo)
 {
-    h223_call_info *data;
+    h223_call_info *datax;
     conversation_t *conv;
 
     /* assume we're running atop TCP or RTP; use the conversation support */
@@ -480,9 +479,9 @@ static h223_call_info *find_or_create_call_info_conv(packet_info * pinfo)
      * we can't find one */
     DISSECTOR_ASSERT(conv);
 
-    data = (h223_call_info *)conversation_get_proto_data(conv, proto_h223);
+    datax = (h223_call_info *)conversation_get_proto_data(conv, proto_h223);
 
-    if(data == NULL && pinfo->ptype == PT_UDP ) {
+    if(datax == NULL && pinfo->ptype == PT_UDP ) {
         conversation_t *conv2;
         
         /* RTP tracks the two sides of the conversation totally separately;
@@ -495,60 +494,60 @@ static h223_call_info *find_or_create_call_info_conv(packet_info * pinfo)
                                   pinfo->ptype,
                                   pinfo->destport,pinfo->srcport, 0 );
         if(conv2 != NULL)
-            data = (h223_call_info *)conversation_get_proto_data(conv2, proto_h223);
+            datax = (h223_call_info *)conversation_get_proto_data(conv2, proto_h223);
 
-        if(data != NULL) {
+        if(datax != NULL) {
 #ifdef DEBUG_H223
             g_debug("%u: Identified conv %p as reverse of conv %p with call %p and type=%u src=%u.%u.%u.%u:%u dst=%u.%u.%u.%u:%u",
-                    pinfo->fd->num, conv, conv2, data, pinfo->ptype,
+                    pinfo->fd->num, conv, conv2, datax, pinfo->ptype,
                     pinfo->dst.data[0], pinfo->dst.data[1], pinfo->dst.data[2], pinfo->dst.data[3],
                     pinfo->destport,
                     pinfo->src.data[0], pinfo->src.data[1], pinfo->src.data[2], pinfo->src.data[3],
                     pinfo->srcport);
 #endif
-            conversation_add_proto_data(conv, proto_h223, data);
+            conversation_add_proto_data(conv, proto_h223, datax);
         }
     }
 
     /* we still haven't found any call data - create a new one for this
      * conversation */
-    if(data == NULL) {
-        data = create_call_info(pinfo->fd->num);
+    if(datax == NULL) {
+        datax = create_call_info(pinfo->fd->num);
 
 #ifdef DEBUG_H223
         g_debug("%u: Created new call %p for conv %p type=%u src=%u.%u.%u.%u:%u dst=%u.%u.%u.%u:%u",
-                pinfo->fd->num, data, conv, pinfo->ptype,
+                pinfo->fd->num, datax, conv, pinfo->ptype,
                 pinfo->src.data[0], pinfo->src.data[1], pinfo->src.data[2], pinfo->src.data[3],
                 pinfo->srcport,
                 pinfo->dst.data[0], pinfo->dst.data[1], pinfo->dst.data[2], pinfo->dst.data[3],
                 pinfo->destport);
 #endif
             
-        conversation_add_proto_data(conv, proto_h223, data);
+        conversation_add_proto_data(conv, proto_h223, datax);
         /* add the source details so we can distinguish directions
          * in future */
-        COPY_ADDRESS(&(data -> srcaddress), &(pinfo->src));
-        data -> srcport = pinfo->srcport;
+        COPY_ADDRESS(&(datax -> srcaddress), &(pinfo->src));
+        datax -> srcport = pinfo->srcport;
     }
 
     /* work out what direction we're really going in */
-    if( ADDRESSES_EQUAL( &(pinfo->src), &(data->srcaddress))
-        && pinfo->srcport == data->srcport )
+    if( ADDRESSES_EQUAL( &(pinfo->src), &(datax->srcaddress))
+        && pinfo->srcport == datax->srcport )
         pinfo->p2p_dir = P2P_DIR_SENT;
     else 
         pinfo->p2p_dir = P2P_DIR_RECV;
 
-    return data;
+    return datax;
 }
 
 static h223_call_info *find_or_create_call_info ( packet_info * pinfo )
 {
-    h223_call_info *data;
+    h223_call_info *datax;
 
-    data = find_or_create_call_info_circ(pinfo);
-    if(data == NULL)
-        data = find_or_create_call_info_conv(pinfo);
-    return data;
+    datax = find_or_create_call_info_circ(pinfo);
+    if(datax == NULL)
+        datax = find_or_create_call_info_conv(pinfo);
+    return datax;
 }
 
 /* called from the h245 dissector to handle a MultiplexEntrySend message */
@@ -604,12 +603,12 @@ const guint8 crctable[256] = {
 
 static guint8 h223_al2_crc8bit( tvbuff_t *tvb ) {
     guint32 len = tvb_reported_length(tvb) - 1;
-    const guint8* data = tvb_get_ptr( tvb, 0, len );
+    const guint8* datax = tvb_get_ptr( tvb, 0, len );
     unsigned char crc = 0;
     guint32 pos = 0;
     DISSECTOR_ASSERT(tvb_reported_length(tvb) >= 1);
     while ( len-- )
-        crc = crctable[crc^data[pos++]];
+        crc = crctable[crc^datax[pos++]];
     return crc;
 }
 
@@ -620,7 +619,7 @@ static void dissect_mux_al_pdu( tvbuff_t *tvb,
                                 h223_lc_params* lc_params )
 {
     proto_tree *al_tree = NULL;
-    proto_item *al_item;
+    proto_item *al_item, *hidden_item;
     proto_tree *al_subtree;
     proto_item *al_subitem = NULL;
     proto_item *tmp_item;
@@ -639,8 +638,10 @@ static void dissect_mux_al_pdu( tvbuff_t *tvb,
         al_item = proto_tree_add_none_format(vc_tree, hf_h223_al1, tvb, 0, -1, "H.223 AL1 (%sframed)",
                 (lc_params->al_type==al1Framed)?"":"not ");
         al_tree = proto_item_add_subtree (al_item, ett_h223_al1);
-        if(lc_params->al_type == al1Framed)
-            proto_tree_add_boolean_hidden(al_tree, hf_h223_al1_framed, tvb, 0, 1, TRUE );
+        if(lc_params->al_type == al1Framed) {
+            hidden_item = proto_tree_add_boolean(al_tree, hf_h223_al1_framed, tvb, 0, 1, TRUE );
+            PROTO_ITEM_SET_HIDDEN(hidden_item);
+        }
         next_tvb = tvb;
         al_subitem = proto_tree_add_item(al_tree, hf_h223_al_payload, next_tvb, 0, -1, FALSE);
         break;
@@ -744,7 +745,7 @@ static void dissect_mux_sdu_fragment(tvbuff_t *volatile next_tvb,
 
         if( subcircuit == NULL ) {
             g_message( "Frame %d: Subcircuit id %d not found for call %p VC %d", pinfo->fd->num,
-                       pinfo->circuit_id, call_info, vc );
+                       pinfo->circuit_id, (void *)call_info, vc );
         } else {
             vc_info = circuit_get_proto_data(subcircuit, proto_h223);
             if( vc_info != NULL ) {
@@ -1142,7 +1143,6 @@ static gboolean h223_mux_check_hdlc(int h223_level, guint32 nbytes, guint32 tail
             /* level 0 isn't byte-aligned, so is a complete pain to implement */
             DISSECTOR_ASSERT_NOT_REACHED();
             return FALSE;
-            break;
 
         case 1:
             masked = tail_buf & 0xffff;
@@ -1331,23 +1331,21 @@ static void dissect_h223 (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree
 static void dissect_h223_bitswapped (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 {
     tvbuff_t *reversed_tvb;
-    guint8 *data;
+    guint8 *datax;
     guint len;
     guint i;
 
     len = tvb_length(tvb);
-    data = g_malloc(len);
+    datax = g_malloc(len);
     for( i=0; i<len; i++)
-        data[i]=BIT_SWAP(tvb_get_guint8(tvb,i));
+        datax[i]=BIT_SWAP(tvb_get_guint8(tvb,i));
 
-    reversed_tvb = tvb_new_real_data(data,len,tvb_reported_length(tvb));
-	    
     /*
      * Add the reversed tvbuff to the list of tvbuffs to which
      * the tvbuff we were handed refers, so it'll get
      * cleaned up when that tvbuff is cleaned up.
      */
-    tvb_set_child_real_data_tvbuff(tvb, reversed_tvb);
+    reversed_tvb = tvb_new_child_real_data(tvb, datax,len,tvb_reported_length(tvb));
 
     /* Add a freer */
     tvb_set_free_cb(reversed_tvb, g_free);
@@ -1548,7 +1546,6 @@ void proto_register_h223 (void)
 	&ett_h223_al_payload
     };
 
-    if (proto_h223 == -1) { /* execute protocol initialization only once */
     proto_h223 =
 	proto_register_protocol ("ITU-T Recommendation H.223", "H.223", "h223");
     proto_h223_bitswapped =
@@ -1562,7 +1559,6 @@ void proto_register_h223 (void)
     /* register our init routine to be called at the start of a capture,
        to clear out our hash tables etc */
     register_init_routine(&h223_init_protocol);
-    }
 
     h245_set_h223_set_mc_handle( &h223_set_mc );
     h245_set_h223_add_lc_handle( &h223_add_lc );
@@ -1573,7 +1569,6 @@ void proto_reg_handoff_h223(void)
     dissector_handle_t h223_bitswapped = find_dissector("h223_bitswapped");
     dissector_handle_t h223 = find_dissector("h223");
     data_handle = find_dissector("data");
-    h245dg_handle = find_dissector("h245dg");
     srp_handle = find_dissector("srp");
 
     dissector_add_handle("tcp.port", h223);
