@@ -2,9 +2,9 @@
  *  packet-h248-annex_c.c
  *  H.248 annex C
  *
- *  (c) 2006, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
+ *  (c) 2006, Luis E. Garcia Ontanon <luis@ontanon.org>
  *
- * $Id: packet-h248_annex_c.c 23252 2007-10-23 05:50:00Z etxrab $
+ * $Id: packet-h248_annex_c.c 28317 2009-05-08 20:35:57Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -175,7 +175,7 @@ static gint ett_annexc = -1;
 static gint ett_vpvc = -1;
 static gint ett_codec = -1;
 
-static value_string h248_annexc_package_properties_vals[] = {
+static const value_string h248_annexc_package_properties_vals[] = {
 	{ 0x1001, "media" },
 	{ 0x1002, "transmission mode" },
 	{ 0x1003, "num_of_channels" },
@@ -296,7 +296,7 @@ static value_string h248_annexc_package_properties_vals[] = {
 	{ 0xB007, "SDP_P (phone number)" },
 	{ 0xB008, "SDP_C (connection)" },
 	{ 0xB009, "SDP_B (bandwidth info)" },
-	{ 0xB00A, "SDP_Z (TZ adjustement)" },
+	{ 0xB00A, "SDP_Z (TZ adjustment)" },
 	{ 0xB00B, "SDP_K (encryption key)" },
 	{ 0xB00C, "SDP_A (Session attributes)" },
 	{ 0xB00D, "SDP_T (Active Session Time)" },
@@ -376,8 +376,8 @@ static const value_string h248_pkg_annexc_uppc_values[] = {
 };
 
 static const value_string h248_pkg_annexc_syncasync_values[] = {
-	{0, "Syncronous Data"},
-	{1, "Asyncronous Data"},
+	{0, "Synchronous Data"},
+	{1, "Asynchronous Data"},
     {0,NULL}
 };
 
@@ -445,7 +445,7 @@ static const value_string h248_pkg_annexc_nicrx_values[] = {
 };
 
 
-static const value_string h248_pkg_annexc_flowconttx_values[] _U_ = {
+static const value_string h248_pkg_annexc_flowconttx_values[] = {
 	{0,"Not Required"},
 	{1,"Required"},
     {0,NULL}
@@ -482,8 +482,8 @@ static const value_string h248_pkg_annexc_llidnegot_values[] = {
 };
 
 static const value_string h248_pkg_annexc_assign_values[] = {
-	{0,"Originatior is default asignee"},
-	{1,"Originatior is asignor only"},
+	{0,"Originator is default assignee"},
+	{1,"Originator is assignor only"},
     {0,NULL}
 };
 
@@ -608,10 +608,10 @@ static const value_string h248_pkg_annexc_addlayer3prot_values[] = {
     {0,NULL}
 };
 
-static const value_string h248_pkg_annexc_nci_satelite_values[] _U_ = {
-	{0x0,"no satelite circuit"},
+static const value_string h248_pkg_annexc_nci_satellite_values[] _U_ = {
+	{0x0,"no satellite circuit"},
 	{0x1,"one satellite circuit"},
-	{0x2,"two satelite circiuts"},
+	{0x2,"two satellite circuits"},
 	{0x3,"spare"},
     {0,NULL}
 };
@@ -660,7 +660,7 @@ static const value_string h248_pkg_annexc_porttype_values[] = {
 
 static const value_string h248_pkg_annexc_aal1st_values[] = {
 	{0x0,"null"},
-	{0x1,"voiceband signall transport on 64kbps"},
+	{0x1,"voiceband signal transport on 64kbps"},
 	{0x2,"circuit transport"},
 	{0x4,"high quality audio signal transport"},
 	{0x5,"video signal transport"},
@@ -742,7 +742,7 @@ static void dissect_h248_annexc_acodec(proto_tree* tree,
 	asn1_ctx_init(&asn1_ctx, ASN1_ENC_BER, TRUE, pinfo);
 	dissect_ber_octet_string(implicit_p ? *((gboolean*)implicit_p) : FALSE, &asn1_ctx, tree, tvb, 0, hfid, &new_tvb);
 	
-	tree = proto_item_add_subtree(get_ber_last_created_item(),ett_codec);
+	tree = proto_item_add_subtree(asn1_ctx.created_item,ett_codec);
 	len = tvb_length(new_tvb);
 	dissect_codec_mode(tree,new_tvb,0,len);
 }
@@ -1009,6 +1009,10 @@ void proto_register_h248_annex_c(void) {
 		{ "Encrypttype", "h248.pkg.annexc.encrypt_type",
 			FT_BYTES, BASE_NONE, NULL, 0,
 			"Encryption Type", HFILL }},
+		{ &hf_h248_pkg_annexc_encrypt_key,
+		{ "Encrypt Key", "h248.pkg.annexc.encrypt_key",
+			FT_UINT32, BASE_DEC, NULL, 0,
+			"Encryption Key", HFILL }},
 		{ &hf_h248_pkg_annexc_gain,
 		{ "Gain", "h248.pkg.annexc.gain",
 			FT_UINT32, BASE_DEC, NULL, 0,
@@ -1124,7 +1128,7 @@ void proto_register_h248_annex_c(void) {
 		{ &hf_h248_pkg_annexc_c2pcdv,
 		{ "C2PCDV", "h248.pkg.annexc.c2pcdv",
 			FT_UINT24, BASE_DEC, NULL, 0,
-			"Cummulative 2 point CDV", HFILL }},
+			"Cumulative 2 point CDV", HFILL }},
 		{ &hf_h248_pkg_annexc_appcdv,
 		{ "APPCDV", "h248.pkg.annexc.appcdv",
 			FT_UINT24, BASE_DEC, NULL, 0,
@@ -1132,7 +1136,7 @@ void proto_register_h248_annex_c(void) {
 		{ &hf_h248_pkg_annexc_cppcdv,
 		{ "CPPCDV", "h248.pkg.annexc.cppcdv",
 			FT_UINT24, BASE_DEC, NULL, 0,
-			"Cummulative Point to Point CDV", HFILL }},
+			"Cumulative Point to Point CDV", HFILL }},
 		{ &hf_h248_pkg_annexc_aclr,
 		{ "ACLR", "h248.pkg.annexc.aclr",
 			FT_UINT8, BASE_DEC, NULL, 0,
@@ -1145,7 +1149,7 @@ void proto_register_h248_annex_c(void) {
 		{ &hf_h248_pkg_annexc_ceetd,
 		{ "CEETD", "h248.pkg.annexc.ceetd",
 			FT_UINT16, BASE_DEC, NULL, 0,
-			"Cummulative End-to-End Transit Delay (Q.2965.2 ATMF UNI 4.0)", HFILL }},
+			"Cumulative End-to-End Transit Delay (Q.2965.2 ATMF UNI 4.0)", HFILL }},
 		{ &hf_h248_pkg_annexc_QosClass,
 		{ "QosClass", "h248.pkg.annexc.qosclass",
 			FT_UINT16, BASE_DEC, VALS(h248_pkg_annexc_QosClass_values), 0,
@@ -1199,12 +1203,12 @@ void proto_register_h248_annex_c(void) {
 			"Served User Transport", HFILL }},
 		{ &hf_h248_pkg_annexc_tci,
 		{ "TCI", "h248.pkg.annexc.tci",
-			FT_BOOLEAN, BASE_DEC, NULL, 0,
+			FT_BOOLEAN, BASE_NONE, NULL, 0,
 			"Test Connection Indicator", HFILL }},
 		{ &hf_h248_pkg_annexc_timer_cu,
 		{ "Timer CU", "h248.pkg.annexc.timer_cu",
 			FT_UINT32, BASE_DEC, NULL, 0,
-			"Milliseconds to hold the  patially filled cell before sending", HFILL }},
+			"Milliseconds to hold the  partially filled cell before sending", HFILL }},
 		{ &hf_h248_pkg_annexc_maxcpssdu,
 		{ "Max CPS SDU", "h248.pkg.annexc.maxcpssdu",
 			FT_UINT8, BASE_DEC, NULL, 0,
@@ -1221,7 +1225,7 @@ void proto_register_h248_annex_c(void) {
 		{ &hf_h248_pkg_annexc_scri,
 		{ "SCRI", "h248.pkg.annexc.scri",
 			FT_UINT8, BASE_DEC, VALS(h248_pkg_annexc_scri_values), 0,
-			"Source Clock frequency Recovery method", HFILL }},
+			"Source Clock frequency Recovery Method", HFILL }},
 		{ &hf_h248_pkg_annexc_ecm,
 		{ "ECM", "h248.pkg.annexc.ecm",
 			FT_UINT8, BASE_DEC, VALS(h248_pkg_annexc_ecm_values), 0,
@@ -1267,7 +1271,7 @@ void proto_register_h248_annex_c(void) {
 		{ &hf_h248_pkg_annexc_syncasync,
 		{ "SyncAsync", "h248.pkg.annexc.syncasync",
 			FT_UINT8, BASE_DEC, VALS(h248_pkg_annexc_syncasync_values), 0x80,
-			"Syncronous/Asyncronous", HFILL }},
+			"Synchronous/Asynchronous", HFILL }},
 		{ &hf_h248_pkg_annexc_negotiation,
 		{ "UPPC", "h248.pkg.annexc.negotiation",
 			FT_UINT8, BASE_DEC, VALS(h248_pkg_annexc_negotiation_values), 0x40,
@@ -1280,15 +1284,19 @@ void proto_register_h248_annex_c(void) {
 		{ &hf_h248_pkg_annexc_intrate,
 		{ "UPPC", "h248.pkg.annexc.intrate",
 			FT_UINT8, BASE_HEX, VALS(h248_pkg_annexc_intrate_values), 0xc0,
-			"Intermediare Rate", HFILL }},
+			"Intermediate Rate", HFILL }},
 		{ &hf_h248_pkg_annexc_nictx,
 		{ "nictx", "h248.pkg.annexc.nictx",
 			FT_UINT8, BASE_HEX, VALS(h248_pkg_annexc_nictx_values), 0xc0,
-			"Intermediare Network indipendent clock in transmission", HFILL }},
+			"Network independent clock on transmission", HFILL }},
 		{ &hf_h248_pkg_annexc_nicrx,
 		{ "nicrx", "h248.pkg.annexc.nicrx",
 			FT_UINT8, BASE_HEX, VALS(h248_pkg_annexc_nicrx_values), 0xc0,
-			"Intermediare Rate", HFILL }},
+			"Network independent clock on reception", HFILL }},
+		{ &hf_h248_pkg_annexc_flowconttx,
+		{ "flowconttx", "h248.pkg.annexc.flowconttx",
+			FT_UINT8, BASE_HEX, VALS(h248_pkg_annexc_flowconttx_values), 0xc0,
+			"Flow Control on Transmission", HFILL }},
 		{ &hf_h248_pkg_annexc_flowcontrx,
 		{ "flowcontrx", "h248.pkg.annexc.flowcontrx",
 			FT_UINT8, BASE_HEX, VALS(h248_pkg_annexc_flowcontrx_values), 0xc0,
@@ -1308,12 +1316,12 @@ void proto_register_h248_annex_c(void) {
 		{ &hf_h248_pkg_annexc_llidnegot,
 		{ "llidnegot", "h248.pkg.annexc.llidnegot",
 			FT_UINT8, BASE_HEX, VALS(h248_pkg_annexc_llidnegot_values), 0xc0,
-			"Intermediare Rate", HFILL }},
+			"Logical Link Identifier negotiation", HFILL }},
 			
 		{ &hf_h248_pkg_annexc_assign,
 		{ "llidnegot", "h248.pkg.annexc.assign",
 			FT_UINT8, BASE_HEX, VALS(h248_pkg_annexc_assign_values), 0xc0,
-			"Assignor/Asignee", HFILL }},
+			"Assignor/Assignee", HFILL }},
 		{ &hf_h248_pkg_annexc_inbandneg,
 		{ "inbandneg", "h248.pkg.annexc.inbandneg",
 			FT_UINT8, BASE_HEX, VALS(h248_pkg_annexc_inbandneg_values), 0xc0,
@@ -1325,7 +1333,7 @@ void proto_register_h248_annex_c(void) {
 		{ &hf_h248_pkg_annexc_databits,
 		{ "databits", "h248.pkg.annexc.databits",
 			FT_UINT8, BASE_HEX, VALS(h248_pkg_annexc_databits_values), 0xc0,
-			"Number of stop bits", HFILL }},
+			"Number of data bits", HFILL }},
 		{ &hf_h248_pkg_annexc_parity,
 		{ "parity", "h248.pkg.annexc.parity",
 			FT_UINT8, BASE_HEX, VALS(h248_pkg_annexc_parity_values), 0xe0,
@@ -1355,6 +1363,10 @@ void proto_register_h248_annex_c(void) {
 		{ "Dialed Number", "h248.pkg.annexc.dialedn",
 			FT_BYTES, BASE_HEX, NULL, 0,
 			"Dialed Number", HFILL }},
+		{ &hf_h248_pkg_annexc_dialingn,
+		{ "Dialing Number", "h248.pkg.annexc.dialingn",
+			FT_BYTES, BASE_HEX, NULL, 0,
+			"Dialing Number", HFILL }},
 		{ &hf_h248_pkg_annexc_echoci,
 		{ "ECHOCI", "h248.pkg.annexc.echoci",
 			FT_BYTES, BASE_HEX, NULL, 0,
@@ -1397,6 +1409,10 @@ void proto_register_h248_annex_c(void) {
 		{ "sdp_s", "h248.pkg.annexc.sdp_s",
 			FT_STRING, BASE_HEX, NULL, 0,
 			"SDP S", HFILL }},
+		{ &hf_h248_pkg_annexc_sdp_i,
+		{ "sdp_i", "h248.pkg.annexc.sdp_i",
+			FT_STRING, BASE_HEX, NULL, 0,
+			"SDP I", HFILL }},
 		{ &hf_h248_pkg_annexc_sdp_u,
 		{ "sdp_u", "h248.pkg.annexc.sdp_u",
 			FT_STRING, BASE_HEX, NULL, 0,
