@@ -2,7 +2,7 @@
  * Routines for H.264 dissection
  * Copyright 2007 - 2009, Anders Broman <anders.broman[at]ericsson.com>
  *
- * $Id: packet-h264.c 28019 2009-04-09 12:41:40Z wmeier $
+ * $Id: packet-h264.c 33973 2010-08-27 23:40:31Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -514,7 +514,11 @@ dissect_h264_exp_golomb_code(proto_tree *tree, int hf_index, tvbuff_t *tvb, gint
 	codenum = 1;
 	codenum = codenum << leading_zero_bits;
 	mask = codenum>>1;
-	if (leading_zero_bits > 8)
+	if (leading_zero_bits > 32)
+		DISSECTOR_ASSERT_NOT_REACHED();
+	else if (leading_zero_bits > 16)
+		value = tvb_get_bits32(tvb, bit_offset,leading_zero_bits, FALSE);
+	else if (leading_zero_bits > 8)
 		value = tvb_get_bits16(tvb, bit_offset,leading_zero_bits, FALSE);
 	else
 		value = tvb_get_bits8(tvb, bit_offset,leading_zero_bits );
