@@ -2,7 +2,7 @@
  * Routines for IEC-60870-5-104 (iec104) Protocol disassembly
  *
  *
- * $Id: packet-iec104.c 28052 2009-04-14 18:31:02Z wmeier $
+ * $Id: packet-iec104.c 29106 2009-07-15 21:37:33Z gerald $
  *
  * Copyright (c) 2008 by Joan Ramio <joan@ramio.cat>
  * Joan is a masculine catalan name. Search the Internet for Joan Pujol (alias Garbo).
@@ -76,6 +76,8 @@ static int proto_iec104asdu = -1;
 /* Protocol constants */
 #define APCI_START	0x68
 #define APCI_LEN	6
+#define APCI_START_LEN	2
+#define APCI_DATA_LEN	(APCI_LEN- APCI_START_LEN)
 #define APDU_MIN_LEN	4
 #define APDU_MAX_LEN	253
 
@@ -600,7 +602,7 @@ static void dissect_iec104apci(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tr
 	if (check_col(pinfo->cinfo, COL_INFO))  {
 		col_add_str(pinfo->cinfo, COL_INFO, res->str);
 		if(apcih->Type == I_TYPE  &&  Brossa != TcpLen)   {
-			call_dissector(iec104asdu_handle, tvb_new_subset(tvb, Off+ APCI_LEN, -1, apcih->ApduLen- APCI_LEN), pinfo, tree);
+			call_dissector(iec104asdu_handle, tvb_new_subset(tvb, Off+ APCI_LEN, -1, apcih->ApduLen- APCI_DATA_LEN), pinfo, tree);
 		} else {
 			col_set_fence(pinfo->cinfo, COL_INFO);
 		}
@@ -618,7 +620,9 @@ static void dissect_iec104apci(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tr
 	if(Brossa == TcpLen)   return;
 
 	/* Don't call ASDU dissector if it was called before */
-	if(apcih->Type == I_TYPE  &&  (!check_col(pinfo->cinfo, COL_INFO)))   call_dissector(iec104asdu_handle, tvb_new_subset(tvb, Off+ APCI_LEN, -1, apcih->ApduLen- APCI_LEN), pinfo, tree);
+	if(apcih->Type == I_TYPE  &&  (!check_col(pinfo->cinfo, COL_INFO))){
+		call_dissector(iec104asdu_handle, tvb_new_subset(tvb, Off+ APCI_LEN, -1, apcih->ApduLen- APCI_DATA_LEN), pinfo, tree);
+	}
 
 	/* 'Packet Details': TREE */
 	trHead = proto_item_add_subtree(it104, ett_apci);
@@ -639,7 +643,9 @@ static void dissect_iec104apci(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tr
 
 static void dissect_iec104reas(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-	/* 5th parameter = 6 = minimum bytes received to calculate the length. (Not 2 in order to find more APCIs in case of 'noisy' bytes between the APCIs) */
+	/* 5th parameter = 6 = minimum bytes received to calculate the length. 
+	 * (Not 2 in order to find more APCIs in case of 'noisy' bytes between the APCIs)
+	 */
 	tcp_dissect_pdus(tvb, pinfo, tree, TRUE, APCI_LEN,
 			get_iec104apdu_len, dissect_iec104apci);
 }
@@ -671,7 +677,7 @@ proto_register_iec104apci(void)
 	};
 
 	proto_iec104apci = proto_register_protocol(
-		"IEC 60870-5-104,Apci",
+		"IEC 60870-5-104-Apci",
 		"104apci",
 		"104apci"
 		);
@@ -732,7 +738,7 @@ proto_register_iec104asdu(void)
 	};
 
 	proto_iec104asdu = proto_register_protocol(
-		"IEC 60870-5-104,Asdu",
+		"IEC 60870-5-104-Asdu",
 		"104asdu",
 		"104asdu"
 		);
@@ -749,7 +755,7 @@ proto_reg_handoff_iec104(void)
 {
 	dissector_handle_t iec104apci_handle;
 
-        iec104apci_handle = create_dissector_handle(dissect_iec104reas, proto_iec104apci);
+	iec104apci_handle = create_dissector_handle(dissect_iec104reas, proto_iec104apci);
 	iec104asdu_handle = create_dissector_handle(dissect_iec104asdu, proto_iec104asdu);
 
 	dissector_add("tcp.port", iec104port, iec104apci_handle);
