@@ -4,7 +4,7 @@
  * 2007 Thomas Morin
  * <See AUTHORS for emails>
  *
- * $Id: packet-igmp.c 27050 2008-12-18 19:08:49Z wmeier $
+ * $Id: packet-igmp.c 33115 2010-06-06 22:13:16Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -314,16 +314,20 @@ static const value_string mtrace_fwd_code_vals[] = {
 };
 
 #define PRINT_IGMP_VERSION(version) 					\
+	do {								\
+		proto_item *ti;						\
 	if (check_col(pinfo->cinfo, COL_INFO)) {			\
 		col_add_fstr(pinfo->cinfo, COL_INFO,			\
 			"V%d %s",version,val_to_str(type, commands, 	\
 				"Unknown Type:0x%02x"));		\
 	}								\
 	/* version of IGMP protocol */					\
-	proto_tree_add_uint(tree, hf_version, tvb, 0, 0, version);	\
+		ti = proto_tree_add_uint(tree, hf_version, tvb, 0, 0, version);	\
+		PROTO_ITEM_SET_GENERATED(ti);				\
 	/* type of command */						\
 	proto_tree_add_uint(tree, hf_type, tvb, offset, 1, type);	\
-	offset += 1;
+		offset += 1;						\
+	} while (0);
 
 void igmp_checksum(proto_tree *tree, tvbuff_t *tvb, int hf_index,
     int hf_index_bad, packet_info *pinfo, guint len)
