@@ -3,7 +3,7 @@
  * Routines for JFIF image/jpeg media dissection
  * Copyright 2004, Olivier Biot.
  *
- * $Id: packet-image-jfif.c 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-image-jfif.c 26308 2008-09-30 14:49:44Z wmeier $
  *
  * Refer to the AUTHORS file or the AUTHORS section in the man page
  * for contacting the author(s) of this file.
@@ -218,6 +218,7 @@ static const value_string vals_marker[] = {
 	{ MARKER_JPG11,	"Reserved for JPEG extensions - 11" },
 	{ MARKER_JPG12,	"Reserved for JPEG extensions - 12" },
 	{ MARKER_JPG13,	"Reserved for JPEG extensions - 13" },
+	{ MARKER_COM,	"Comment" },
 	{ 0x00, NULL }
 };
 
@@ -669,8 +670,8 @@ process_app1_segment(proto_tree *tree, tvbuff_t *tvb, guint32 len,
 			    "Skipped data between end of TIFF header and start of IFD (%u bytes)",
 			    val_32 + tiff_start - offset);
 		}
-		offset = val_32 + tiff_start;
 		for (;;) {
+			offset = val_32 + tiff_start;
 			/*
 			 * Process the IFD
 			 */
@@ -1213,7 +1214,7 @@ proto_reg_handoff_jfif(void)
 {
 	dissector_handle_t jfif_handle;
 
-	jfif_handle = create_dissector_handle(dissect_jfif, proto_jfif);
+	jfif_handle = find_dissector("image-jfif");
 
 	/* Register the JPEG media type */
 	dissector_add_string("media_type", "image/jfif", jfif_handle);
