@@ -2,7 +2,7 @@
  * Routines for IPMI dissection
  * Copyright 2002-2008, Alexey Neyman, Pigeon Point Systems <avn@pigeonpoint.com>
  *
- * $Id: packet-ipmi.c 31271 2009-12-15 01:27:47Z gerald $
+ * $Id: packet-ipmi.c 33653 2010-07-28 20:52:30Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1129,8 +1129,8 @@ ipmi_do_dissect(tvbuff_t *tvb, proto_tree *ipmi_tree, ipmi_dissect_format_t *dfm
 	struct ipmi_saved_data *saved_saved_data;
 	struct ipmi_header hdr, *saved_hdr;
 	guint8 hdr_crc, hdr_exp_crc, data_crc, data_exp_crc;
-	guint8 is_resp, is_broadcast = 0, i, tmp;
-	guint len, siglen, hdrlen, offs, data_chk_offs;
+	guint8 is_resp, is_broadcast = 0, tmp;
+	guint i, len, siglen, hdrlen, offs, data_chk_offs;
 	const char *bcast, *ndesc, *cdesc, *ccdesc;
 
 	if (dfmt->flags & IPMI_D_NONE) {
