@@ -4,7 +4,7 @@
  * Copyright 2008, Yves Geissbuehler <yves.geissbuehler@gmx.net>
  * Copyright 2008, Philip Frey <frey.philip@gmail.com>
  *
- * $Id: packet-iwarp-mpa.c 26281 2008-09-26 22:07:45Z wmeier $
+ * $Id: packet-iwarp-mpa.c 28356 2009-05-13 19:46:11Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -344,9 +344,8 @@ remove_markers(tvbuff_t *tvb, packet_info *pinfo, guint32 marker_offset,
 		raw_data_ptr += cur_copy + MPA_MARKER_LEN;
 		cur_copy = MIN(MPA_MARKER_INTERVAL, (mfree_buff_length - tot_copy));
 	}
-	mfree_tvb = tvb_new_real_data(mfree_buff, mfree_buff_length,
+	mfree_tvb = tvb_new_child_real_data(tvb, mfree_buff, mfree_buff_length,
 			mfree_buff_length);
-	tvb_set_child_real_data_tvbuff(tvb, mfree_tvb);
 	add_new_data_source(pinfo, mfree_tvb, "FPDU without Markers");
 
 	return mfree_tvb;
