@@ -1,6 +1,6 @@
 /* packet-kerberos.h
  *
- * $Id: packet-kerberos.h 21753 2007-05-13 20:58:29Z etxrab $
+ * $Id: packet-kerberos.h 31539 2010-01-16 01:02:51Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -77,12 +77,14 @@ extern enc_key_t *enc_key_list;
 guint8 *
 decrypt_krb5_data(proto_tree *tree, packet_info *pinfo,
 			int usage,
-			int length,
-			const guint8 *cryptotext,
-			int keytype);
+			tvbuff_t *crypototvb,
+			int keytype,
+			int *datalen);
 
 #endif /* HAVE_HEIMDAL_KERBEROS || HAVE_MIT_KERBEROS */
 
+extern gboolean krb_decrypt;
+
 #endif /* HAVE_KERBEROS */
 
 #endif /* __PACKET_KERBEROS_H */
