@@ -2,7 +2,7 @@
  * Routines for kingfisher packet dissection
  * By Rob Casey 2007
  *
- * $Id: packet-kingfisher.c 21878 2007-05-22 02:55:14Z sahlberg $
+ * $Id: packet-kingfisher.c 29704 2009-09-04 22:17:02Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -260,18 +260,18 @@ dissect_kingfisher(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
 
 
     kfp->version = (kfp->function & 0x80)?3:2;
-    kfp->system = tvb_get_guint8(tvb, 0);
-    kfp->message = tvb_get_guint8(tvb, 5);
+    kfp->system = tvb_get_guint8( tvb, 0 );
+    kfp->message = tvb_get_guint8( tvb, 5 );
 
+    kfp->target = tvb_get_guint8( tvb, 1 );
+    kfp->from = tvb_get_guint8( tvb, 3 );
+    kfp->via = tvb_get_guint8( tvb, 4 );
 
-    if(kfp->version == 2){
-        kfp->target = tvb_get_guint8(tvb, 1);
-        kfp->from = tvb_get_guint8(tvb, 3);
-        kfp->via = tvb_get_guint8(tvb, 4);
-    } else {
-        kfp->target |= (tvb_get_guint8(tvb, 7) << 8);
-        kfp->from   |= (tvb_get_guint8(tvb, 8) << 8);
-        kfp->via    |= (tvb_get_guint8(tvb, 9) << 8);
+    if( kfp->version == 3 )
+    {
+        kfp->target |= ( tvb_get_guint8( tvb, 7 ) << 8 );
+        kfp->from   |= ( tvb_get_guint8( tvb, 8 ) << 8 );
+        kfp->via    |= ( tvb_get_guint8( tvb, 9 ) << 8 );
     }
 
 
