@@ -2,7 +2,7 @@
  * Routines for kismet packet dissection
  * Copyright 2006, Krzysztof Burghardt <krzysztof@burghardt.pl>
  *
- * $Id: packet-kismet.c 25465 2008-06-17 17:10:51Z gerald $
+ * $Id: packet-kismet.c 27968 2009-04-06 00:08:46Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -49,7 +49,6 @@ static dissector_handle_t data_handle;
 #define TCP_PORT_KISMET	2501
 
 static guint global_kismet_tcp_port = TCP_PORT_KISMET;
-static guint tcp_port = 0;
 
 static gboolean response_is_continuation(const guchar * data);
 void proto_reg_handoff_kismet(void);
@@ -183,48 +182,48 @@ dissect_kismet(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 					 * two fields left undocumented: {???} {?ExtendedVersion?}
 					 */
 					if (!strncmp(reqresp, "*KISMET", 7)) {
-						offset += next_token - line;
-						linelen -= next_token - line;
+						offset += (gint) (next_token - line);
+						linelen -= (int) (next_token - line);
 						line = next_token;
 						tokenlen = get_token_len(line, line + linelen, &next_token);
 						proto_tree_add_text(reqresp_tree, tvb, offset,
 							tokenlen, "Kismet version: %s",
 							format_text(line, tokenlen));
 
-						offset += next_token - line;
-						linelen -= next_token - line;
+						offset += (gint) (next_token - line);
+						linelen -= (int) (next_token - line);
 						line = next_token;
 						tokenlen = get_token_len(line, line + linelen, &next_token);
 						proto_tree_add_text(reqresp_tree, tvb, offset,
 							tokenlen, "Start time: %s",
 							format_text(line, tokenlen));
 
-						offset += next_token - line;
-						linelen -= next_token - line;
+						offset += (gint) (next_token - line);
+						linelen -= (int) (next_token - line);
 						line = next_token;
 						tokenlen = get_token_len(line, line + linelen, &next_token);
 						proto_tree_add_text(reqresp_tree, tvb, offset,
 							tokenlen, "Server name: %s",
 							format_text(line + 1, tokenlen - 2));
 
-						offset += next_token - line;
-						linelen -= next_token - line;
+						offset += (gint) (next_token - line);
+						linelen -= (int) (next_token - line);
 						line = next_token;
 						tokenlen = get_token_len(line, line + linelen, &next_token);
 						proto_tree_add_text(reqresp_tree, tvb, offset,
 							tokenlen, "Build revision: %s",
 							format_text(line, tokenlen));
 
-						offset += next_token - line;
-						linelen -= next_token - line;
+						offset += (gint) (next_token - line);
+						linelen -= (int) (next_token - line);
 						line = next_token;
 						tokenlen = get_token_len(line, line + linelen, &next_token);
 						proto_tree_add_text(reqresp_tree, tvb, offset,
 							tokenlen, "Unknown field: %s",
 							format_text(line, tokenlen));
 
-						offset += next_token - line;
-						linelen -= next_token - line;
+						offset += (gint) (next_token - line);
+						linelen -= (int) (next_token - line);
 						line = next_token;
 						tokenlen = get_token_len(line, line + linelen, &next_token);
 						proto_tree_add_text(reqresp_tree, tvb, offset,
@@ -239,8 +238,8 @@ dissect_kismet(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 						time_t t;
 						char *ptr;
 
-						offset += next_token - line;
-						linelen -= next_token - line;
+						offset += (gint) (next_token - line);
+						linelen -= (int) (next_token - line);
 						line = next_token;
 						tokenlen = get_token_len(line, line + linelen, &next_token);
 
@@ -263,8 +262,8 @@ dissect_kismet(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 					}
 				}
 
-				offset += next_token - line;
-				linelen -= next_token - line;
+				offset += (gint) (next_token - line);
+				linelen -= (int) (next_token - line);
 				line = next_token;
 			}
 		}
@@ -323,11 +322,13 @@ proto_register_kismet(void)
 void
 proto_reg_handoff_kismet(void)
 {
-	static int kismet_prefs_initialized = FALSE;
+	static gboolean kismet_prefs_initialized = FALSE;
 	static dissector_handle_t kismet_handle;
+	static guint tcp_port;
 
 	if (!kismet_prefs_initialized) {
 		kismet_handle = new_create_dissector_handle(dissect_kismet, proto_kismet);
+		data_handle = find_dissector("data");
 		kismet_prefs_initialized = TRUE;
 	} else {
 		dissector_delete("tcp.port", tcp_port, kismet_handle);
@@ -337,5 +338,4 @@ proto_reg_handoff_kismet(void)
 	tcp_port = global_kismet_tcp_port;
 
 	dissector_add("tcp.port", global_kismet_tcp_port, kismet_handle);
-	data_handle = find_dissector("data");
 }
