@@ -9,7 +9,7 @@
  *          Laboratories, Inc., http://www.PacketCable.com/
  * www.iana.org/assignments/mgcp-localconnectionoptions
  *
- * $Id: packet-mgcp.c 27888 2009-03-29 21:20:15Z etxrab $
+ * $Id: packet-mgcp.c 30679 2009-10-23 19:17:17Z gerald $
  *
  * Copyright (c) 2000 by Ed Warnicke <hagbard@physics.rutgers.edu>
  * Copyright (c) 2004 by Thomas Anders <thomas.anders [AT] blue-cable.de>
@@ -303,8 +303,6 @@ typedef struct _mgcp_call_info_key
 	conversation_t *conversation;
 } mgcp_call_info_key;
 
-static GMemChunk *mgcp_call_info_key_chunk;
-static GMemChunk *mgcp_call_info_value_chunk;
 static GHashTable *mgcp_calls;
 
 /* Compare 2 keys */
@@ -597,26 +595,8 @@ static void mgcp_init_protocol(void)
 		g_hash_table_destroy(mgcp_calls);
 		mgcp_calls = NULL;
 	}
-	if (mgcp_call_info_key_chunk != NULL)
-	{
-		g_mem_chunk_destroy(mgcp_call_info_key_chunk);
-		mgcp_call_info_key_chunk = NULL;
-	}
-	if (mgcp_call_info_value_chunk != NULL)
-	{
-		g_mem_chunk_destroy(mgcp_call_info_value_chunk);
-		mgcp_call_info_value_chunk = NULL;
-	}
 
 	mgcp_calls = g_hash_table_new(mgcp_call_hash, mgcp_call_equal);
-	mgcp_call_info_key_chunk = g_mem_chunk_new("call_info_key_chunk",
-	                                           sizeof(mgcp_call_info_key),
-	                                           200 * sizeof(mgcp_call_info_key),
-	                                           G_ALLOC_ONLY);
-	mgcp_call_info_value_chunk = g_mem_chunk_new("call_info_value_chunk",
-	                                             sizeof(mgcp_call_t),
-	                                             200 * sizeof(mgcp_call_t),
-	                                             G_ALLOC_ONLY);
 }
 
 /* Register all the bits needed with the filtering engine */
@@ -1753,9 +1733,9 @@ static void dissect_mgcp_firstline(tvbuff_t *tvb, packet_info *pinfo, proto_tree
 					   frame numbers are 1-origin, so we use 0
 					   to mean "we don't yet know in which frame
 					   the reply for this call appears". */
-					new_mgcp_call_key = g_mem_chunk_alloc(mgcp_call_info_key_chunk);
+					new_mgcp_call_key = se_alloc(sizeof(*new_mgcp_call_key));
 					*new_mgcp_call_key = mgcp_call_key;
-					mgcp_call = g_mem_chunk_alloc(mgcp_call_info_value_chunk);
+					mgcp_call = se_alloc(sizeof(*mgcp_call));
 					mgcp_call->req_num = pinfo->fd->num;
 					mgcp_call->rsp_num = 0;
 					mgcp_call->transid = mi->transid;
