@@ -1,7 +1,7 @@
 /* packet-mount.c
  * Routines for mount dissection
  *
- * $Id: packet-mount.c 21253 2007-03-28 21:55:11Z sfisher $
+ * $Id: packet-mount.c 28216 2009-05-01 07:14:44Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -35,7 +35,6 @@
 #include "packet-mount.h"
 #include "packet-nfs.h"
 
-#include <epan/emem.h>
 
 
 static int proto_mount = -1;
@@ -168,7 +167,8 @@ dissect_mount_dirpath_call(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		rpc_call_info_value *civ=pinfo->private_data;
 
 		if(civ->request && (civ->proc==1)){
-			unsigned char *host, *name;
+			const gchar *host;
+			unsigned char *name;
 			unsigned const char *dir;
 			int len;
 
@@ -189,7 +189,7 @@ dissect_mount_dirpath_call(tvbuff_t *tvb, int offset, packet_info *pinfo,
 				ptr+=len;
 				*ptr=0;
 
-				nfs_name_snoop_add_name(civ->xid, tvb, -1, strlen(name), 0, 0, name);
+				nfs_name_snoop_add_name(civ->xid, tvb, -1, (gint)strlen(name), 0, 0, name);
 			}
 		}
 	}
@@ -650,7 +650,7 @@ static const true_false_string tos_st_nosuid = {
 };
 
 static const true_false_string tos_st_notrunc = {
-	"Does not trunctate filenames longer than NAME_MAX",
+	"Does not truncate filenames longer than NAME_MAX",
 	"Truncates filenames longer than NAME_MAX"
 };
 
