@@ -5,9 +5,13 @@
  * (c) Copyright Ashok Narayanan <ashokn@cisco.com>
  *
  * (c) Copyright 2006, _FF_ Francesco Fondelli <francesco.fondelli@gmail.com>  
- *                     added MPLS OAM support, ITU-T Y.1711
+ *     - added MPLS OAM support, ITU-T Y.1711
+ *     - PW Associated Channel Header dissection as per RFC 4385
+ *     - PW MPLS Control Word dissection as per RFC 4385
+ *     - mpls subdissector table indexed by label value
+ *     - enhanced "what's past last mpls label?" heuristic
  *
- * $Id: packet-mpls.c 18735 2006-07-14 14:58:17Z gram $
+ * $Id: packet-mpls.c 28181 2009-04-27 16:57:02Z rbalint $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -51,15 +55,21 @@
 #include <epan/etypes.h>
 #include <epan/prefs.h>
 #include <epan/ipproto.h>
+#include <epan/addr_resolv.h>
 #include "packet-ppp.h"
 #include "packet-mpls.h"
 
 static gint proto_mpls = -1;
+static gint proto_pw_ach = -1;
+static gint proto_pw_mcw = -1;
 
 static gint ett_mpls = -1;
-static gint ett_mpls_control = -1;
+static gint ett_mpls_pw_ach = -1;
+static gint ett_mpls_pw_mcw = -1;
 static gint ett_mpls_oam = -1;
 
+void proto_reg_handoff_mpls(void);
+
 const value_string special_labels[] = {
     {LABEL_IP4_EXPLICIT_NULL,	"IPv4 Explicit-Null"},
     {LABEL_ROUTER_ALERT,	"Router Alert"},
@@ -71,22 +81,116 @@ const value_string special_labels[] = {
 
 /* MPLS filter values */
 enum mpls_filter_keys {
-
-    /* Is the packet MPLS-encapsulated? */
-/*    MPLSF_PACKET,*/
-
     /* MPLS encap properties */
     MPLSF_LABEL,
     MPLSF_EXP,
     MPLSF_BOTTOM_OF_STACK,
     MPLSF_TTL,
-
     MPLSF_MAX
 };
 
+static dissector_handle_t dissector_data;
+static dissector_handle_t dissector_ipv6;
+static dissector_handle_t dissector_ip;
+static dissector_handle_t dissector_pw_eth_heuristic;
+static dissector_handle_t dissector_pw_fr;
+static dissector_handle_t dissector_pw_hdlc_nocw_fr;
+static dissector_handle_t dissector_pw_hdlc_nocw_hdlc_ppp;
+static dissector_handle_t dissector_pw_eth_cw;
+static dissector_handle_t dissector_pw_eth_nocw;
+static dissector_handle_t dissector_pw_satop;
+static dissector_handle_t dissector_itdm;
+static dissector_handle_t dissector_pw_cesopsn;
+
+enum mpls_default_dissector_t {
+    MDD_PW_ETH_HEUR = 0
+    ,MDD_PW_SATOP
+    ,MDD_PW_CESOPSN
+    ,MDD_MPLS_PW_FR_DLCI
+    ,MDD_MPLS_PW_HDLC_NOCW_FRPORT
+    ,MDD_MPLS_PW_HDLC_NOCW_HDLC_PPP
+    ,MDD_MPLS_PW_ETH_CW
+    ,MDD_MPLS_PW_ETH_NOCW
+    ,MDD_MPLS_PW_GENERIC
+    ,MDD_ITDM
+};
+
+/* TODO the content of mpls_default_payload menu
+ * should be automatically built like mpls "decode as..." menu;
+ * this way, mpls_default_payload will be automatically filled up when
+ * new mpls-specific dissector added.
+ */
+static enum_val_t mpls_default_payload_defs[] = {
+    {
+        "pw satop"
+        ,"SAToP (no RTP support)"
+        ,MDD_PW_SATOP
+    },
+    {
+        "pw cesopsn"
+        ,"CESoPSN basic NxDS0 mode (no RTP support)"
+        ,MDD_PW_CESOPSN
+    },
+    {
+        "mpls pw ethernet heuristic"
+        ,"Ethernet MPLS PW (CW is heuristically detected)"
+        ,MDD_PW_ETH_HEUR
+    },
+    {
+        "mpls pw fr dlci"
+        ,"Frame relay DLCI MPLS PW"
+        ,MDD_MPLS_PW_FR_DLCI
+    },
+    {
+        "mpls pw hdlc no_cw fr_port"
+        ,"HDLC MPLS PW (no CW), FR Port mode"
+        ,MDD_MPLS_PW_HDLC_NOCW_FRPORT
+    },
+    {
+        "mpls pw hdlc no_cw hdlc payload_ppp"
+        ,"HDLC MPLS PW (no CW), HDLC mode, PPP payload"
+        ,MDD_MPLS_PW_HDLC_NOCW_HDLC_PPP
+    },
+    {
+        "mpls pw ethernet cw"
+        ,"Ethernet MPLS PW (with CW)"
+        ,MDD_MPLS_PW_ETH_CW
+    },
+    {
+        "mpls pw ethernet no_cw"
+        ,"Ethernet MPLS PW (no CW, early implementations)"
+        ,MDD_MPLS_PW_ETH_NOCW
+    },
+    {
+        "mpls pw generic cw"
+        ,"Generic MPLS PW (with Generic/Preferred MPLS CW)"
+        ,MDD_MPLS_PW_GENERIC
+    },
+    {
+        "itdm"
+        ,"Internal TDM"
+        ,MDD_ITDM
+    },
+    {
+        NULL
+        ,NULL
+        ,-1
+    }
+};
+
 static int mpls_filter[MPLSF_MAX];
-static int hf_mpls_control_control = -1;
-static int hf_mpls_control_res = -1;
+
+static gint mpls_default_payload = 0;
+
+static int hf_mpls_1st_nibble = -1;
+
+static int hf_mpls_pw_ach_ver = -1;
+static int hf_mpls_pw_ach_res = -1;
+static int hf_mpls_pw_ach_channel_type = -1;
+
+static int hf_mpls_pw_mcw_flags = -1;
+static int hf_mpls_pw_mcw_length = -1;
+static int hf_mpls_pw_mcw_sequence_number = -1;
 
 static int hf_mpls_oam_function_type = -1;
 static int hf_mpls_oam_ttsi = -1;
@@ -134,10 +238,7 @@ static const value_string oam_defect_type_vals[] = {
 
 static hf_register_info mplsf_info[] = {
 
-/*    {&mpls_filter[MPLSF_PACKET],
-     {"MPLS Label Switched Packet", "mpls", FT_UINT8, BASE_DEC, NULL, 0x0,
-      "", HFILL }},*/
-
+    /* MPLS header fields */
     {&mpls_filter[MPLSF_LABEL],
      {"MPLS Label", "mpls.label", FT_UINT32, BASE_DEC, VALS(special_labels), 0x0,
       "", HFILL }},
@@ -154,13 +255,39 @@ static hf_register_info mplsf_info[] = {
      {"MPLS TTL", "mpls.ttl", FT_UINT8, BASE_DEC, NULL, 0x0,
       "", HFILL }},
 
-    {&hf_mpls_control_control,
-     {"MPLS Control Channel", "mpls.cw.control", FT_UINT8, BASE_DEC, NULL, 0xF0,
-      "First nibble", HFILL }},
+    /* 1st nibble */
+     {&hf_mpls_1st_nibble,
+     {"MPLS 1st nibble", "mpls.1st_nibble", FT_UINT8, 
+       BASE_DEC, NULL, 0x0, "MPLS 1st nibble", HFILL }},
 
-    {&hf_mpls_control_res,
-     {"Reserved", "mpls.cw.res", FT_UINT16, BASE_HEX, NULL, 0xFFF, 
-      "Reserved", HFILL }},
+    /* PW Associated Channel Header fields */
+    {&hf_mpls_pw_ach_ver,
+     {"PW Associated Channel Version", "pwach.ver", FT_UINT8, BASE_DEC, 
+      NULL, 0x0, "PW Associated Channel Version", HFILL }},
+
+    {&hf_mpls_pw_ach_res,
+     {"Reserved", "pwach.res", FT_UINT8, BASE_DEC, 
+      NULL, 0x0, "Reserved", HFILL }},
+
+    {&hf_mpls_pw_ach_channel_type,
+     {"PW Associated Channel Type", "pwach.channel_type", FT_UINT16, BASE_HEX, 
+      NULL, 0x0, "PW Associated Channel Type", HFILL }},
+
+    /* Generic/Preferred PW MPLS Control Word fields */
+    {&hf_mpls_pw_mcw_flags,
+     {"Generic/Preferred PW MPLS Control Word Flags", "pwmcw.flags", FT_UINT8,
+      BASE_HEX, NULL, 0x0, "Generic/Preferred PW MPLS Control Word Flags", 
+      HFILL }},
+
+    {&hf_mpls_pw_mcw_length,
+     {"Generic/Preferred PW MPLS Control Word Length", "pwmcw.length", FT_UINT8,
+      BASE_DEC, NULL, 0x0, "Generic/Preferred PW MPLS Control Word Length", 
+      HFILL }},
+
+    {&hf_mpls_pw_mcw_sequence_number,
+     {"Generic/Preferred PW MPLS Control Word Sequence Number",
+      "pwmcw.sequence_number", FT_UINT16, BASE_DEC, NULL, 0x0,
+      "Generic/Preferred PW MPLS Control Word Sequence Number", HFILL }},
 
     /* OAM header fields */
     {&hf_mpls_oam_function_type,
@@ -188,11 +315,8 @@ static hf_register_info mplsf_info[] = {
       BASE_HEX, NULL, 0x0, "BIP16", HFILL }},
 };
 
-static dissector_handle_t ipv4_handle;
-static dissector_handle_t ipv6_handle;
-static dissector_handle_t eth_withoutfcs_handle;
-static dissector_handle_t data_handle;
 static dissector_table_t ppp_subdissector_table;
+static dissector_table_t mpls_subdissector_table;
 
 /*
  * Given a 4-byte MPLS label starting at offset "offset", in tvbuff "tvb",
@@ -214,43 +338,118 @@ void decode_mpls_label(tvbuff_t *tvb, int offset,
     *ttl = tvb_get_guint8(tvb, offset+3);
 }
 
+/*
+ * FF: PW Associated Channel Header dissection as per RFC 4385.
+ */
 static void
-dissect_mpls_control(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+dissect_pw_ach(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-    proto_tree  *mpls_control_tree = NULL;
-    proto_item  *ti;
-    tvbuff_t    *next_tvb;
-    guint8      ctrl;
-    guint16     res, ppp_proto;
+    proto_tree  *mpls_pw_ach_tree = NULL;
+    proto_item  *ti = NULL;
+    tvbuff_t    *next_tvb = NULL;
+    guint8      ver = 0;
+    guint16     res = 0;
+    guint16     channel_type = 0;
 
-    if (tvb_reported_length_remaining(tvb, 0) < 4){
-        if(tree)
+    if (tvb_reported_length_remaining(tvb, 0) < 4) {
+        if (tree)
             proto_tree_add_text(tree, tvb, 0, -1, "Error processing Message");
         return;
     }
-    ctrl = (tvb_get_guint8(tvb, 0) & 0xF0) >> 4;
-    res = tvb_get_ntohs(tvb, 0) & 0x0FFF;
-    ppp_proto = tvb_get_ntohs(tvb, 2);
+    ver = (tvb_get_guint8(tvb, 0) & 0x0F);
+    res = tvb_get_guint8(tvb, 1);
+    channel_type = tvb_get_ntohs(tvb, 2);
     if (tree) {
-        ti = proto_tree_add_text(tree, tvb, 0, 4, "MPLS PW Control Channel Header");
-        mpls_control_tree = proto_item_add_subtree(ti, ett_mpls_control);
-        if(mpls_control_tree == NULL) return;
-
-        proto_tree_add_uint_format(mpls_control_tree, hf_mpls_control_control, tvb, 0, 1,
-            ctrl, "Control Channel: 0x%1x", ctrl);
-        proto_tree_add_uint_format(mpls_control_tree, hf_mpls_control_res, tvb, 0, 2,
-            res, "Reserved: 0x%03x", res);
-        proto_tree_add_text(mpls_control_tree, tvb, 2, 2,
-            "PPP DLL Protocol Number: %s (0x%04X)", 
-                val_to_str(ppp_proto, ppp_vals, "Unknown"), ppp_proto);
+        ti = proto_tree_add_item(tree, proto_pw_ach, tvb, 0, 4, FALSE);
+        mpls_pw_ach_tree = proto_item_add_subtree(ti, ett_mpls_pw_ach);
+        if (mpls_pw_ach_tree == NULL)
+            return;
+        proto_tree_add_uint_format(mpls_pw_ach_tree, hf_mpls_pw_ach_ver,
+                                   tvb, 0, 1, ver, "Version: %d", ver);
+        ti = proto_tree_add_uint_format(mpls_pw_ach_tree, hf_mpls_pw_ach_res,
+                                        tvb, 1, 1, res, "Reserved: 0x%02x", res);
+        PROTO_ITEM_SET_HIDDEN(ti);
+        if (res != 0)
+            proto_tree_add_text(mpls_pw_ach_tree, tvb, 1, 1,
+                "Error: this byte is reserved and must be 0");
+        proto_tree_add_uint_format(mpls_pw_ach_tree, hf_mpls_pw_ach_channel_type,
+                                   tvb, 2, 2, channel_type,
+                                   "Channel Type: %s (0x%04x)",
+                                   val_to_str(channel_type, ppp_vals, "Unknown"),
+                                              channel_type);
     }
     next_tvb = tvb_new_subset(tvb, 4, -1, -1);
-    if (!dissector_try_port(ppp_subdissector_table, ppp_proto, 
-        next_tvb, pinfo, tree)) {
-            call_dissector(data_handle, next_tvb, pinfo, tree);
+    if (!dissector_try_port(ppp_subdissector_table, channel_type, 
+                            next_tvb, pinfo, tree)) {
+            call_dissector(dissector_data, next_tvb, pinfo, tree);
+    }
+}
+
+gboolean dissect_try_cw_first_nibble( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
+{
+	guint8 nibble;
+	nibble = (tvb_get_guint8(tvb, 0 ) >> 4) & 0x0F;
+	switch ( nibble )
+	{
+	case 6:
+		call_dissector( dissector_ipv6, tvb, pinfo, tree);
+		return TRUE;
+	case 4:
+		call_dissector( dissector_ip, tvb, pinfo, tree);
+		return TRUE;
+	case 1:
+		dissect_pw_ach( tvb, pinfo, tree );
+		return TRUE;
+	default:
+		break;
+	}
+	return FALSE;
+}
+
+/*
+ * FF: Generic/Preferred PW MPLS Control Word dissection as per RFC 4385.
+ */
+static void
+dissect_pw_mcw(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+{
+    proto_tree  *mpls_pw_mcw_tree = NULL;
+    proto_item  *ti = NULL;
+    tvbuff_t    *next_tvb = NULL;
+    guint8      flags = 0;
+    guint8      frg = 0;
+    guint8      length = 0;
+    guint16     sequence_number = 0;
+
+    if (tvb_reported_length_remaining(tvb, 0) < 4) {
+        if (tree)
+            proto_tree_add_text(tree, tvb, 0, -1, "Error processing Message");
+        return;
     }
 
+    if ( dissect_try_cw_first_nibble( tvb, pinfo, tree )) 
+       return;
 
+    /* bits 4 to 7 and FRG bits are displayed together */
+    flags = (tvb_get_guint8(tvb, 0) & 0x0F) << 2;
+    frg = (tvb_get_guint8(tvb, 1) & 0xC0) >> 6;
+    flags |= frg;
+    length = tvb_get_guint8(tvb, 1) & 0x3F;
+    sequence_number = tvb_get_ntohs(tvb, 2);
+    if (tree) {
+        ti = proto_tree_add_item(tree, proto_pw_mcw, tvb, 0, 4, FALSE);
+        mpls_pw_mcw_tree = proto_item_add_subtree(ti, ett_mpls_pw_mcw);
+        if (mpls_pw_mcw_tree == NULL)
+            return;
+        proto_tree_add_uint_format(mpls_pw_mcw_tree, hf_mpls_pw_mcw_flags,
+                                   tvb, 0, 1, flags, "Flags: 0x%02x", flags);
+        ti = proto_tree_add_uint_format(mpls_pw_mcw_tree, hf_mpls_pw_mcw_length,
+                                        tvb, 1, 1, length, "Length: %u", length);
+        proto_tree_add_uint_format(mpls_pw_mcw_tree, hf_mpls_pw_mcw_sequence_number,
+                                   tvb, 2, 2, sequence_number,
+                                   "Sequence Number: %d", sequence_number);
+    }
+    next_tvb = tvb_new_subset(tvb, 4, -1, -1);
+    call_dissector( dissector_data, next_tvb, pinfo, tree );
 }
 
 static void
@@ -460,18 +659,15 @@ dissect_mpls_oam_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, proto_
     proto_tree_add_item(mpls_oam_tree, hf_mpls_oam_bip16, tvb, offset, 2, TRUE);
     offset+=2;
 }
-    
 
 static void
 dissect_mpls(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
     int offset = 0;
-    guint32 label;
+    guint32 label = LABEL_INVALID;
     guint8 exp;
     guint8 bos;
     guint8 ttl;
-    guint8 ipvers;
-
     proto_tree  *mpls_tree = NULL;
     proto_item  *ti;
     tvbuff_t *next_tvb;
@@ -481,14 +677,15 @@ dissect_mpls(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     }
 
     if (check_col(pinfo->cinfo,COL_INFO)) {
-	col_add_fstr(pinfo->cinfo,COL_INFO,"MPLS Label Switched Packet");
+	col_set_str(pinfo->cinfo,COL_INFO,"MPLS Label Switched Packet");
     }
 
     /* Start Decoding Here. */
     while (tvb_reported_length_remaining(tvb, offset) > 0) {
 	
 	decode_mpls_label(tvb, offset, &label, &exp, &bos, &ttl);
-		
+	pinfo->mpls_label = label;
+	
 	if (tree) {
 
 	    ti = proto_tree_add_item(tree, proto_mpls, tvb, offset, 4, FALSE);
@@ -531,17 +728,45 @@ dissect_mpls(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	offset += 4;
 	if (bos) break;
     }
+
     next_tvb = tvb_new_subset(tvb, offset, -1, -1);
 
-    ipvers = (tvb_get_guint8(tvb, offset) >> 4) & 0x0F;
-    if (ipvers == 6) {
-      call_dissector(ipv6_handle, next_tvb, pinfo, tree);
-    } else if (ipvers == 4) {
-      call_dissector(ipv4_handle, next_tvb, pinfo, tree);
-    } else if (ipvers == 1) {
-      dissect_mpls_control(next_tvb, pinfo, tree);
-    } else {
-      call_dissector(eth_withoutfcs_handle, next_tvb, pinfo, tree);
+    if ( !dissector_try_port(mpls_subdissector_table, label, next_tvb, pinfo, tree))
+    {
+        switch ( mpls_default_payload )
+        {
+        case MDD_PW_SATOP:
+               call_dissector(dissector_pw_satop, next_tvb, pinfo, tree);
+               break;
+        case MDD_PW_CESOPSN:
+               call_dissector(dissector_pw_cesopsn, next_tvb, pinfo, tree);
+               break;
+        case MDD_PW_ETH_HEUR:
+               call_dissector(dissector_pw_eth_heuristic, next_tvb, pinfo, tree);
+               break;
+        case MDD_MPLS_PW_FR_DLCI:
+               call_dissector(dissector_pw_fr, next_tvb, pinfo, tree);
+               break;
+        case MDD_MPLS_PW_HDLC_NOCW_FRPORT:
+               call_dissector(dissector_pw_hdlc_nocw_fr, next_tvb, pinfo, tree);
+               break;
+        case MDD_MPLS_PW_HDLC_NOCW_HDLC_PPP:
+               call_dissector(dissector_pw_hdlc_nocw_hdlc_ppp, next_tvb, pinfo, tree);
+               break;
+        case MDD_MPLS_PW_ETH_CW:
+               call_dissector(dissector_pw_eth_cw, next_tvb, pinfo, tree);
+               break;
+        case MDD_MPLS_PW_ETH_NOCW:
+               call_dissector(dissector_pw_eth_nocw, next_tvb, pinfo, tree);
+               break;
+        case MDD_ITDM:
+               call_dissector(dissector_itdm, next_tvb, pinfo, tree);
+               break;
+        default: /*fallthrough*/
+        case MDD_MPLS_PW_GENERIC:
+               dissect_pw_mcw(next_tvb, pinfo, tree);
+               break;
+        }
     }
 }
 
@@ -550,40 +775,77 @@ proto_register_mpls(void)
 {
 	static gint *ett[] = {
 		&ett_mpls,
-                &ett_mpls_control,
+		&ett_mpls_pw_ach,
+		&ett_mpls_pw_mcw,
 		&ett_mpls_oam,
 	};
+	module_t * module_mpls;
 
+	/* FF: mpls subdissector table is indexed by label */
+	mpls_subdissector_table = register_dissector_table("mpls.label",
+                                                           "MPLS protocol", 
+                                                           FT_UINT32, BASE_DEC);
 	proto_mpls = proto_register_protocol("MultiProtocol Label Switching Header",
-	    "MPLS", "mpls");
+                                             "MPLS", "mpls");
+	proto_pw_ach = proto_register_protocol("PW Associated Channel Header",
+					       "PW Associated Channel", "pwach");
+	proto_pw_mcw = proto_register_protocol("PW MPLS Control Word (generic/preferred)",
+					       "Generic PW (with CW)", "pwmcw");
+
 	proto_register_field_array(proto_mpls, mplsf_info, array_length(mplsf_info));
 	proto_register_subtree_array(ett, array_length(ett));
 	register_dissector("mpls", dissect_mpls, proto_mpls);
+	register_dissector("mplspwcw", dissect_pw_mcw, proto_pw_mcw );
+
+	module_mpls = prefs_register_protocol( proto_mpls, proto_reg_handoff_mpls );
+
+	prefs_register_enum_preference(	module_mpls,
+					"mplspref.payload",
+					"Default decoder for MPLS payload",
+					"Default decoder for MPLS payload",
+					&mpls_default_payload,
+					mpls_default_payload_defs,
+					FALSE );
 }
 
 void
 proto_reg_handoff_mpls(void)
 {
-	dissector_handle_t mpls_handle;
+	static gboolean initialized=FALSE;
 
-	/*
-	 * Get a handle for the IPv4 and IPv6 dissectors and PPP protocol dissector table.
-	 */
-	ipv4_handle = find_dissector("ip");
-	ipv6_handle = find_dissector("ipv6");
-	eth_withoutfcs_handle = find_dissector("eth_withoutfcs");
-        data_handle = find_dissector("data");
-        ppp_subdissector_table = find_dissector_table("ppp.protocol");
+	if ( !initialized )
+	{
+		dissector_handle_t mpls_handle;
 
+		ppp_subdissector_table = find_dissector_table("ppp.protocol");
 
-	mpls_handle = create_dissector_handle(dissect_mpls, proto_mpls);
-	dissector_add("ethertype", ETHERTYPE_MPLS, mpls_handle);
-	dissector_add("ethertype", ETHERTYPE_MPLS_MULTI, mpls_handle);
-	dissector_add("ppp.protocol", PPP_MPLS_UNI, mpls_handle);
-	dissector_add("ppp.protocol", PPP_MPLS_MULTI, mpls_handle);
-	dissector_add("chdlctype", ETHERTYPE_MPLS, mpls_handle);
-	dissector_add("chdlctype", ETHERTYPE_MPLS_MULTI, mpls_handle);
-	dissector_add("gre.proto", ETHERTYPE_MPLS, mpls_handle);
-	dissector_add("gre.proto", ETHERTYPE_MPLS_MULTI, mpls_handle);
-    dissector_add("ip.proto", IP_PROTO_MPLS_IN_IP, mpls_handle);
+		mpls_handle = find_dissector("mpls");
+		dissector_add("ethertype", ETHERTYPE_MPLS, mpls_handle);
+		dissector_add("ethertype", ETHERTYPE_MPLS_MULTI, mpls_handle);
+		dissector_add("ppp.protocol", PPP_MPLS_UNI, mpls_handle);
+		dissector_add("ppp.protocol", PPP_MPLS_MULTI, mpls_handle);
+		dissector_add("chdlctype", ETHERTYPE_MPLS, mpls_handle);
+		dissector_add("chdlctype", ETHERTYPE_MPLS_MULTI, mpls_handle);
+		dissector_add("gre.proto", ETHERTYPE_MPLS, mpls_handle);
+		dissector_add("gre.proto", ETHERTYPE_MPLS_MULTI, mpls_handle);
+		dissector_add("ip.proto", IP_PROTO_MPLS_IN_IP, mpls_handle);
+
+		mpls_handle = find_dissector("mplspwcw");
+		dissector_add( "mpls.label", LABEL_INVALID, mpls_handle );
+
+		dissector_data 			= find_dissector("data");
+		dissector_ipv6 			= find_dissector("ipv6");
+		dissector_ip 			= find_dissector("ip");
+		dissector_pw_eth_heuristic 	= find_dissector("pw_eth_heuristic");
+		dissector_pw_fr 		= find_dissector("pw_fr");
+		dissector_pw_hdlc_nocw_fr 	= find_dissector("pw_hdlc_nocw_fr");
+		dissector_pw_hdlc_nocw_hdlc_ppp = find_dissector("pw_hdlc_nocw_hdlc_ppp");
+		dissector_pw_eth_cw 		= find_dissector("pw_eth_cw");
+		dissector_pw_eth_nocw 		= find_dissector("pw_eth_nocw");
+		dissector_pw_satop 		= find_dissector("pw_satop");
+		dissector_itdm 			= find_dissector("itdm");
+		dissector_pw_cesopsn		= find_dissector("pw_cesopsn");
+
+		initialized = TRUE;
+	}
 }
