@@ -14,7 +14,7 @@
  *
  * Copyright 2003, Jeff Morriss <jeff.morriss[AT]ulticom.com>
  *
- * $Id: packet-mtp3mg.c 23704 2007-12-03 17:32:02Z morriss $
+ * $Id: packet-mtp3mg.c 26308 2008-09-30 14:49:44Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -44,7 +44,6 @@
 #include <glib.h>
 
 #include <epan/packet.h>
-#include <epan/prefs.h>
 
 #include <packet-mtp3.h>
 
@@ -1533,7 +1532,7 @@ proto_reg_handoff_mtp3mg(void)
 {
     dissector_handle_t mtp3mg_handle;
 
-    mtp3mg_handle = create_dissector_handle(dissect_mtp3mg, proto_mtp3mg);
+    mtp3mg_handle = find_dissector("mtp3mg");
 
     dissector_add("mtp3.service_indicator", MTP3MG_SI, mtp3mg_handle);
 
