@@ -1,7 +1,7 @@
 /* packet-netsync.c
  * Routines for Monotone Netsync packet disassembly
  *
- * $Id: packet-netsync.c 22356 2007-07-19 13:05:39Z morriss $
+ * $Id: packet-netsync.c 27826 2009-03-23 12:44:50Z stig $
  *
  * Copyright (c) 2005 by Erwin Rol <erwin@erwinrol.com>
  *
@@ -39,7 +39,6 @@
 #include <epan/addr_resolv.h>
 #include <epan/prefs.h>
 #include <epan/strutil.h>
-#include <epan/emem.h>
 #include "packet-tcp.h"
 
 /*
@@ -76,7 +75,7 @@ static const value_string netsync_role_vals[] = {
 #define NETSYNC_CMD_SEND_DELTA	9
 #define NETSYNC_CMD_DATA	10
 #define NETSYNC_CMD_DELTA	11
-#define NETSYNC_CMD_NONEXISTANT	12
+#define NETSYNC_CMD_NONEXISTENT	12
 
 static const value_string netsync_cmd_vals[] = {
 	{ NETSYNC_CMD_ERROR,		"Error" },
@@ -91,7 +90,7 @@ static const value_string netsync_cmd_vals[] = {
 	{ NETSYNC_CMD_SEND_DELTA, 	"Send Delta" },
 	{ NETSYNC_CMD_DATA,		"Data" },
 	{ NETSYNC_CMD_DELTA,		"Delta" },
-	{ NETSYNC_CMD_NONEXISTANT, 	"Nonexistant" },
+	{ NETSYNC_CMD_NONEXISTENT, 	"Nonexistent" },
 	{ 0,				NULL }
 };
 
@@ -150,8 +149,8 @@ static int hf_netsync_cmd_send_delta_type = -1;
 static int hf_netsync_cmd_send_delta_base_id = -1;
 static int hf_netsync_cmd_send_delta_ident_id = -1;
 
-static int hf_netsync_cmd_nonexistant_type = -1;
-static int hf_netsync_cmd_nonexistant_id = -1;
+static int hf_netsync_cmd_nonexistent_type = -1;
+static int hf_netsync_cmd_nonexistent_id = -1;
 
 /* Define the tree for netsync */
 static int ett_netsync = -1;
@@ -162,10 +161,7 @@ static int ett_netsync = -1;
  * for monotone netsync
  */
 
-static dissector_handle_t netsync_handle;
-
 static guint global_tcp_port_netsync = TCP_PORT_NETSYNC;
-static guint tcp_port_netsync = TCP_PORT_NETSYNC;
 static gboolean netsync_desegment = TRUE;
 
 static gint dissect_uleb128( tvbuff_t *tvb, gint offset, guint* size)
@@ -375,7 +371,7 @@ static gint dissect_netsync_cmd_send_delta(tvbuff_t *tvb,  gint offset, proto_tr
 
 static gint dissect_netsync_cmd_data(tvbuff_t *tvb,  gint offset, proto_tree *tree, guint size _U_)
 {
-	guint len = -1;
+	guint len = 0;
 
 	proto_tree_add_item(tree, hf_netsync_cmd_data_type, tvb,
 				offset, 1, FALSE );
@@ -429,13 +425,13 @@ static gint dissect_netsync_cmd_delta(tvbuff_t *tvb,  gint offset, proto_tree *t
 }
 
 
-static gint dissect_netsync_cmd_nonexistant(tvbuff_t *tvb,  gint offset, proto_tree *tree, guint size _U_)
+static gint dissect_netsync_cmd_nonexistent(tvbuff_t *tvb,  gint offset, proto_tree *tree, guint size _U_)
 {
-	proto_tree_add_item(tree, hf_netsync_cmd_nonexistant_type, tvb,
+	proto_tree_add_item(tree, hf_netsync_cmd_nonexistent_type, tvb,
 				offset, 1, FALSE );
 	offset += 1;
 
-	proto_tree_add_item(tree, hf_netsync_cmd_nonexistant_id, tvb,
+	proto_tree_add_item(tree, hf_netsync_cmd_nonexistent_id, tvb,
 				offset, NETSNYC_MERKLE_HASH_LENGTH, FALSE );
 	offset += NETSNYC_MERKLE_HASH_LENGTH;
 
@@ -559,8 +555,8 @@ dissect_netsync_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				dissect_netsync_cmd_delta( tvb, offset, netsync_tree, size );
 				break;
 
-			case NETSYNC_CMD_NONEXISTANT:
-				dissect_netsync_cmd_nonexistant( tvb, offset, netsync_tree, size );
+			case NETSYNC_CMD_NONEXISTENT:
+				dissect_netsync_cmd_nonexistent( tvb, offset, netsync_tree, size );
 				break;
 
 			default:
@@ -732,12 +728,12 @@ proto_register_netsync(void)
 			{ "Ident ID", "netsync.cmd.send_delta.ident_id",
 			  FT_BYTES, BASE_DEC, NULL, 0x0,
 			  "Ident ID", HFILL } },
-		{ &hf_netsync_cmd_nonexistant_id,
-			{ "ID", "netsync.cmd.nonexistant.id",
+		{ &hf_netsync_cmd_nonexistent_id,
+			{ "ID", "netsync.cmd.nonexistent.id",
 			  FT_BYTES, BASE_DEC, NULL, 0x0,
 			  "ID", HFILL } },
-		{ &hf_netsync_cmd_nonexistant_type,
-			{ "Type", "netsync.cmd.nonexistant.type",
+		{ &hf_netsync_cmd_nonexistent_type,
+			{ "Type", "netsync.cmd.nonexistent.type",
 			  FT_UINT8, BASE_DEC, NULL, 0x0,
 			  "Type", HFILL } },
 		{ &hf_netsync_cmd_done_type,
@@ -758,8 +754,6 @@ proto_register_netsync(void)
 	proto_register_field_array(proto_netsync, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
 
-	netsync_handle = create_dissector_handle(dissect_netsync, proto_netsync);
-
 	netsync_module = prefs_register_protocol(proto_netsync,
 						proto_reg_handoff_netsync);
 
@@ -780,12 +774,15 @@ proto_register_netsync(void)
 void
 proto_reg_handoff_netsync(void)
 {
-	static gint initialized = 0;
+	static dissector_handle_t netsync_handle;
+	static guint tcp_port_netsync;
+	static gboolean initialized = FALSE;
 
-	if (initialized) {
-		dissector_delete("tcp.port", tcp_port_netsync, netsync_handle);
+	if (!initialized) {
+		netsync_handle = create_dissector_handle(dissect_netsync, proto_netsync);
+		initialized = TRUE;
 	} else {
-		initialized = 1;
+		dissector_delete("tcp.port", tcp_port_netsync, netsync_handle);
 	}
 
 	tcp_port_netsync = global_tcp_port_netsync;
