@@ -2,7 +2,7 @@
  * Routines for NTP packet dissection
  * Copyright 1999, Nathan Neulinger <nneul@umr.edu>
  *
- * $Id: packet-ntp.c 27290 2009-01-23 19:36:48Z jake $
+ * $Id: packet-ntp.c 32661 2010-05-04 19:13:29Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -168,13 +168,15 @@ static const struct {
 	const char *data;
 } primary_sources[] = {
 	{ "LOCL",	"uncalibrated local clock" },
-	{ "PPS\0",	"atomic clock or other pulse-per-second source" },
+	{ "CESM",	"calibrated Cesium clock" },
+	{ "RBDM",	"calibrated Rubidium clock" },
+	{ "PPS\0",	"calibrated quartz clock or other pulse-per-second source" },
 	{ "ACTS",	"NIST dialup modem service" },
 	{ "USNO",	"USNO modem service" },
 	{ "PTB\0",	"PTB (Germany) modem service" },
 	{ "TDF\0",	"Allouis (France) Radio 164 kHz" },
 	{ "DCF\0",	"Mainflingen (Germany) Radio 77.5 kHz" },
-	{ "MSF\0",	"Rugby (UK) Radio 60 kHz" },
+	{ "MSF\0",	"Anthorn (UK) Radio 60 kHz" },
 	{ "WWV\0",	"Ft. Collins (US) Radio 2.5, 5, 10, 15, 20 MHz" },
 	{ "WWVB",	"Boulder (US) Radio 60 kHz" },
 	{ "WWVH",	"Kauai Hawaii (US) Radio 2.5, 5, 10, 15 MHz" },
@@ -514,7 +516,7 @@ dissect_ntp_std(tvbuff_t *tvb, proto_tree *ntp_tree, guint8 flags)
 	ppoll = tvb_get_guint8(tvb, 2);
 	proto_tree_add_uint_format(ntp_tree, hf_ntp_ppoll, tvb, 2, 1,
 				   ppoll,
-				   (((ppoll >= 4) && (ppoll <= 16)) ?
+				   (((ppoll >= 4) && (ppoll <= 17)) ?
 				   "Peer Polling Interval: %u (%u sec)" :
 				   "Peer Polling Interval: invalid (%u)"),
 				   ppoll,
