@@ -2,7 +2,7 @@
  * ISC OMAPI (Object Management API) dissector
  * Copyright 2006, Jaap Keuter <jaap.keuter@xs4all.nl>
  *
- * $Id: packet-omapi.c 23252 2007-10-23 05:50:00Z etxrab $
+ * $Id: packet-omapi.c 33645 2010-07-27 23:41:12Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -50,7 +50,6 @@
 #endif
 
 #include <epan/packet.h>
-#include <epan/emem.h>
 #include <epan/ptvcursor.h>
 
 static int proto_omapi = -1;
@@ -142,6 +141,18 @@ dissect_omapi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     return;
   }
+  else if ( !(tvb_get_ntohl(tvb, 8) || tvb_get_ntohl(tvb, 12)) )
+  {
+    /* This is a startup message, and more */
+    ptvcursor_add(cursor, hf_omapi_version, 4, FALSE);
+    ptvcursor_add(cursor, hf_omapi_hlength, 4, FALSE);
+
+    if (check_col(pinfo->cinfo, COL_INFO))
+    {
+      col_append_str(pinfo->cinfo, COL_INFO, "Status message");
+    }
+    proto_item_append_text(ti, ", Status message"); 
+  }
 
   ptvcursor_add(cursor, hf_omapi_auth_id, 4, FALSE);
   authlength = tvb_get_ntohl(tvb, ptvcursor_current_offset(cursor));
@@ -149,7 +160,7 @@ dissect_omapi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
   if (check_col(pinfo->cinfo, COL_INFO)) 
   {
-    col_add_str(pinfo->cinfo, COL_INFO, 
+    col_append_sep_str(pinfo->cinfo, COL_INFO, NULL,
       val_to_str(tvb_get_ntohl(tvb, ptvcursor_current_offset(cursor)), omapi_opcode_vals, "Unknown opcode (0x%04x)"));
   }
   proto_item_append_text(ti, ", Opcode: %s", 
