@@ -7,7 +7,7 @@ proper helper routines
  * Routines for dissection of ASN.1 Aligned PER
  * 2003  Ronnie Sahlberg
  *
- * $Id: packet-per.c 27603 2009-03-03 22:46:47Z stig $
+ * $Id: packet-per.c 31280 2009-12-16 00:43:19Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -75,6 +75,7 @@ static int hf_per_encoding = -1;                  /* External_encoding */
 static int hf_per_single_ASN1_type = -1;          /* T_single_ASN1_type */
 static int hf_per_octet_aligned = -1;             /* T_octet_aligned */
 static int hf_per_arbitrary = -1;                 /* T_arbitrary */
+static int hf_per_integer_length = -1;			  /* Show integer length if "show internal per fields" */
 
 static gint ett_per_open_type = -1;
 static gint ett_per_containing = -1;
@@ -126,6 +127,9 @@ static tvbuff_t *new_octet_aligned_subset(tvbuff_t *tvb, guint32 offset, asn1_ct
   guint8 octet0, octet1, *buf;
   guint32 actual_length;
 
+  /*  XXX - why are we doing this?  Shouldn't we throw an exception if we've
+   *  been asked to decode more octets than exist?
+   */
   actual_length = tvb_length_remaining(tvb,boffset);
   if (length <= actual_length)
 	  actual_length = length;
@@ -133,15 +137,15 @@ static tvbuff_t *new_octet_aligned_subset(tvbuff_t *tvb, guint32 offset, asn1_ct
   if (offset & 0x07) {  /* unaligned */
     shift1 = offset & 0x07;
     shift0 = 8 - shift1;
-    buf = ep_alloc(actual_length);
+    buf = g_malloc(actual_length);
     octet0 = tvb_get_guint8(tvb, boffset);
     for (i=0; i<actual_length; i++) {
       octet1 = octet0;
       octet0 = tvb_get_guint8(tvb, boffset + i + 1);
       buf[i] = (octet1 << shift1) | (octet0 >> shift0);
     }
-    sub_tvb = tvb_new_real_data(buf, actual_length, length);
-    tvb_set_child_real_data_tvbuff(tvb, sub_tvb);
+    sub_tvb = tvb_new_child_real_data(tvb, buf, actual_length, length);
+    tvb_set_free_cb(sub_tvb, g_free);
     add_new_data_source(actx->pinfo, sub_tvb, "Unaligned OCTET STRING");
   } else {  /* aligned */
     sub_tvb = tvb_new_subset(tvb, boffset, actual_length, length);
@@ -160,54 +164,112 @@ static const guint16 bit_mask16[] = {
     0x01ff
 };
 
+static const guint16 bit_mask16_unalligned[] = {
+    0xff00,
+    0x8000,
+    0xc000,
+    0xe000,
+    0xf000,
+    0xf800,
+    0xfc00,
+    0xfe00
+};
+
 /* Fetch a number of bits to a new tvb right adjusted to the nearest number of bytes.
- * (add proceeding zeros).
+ * (add proceeding zeros in case of aligned PER)
  */
-static tvbuff_t *new_octet_aligned_subset_bits(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, guint32 no_of_bits)
+tvbuff_t *new_octet_aligned_subset_bits(tvbuff_t *tvb, guint32 boffset, asn1_ctx_t *actx, guint32 no_of_bits)
 {
   tvbuff_t *sub_tvb = NULL;
-  guint32 boffset = offset >> 3;
+  /* offset is offset in bytes boffset is in bits */
+  guint32 offset = boffset >> 3;
   unsigned int i, shift0, shift1;
   guint8 octet0, octet1, *buf;
   guint16	word;
 
-  guint32	length;
-  guint32	remainder;
+  guint32	new_length, check_length;
+  guint32	remainder, tvb_bits;
 
   /* Calculate the size reqired */
 
-  length = no_of_bits/8;
+  new_length = no_of_bits/8;
   remainder = no_of_bits % 8;
+  
   if(remainder){
-	  length++;
+	  new_length++;
   }else{
 	  /* Number of bits = even number of octets */
-	return new_octet_aligned_subset(tvb, offset, actx, length);
+	return new_octet_aligned_subset(tvb, boffset, actx, new_length);
   }
-  buf = ep_alloc(length);
 
-  /* get the 'odd' bits */
-  shift1 = offset & 0x07;
-  word = tvb_get_ntohs(tvb,boffset) & bit_mask16[offset & 0x07];
-  word = word >> (16-(shift1+remainder));
-  buf[0] = word & 0x00ff;
+  /* The bits can be contained in two "extra octets" .... .xxx [xxxx]*n xx... ....*/
+  tvb_bits = (boffset & 7)+ no_of_bits;
+  check_length = tvb_bits/8;
+  remainder = no_of_bits % 8;
+  if(remainder){
+	  check_length++;
+  }
 
-  offset = offset + remainder;
-  boffset = offset >> 3;
-  if (length >1){
+
+  /*  Throw an exception if we're asked to display more bits than exist.
+   *  We check now to ensure we don't cause g_malloc() to abort because
+   *  we asked for entirely too much memory.
+   */
+  if (new_length > check_length)
+    THROW(ReportedBoundsError);	/* indicate that the packet is malformed */
+  tvb_ensure_bytes_exist(tvb, offset, check_length);
+  buf = g_malloc(new_length);
+
+  if (actx->aligned)
+  {
+    /* get the 'odd' bits */
     shift1 = offset & 0x07;
-    shift0 = 8 - shift1;
-    octet0 = tvb_get_guint8(tvb, boffset);
-    for (i=1; i<length; i++) {
-      octet1 = octet0;
-      octet0 = tvb_get_guint8(tvb, boffset + i);
-      buf[i] = (octet1 << shift1) | (octet0 >> shift0);
+    word = tvb_get_ntohs(tvb, offset) & bit_mask16[offset & 0x07];
+    word = word >> (16-(shift1+remainder));
+    buf[0] = word & 0x00ff;
+
+    boffset = boffset + remainder;
+    offset = boffset >> 3;
+    if (new_length >1){
+      shift1 = offset & 0x07;
+      shift0 = 8 - shift1;
+      octet0 = tvb_get_guint8(tvb, offset);
+      for (i=1; i<new_length; i++) {
+        octet1 = octet0;
+        octet0 = tvb_get_guint8(tvb, offset + i);
+        buf[i] = (octet1 << shift1) | (octet0 >> shift0);
+      }
     }
   }
-  sub_tvb = tvb_new_real_data(buf, length, length);
-  tvb_set_child_real_data_tvbuff(tvb, sub_tvb);
+  else
+  {
+    /* Do not preceed with zeros in case of PER unaligned */
+    i = 0;
+    shift1 = boffset & 0x07;
+    shift0 = 8 - shift1;
+
+    if (new_length > 1){
+      octet0 = tvb_get_guint8(tvb, offset);
+      for (; i < new_length-1; i++) {
+        octet1 = octet0;
+        octet0 = tvb_get_guint8(tvb, offset + i + 1);
+        buf[i] = (octet1 << shift1) | (octet0 >> shift0);
+      }
+    }
+    /* get the 'odd' bits */
+    if ((no_of_bits - 8*i) > shift0){
+      word = tvb_get_ntohs(tvb,offset+i) << shift1;
+    }else{
+      word = tvb_get_guint8(tvb,offset+i) << (shift1 + 8);
+    }
+    word = word & bit_mask16_unalligned[remainder];
+    word = word >> 8;
+    buf[i] = (guint8) (word & 0x00ff);
+  }
+  sub_tvb = tvb_new_child_real_data(tvb, buf, new_length, new_length);
+  tvb_set_free_cb(sub_tvb, g_free);
   add_new_data_source(actx->pinfo, sub_tvb, "Unaligned OCTET STRING");
-  
+
   return sub_tvb;
 }
 
@@ -215,7 +277,7 @@ static tvbuff_t *new_octet_aligned_subset_bits(tvbuff_t *tvb, guint32 offset, as
 /* 10 Encoding procedures -------------------------------------------------- */
 
 /* 10.2 Open type fields --------------------------------------------------- */
-static guint32 
+static guint32
 dissect_per_open_type_internal(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, void* type_cb, asn1_cb_variant variant)
 {
 	guint32 type_length, end_offset;
@@ -266,47 +328,47 @@ dissect_per_open_type_internal(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx,
 	return end_offset;
 }
 
-guint32 
+guint32
 dissect_per_open_type(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, per_type_fn type_cb)
 {
 	return dissect_per_open_type_internal(tvb, offset, actx, tree, hf_index, (void*)type_cb, CB_ASN1_ENC);
 }
 
-guint32 
+guint32
 dissect_per_open_type_pdu(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, dissector_t type_cb)
 {
 	return dissect_per_open_type_internal(tvb, offset, actx, tree, hf_index, (void*)type_cb, CB_DISSECTOR);
 }
 
-guint32 
+guint32
 dissect_per_open_type_pdu_new(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, new_dissector_t type_cb)
 {
 	return dissect_per_open_type_internal(tvb, offset, actx, tree, hf_index, (void*)type_cb, CB_NEW_DISSECTOR);
 }
 
-/* 10.9 General rules for encoding a length determinant -------------------- 
-	
-	  NOTE 1 - (Tutorial) The procedures of this subclause are invoked when an explicit length field is needed 
-				for some part of the encoding regardless of whether the length count is bounded above 
-				(by PER-visible constraints) or not. The part of the encoding to which the length applies may 
-				be a bit string (with the length count in bits), an octet string (with the length count in octets), 
-				a known-multiplier character string (with the length count in characters), or a list of fields 
+/* 10.9 General rules for encoding a length determinant --------------------
+
+	  NOTE 1 - (Tutorial) The procedures of this subclause are invoked when an explicit length field is needed
+				for some part of the encoding regardless of whether the length count is bounded above
+				(by PER-visible constraints) or not. The part of the encoding to which the length applies may
+				be a bit string (with the length count in bits), an octet string (with the length count in octets),
+				a known-multiplier character string (with the length count in characters), or a list of fields
 				(with the length count in components of a sequence-of or set-of).
-	
-	  NOTE 2 - (Tutorial) In the case of the ALIGNED variant if the length count is bounded above by an upper bound 
-				that is less than 64K, then the constrained whole number encoding is used for the length. 
-				For sufficiently small ranges the result is a bit-field, otherwise the unconstrained length ("n" say) 
+
+	  NOTE 2 - (Tutorial) In the case of the ALIGNED variant if the length count is bounded above by an upper bound
+				that is less than 64K, then the constrained whole number encoding is used for the length.
+				For sufficiently small ranges the result is a bit-field, otherwise the unconstrained length ("n" say)
 				is encoded into an octet-aligned bit-field in one of three ways (in order of increasing size):
 		a)	("n" less than 128) a single octet containing "n" with bit 8 set to zero;
 		b)	("n" less than 16K) two octets containing "n" with bit 8 of the first octet set to 1 and bit 7 set to zero;
-		c)	(large "n") a single octet containing a count "m" with bit 8 set to 1 and bit 7 set to 1. 
-			The count "m" is one to four, and the length indicates that a fragment of the material follows 
+		c)	(large "n") a single octet containing a count "m" with bit 8 set to 1 and bit 7 set to 1.
+			The count "m" is one to four, and the length indicates that a fragment of the material follows
 			(a multiple "m" of 16K items). For all values of "m", the fragment is then followed by another length encoding
 			for the remainder of the material.
-	
+
 	  NOTE 3 - (Tutorial) In the UNALIGNED variant, if the length count is bounded above by an upper bound that is less
-			than 64K, then the constrained whole number encoding is used to encode the length in the minimum number of 
-			bits necessary to represent the range. Otherwise, the unconstrained length ("n" say) is encoded into a bit 
+			than 64K, then the constrained whole number encoding is used to encode the length in the minimum number of
+			bits necessary to represent the range. Otherwise, the unconstrained length ("n" say) is encoded into a bit
 			field in the manner described above in Note 2.
 
  */
@@ -333,7 +395,7 @@ dissect_per_length_determinant(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx _
 		char *str;
 		guint32 val;
 		gint val_start;
-		
+
 		val_start = offset>>3;
 		val = 0;
 		str=ep_alloc(256);
@@ -380,7 +442,7 @@ dissect_per_length_determinant(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx _
 				else
 					PROTO_ITEM_SET_HIDDEN(pi);
 			}
-		
+
 			return offset;
 		}
 		else if (num_bits==16) {
@@ -392,7 +454,7 @@ dissect_per_length_determinant(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx _
 				else
 					PROTO_ITEM_SET_HIDDEN(pi);
 			}
-        
+
 			return offset;
 		}
 		PER_NOT_DECODED_YET("10.9 Unaligned");
@@ -429,7 +491,7 @@ dissect_per_length_determinant(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx _
 static guint32
 dissect_per_normally_small_nonnegative_whole_number(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, guint32 *length)
 {
-	gboolean small_number;
+	gboolean small_number, length_bit;
 	guint32 len;
 	proto_item *pi;
 
@@ -445,18 +507,14 @@ DEBUG_ENTRY("dissect_per_normally_small_nonnegative_whole_number");
 		/* 10.6.1 */
 		*length=0;
 		for(i=0;i<6;i++){
-			offset=dissect_per_boolean(tvb, offset, actx, tree, -1, &small_number);
+			offset=dissect_per_boolean(tvb, offset, actx, tree, -1, &length_bit);
 			*length<<=1;
-			if(small_number){
+			if (length_bit) {
 				*length|=1;
 			}
 		}
 		if(hf_index!=-1){
-			if((offset&0x07)<7){
-				pi = proto_tree_add_uint(tree, hf_index, tvb, (offset>>3)-1, 1, *length);
-			} else {
-				pi = proto_tree_add_uint(tree, hf_index, tvb, (offset>>3), 1, *length);
-			}
+			pi = proto_tree_add_uint(tree, hf_index, tvb, (offset-6)>>3, (offset%8<6)?2:1, *length);
 			if (!display_internal_per_fields) PROTO_ITEM_SET_HIDDEN(pi);
 		}
 		return offset;
@@ -497,7 +555,7 @@ guint32
 dissect_per_null(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx _U_, proto_tree *tree, int hf_index) {
   proto_item *ti_tmp;
 
-  ti_tmp = proto_tree_add_item(tree, hf_index, tvb, offset>>8, 0, FALSE);
+  ti_tmp = proto_tree_add_item(tree, hf_index, tvb, offset>>3, 1, FALSE);
   proto_item_append_text(ti_tmp, ": NULL");
 
   return offset;
@@ -561,16 +619,16 @@ DEBUG_ENTRY("dissect_per_sequence_of");
    i.e. no FROM stuff limiting the alphabet
 */
 guint32
-dissect_per_IA5String(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len)
+dissect_per_IA5String(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len, gboolean has_extension)
 {
-	offset=dissect_per_octet_string(tvb, offset, actx, tree, hf_index, min_len, max_len, FALSE, NULL);
+	offset=dissect_per_octet_string(tvb, offset, actx, tree, hf_index, min_len, max_len, has_extension, NULL);
 
 	return offset;
 }
 
 /* XXX we dont do >64k length strings   yet */
 static guint32
-dissect_per_restricted_character_string_sorted(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len, const char *alphabet, int alphabet_length, tvbuff_t **value_tvb)
+dissect_per_restricted_character_string_sorted(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len, gboolean has_extension _U_,const char *alphabet, int alphabet_length, tvbuff_t **value_tvb)
 {
 	guint32 length;
 	gboolean byte_aligned;
@@ -584,8 +642,7 @@ DEBUG_ENTRY("dissect_per_restricted_character_string");
 	/* xx.x if the length is 0 bytes there will be no encoding */
 	if(max_len==0){
 		if (value_tvb) {
-			*value_tvb = tvb_new_real_data(NULL, 0, 0); 
-			tvb_set_child_real_data_tvbuff(tvb, *value_tvb);
+			*value_tvb = tvb_new_child_real_data(tvb, NULL, 0, 0);
 		}
 		return offset;
 	}
@@ -629,6 +686,25 @@ DEBUG_ENTRY("dissect_per_restricted_character_string");
 			bits_per_char=8;
 		}
 	}
+	/* 27.4	If the type is extensible for PER encodings (see 9.3.16), 
+	 * then a bit-field consisting of a single bit shall be added to the field-list. 
+	 * The single bit shall be set to zero if the value is within the range of the extension root,
+	 * and to one otherwise. If the value is outside the range of the extension root, 
+	 * then the following encoding shall be as if there was no effective size constraint, 
+	 * and shall have an effective permitted-alphabet constraint that consists of the set of characters 
+	 * of the unconstrained type.
+	 * 	NOTE - Only the known-multiplier character string types can be extensible for PER encodings. 
+	 * Extensibility markers on other character string types do not affect the PER encoding.
+	 */
+
+	if (has_extension) {
+		gboolean extension_present;
+		offset = dissect_per_boolean(tvb, offset, actx, tree, hf_per_extension_present_bit, &extension_present);
+		if(extension_present){
+			min_len = NO_BOUND;
+			max_len = NO_BOUND;
+		}
+	}
 
 	byte_aligned=TRUE;
 	if((min_len==max_len)&&(max_len<=2)){
@@ -674,8 +750,8 @@ DEBUG_ENTRY("dissect_per_restricted_character_string");
 			offset=dissect_per_boolean(tvb, offset, actx, tree, -1, &bit);
 			val=(val<<1)|bit;
 		}
-		/* ALIGNED PER does not do any remapping of chars if 
-		   bitsperchar is 8 
+		/* ALIGNED PER does not do any remapping of chars if
+		   bitsperchar is 8
 		*/
 		if(bits_per_char==8){
 			buf[char_pos]=val;
@@ -690,9 +766,8 @@ DEBUG_ENTRY("dissect_per_restricted_character_string");
 	buf[char_pos]=0;
 	proto_tree_add_string(tree, hf_index, tvb, (old_offset>>3), (offset>>3)-(old_offset>>3), (char*)buf);
 	if (value_tvb) {
-		*value_tvb = tvb_new_real_data(buf, length, length); 
+		*value_tvb = tvb_new_child_real_data(tvb, buf, length, length);
 		tvb_set_free_cb(*value_tvb, g_free);
-		tvb_set_child_real_data_tvbuff(tvb, *value_tvb);
 	} else {
 		g_free(buf);
 	}
@@ -722,7 +797,7 @@ sort_alphabet(char *sorted_alphabet, const char *alphabet, int alphabet_length)
 }
 
 guint32
-dissect_per_restricted_character_string(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len, const char *alphabet, int alphabet_length, tvbuff_t **value_tvb)
+dissect_per_restricted_character_string(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len, gboolean has_extension, const char *alphabet, int alphabet_length, tvbuff_t **value_tvb)
 {
   const char *alphabet_ptr;
   char sorted_alphabet[128];
@@ -732,33 +807,33 @@ dissect_per_restricted_character_string(tvbuff_t *tvb, guint32 offset, asn1_ctx_
   } else {
     alphabet_ptr = sort_alphabet(sorted_alphabet, alphabet, alphabet_length);
   }
-  return dissect_per_restricted_character_string_sorted(tvb, offset, actx, tree, hf_index, min_len, max_len, alphabet_ptr, alphabet_length, value_tvb);
+  return dissect_per_restricted_character_string_sorted(tvb, offset, actx, tree, hf_index, min_len, max_len, has_extension, alphabet_ptr, alphabet_length, value_tvb);
 }
 
 guint32
-dissect_per_NumericString(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len)
+dissect_per_NumericString(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len, gboolean has_extension)
 {
-	offset=dissect_per_restricted_character_string_sorted(tvb, offset, actx, tree, hf_index, min_len, max_len, 
+	offset=dissect_per_restricted_character_string_sorted(tvb, offset, actx, tree, hf_index, min_len, max_len, has_extension,
 		" 0123456789", 11, NULL);
 
 	return offset;
 }
 guint32
-dissect_per_PrintableString(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len)
+dissect_per_PrintableString(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len, gboolean has_extension)
 {
-	offset=dissect_per_restricted_character_string_sorted(tvb, offset, actx, tree, hf_index, min_len, max_len, 
+	offset=dissect_per_restricted_character_string_sorted(tvb, offset, actx, tree, hf_index, min_len, max_len, has_extension,
 		" '()+,-.*0123456789:=?ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz", 74, NULL);
 	return offset;
 }
 guint32
-dissect_per_VisibleString(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len)
+dissect_per_VisibleString(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len, gboolean has_extension)
 {
-	offset=dissect_per_restricted_character_string_sorted(tvb, offset, actx, tree, hf_index, min_len, max_len,
+	offset=dissect_per_restricted_character_string_sorted(tvb, offset, actx, tree, hf_index, min_len, max_len, has_extension,
 		" !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~", 95, NULL);
 	return offset;
 }
 guint32
-dissect_per_BMPString(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len)
+dissect_per_BMPString(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len, gboolean has_extension _U_)
 {
 	guint32 length;
 	static char *str;
@@ -801,7 +876,7 @@ dissect_per_BMPString(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tre
 	return offset;
 }
 
-guint32 
+guint32
 dissect_per_object_descriptor(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, tvbuff_t **value_tvb)
 {
 	offset=dissect_per_octet_string(tvb, offset, actx, tree, hf_index, -1, -1, FALSE, value_tvb);
@@ -812,7 +887,7 @@ dissect_per_object_descriptor(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, p
 
 /* this function dissects a constrained sequence of */
 guint32
-dissect_per_constrained_sequence_of(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *parent_tree, int hf_index, gint ett_index, const per_sequence_t *seq, int min_len, int max_len)
+dissect_per_constrained_sequence_of(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *parent_tree, int hf_index, gint ett_index, const per_sequence_t *seq, int min_len, int max_len, gboolean has_extension _U_)
 {
 	proto_item *item;
 	proto_tree *tree;
@@ -822,6 +897,22 @@ dissect_per_constrained_sequence_of(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *a
 
 DEBUG_ENTRY("dissect_per_constrained_sequence_of");
 
+	/* 19.4	If there is a PER-visible constraint and an extension marker is present in it,
+	 * a single bit shall be added to the field-list in a bit-field of length one
+	 */
+	if(has_extension){
+		gboolean extension_present;
+		offset=dissect_per_boolean(tvb, offset, actx, parent_tree, hf_per_extension_present_bit, &extension_present);
+		if (!display_internal_per_fields) PROTO_ITEM_SET_HIDDEN(actx->created_item);
+		if(extension_present){
+			/* 10.9 shall be invoked to add the length determinant as a semi-constrained whole number to the field-list,
+			 * followed by the component values
+			 * TODO: Handle extension
+			 */
+			proto_tree_add_text(parent_tree, tvb, (offset>>3), 1, "dissect_per_constrained_sequence_of with extension is not handled");
+		}
+	}
+
 	/* 19.5 if min==max and min,max<64k ==> no length determinant */
 	if((min_len==max_len) && (min_len<65536)){
 		length=min_len;
@@ -851,20 +942,27 @@ call_sohelper:
 	}
 	tree=proto_item_add_subtree(item, ett_index);
 
+	old_offset = offset;
 	offset=dissect_per_sequence_of_helper(tvb, offset, actx, tree, seq->func, *seq->p_id, length);
 
+	if (offset == old_offset)
+		length = 0;
+	else if (offset >> 3 == old_offset >> 3)
+			length = 1;
+		else
+			length = (offset >> 3) - (old_offset >> 3);
 
-	proto_item_set_len(item, (offset>>3)!=(old_offset>>3)?(offset>>3)-(old_offset>>3):1);
+	proto_item_set_len(item, length);
 	return offset;
 }
 
 /* this function dissects a constrained set of */
 guint32
-dissect_per_constrained_set_of(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *parent_tree, int hf_index, gint ett_index, const per_sequence_t *seq, int min_len, int max_len)
+dissect_per_constrained_set_of(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *parent_tree, int hf_index, gint ett_index, const per_sequence_t *seq, int min_len, int max_len, gboolean has_extension)
 {
 	/* for basic-per  a set-of is encoded in the same way as a sequence-of */
 DEBUG_ENTRY("dissect_per_constrained_set_of");
-	offset=dissect_per_constrained_sequence_of(tvb, offset, actx, parent_tree, hf_index, ett_index, seq, min_len, max_len);
+	offset=dissect_per_constrained_sequence_of(tvb, offset, actx, parent_tree, hf_index, ett_index, seq, min_len, max_len, has_extension);
 	return offset;
 }
 
@@ -900,7 +998,7 @@ DEBUG_ENTRY("dissect_per_object_identifier");
   offset = dissect_per_length_determinant(tvb, offset, actx, tree, hf_per_object_identifier_length, &length);
   if (actx->aligned) BYTE_ALIGN_OFFSET(offset);
   val_tvb = new_octet_aligned_subset(tvb, offset, actx, length);
-	
+
   hfi = proto_registrar_get_nth(hf_index);
   if (hfi->type == FT_OID) {
     actx->created_item = proto_tree_add_item(tree, hf_index, val_tvb, 0, length, FALSE);
@@ -959,8 +1057,7 @@ DEBUG_ENTRY("dissect_per_boolean");
 	if(hf_index!=-1){
 		char *str;
 		hfi = proto_registrar_get_nth(hf_index);
-		str=ep_alloc(256);
-		g_snprintf(str, 256, "%c%c%c%c %c%c%c%c %s: %s",
+		str=ep_strdup_printf("%c%c%c%c %c%c%c%c %s: %s",
 			mask&0x80?'0'+value:'.',
 			mask&0x40?'0'+value:'.',
 			mask&0x20?'0'+value:'.',
@@ -996,10 +1093,10 @@ dissect_per_integer(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree
 	header_field_info *hfi;
 
 	/* 12.2.6 b */
-	offset=dissect_per_length_determinant(tvb, offset, actx, tree, -1, &length);
+	offset=dissect_per_length_determinant(tvb, offset, actx, tree,hf_per_integer_length, &length);
 	/* gassert here? */
 	if(length>4){
-PER_NOT_DECODED_YET("too long integer");
+PER_NOT_DECODED_YET("too long integer(per_integer)");
 		length=4;
 	}
 
@@ -1052,7 +1149,7 @@ dissect_per_integer64b(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tr
 	offset=dissect_per_length_determinant(tvb, offset, actx, tree, -1, &length);
 	/* gassert here? */
 	if(length>8){
-PER_NOT_DECODED_YET("too long integer");
+PER_NOT_DECODED_YET("too long integer (64b)");
 		length=4;
 	}
 
@@ -1138,7 +1235,7 @@ DEBUG_ENTRY("dissect_per_constrained_integer");
 
 	hfi = proto_registrar_get_nth(hf_index);
 
-	/* 10.5.3 Let "range" be defined as the integer value ("ub" - "lb"   1), and let the value to be encoded be "n". 
+	/* 10.5.3 Let "range" be defined as the integer value ("ub" - "lb"   1), and let the value to be encoded be "n".
 	 * 10.5.7	In the case of the ALIGNED variant the encoding depends on whether
 	 *			d)	"range" is greater than 64K (the indefinite length case).
 	 */
@@ -1173,9 +1270,9 @@ DEBUG_ENTRY("dissect_per_constrained_integer");
 
 	if(range==1){
 		val_start = offset>>3; val_length = 0;
-		val = min; 
+		val = min;
 	} else if((range<=255)||(!actx->aligned)) {
-		/* 10.5.7.1 
+		/* 10.5.7.1
 		 * 10.5.6	In the case of the UNALIGNED variant the value ("n" - "lb") shall be encoded
 		 * as a non-negative  binary integer in a bit field as specified in 10.3 with the minimum
 		 * number of bits necessary to represent the range.
@@ -1309,7 +1406,7 @@ DEBUG_ENTRY("dissect_per_constrained_integer");
 guint32
 dissect_per_constrained_integer_64b(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, guint64 min, guint64 max, guint64 *value, gboolean has_extension)
 {
-	proto_item *it=NULL;
+	proto_item *it=NULL, *int_item=NULL;
 	guint64 range, val;
 	gint val_start, val_length;
 	nstime_t timeval;
@@ -1331,14 +1428,17 @@ DEBUG_ENTRY("dissect_per_constrained_integer_64b");
 
 	hfi = proto_registrar_get_nth(hf_index);
 
-	/* 10.5.3 Let "range" be defined as the integer value ("ub" - "lb"   1), and let the value to be encoded be "n". 
+	/* 10.5.3 Let "range" be defined as the integer value ("ub" - "lb"   1), and let the value to be encoded be "n".
 	 * 10.5.7	In the case of the ALIGNED variant the encoding depends on whether
 	 *			d)	"range" is greater than 64K (the indefinite length case).
 	 */
 	if(((max-min)>65536)&&(actx->aligned)){
-		/* just set range really big so it will fall through
-		   to the bottom of the encoding */
-		range=1000000;
+               /* just set range really big so it will fall through
+                  to the bottom of the encoding */
+               /* range=1000000; */
+			   range = max-min;
+			   if (range==65536)
+				   range++; /* make it fall trough? */
 	} else {
 		/* Copied from the 32 bit version, asuming the same problem occures
 		 * at 64 bit boundary.
@@ -1368,9 +1468,9 @@ DEBUG_ENTRY("dissect_per_constrained_integer_64b");
 
 	if(range==1){
 		val_start = offset>>3; val_length = 0;
-		val = min; 
+		val = min;
 	} else if((range<=255)||(!actx->aligned)) {
-		/* 10.5.7.1 
+		/* 10.5.7.1
 		 * 10.5.6	In the case of the UNALIGNED variant the value ("n" - "lb") shall be encoded
 		 * as a non-negative  binary integer in a bit field as specified in 10.3 with the minimum
 		 * number of bits necessary to represent the range.
@@ -1462,20 +1562,23 @@ DEBUG_ENTRY("dissect_per_constrained_integer_64b");
 		val_start = (offset>>3)-2; val_length = 2;
 		val+=min;
 	} else {
-		int i,num_bytes;
-		gboolean bit;
+		int i,num_bytes,num_bits;
 
 		/* 10.5.7.4 */
 		/* 12.2.6 */
-		offset=dissect_per_boolean(tvb, offset, actx, tree, -1, &bit);
-		num_bytes=bit;
-		offset=dissect_per_boolean(tvb, offset, actx, tree, -1, &bit);
-		num_bytes=(num_bytes<<1)|bit;
-
+		/* calculate the number of bits to hold the length */
+		if ((range & G_GINT64_CONSTANT(0xffffffff0000000)) != 0){
+			num_bits=3;
+		}else{
+			num_bits=2;
+		}
+		num_bytes =tvb_get_bits8(tvb, offset, num_bits);
 		num_bytes++;  /* lower bound for length determinant is 1 */
-		if (display_internal_per_fields)
-			proto_tree_add_uint(tree, hf_per_const_int_len, tvb, (offset>>3), 1, num_bytes);
-
+		if (display_internal_per_fields){
+			int_item = proto_tree_add_bits_item(tree, hf_per_const_int_len, tvb, offset,num_bits, FALSE);
+			proto_item_append_text(int_item,"+1=%u bytes, Range = (%" G_GINT64_MODIFIER "u)",num_bytes, range);
+		}
+		offset = offset+num_bits;
 		/* byte aligned */
 		BYTE_ALIGN_OFFSET(offset);
 		val=0;
@@ -1487,7 +1590,7 @@ DEBUG_ENTRY("dissect_per_constrained_integer_64b");
 		val+=min;
 	}
 
-	
+
 	if (IS_FT_UINT(hfi->type)) {
 		it = proto_tree_add_uint64(tree, hf_index, tvb, val_start, val_length, val);
 	} else if (IS_FT_INT(hfi->type)) {
@@ -1533,7 +1636,7 @@ dissect_per_enumerated(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tr
 			enum_index = 0;
 		} else {
 			/* 13.3 ".. and the value shall be added to the field-list as a
-			 * normally small non-negative whole number whose value is the 
+			 * normally small non-negative whole number whose value is the
 			 * enumeration index of the additional enumeration and with "lb" set to 0.."
 			 */
 			offset = dissect_per_normally_small_nonnegative_whole_number(tvb, offset, actx, tree, hf_per_enum_extension_index, &enum_index);
@@ -1553,7 +1656,7 @@ dissect_per_enumerated(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tr
 }
 
 /* 14 Encoding the real type */
-guint32 
+guint32
 dissect_per_real(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, double *value)
 {
 	guint32 val_length, end_offset;
@@ -1666,7 +1769,7 @@ DEBUG_ENTRY("dissect_per_choice");
 		}
 	}
 
-	if (value && (index != -1)) 
+	if (value && (index != -1))
 		*value = choice[index].value;
 
 	return offset;
@@ -1787,6 +1890,9 @@ DEBUG_ENTRY("dissect_per_sequence");
 		||  (sequence[i].extension==ASN1_EXTENSION_ROOT) ){
 			if(sequence[i].optional==ASN1_OPTIONAL){
 				gboolean is_present;
+				if (num_opts == 0){
+					continue;
+				}
 				is_present=(1<<(num_opts-1))&optional_mask;
 				num_opts--;
 				if(!is_present){
@@ -1883,14 +1989,15 @@ DEBUG_ENTRY("dissect_per_sequence");
 
 			if(sequence[extension_index].func){
 				new_offset=sequence[extension_index].func(tvb, offset, actx, tree, *sequence[extension_index].p_id);
+				if (new_offset == offset) new_offset += 8;  /* OpenType has at least 1 octet */
 				offset+=length*8;
 				difference = offset - new_offset;
 				/* A difference of 7 or less might be byte aligning */
 				if(difference > 7){
-					cause=proto_tree_add_text(tree, tvb, new_offset>>3, (offset-new_offset)>>3, 
+					cause=proto_tree_add_text(tree, tvb, new_offset>>3, (offset-new_offset)>>3,
 						"[Possible encoding error full length not decoded. Open type length %u ,decoded %u]",length, length - (difference>>3));
 					proto_item_set_expert_flags(cause, PI_MALFORMED, PI_WARN);
-					expert_add_info_format(actx->pinfo, cause, PI_MALFORMED, PI_WARN, 
+					expert_add_info_format(actx->pinfo, cause, PI_MALFORMED, PI_WARN,
 						"Possible encoding error full length not decoded. Open type length %u ,decoded %u",length, length - (difference>>3));
 				}
 			} else {
@@ -1931,6 +2038,38 @@ DEBUG_ENTRY("dissect_per_bit_string");
 	if (min_len == NO_BOUND) {
 		min_len = 0;
 	}
+	/* 15.6	If an extension marker is present in the size constraint specification of the bitstring type,
+	 * a single bit shall be added to the field-list in a bit-field of length one. 
+	 * The bit shall be set to 1 if the length of this encoding is not within the range of the extension root,
+	 * and zero otherwise.
+	 */
+	 if (has_extension) {
+		 gboolean extension_present;
+		 offset = dissect_per_boolean(tvb, offset, actx, tree, hf_per_extension_present_bit, &extension_present);
+		 if(extension_present){
+			offset=dissect_per_length_determinant(tvb, offset, actx, tree, hf_per_bit_string_length, &length);
+			if(length){
+				/* align to byte */
+				if (actx->aligned){
+					BYTE_ALIGN_OFFSET(offset);
+				}
+				out_tvb = new_octet_aligned_subset_bits(tvb, offset, actx, length);
+
+				if (hfi) {
+					actx->created_item = proto_tree_add_item(tree, hf_index, out_tvb, 0, -1, FALSE);
+					proto_item_append_text(actx->created_item, " [bit length %u]", length);
+				}
+			}
+			val_start = offset>>3;
+			val_length = (length+7)/8;
+			offset+=length;
+
+			if (value_tvb)
+				*value_tvb = out_tvb;
+
+			return offset;
+		 }
+	 }
 
 	/* 15.9 if length is fixed and less than or equal to sixteen bits*/
 	if ((min_len==max_len) && (max_len<=16)) {
@@ -1948,8 +2087,8 @@ DEBUG_ENTRY("dissect_per_bit_string");
 
 	/* 15.10 if length is fixed and less than to 64kbits*/
 	if((min_len==max_len)&&(min_len<65536)){
-		/* (octet-aligned in the ALIGNED variant) 
-		 * align to byte 
+		/* (octet-aligned in the ALIGNED variant)
+		 * align to byte
 		 */
 		if (actx->aligned){
 			/* TODO the displayed value will be wrong for the unaligned variant */
@@ -1970,7 +2109,7 @@ DEBUG_ENTRY("dissect_per_bit_string");
 	if (max_len != NO_BOUND) {
 		offset=dissect_per_constrained_integer(tvb, offset, actx,
 			tree, hf_per_bit_string_length, min_len, max_len,
-			&length, has_extension);
+			&length, FALSE);
 			if (!display_internal_per_fields) PROTO_ITEM_SET_HIDDEN(actx->created_item);
 	} else {
 		offset=dissect_per_length_determinant(tvb, offset, actx, tree, hf_per_bit_string_length, &length);
@@ -1981,6 +2120,7 @@ DEBUG_ENTRY("dissect_per_bit_string");
 			BYTE_ALIGN_OFFSET(offset);
 		}
 		out_tvb = new_octet_aligned_subset_bits(tvb, offset, actx, length);
+
 		if (hfi) {
 			actx->created_item = proto_tree_add_item(tree, hf_index, out_tvb, 0, -1, FALSE);
 			proto_item_append_text(actx->created_item, " [bit length %u]", length);
@@ -2063,17 +2203,17 @@ DEBUG_ENTRY("dissect_per_octet_string");
 		min_len = 0;
 	}
 	if (max_len==0) {  /* 16.5 if the length is 0 bytes there will be no encoding */
-		val_start = offset>>3; 
+		val_start = offset>>3;
 		val_length = 0;
 
-	} else if((min_len==max_len)&&(max_len<=2)) {  
+	} else if((min_len==max_len)&&(max_len<=2)) {
 		/* 16.6 if length is fixed and less than or equal to two bytes*/
-		val_start = offset>>3; 
+		val_start = offset>>3;
 		val_length = min_len;
 		out_tvb = new_octet_aligned_subset(tvb, offset, actx, val_length);
 		offset+=min_len*8;
 
-	} else if ((min_len==max_len)&&(min_len<65536)) {  
+	} else if ((min_len==max_len)&&(min_len<65536)) {
 		/* 16.7 if length is fixed and less than to 64k*/
 
 		/* align to byte */
@@ -2086,14 +2226,14 @@ DEBUG_ENTRY("dissect_per_octet_string");
 		offset+=min_len*8;
 
 	} else {  /* 16.8 */
-		if(max_len>0) {  
+		if(max_len>0) {
 			offset = dissect_per_constrained_integer(tvb, offset, actx, tree,
 				hf_per_octet_string_length, min_len, max_len, &length, FALSE);
 
-				if (!display_internal_per_fields) 
+				if (!display_internal_per_fields)
 					PROTO_ITEM_SET_HIDDEN(actx->created_item);
 		} else {
-			offset = dissect_per_length_determinant(tvb, offset, actx, tree, 
+			offset = dissect_per_length_determinant(tvb, offset, actx, tree,
 				hf_per_octet_string_length, &length);
 		}
 
@@ -2104,7 +2244,7 @@ DEBUG_ENTRY("dissect_per_octet_string");
 			}
 			out_tvb = new_octet_aligned_subset(tvb, offset, actx, length);
 		} else {
-			val_start = offset>>3; 
+			val_start = offset>>3;
 		}
 		val_length = length;
 		offset+=length*8;
@@ -2216,8 +2356,8 @@ gboolean get_size_constraint_from_stack(asn1_ctx_t *actx, const gchar *name, int
     encoding CHOICE {
     single-ASN1-type [0] ABSTRACT-SYNTAX.&Type,
     octet-aligned [1] IMPLICIT OCTET STRING,
-    arbitrary [2] IMPLICIT BIT STRING 
-  } 
+    arbitrary [2] IMPLICIT BIT STRING
+  }
 }
 */
 /* NOTE: This sequence type differs from that in ITU-T Rec. X.680 | ISO/IEC 8824-1 for historical reasons. */
@@ -2330,7 +2470,7 @@ dissect_per_External(tvbuff_t *tvb _U_, int offset _U_, asn1_ctx_t *actx _U_, pr
   return offset;
 }
 
-guint32 
+guint32
 dissect_per_external_type(tvbuff_t *tvb _U_, guint32 offset, asn1_ctx_t *actx, proto_tree *tree _U_, int hf_index _U_, per_type_fn type_cb)
 {
   asn1_ctx_clean_external(actx);
@@ -2420,12 +2560,16 @@ proto_register_per(void)
         "per.T_single_ASN1_type", HFILL }},
     { &hf_per_octet_aligned,
       { "octet-aligned", "per.octet_aligned",
-        FT_BYTES, BASE_HEX, NULL, 0,
+        FT_BYTES, BASE_NONE, NULL, 0,
         "per.T_octet_aligned", HFILL }},
     { &hf_per_arbitrary,
       { "arbitrary", "per.arbitrary",
-        FT_BYTES, BASE_HEX, NULL, 0,
+        FT_BYTES, BASE_NONE, NULL, 0,
         "per.T_arbitrary", HFILL }},
+    { &hf_per_integer_length,
+      { "integer length", "per.integer_length",
+        FT_UINT32, BASE_DEC, NULL, 0,
+        NULL, HFILL }},
 	};
 	static gint *ett[] =
 	{
