@@ -1,7 +1,7 @@
 /* packet-pgm.c
  * Routines for PGM packet disassembly, RFC 3208
  *
- * $Id: packet-pgm.c 27822 2009-03-22 20:55:31Z wmeier $
+ * $Id: packet-pgm.c 33123 2010-06-07 01:58:57Z gerald $
  *
  * Copyright (c) 2000 by Talarian Corp
  * Rewritten by Jaap Keuter
@@ -200,6 +200,7 @@ static int hf_pgm_opt_type = -1;
 static int hf_pgm_opt_len = -1;
 static int hf_pgm_opt_tlen = -1;
 
+static int hf_pgm_genopt_end = -1;
 static int hf_pgm_genopt_type = -1;
 static int hf_pgm_genopt_len = -1;
 static int hf_pgm_genopt_opx = -1;
@@ -423,6 +424,7 @@ dissect_pgmopts(ptvcursor_t* cursor, const char *pktname)
 			opt_tree = proto_item_add_subtree(tf, ett_pgm_opts_join);
 			ptvcursor_set_tree(cursor, opt_tree);
 
+			ptvcursor_add_no_advance(cursor, hf_pgm_genopt_end, 1, FALSE);
 			ptvcursor_add(cursor, hf_pgm_genopt_type, 1, FALSE);
 
 			if (genopts_len < PGM_OPT_JOIN_SIZE) {
@@ -445,8 +447,10 @@ dissect_pgmopts(ptvcursor_t* cursor, const char *pktname)
 			opt_tree = proto_item_add_subtree(tf, ett_pgm_opts_parityprm);
 			ptvcursor_set_tree(cursor, opt_tree);
 
+			ptvcursor_add_no_advance(cursor, hf_pgm_genopt_end, 1, FALSE);
 			ptvcursor_add(cursor, hf_pgm_genopt_type, 1, FALSE);
 			
+			
 			if (genopts_len < PGM_OPT_PARITY_PRM_SIZE) {
 				proto_tree_add_uint_format(opt_tree, hf_pgm_genopt_len, ptvcursor_tvbuff(cursor),
 					ptvcursor_current_offset(cursor), 1, genopts_len,
@@ -470,6 +474,7 @@ dissect_pgmopts(ptvcursor_t* cursor, const char *pktname)
 			opt_tree = proto_item_add_subtree(tf, ett_pgm_opts_paritygrp);
 			ptvcursor_set_tree(cursor, opt_tree);
 
+			ptvcursor_add_no_advance(cursor, hf_pgm_genopt_end, 1, FALSE);
 			ptvcursor_add(cursor, hf_pgm_genopt_type, 1, FALSE);
 
 			if (genopts_len < PGM_OPT_PARITY_GRP_SIZE) {
@@ -496,6 +501,7 @@ dissect_pgmopts(ptvcursor_t* cursor, const char *pktname)
 			opt_tree = proto_item_add_subtree(tf, ett_pgm_opts_naklist);
 			ptvcursor_set_tree(cursor, opt_tree);
 
+			ptvcursor_add_no_advance(cursor, hf_pgm_genopt_end, 1, FALSE);
 			ptvcursor_add(cursor, hf_pgm_genopt_type, 1, FALSE);
 			
 			optdata_len = tvb_get_guint8(tvb, ptvcursor_current_offset(cursor));
@@ -554,6 +560,7 @@ dissect_pgmopts(ptvcursor_t* cursor, const char *pktname)
 			opt_tree = proto_item_add_subtree(tf, ett_pgm_opts_ccdata);
 			ptvcursor_set_tree(cursor, opt_tree);
 
+			ptvcursor_add_no_advance(cursor, hf_pgm_genopt_end, 1, FALSE);
 			ptvcursor_add(cursor, hf_pgm_genopt_type, 1, FALSE);
 
 			if (genopts_len < PGM_OPT_PGMCC_DATA_SIZE) {
@@ -568,8 +575,8 @@ dissect_pgmopts(ptvcursor_t* cursor, const char *pktname)
 			ptvcursor_add(cursor, hf_pgm_opt_ccdata_res, 1, FALSE);
 			ptvcursor_add(cursor, hf_pgm_opt_ccdata_tsp, 4, FALSE);
 			optdata_afi = tvb_get_ntohs(tvb, ptvcursor_current_offset(cursor));
-			ptvcursor_add(cursor, hf_pgm_opt_ccdata_afi, 1, FALSE);
-			ptvcursor_add(cursor, hf_pgm_opt_ccdata_res2, 1, FALSE);
+			ptvcursor_add(cursor, hf_pgm_opt_ccdata_afi, 2, FALSE);
+			ptvcursor_add(cursor, hf_pgm_opt_ccdata_res2, 2, FALSE);
 
 			switch (optdata_afi) {
 
@@ -595,6 +602,7 @@ dissect_pgmopts(ptvcursor_t* cursor, const char *pktname)
 			opt_tree = proto_item_add_subtree(tf, ett_pgm_opts_ccdata);
 			ptvcursor_set_tree(cursor, opt_tree);
 
+			ptvcursor_add_no_advance(cursor, hf_pgm_genopt_end, 1, FALSE);
 			ptvcursor_add(cursor, hf_pgm_genopt_type, 1, FALSE);
 
 			if (genopts_len < PGM_OPT_PGMCC_FEEDBACK_SIZE) {
@@ -634,6 +642,7 @@ dissect_pgmopts(ptvcursor_t* cursor, const char *pktname)
 			opt_tree = proto_item_add_subtree(tf, ett_pgm_opts_nak_bo_ivl);
 			ptvcursor_set_tree(cursor, opt_tree);
 
+			ptvcursor_add_no_advance(cursor, hf_pgm_genopt_end, 1, FALSE);
 			ptvcursor_add(cursor, hf_pgm_genopt_type, 1, FALSE);
 
 			if (genopts_len < PGM_OPT_NAK_BO_IVL_SIZE) {
@@ -646,8 +655,8 @@ dissect_pgmopts(ptvcursor_t* cursor, const char *pktname)
 			ptvcursor_add(cursor, hf_pgm_genopt_len, 1, FALSE);
 			ptvcursor_add(cursor, hf_pgm_genopt_opx, 1, FALSE);
 			ptvcursor_add(cursor, hf_pgm_opt_nak_bo_ivl_res, 1, FALSE);
-			ptvcursor_add(cursor, hf_pgm_opt_nak_bo_ivl_bo_ivl, 1, FALSE);
-			ptvcursor_add(cursor, hf_pgm_opt_nak_bo_ivl_bo_ivl_sqn, 1, FALSE);
+			ptvcursor_add(cursor, hf_pgm_opt_nak_bo_ivl_bo_ivl, 4, FALSE);
+			ptvcursor_add(cursor, hf_pgm_opt_nak_bo_ivl_bo_ivl_sqn, 4, FALSE);
 
 			break;
 		}
@@ -655,6 +664,7 @@ dissect_pgmopts(ptvcursor_t* cursor, const char *pktname)
 			opt_tree = proto_item_add_subtree(tf, ett_pgm_opts_nak_bo_rng);
 			ptvcursor_set_tree(cursor, opt_tree);
 
+			ptvcursor_add_no_advance(cursor, hf_pgm_genopt_end, 1, FALSE);
 			ptvcursor_add(cursor, hf_pgm_genopt_type, 1, FALSE);
 
 			if (genopts_len < PGM_OPT_NAK_BO_RNG_SIZE) {
@@ -678,6 +688,7 @@ dissect_pgmopts(ptvcursor_t* cursor, const char *pktname)
 			opt_tree = proto_item_add_subtree(tf, ett_pgm_opts_redirect);
 			ptvcursor_set_tree(cursor, opt_tree);
 
+			ptvcursor_add_no_advance(cursor, hf_pgm_genopt_end, 1, FALSE);
 			ptvcursor_add(cursor, hf_pgm_genopt_type, 1, FALSE);
 
 			if (genopts_len < PGM_OPT_REDIRECT_SIZE) {
@@ -691,8 +702,8 @@ dissect_pgmopts(ptvcursor_t* cursor, const char *pktname)
 			ptvcursor_add(cursor, hf_pgm_genopt_opx, 1, FALSE);
 			ptvcursor_add(cursor, hf_pgm_opt_redirect_res, 1, FALSE);
 			optdata_afi = tvb_get_ntohs(tvb, ptvcursor_current_offset(cursor));
-			ptvcursor_add(cursor, hf_pgm_opt_redirect_afi, 1, FALSE);
-			ptvcursor_add(cursor, hf_pgm_opt_redirect_res2, 1, FALSE);
+			ptvcursor_add(cursor, hf_pgm_opt_redirect_afi, 2, FALSE);
+			ptvcursor_add(cursor, hf_pgm_opt_redirect_res2, 2, FALSE);
 
 			switch (optdata_afi) {
 
@@ -716,6 +727,7 @@ dissect_pgmopts(ptvcursor_t* cursor, const char *pktname)
 			opt_tree = proto_item_add_subtree(tf, ett_pgm_opts_fragment);
 			ptvcursor_set_tree(cursor, opt_tree);
 
+			ptvcursor_add_no_advance(cursor, hf_pgm_genopt_end, 1, FALSE);
 			ptvcursor_add(cursor, hf_pgm_genopt_type, 1, FALSE);
 
 			if (genopts_len < PGM_OPT_FRAGMENT_SIZE) {
@@ -1238,9 +1250,12 @@ proto_register_pgm(void)
     { &hf_pgm_opt_tlen,
       { "Total Length", "pgm.opts.tlen", FT_UINT16, BASE_DEC,
           NULL, 0x0, "", HFILL }},
+    { &hf_pgm_genopt_end,
+      { "Option end", "pgm.genopts.end", FT_BOOLEAN, 8,
+          TFS(&tfs_yes_no), 0x80, NULL, HFILL }},
     { &hf_pgm_genopt_type,
       { "Type", "pgm.genopts.type", FT_UINT8, BASE_HEX,
-          VALS(opt_vals), 0x0, "", HFILL }},
+          VALS(opt_vals), 0x7f, NULL, HFILL }},
     { &hf_pgm_genopt_len,
       { "Length", "pgm.genopts.len", FT_UINT8, BASE_DEC,
           NULL, 0x0, "", HFILL }},
