@@ -3,7 +3,7 @@
  * RFC 1939
  * Copyright 1999, Richard Sharpe <rsharpe@ns.aus.com>
  *
- * $Id: packet-pop.c 26356 2008-10-05 23:08:54Z wmeier $
+ * $Id: packet-pop.c 27976 2009-04-06 19:30:48Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -309,8 +309,8 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			  }
 			}
 
-			offset += next_token - line;
-			linelen -= next_token - line;
+			offset += (gint) (next_token - line);
+			linelen -= (int) (next_token - line);
 			line = next_token;
 
 		}
