@@ -2,7 +2,7 @@
  * Routines for PPP Over Ethernet (PPPoE) packet disassembly (RFC2516)
  * Up to date with http://www.iana.org/assignments/pppoe-parameters (2008-04-30)
  *
- * $Id: packet-pppoe.c 27542 2009-02-25 11:25:12Z guy $
+ * $Id: packet-pppoe.c 28220 2009-05-01 07:17:10Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -174,7 +174,7 @@ static const value_string tag_vals[] = {
 		{PPPOE_TAG_VENDOR,     "Vendor-Specific"   },
 		{PPPOE_TAG_CREDITS,    "Credits"           },
 		{PPPOE_TAG_METRICS,    "Metrics"           },
-		{PPPOE_TAG_SEQ_NUM,    "Seqence Number"    },
+		{PPPOE_TAG_SEQ_NUM,    "Sequence Number"    },
 		{PPPOE_TAG_CRED_SCALE, "Credit Scale Factor"},
 		{PPPOE_TAG_RELAY_ID,   "Relay-Session-Id"  },
 		{PPPOE_TAG_HURL,       "HURL"              },
