@@ -4,7 +4,7 @@
  * Uwe Girlich <uwe@planetquake.com>
  *	http://www.idsoftware.com/q1source/q1source.zip
  *
- * $Id: packet-quakeworld.c 24247 2008-02-02 17:13:30Z stig $
+ * $Id: packet-quakeworld.c 28317 2009-05-08 20:35:57Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -35,6 +35,7 @@
 #include <string.h>
 #include <epan/packet.h>
 #include <epan/prefs.h>
+#include <epan/strutil.h>
 
 static int proto_quakeworld = -1;
 
@@ -292,7 +293,7 @@ dissect_id_infostring(tvbuff_t *tvb, proto_tree* tree,
 			sub_item = proto_tree_add_string(tree,
 				hf_key_value,
 				tvb,
-				offset + (keypos-infostring),
+				offset + (gint)(keypos-infostring),
 				keylength + 1 + valuelength, keypos);
 			if (sub_item)
 				sub_tree =
@@ -304,12 +305,12 @@ dissect_id_infostring(tvbuff_t *tvb, proto_tree* tree,
 				proto_tree_add_string(sub_tree,
 					hf_key,
 					tvb,
-					offset + (keypos-infostring),
+					offset + (gint)(keypos-infostring),
 					keylength, keypos);
 				proto_tree_add_string(sub_tree,
 					hf_value,
 					tvb,
-					offset + (valuepos-infostring),
+					offset + (gint)(valuepos-infostring),
 					valuelength, valuepos);
 			}
 		}
@@ -329,7 +330,7 @@ static const value_string names_direction[] = {
 
 /* I took this name and value directly out of the QW source. */
 #define PORT_MASTER 27500
-static unsigned int gbl_quakeworldServerPort=PORT_MASTER;
+static guint gbl_quakeworldServerPort=PORT_MASTER;
 
 
 /* out of band message id bytes (taken out of quakeworldsource/client/protocol.h */
@@ -509,10 +510,9 @@ dissect_quakeworld_ConnectionlessPacket(tvbuff_t *tvb, packet_info *pinfo,
 			}
 			remaining[0] = 0;
 			for (i=2; i<Cmd_Argc() ; i++) {
-				strncat (remaining, Cmd_Argv(i), MAX_TEXT_SIZE - strlen(remaining));
-				strncat (remaining, " ", MAX_TEXT_SIZE - strlen(remaining));
+				g_strlcat (remaining, Cmd_Argv(i), MAX_TEXT_SIZE+1);
+				g_strlcat (remaining, " ", MAX_TEXT_SIZE+1);
 			}
-			remaining[MAX_TEXT_SIZE] = '\0';
 			if (text_tree) {
 				proto_tree_add_string(argument_tree,
 					hf_quakeworld_connectionless_rcon_command,
@@ -771,13 +771,14 @@ dissect_quakeworld(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 void
 proto_reg_handoff_quakeworld(void)
 {
-	static int Initialized=FALSE;
+	static gboolean Initialized=FALSE;
 	static dissector_handle_t quakeworld_handle;
-	static int ServerPort=0;
+	static guint ServerPort;
 
 	if (!Initialized) {
 		quakeworld_handle = create_dissector_handle(dissect_quakeworld,
 				proto_quakeworld);
+		data_handle = find_dissector("data");
 		Initialized=TRUE;
 	} else {
 		dissector_delete("udp.port", ServerPort, quakeworld_handle);
@@ -787,7 +788,6 @@ proto_reg_handoff_quakeworld(void)
         ServerPort=gbl_quakeworldServerPort;
 
 	dissector_add("udp.port", gbl_quakeworldServerPort, quakeworld_handle);
-	data_handle = find_dissector("data");
 }
 
 
@@ -869,7 +869,7 @@ proto_register_quakeworld(void)
 			"Sequence number of the current packet", HFILL }},
 		{ &hf_quakeworld_game_rel1,
 			{ "Reliable", "quakeworld.game.rel1",
-			FT_BOOLEAN, BASE_DEC, NULL, 0x0,
+			FT_BOOLEAN, BASE_NONE, NULL, 0x0,
 			"Packet is reliable and may be retransmitted", HFILL }},
 		{ &hf_quakeworld_game_seq2,
 			{ "Sequence Number", "quakeworld.game.seq2",
@@ -877,7 +877,7 @@ proto_register_quakeworld(void)
 			"Sequence number of the last received packet", HFILL }},
 		{ &hf_quakeworld_game_rel2,
 			{ "Reliable", "quakeworld.game.rel2",
-			FT_BOOLEAN, BASE_DEC, NULL, 0x0,
+			FT_BOOLEAN, BASE_NONE, NULL, 0x0,
 			"Packet was reliable and may be retransmitted", HFILL }},
 		{ &hf_quakeworld_game_qport,
 			{ "QPort", "quakeworld.game.qport",
