@@ -2,7 +2,7 @@
  * Routines for java rmiregistry dissection
  * Copyright 2002, Michael Stiller <ms@2scale.net>
  *
- * $Id: packet-rmi.c 23252 2007-10-23 05:50:00Z etxrab $
+ * $Id: packet-rmi.c 25586 2008-06-24 19:18:21Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -125,7 +125,8 @@ dissect_rmi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     rmi_type   rmitype;
 
-    char epid_hostname[256];
+    char *epid_hostname;
+	guint epid_len;
 
     offset     = 0;
     rmitype    = 0;
@@ -202,18 +203,14 @@ dissect_rmi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		len = tvb_get_ntohs(tvb, 1);
 		proto_tree_add_uint(rmi_tree, hf_rmi_epid_length,
 				       tvb, offset + 1, 2, len);
-		memset(epid_hostname, 0, sizeof(epid_hostname));
-		if (len < sizeof(epid_hostname)) {
-		    strncpy(epid_hostname,tvb_get_ptr(tvb, offset + 3, len),
-			    sizeof(epid_hostname));
+		epid_len = len < ITEM_LABEL_LENGTH ? len : ITEM_LABEL_LENGTH;
+		if (epid_len > 0) {
+			epid_hostname = tvb_format_text(tvb, offset + 3, epid_len);
 		} else {
-		    strncpy(epid_hostname,
-			    "<string too long>", sizeof(epid_hostname));
+			epid_hostname = "[Empty]";
 		}
-		epid_hostname[sizeof(epid_hostname)-1] = '\0';
 		proto_tree_add_string(rmi_tree, hf_rmi_epid_hostname,
-				      tvb, offset + 3, strlen(epid_hostname),
-				      epid_hostname);
+				      tvb, offset + 3, len, epid_hostname);
 
 		port = tvb_get_ntohs(tvb, offset + len + 5);
   		proto_tree_add_uint(rmi_tree, hf_rmi_epid_port,
