@@ -4,7 +4,7 @@
  *
  * Copyright 2008, Stig Bjorlykke <stig@bjorlykke.org>, Thales Norway AS
  *
- * $Id: packet-rpcap.c 27983 2009-04-07 12:20:41Z wmeier $
+ * $Id: packet-rpcap.c 31211 2009-12-09 00:15:27Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,6 +29,10 @@
 #include "config.h"
 #endif
 
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
+
 #ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
 #endif
