@@ -3,7 +3,7 @@
  *
  * metatech <metatech@flashmail.com>
  *
- * $Id: packet-rtmpt.c 23902 2007-12-17 20:43:38Z sfisher $
+ * $Id: packet-rtmpt.c 28317 2009-05-08 20:35:57Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -48,7 +48,6 @@
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/emem.h>
 #include <epan/conversation.h>
 #include <epan/prefs.h>
 #include "packet-tcp.h"
@@ -195,7 +194,7 @@ dissect_rtmpt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	struct tcpinfo* tcpinfo = pinfo->private_data;
 	static gint iPreviousFrameNumber = -1;
 
-	guint16 iCommand = -1;
+	guint16 iCommand = G_MAXUINT16;
 	guint16 iLength = 1;
 	guint16 iHeaderType = 4; 
 	guint16 iHeaderLength;
@@ -309,8 +308,8 @@ dissect_rtmpt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	
 					switch (iObjType) {
 						case RTMPT_TYPE_NUMBER:  
-							proto_tree_add_item(rtmpt_tree, hf_rtmpt_amf_number, tvb, offset + 0, 2, FALSE);
-							offset += 2;
+							proto_tree_add_item(rtmpt_tree, hf_rtmpt_amf_number, tvb, offset + 0, 8, FALSE);
+							offset += 8;
 							break;
 						case RTMPT_TYPE_BOOLEAN: 
 							proto_tree_add_item(rtmpt_tree, hf_rtmpt_amf_boolean, tvb, offset + 0, 1, FALSE);
@@ -350,9 +349,9 @@ dissect_rtmpt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 								iObjType = tvb_get_guint8(tvb, offset + 0);
 								switch (iObjType) {
 									case RTMPT_TYPE_NUMBER:  
-										proto_tree_add_item(rtmpt_tree_prop, hf_rtmpt_amf_number, tvb, offset + 1, 2, FALSE);
-										offset += 3;
-										iPropertyLength += 3;
+										proto_tree_add_item(rtmpt_tree_prop, hf_rtmpt_amf_number, tvb, offset + 1, 8, FALSE);
+										offset += 9;
+										iPropertyLength += 9;
 										break;
 									case RTMPT_TYPE_BOOLEAN: 
 										proto_tree_add_item(rtmpt_tree_prop, hf_rtmpt_amf_boolean, tvb, offset + 1, 1, FALSE);
@@ -392,7 +391,7 @@ get_rtmpt_pdu_len(packet_info *pinfo _U_, tvbuff_t *tvb, int offset)
 	{
 		guint16 iHeaderType;
 		guint8 iID;
-		guint16 iCommand = -1;
+		guint16 iCommand = G_MAXUINT16;
 
 		iID = tvb_get_guint8(tvb, offset + 0);
 		iHeaderType = iID >> 6;
@@ -454,7 +453,7 @@ proto_register_rtmpt(void)
 {
   static hf_register_info hf[] = {
    { &hf_rtmpt_header_objid,
-      { "ObjectID", "rtmpt.header.objid", FT_UINT8, BASE_DEC, NULL, 0x0, "RTMPT Header object ID", HFILL }},
+      { "ObjectID", "rtmpt.header.objid", FT_UINT8, BASE_DEC, NULL, 0x3F, "RTMPT Header object ID", HFILL }},
 
    { &hf_rtmpt_header_timestamp,
       { "Timestamp", "rtmpt.header.timestamp", FT_UINT24, BASE_DEC, NULL, 0x0, "RTMPT Header timestamp", HFILL }},
@@ -475,10 +474,10 @@ proto_register_rtmpt(void)
       { "AMF type", "rtmpt.amf.type", FT_UINT8, BASE_DEC, VALS(rtmpt_type_vals), 0x0, "RTMPT AMF type", HFILL }},
 
    { &hf_rtmpt_amf_number,
-      { "AMF number", "rtmpt.amf.number", FT_UINT16, BASE_DEC, NULL, 0x0, "RTMPT AMF number", HFILL }},
+      { "AMF number", "rtmpt.amf.number", FT_DOUBLE, BASE_DEC, NULL, 0x0, "RTMPT AMF number", HFILL }},
 
    { &hf_rtmpt_amf_boolean,
-      { "AMF boolean", "rtmpt.amf.boolean", FT_BOOLEAN, BASE_DEC, NULL, 0x0, "RTMPT AMF boolean", HFILL }},
+      { "AMF boolean", "rtmpt.amf.boolean", FT_BOOLEAN, BASE_NONE, NULL, 0x0, "RTMPT AMF boolean", HFILL }},
 
    { &hf_rtmpt_amf_string,
       { "AMF string", "rtmpt.amf.string", FT_STRINGZ, BASE_DEC, NULL, 0x0, "RTMPT AMF string", HFILL }}
