@@ -1,7 +1,7 @@
 /* packet-rtnet.c
  * Routines for RTnet packet disassembly
  *
- * $Id: packet-rtnet.c 27497 2009-02-22 09:09:27Z jake $
+ * $Id: packet-rtnet.c 27983 2009-04-07 12:20:41Z wmeier $
  *
  * Copyright (c) 2003 by Erwin Rol <erwin@erwinrol.com>
  * Copyright (c) 2004 by Jan Kiszka <jan.kiszka@web.de>
@@ -905,11 +905,6 @@ dissect_rtcfg(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
 
 void
 proto_register_rtmac(void) {
-  static const true_false_string rtnet_flags_set_truth = {
-    "Set",
-    "Not set"
-  };
-
   static hf_register_info hf_array_rtmac[] = {
 
     /* RTmac header */
@@ -934,7 +929,7 @@ proto_register_rtmac(void) {
     { &hf_rtmac_header_flags_tunnel,
       { "Tunnelling Flag",
         "rtmac.header.flags.tunnel",
-        FT_BOOLEAN, 8, TFS(&rtnet_flags_set_truth), RTMAC_FLAG_TUNNEL,
+        FT_BOOLEAN, 8, TFS(&tfs_set_notset), RTMAC_FLAG_TUNNEL,
         "RTmac Tunnelling Flag", HFILL }},
 
     { &hf_rtmac_header_flags_res,
