@@ -1,7 +1,7 @@
 /* packet-s5066.c
  * Routines for STANAG 5066 SIS layer packet disassembly
  *
- * $Id: packet-s5066.c 26927 2008-12-05 23:32:25Z gerald $
+ * $Id: packet-s5066.c 27714 2009-03-12 22:06:59Z stig $
  *
  * Copyright (c) 2005 by Menno Andriesse <s5066 [AT] nc3a.nato.int>
  *
@@ -31,7 +31,6 @@
 #include <gmodule.h>
 #include <epan/packet.h>
 #include <epan/prefs.h>
-#include <epan/emem.h>
 #include <epan/dissectors/packet-tcp.h> /* For tcp_dissect_pdus() */
 
 /* Forward reference */
@@ -81,7 +80,7 @@ static gboolean s5066_desegment = TRUE;
 /* Dissect old 'edition 1' of STANAG 5066 (It lacks the 'version' field.) */
 static gboolean s5066_edition_one = FALSE;
 /* This port is registered with IANA */
-static gint global_s5066_port = 5066;
+static guint global_s5066_port = 5066;
 /* Size of header outside 'size' field */
 static gint s5066_header_size = 5;
 /* Offset of 'size' field */
@@ -141,7 +140,7 @@ static gint hf_s5066_st_txmode = -1;
 static const value_string s5066_st_txmode[] = {
 	{ 0, "Ignore service type field"},
 	{ 1, "ARQ"},
-	{ 2, "Non-ARQ (Broacast)"},
+	{ 2, "Non-ARQ (Broadcast)"},
 	{ 3, "Non-ARQ (with errors)"},
 	{ 4, "Other non-ARQ types"},
 	{ 5, "Other non-ARQ types"},
@@ -430,7 +429,7 @@ proto_register_s5066(void)
 {
 	static hf_register_info hf[] = {
 		{ &hf_s5066_sync_word,
-			{ "Sync preample", "s5066.sync", FT_UINT16, BASE_HEX, NULL, 0x0, "", HFILL }
+			{ "Sync preamble", "s5066.sync", FT_UINT16, BASE_HEX, NULL, 0x0, "", HFILL }
 		},
 		{ &hf_s5066_version,
 			{ "S5066 version", "s5066.version", FT_UINT8, BASE_HEX, NULL, 0x0, "", HFILL }
@@ -780,20 +779,20 @@ proto_register_s5066(void)
 
 	s5066_module = prefs_register_protocol(proto_s5066, proto_reg_handoff_s5066);
 	prefs_register_bool_preference(s5066_module, "desegment_pdus",
-		"Reassemble S5066 PDUs spanning multiple TCP segments",
-		"Whether the S5066 dissector should reassemble PDUs spanning multiple TCP segments."
-		" The default is to use reassembly.",
-		&s5066_desegment);
+				       "Reassemble S5066 PDUs spanning multiple TCP segments",
+				       "Whether the S5066 dissector should reassemble PDUs spanning multiple TCP segments."
+				       " The default is to use reassembly.",
+				       &s5066_desegment);
 	prefs_register_bool_preference(s5066_module, "edition_one",
-		"Dissect edition 1.0 of STANAG 5066",
-		"Whether the S5066 dissector should dissect editon 1 of the STANAG."
-		" This editon was never formally approved and is very rare. The common edition is editon 1.2.",
-		&s5066_edition_one);
+				       "Dissect edition 1.0 of STANAG 5066",
+				       "Whether the S5066 dissector should dissect this edition of the STANAG."
+				       " This edition was never formally approved and is very rare. The common edition is edition 1.2.",
+				       &s5066_edition_one);
 	prefs_register_uint_preference(s5066_module, "tcp.port",
-		"STANAG 5066 TCP Port",
-		"Set the port for STANAG 5066. (If other than the default 5066."
-		" This number is registered with IANA.)",
-		10, &global_s5066_port);
+				       "STANAG 5066 TCP Port",
+				       "Set the port for STANAG 5066. (If other than the default 5066."
+				       " This number is registered with IANA.)",
+				       10, &global_s5066_port);
 }
 
 void
@@ -1093,7 +1092,7 @@ dissect_s5066_21(tvbuff_t *tvb, guint offset, proto_tree *tree, guint pdu_size)
 
 	tx_mode = tvb_get_guint8(tvb, offset);
 	tx_mode = (tx_mode & 0xF0) >> 4;
-	if (tx_mode == 2) {
+	if (tx_mode == 3) {
 		non_arq_w_errors = TRUE;
 	}
 
@@ -1191,7 +1190,7 @@ dissect_s5066_25(tvbuff_t *tvb, guint offset, proto_tree *tree, guint pdu_size)
 
 	tx_mode = tvb_get_guint8(tvb, offset);
 	tx_mode = (tx_mode & 0xF0) >> 4;
-	if (tx_mode == 2) {
+	if (tx_mode == 3) {
 		non_arq_w_errors = TRUE;
 	}
 
@@ -1203,7 +1202,7 @@ dissect_s5066_25(tvbuff_t *tvb, guint offset, proto_tree *tree, guint pdu_size)
 	proto_tree_add_item(tree, hf_s5066_25_size, tvb, offset, 2, FALSE); offset += 2;
 
 	/* Handle RockwellCollins (<= v2.1) 4-byte offset */
-	if ( (pdu_size - offset) == d_pdu_size + 4 ) {
+	if ( (pdu_size - offset) == (d_pdu_size + 4) ) {
 		ti = proto_tree_add_item(tree, hf_s5066_25_err_blocks, tvb, offset, 2, FALSE); offset += 2;
 		proto_item_append_text(ti, ", (Field should not be present. Rockwell Collins v2.1 or earlier.) ");
 		ti = proto_tree_add_item(tree, hf_s5066_25_nrx_blocks, tvb, offset, 2, FALSE); offset += 2;
