@@ -12,7 +12,7 @@
  *
  * Copyright 2002, Jeff Morriss <jeff.morriss[AT]ulticom.com>
  *
- * $Id: packet-sccpmg.c 19231 2006-09-14 10:51:44Z jmayer $
+ * $Id: packet-sccpmg.c 27028 2008-12-17 00:08:38Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -342,7 +342,7 @@ proto_register_sccpmg(void)
 	      FT_UINT8, BASE_DEC, NULL, SCCPMG_SMI_MASK,
 	      "", HFILL}},
 	  { &hf_sccpmg_congestion_level,
-	    { "SCCP Congestionl Level (ITU)", "sccpmg.congestion",
+	    { "SCCP Congestion Level (ITU)", "sccpmg.congestion",
 	      FT_UINT8, BASE_DEC, NULL, ITU_SCCPMG_CONGESTION_MASK,
 	      "", HFILL}}
 	};
