@@ -2,7 +2,7 @@
  * Defines for SMB packet dissection
  * Copyright 1999, Richard Sharpe <rsharpe@ns.aus.com>
  *
- * $Id: packet-smb.h 26263 2008-09-24 16:16:01Z sahlberg $
+ * $Id: packet-smb.h 33756 2010-08-10 08:13:49Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -363,7 +363,7 @@ extern int dissect_ipc_state(tvbuff_t *tvb, proto_tree *parent_tree,
 
 extern gboolean smb_dcerpc_reassembly;
 
-extern int dissect_file_attributes(tvbuff_t *tvb, proto_tree *parent_tree, int offset, int bytes);
+extern int dissect_file_ext_attr(tvbuff_t *tvb, proto_tree *parent_tree, int offset);
 
 extern const value_string create_disposition_vals[];
 
