@@ -2,7 +2,7 @@
  * Routines for synergy dissection
  * Copyright 2005, Vasanth Manickam <vasanthm@gmail.com>
  *
- * $Id: packet-synergy.c 26089 2008-08-25 22:06:20Z wmeier $
+ * $Id: packet-synergy.c 28317 2009-05-08 20:35:57Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -415,7 +415,7 @@ proto_register_synergy(void)
 			{ "Sequence Number","synergy.clipboard.sequence",FT_UINT32, BASE_DEC, NULL, 0x0,"", HFILL }
 		},
 		{ &hf_synergy_csec,
-			{ "Screen Saver Change","synergy.screensaver",FT_BOOLEAN, BASE_DEC, NULL, 0x0,"", HFILL }
+			{ "Screen Saver Change","synergy.screensaver",FT_BOOLEAN, BASE_NONE, NULL, 0x0,"", HFILL }
 		},
 		{ &hf_synergy_crop,
 			{ "Reset Options","synergy.resetoptions",FT_NONE, BASE_DEC, NULL, 0x0,"", HFILL }
