@@ -1,7 +1,7 @@
 /* packet-3com-tapa.c
  * Routines for the disassembly of the Trapeze TAPA protocol
  *
- * $Id: packet-tapa.c 23405 2007-11-08 22:40:20Z etxrab $
+ * $Id: packet-tapa.c 26308 2008-09-30 14:49:44Z wmeier $
  *
  * Copyright 2007 Joerg Mayer (see AUTHORS file)
  *
@@ -38,7 +38,6 @@ Specs:
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/emem.h>
 
 /* protocol handles */
 static int proto_tapa = -1;
@@ -424,7 +423,7 @@ dissect_tapa_tunnel(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 static gboolean
 test_tapa_discover(tvbuff_t *tvb)
 {
-	guint8 type, unknown, req_type;
+	guint8 type, req_type;
 	guint16 length;
 
 	if (tvb_length(tvb) < 4)
@@ -432,15 +431,14 @@ test_tapa_discover(tvbuff_t *tvb)
 
 	/* Type(1 byte) <= 5, unknown(1 byte), length(2 bytes) */
 	type = tvb_get_guint8(tvb, 0);
-	unknown = tvb_get_guint8(tvb, 1);
+	/* unknown = tvb_get_guint8(tvb, 1); */
 	length = tvb_get_ntohs(tvb, 2);
 	req_type = tvb_get_guint8(tvb, 4);
 
-	if (type < TAPA_TYPE_REQUEST	||
-	    type > TAPA_TYPE_REPLY_NEW	||
-	    unknown > 8			||
-	    length < 12			||
-	    length > 1472		||
+	if (type < TAPA_TYPE_REQUEST		||
+	    type > TAPA_TYPE_REPLY_NEW		||
+	    length < 12				||
+	    length > 1472			||
 	    (type == TAPA_TYPE_REQUEST && (req_type < TAPA_REQUEST_SERIAL || req_type > TAPA_REQUEST_MODEL))) {
 		return FALSE;
 	}
@@ -621,7 +619,7 @@ proto_reg_handoff_tapa(void)
 {
 	dissector_handle_t tapa_handle;
 
-	tapa_handle = new_create_dissector_handle(dissect_tapa_static, proto_tapa);
+	tapa_handle = find_dissector("tapa");
 	dissector_add("udp.port", PORT_TAPA, tapa_handle);
 }
 
