@@ -2,7 +2,7 @@
  * Routines for Telnet packet dissection; see RFC 854 and RFC 855
  * Copyright 1999, Richard Sharpe <rsharpe@ns.aus.com>
  *
- * $Id: packet-telnet.c 21705 2007-05-06 22:34:05Z etxrab $
+ * $Id: packet-telnet.c 28356 2009-05-13 19:46:11Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -500,9 +500,9 @@ dissect_comport_subopt(packet_info *pinfo _U_, const char *optname, tvbuff_t *tv
             int bit = ls & 1;
             if (bit) {
                 if (print_count != 0) {
-                    strcat(ls_buffer,", ");
+                    g_strlcat(ls_buffer,", ",512);
                 }
-                strcat(ls_buffer,linestate_bits[idx]);
+                g_strlcat(ls_buffer,linestate_bits[idx], 512);
                 print_count++;
             }
             ls = ls >> 1;
@@ -530,9 +530,9 @@ dissect_comport_subopt(packet_info *pinfo _U_, const char *optname, tvbuff_t *tv
             int bit = ms & 1;
             if (bit) {
                 if (print_count != 0) {
-                    strcat(ms_buffer,", ");
+                    g_strlcat(ms_buffer,", ",256);
                 }
-                strcat(ms_buffer,modemstate_bits[idx]);
+                g_strlcat(ms_buffer,modemstate_bits[idx],256);
                 print_count++;
             }
             ms = ms >> 1;
@@ -771,9 +771,8 @@ unescape_and_tvbuffify_telnet_option(packet_info *pinfo, tvbuff_t *tvb, int offs
 		*(dpos++)=*(spos++);
 		l--;
 	}
-	krb5_tvb = tvb_new_real_data(buf, len-skip, len-skip); 
+	krb5_tvb = tvb_new_child_real_data(tvb, buf, len-skip, len-skip); 
 	tvb_set_free_cb(krb5_tvb, g_free);
-	tvb_set_child_real_data_tvbuff(tvb, krb5_tvb);
 	add_new_data_source(pinfo, krb5_tvb, "Unpacked Telnet Uption");
 
 	return krb5_tvb;
@@ -1605,7 +1604,7 @@ dissect_telnet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		col_set_str(pinfo->cinfo, COL_PROTOCOL, "TELNET");
 
 	if (check_col(pinfo->cinfo, COL_INFO))
-		col_add_fstr(pinfo->cinfo, COL_INFO, "Telnet Data ...");
+		col_set_str(pinfo->cinfo, COL_INFO, "Telnet Data ...");
 
 	if (tree) {
 	  gint offset = 0;
