@@ -1,7 +1,7 @@
 /* packet-vlan.c
  * Routines for VLAN 802.1Q ethernet header disassembly
  *
- * $Id: packet-vlan.c 23837 2007-12-11 07:42:36Z jake $
+ * $Id: packet-vlan.c 27650 2009-03-08 11:55:44Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -37,7 +37,6 @@
 
 void proto_reg_handoff_vlan(void);
 
-static unsigned int old_q_in_q_ethertype;
 static unsigned int q_in_q_ethertype = 0x9100;
 
 static gboolean vlan_summary_in_tree = TRUE;
@@ -75,7 +74,8 @@ static void
 dissect_vlan(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
   proto_tree *ti;
-  guint16 tci,encap_proto;
+  guint16 tci;
+  volatile guint16 encap_proto;
   volatile gboolean is_802_2;
   proto_tree *volatile vlan_tree;
 
@@ -181,8 +181,8 @@ proto_register_vlan(void)
         "Whether the vlan summary line should be shown in the protocol tree",
         &vlan_summary_in_tree);
   prefs_register_uint_preference(vlan_module, "qinq_ethertype",
-        "802.1QinQ Ethertype",
-        "The Ethertype used to indicate 802.1QinQ VLAN in VLAN tunneling.",
+        "802.1QinQ Ethertype (in hex)",
+        "The (hexadecimal) Ethertype used to indicate 802.1QinQ VLAN in VLAN tunneling.",
         16, &q_in_q_ethertype);
 
 }
@@ -192,6 +192,7 @@ proto_reg_handoff_vlan(void)
 {
   static gboolean prefs_initialized = FALSE;
   static dissector_handle_t vlan_handle;
+  static unsigned int old_q_in_q_ethertype;
 
   if (!prefs_initialized)
   {
