@@ -2,7 +2,7 @@
  * Routines for Wellfleet Compression frame disassembly
  * Copyright 2001, Jeffrey C. Foster <jfoste@woodward.com>
  *
- * $Id: packet-wcp.c 21398 2007-04-13 00:50:23Z sfisher $
+ * $Id: packet-wcp.c 28356 2009-05-13 19:46:11Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -272,7 +272,7 @@ dissect_wcp_reset( tvbuff_t *tvb, int offset, proto_tree *tree){
 static void wcp_save_data( tvbuff_t *tvb, packet_info *pinfo){
 
 	wcp_window_t *buf_ptr = 0;
-	int len;
+	size_t len;
 
 	/* discard first 2 bytes, header and last byte (check byte) */
 	len = tvb_reported_length( tvb)-3;
@@ -285,8 +285,8 @@ static void wcp_save_data( tvbuff_t *tvb, packet_info *pinfo){
 	} else {
 		guint8 *buf_end = buf_ptr->buffer + MAX_WIN_BUF_LEN;
 		tvb_memcpy( tvb, buf_ptr->buf_cur, 2, buf_end - buf_ptr->buf_cur);
-		tvb_memcpy( tvb, buf_ptr->buffer, buf_end - buf_ptr->buf_cur-2,
-			len - (int)(buf_end - buf_ptr->buf_cur));
+		tvb_memcpy( tvb, buf_ptr->buffer, (gint) (buf_end - buf_ptr->buf_cur-2),
+			len - (buf_end - buf_ptr->buf_cur));
 		buf_ptr->buf_cur = buf_ptr->buf_cur + len - MAX_WIN_BUF_LEN;
 	}
 
@@ -587,7 +587,7 @@ static tvbuff_t *wcp_uncompress( tvbuff_t *src_tvb, int offset, packet_info *pin
 
 
         TRY {
-                tvb = tvb_new_real_data( pdata_ptr->buffer, pdata_ptr->len, pdata_ptr->len);
+                tvb = tvb_new_child_real_data(src_tvb,  pdata_ptr->buffer, pdata_ptr->len, pdata_ptr->len);
         }
         CATCH(BoundsError) {
 		DISSECTOR_ASSERT_NOT_REACHED();
@@ -599,9 +599,6 @@ static tvbuff_t *wcp_uncompress( tvbuff_t *src_tvb, int offset, packet_info *pin
 
 	if (bounds_error) return NULL;
 		
-	/* link new tvbuff into tvbuff chain so cleanup is done later */
-        tvb_set_child_real_data_tvbuff( src_tvb, tvb);
-
 	/* Add new data to the data source list */
 	add_new_data_source( pinfo, tvb, "Uncompressed WCP");
 	return tvb;
