@@ -1,9 +1,9 @@
 /* packet-zrtp.c
  * Routines for zrtp packet dissection
- * IETF draft draft-zimmermann-avt-zrtp-12
+ * IETF draft draft-zimmermann-avt-zrtp-17
  * Copyright 2007, Sagar Pai <sagar@gmail.com>
  *
- * $Id: packet-zrtp.c 27209 2009-01-11 13:28:20Z jake $
+ * $Id: packet-zrtp.c 31672 2010-01-25 23:46:42Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -103,6 +103,14 @@ static int hf_zrtp_msg_cfb = -1;
 */
 static int hf_zrtp_msg_error = -1;
 
+/*
+  Ping Data
+*/
+static int hf_zrtp_msg_ping_version = -1;
+static int hf_zrtp_msg_ping_endpointhash = -1;
+static int hf_zrtp_msg_pingack_endpointhash = -1;
+static int hf_zrtp_msg_ping_ssrc = -1;
+
 /*
   Checksum Data
 */
@@ -184,6 +192,12 @@ const value_string_keyval zrtp_cipher_type_vals[] =
     { "AES1",	"AES-CM with 128 bit keys"},
     { "AES2",	"AES-CM with 192 bit keys"},
     { "AES3",	"AES-CM with 256 bit keys"},
+    { "2FS1",   "TwoFish with 128 bit keys"},
+    { "2FS2",   "TwoFish with 192 bit keys"},
+    { "2FS3",   "TwoFish with 256 bit keys"},
+    { "CAM1",   "Camellia with 128 bit keys"},
+    { "CAM2",   "Camellia with 192 bit keys"},
+    { "CAM3",   "Camellia with 256 bit keys"},
     { NULL,		NULL }
   };
 
@@ -191,6 +205,8 @@ const value_string_keyval zrtp_auth_tag_vals[] =
   {
     { "HS32",	"HMAC-SHA1 32 bit authentication tag"},
     { "HS80",	"HMAC-SHA1 80 bit authentication tag"},
+    { "SK32",	"Skein-512-MAC 32 bit authentication tag"},
+    { "SK64",	"Skein-512-MAC 64 bit authentication tag"},
     { NULL,		NULL }
   };
 
@@ -261,6 +277,10 @@ static void
 dissect_SASrelay(tvbuff_t *tvb, packet_info *pinfo, proto_tree *zrtp_tree);
 static void
 dissect_RelayACK(packet_info *pinfo);
+static void
+dissect_Ping(tvbuff_t *tvb, packet_info *pinfo, proto_tree *zrtp_tree);
+static void
+dissect_PingACK(tvbuff_t *tvb, packet_info *pinfo, proto_tree *zrtp_tree);
 
 
 static const gchar *
@@ -310,103 +330,111 @@ dissect_zrtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   if (check_col(pinfo->cinfo, COL_INFO))
     col_add_fstr(pinfo->cinfo, COL_INFO, "Unknown ZRTP Packet");
 
-    ti = proto_tree_add_protocol_format(tree,proto_zrtp,tvb,0,-1,"ZRTP protocol");
-    zrtp_tree = proto_item_add_subtree(ti,ett_zrtp);
+  ti = proto_tree_add_protocol_format(tree,proto_zrtp,tvb,0,-1,"ZRTP protocol");
+  zrtp_tree = proto_item_add_subtree(ti,ett_zrtp);
 
-    proto_tree_add_item(zrtp_tree,hf_zrtp_rtpversion,tvb,prime_offset+0,1,FALSE);
-    proto_tree_add_item(zrtp_tree,hf_zrtp_rtppadding,tvb,prime_offset+0,1,FALSE);
-    proto_tree_add_item(zrtp_tree,hf_zrtp_rtpextension,tvb,prime_offset+0,1,FALSE);
+  proto_tree_add_item(zrtp_tree,hf_zrtp_rtpversion,tvb,prime_offset+0,1,FALSE);
+  proto_tree_add_item(zrtp_tree,hf_zrtp_rtppadding,tvb,prime_offset+0,1,FALSE);
+  proto_tree_add_item(zrtp_tree,hf_zrtp_rtpextension,tvb,prime_offset+0,1,FALSE);
 
-    proto_tree_add_item(zrtp_tree,hf_zrtp_sequence,tvb,prime_offset+2,2,FALSE);
+  proto_tree_add_item(zrtp_tree,hf_zrtp_sequence,tvb,prime_offset+2,2,FALSE);
 
-    proto_tree_add_item(zrtp_tree,hf_zrtp_cookie,tvb,prime_offset+4,4,FALSE);
+  proto_tree_add_item(zrtp_tree,hf_zrtp_cookie,tvb,prime_offset+4,4,FALSE);
 
-    proto_tree_add_item(zrtp_tree,hf_zrtp_source_id,tvb,prime_offset+8,4,FALSE);
+  proto_tree_add_item(zrtp_tree,hf_zrtp_source_id,tvb,prime_offset+8,4,FALSE);
 
-    linelen = tvb_reported_length_remaining(tvb,msg_offset);
-    checksum_offset = linelen-4;
+  linelen = tvb_reported_length_remaining(tvb,msg_offset);
+  checksum_offset = linelen-4;
 
-    ti = proto_tree_add_protocol_format(zrtp_tree,proto_zrtp,tvb,msg_offset,linelen-4,"Message");
-    zrtp_msg_tree = proto_item_add_subtree(ti,ett_zrtp_msg);
+  ti = proto_tree_add_protocol_format(zrtp_tree,proto_zrtp,tvb,msg_offset,linelen-4,"Message");
+  zrtp_msg_tree = proto_item_add_subtree(ti,ett_zrtp_msg);
 
-    proto_tree_add_item(zrtp_msg_tree,hf_zrtp_signature,tvb,msg_offset+0,2,FALSE);
+  proto_tree_add_item(zrtp_msg_tree,hf_zrtp_signature,tvb,msg_offset+0,2,FALSE);
 
-    proto_tree_add_item(zrtp_msg_tree,hf_zrtp_msg_length,tvb,msg_offset+2,2,FALSE);
+  proto_tree_add_item(zrtp_msg_tree,hf_zrtp_msg_length,tvb,msg_offset+2,2,FALSE);
 
-    tvb_memcpy(tvb,(void *)message_type,msg_offset+4,8);
-    message_type[8] = 0;
-    proto_tree_add_item(zrtp_msg_tree,hf_zrtp_msg_type,tvb,msg_offset+4,8,FALSE);
+  tvb_memcpy(tvb,(void *)message_type,msg_offset+4,8);
+  message_type[8] = '\0';
+  proto_tree_add_item(zrtp_msg_tree,hf_zrtp_msg_type,tvb,msg_offset+4,8,FALSE);
 
-    linelen = tvb_reported_length_remaining(tvb,msg_offset+12);
+  linelen = tvb_reported_length_remaining(tvb,msg_offset+12);
 
-    if (!strncmp(message_type,"Hello   ",8)){
-      ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
-      zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
-      dissect_Hello(tvb,pinfo,zrtp_msg_data_tree);
-    } else if (!strncmp(message_type,"HelloACK",8)){
-      dissect_HelloACK(pinfo);
-    } else if (!strncmp(message_type,"Commit  ",8)){
-      ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
-      zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
-      dissect_Commit(tvb,pinfo,zrtp_msg_data_tree);
-    } else if (!strncmp(message_type,"DHPart1 ",8)){
-      ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
-      zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
-      dissect_DHPart(tvb,pinfo,zrtp_msg_data_tree,1);
-    } else if (!strncmp(message_type,"DHPart2 ",8)){
-      ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
-      zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
-      dissect_DHPart(tvb,pinfo,zrtp_msg_data_tree,2);
-    } else if (!strncmp(message_type,"Confirm1",8)){
-      ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
-      zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
-      dissect_Confirm(tvb,pinfo,zrtp_msg_data_tree,1);
-    } else if (!strncmp(message_type,"Confirm2",8)){
-      ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
-      zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
-      dissect_Confirm(tvb,pinfo,zrtp_msg_data_tree,2);
-    } else if (!strncmp(message_type,"Conf2ACK",8)){
-      dissect_Conf2ACK(pinfo);
-    } else if (!strncmp(message_type,"Error   ",8)){
-      ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
-      zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
-      dissect_Error(tvb,pinfo,zrtp_msg_data_tree);
-    } else if (!strncmp(message_type,"ErrorACK",8)){
-      dissect_ErrorACK(pinfo);
-    } else if (!strncmp(message_type,"GoClear ",8)){
-      ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
-      zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
-      dissect_GoClear(tvb,pinfo,zrtp_msg_data_tree);
-    } else if (!strncmp(message_type,"ClearACK",8)){
-      dissect_ClearACK(pinfo);
-    } else if (!strncmp(message_type,"SASrelay",8)){
-      ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
-      zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
-      dissect_SASrelay(tvb,pinfo,zrtp_msg_data_tree);
-    } else if (!strncmp(message_type,"RelayACK",8)){
-      dissect_RelayACK(pinfo);
-    }
+  if (!strncmp(message_type,"Hello   ",8)){
+    ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
+    zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
+    dissect_Hello(tvb,pinfo,zrtp_msg_data_tree);
+  } else if (!strncmp(message_type,"HelloACK",8)){
+    dissect_HelloACK(pinfo);
+  } else if (!strncmp(message_type,"Commit  ",8)){
+    ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
+    zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
+    dissect_Commit(tvb,pinfo,zrtp_msg_data_tree);
+  } else if (!strncmp(message_type,"DHPart1 ",8)){
+    ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
+    zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
+    dissect_DHPart(tvb,pinfo,zrtp_msg_data_tree,1);
+  } else if (!strncmp(message_type,"DHPart2 ",8)){
+    ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
+    zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
+    dissect_DHPart(tvb,pinfo,zrtp_msg_data_tree,2);
+  } else if (!strncmp(message_type,"Confirm1",8)){
+    ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
+    zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
+    dissect_Confirm(tvb,pinfo,zrtp_msg_data_tree,1);
+  } else if (!strncmp(message_type,"Confirm2",8)){
+    ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
+    zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
+    dissect_Confirm(tvb,pinfo,zrtp_msg_data_tree,2);
+  } else if (!strncmp(message_type,"Conf2ACK",8)){
+    dissect_Conf2ACK(pinfo);
+  } else if (!strncmp(message_type,"Error   ",8)){
+    ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
+    zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
+    dissect_Error(tvb,pinfo,zrtp_msg_data_tree);
+  } else if (!strncmp(message_type,"ErrorACK",8)){
+    dissect_ErrorACK(pinfo);
+  } else if (!strncmp(message_type,"GoClear ",8)){
+    ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
+    zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
+    dissect_GoClear(tvb,pinfo,zrtp_msg_data_tree);
+  } else if (!strncmp(message_type,"ClearACK",8)){
+    dissect_ClearACK(pinfo);
+  } else if (!strncmp(message_type,"SASrelay",8)){
+    ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
+    zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
+    dissect_SASrelay(tvb,pinfo,zrtp_msg_data_tree);
+  } else if (!strncmp(message_type,"RelayACK",8)){
+    dissect_RelayACK(pinfo);
+  } else if (!strncmp(message_type,"Ping    ",8)){
+    ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
+    zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
+    dissect_Ping(tvb,pinfo,zrtp_msg_data_tree);
+  } else if (!strncmp(message_type,"PingACK ",8)){
+    ti = proto_tree_add_protocol_format(zrtp_msg_tree,proto_zrtp,tvb,msg_offset+12,linelen-4,"Data");
+    zrtp_msg_data_tree = proto_item_add_subtree(ti,ett_zrtp_msg_data);
+    dissect_PingACK(tvb,pinfo,zrtp_msg_data_tree);
+  }
 
-    sent_crc = tvb_get_ntohl(tvb,msg_offset+checksum_offset);
-    calc_crc = ~calculate_crc32c(tvb_get_ptr(tvb,0,msg_offset+checksum_offset),msg_offset+checksum_offset,CRC32C_PRELOAD);
+  sent_crc = tvb_get_ntohl(tvb,msg_offset+checksum_offset);
+  calc_crc = ~calculate_crc32c(tvb_get_ptr(tvb,0,msg_offset+checksum_offset),msg_offset+checksum_offset,CRC32C_PRELOAD);
 
-    if (sent_crc == calc_crc) {
-      ti = proto_tree_add_uint_format_value(zrtp_tree, hf_zrtp_checksum, tvb, msg_offset+checksum_offset, 4, sent_crc,
-                                           "0x%04x [correct]", sent_crc);
-      checksum_tree = proto_item_add_subtree(ti, ett_zrtp_checksum);
-      ti = proto_tree_add_boolean(checksum_tree, hf_zrtp_checksum_good, tvb, msg_offset+checksum_offset, 4, TRUE);
-      PROTO_ITEM_SET_GENERATED(ti);
-      ti = proto_tree_add_boolean(checksum_tree, hf_zrtp_checksum_bad, tvb, msg_offset+checksum_offset, 4, FALSE);
-      PROTO_ITEM_SET_GENERATED(ti);
-    } else {
-      ti = proto_tree_add_uint_format_value(zrtp_tree, hf_zrtp_checksum, tvb, msg_offset+checksum_offset, 4, sent_crc,
-                                      "0x%04x [incorrect, should be 0x%04x]", sent_crc, calc_crc);
-      checksum_tree = proto_item_add_subtree(ti, ett_zrtp_checksum);
-      ti = proto_tree_add_boolean(checksum_tree, hf_zrtp_checksum_good, tvb, msg_offset+checksum_offset, 4, FALSE);
-      PROTO_ITEM_SET_GENERATED(ti);
-      ti = proto_tree_add_boolean(checksum_tree, hf_zrtp_checksum_bad, tvb, msg_offset+checksum_offset, 4, TRUE);
-      PROTO_ITEM_SET_GENERATED(ti);
-    }
+  if (sent_crc == calc_crc) {
+    ti = proto_tree_add_uint_format_value(zrtp_tree, hf_zrtp_checksum, tvb, msg_offset+checksum_offset, 4, sent_crc,
+                                          "0x%04x [correct]", sent_crc);
+    checksum_tree = proto_item_add_subtree(ti, ett_zrtp_checksum);
+    ti = proto_tree_add_boolean(checksum_tree, hf_zrtp_checksum_good, tvb, msg_offset+checksum_offset, 4, TRUE);
+    PROTO_ITEM_SET_GENERATED(ti);
+    ti = proto_tree_add_boolean(checksum_tree, hf_zrtp_checksum_bad, tvb, msg_offset+checksum_offset, 4, FALSE);
+    PROTO_ITEM_SET_GENERATED(ti);
+  } else {
+    ti = proto_tree_add_uint_format_value(zrtp_tree, hf_zrtp_checksum, tvb, msg_offset+checksum_offset, 4, sent_crc,
+                                          "0x%04x [incorrect, should be 0x%04x]", sent_crc, calc_crc);
+    checksum_tree = proto_item_add_subtree(ti, ett_zrtp_checksum);
+    ti = proto_tree_add_boolean(checksum_tree, hf_zrtp_checksum_good, tvb, msg_offset+checksum_offset, 4, FALSE);
+    PROTO_ITEM_SET_GENERATED(ti);
+    ti = proto_tree_add_boolean(checksum_tree, hf_zrtp_checksum_bad, tvb, msg_offset+checksum_offset, 4, TRUE);
+    PROTO_ITEM_SET_GENERATED(ti);
+  }
 
 }
 
@@ -445,6 +473,32 @@ dissect_HelloACK(packet_info *pinfo) {
   }
 }
 
+static void
+dissect_Ping(tvbuff_t *tvb, packet_info *pinfo, proto_tree *zrtp_tree) {
+  unsigned int data_offset=24;
+
+  if (check_col(pinfo->cinfo, COL_INFO)) {
+    col_add_fstr(pinfo->cinfo, COL_INFO, "Ping Packet");
+  }
+
+  proto_tree_add_item(zrtp_tree,hf_zrtp_msg_ping_version,tvb,data_offset,4,FALSE);
+  proto_tree_add_item(zrtp_tree,hf_zrtp_msg_ping_endpointhash,tvb,data_offset+4,8,FALSE);
+}
+
+static void
+dissect_PingACK(tvbuff_t *tvb, packet_info *pinfo, proto_tree *zrtp_tree) {
+  unsigned int data_offset=24;
+
+  if (check_col(pinfo->cinfo, COL_INFO)) {
+    col_add_fstr(pinfo->cinfo, COL_INFO, "PingACK Packet");
+  }
+
+  proto_tree_add_item(zrtp_tree,hf_zrtp_msg_ping_version,tvb,data_offset,4,FALSE);
+  proto_tree_add_item(zrtp_tree,hf_zrtp_msg_pingack_endpointhash,tvb,data_offset+4,8,FALSE);
+  proto_tree_add_item(zrtp_tree,hf_zrtp_msg_ping_endpointhash,tvb,data_offset+12,8,FALSE);
+  proto_tree_add_item(zrtp_tree,hf_zrtp_msg_ping_ssrc,tvb,data_offset+20,4,FALSE);
+}
+
 static void
 dissect_GoClear(tvbuff_t *tvb, packet_info *pinfo, proto_tree *zrtp_tree) {
   unsigned int data_offset=24;
@@ -548,19 +602,19 @@ dissect_Commit(tvbuff_t *tvb, packet_info *pinfo, proto_tree *zrtp_tree) {
   /* ZID */
   proto_tree_add_item(zrtp_tree,hf_zrtp_msg_zid,tvb,data_offset+0,12,FALSE);
   tvb_memcpy(tvb,(void *)value,data_offset+12,4);
-  value[4]=0;
+  value[4]='\0';
   proto_tree_add_string_format(zrtp_tree,hf_zrtp_msg_hash,tvb,data_offset+12,4,value,
 				  "Hash: %s",key_to_val(value,4,zrtp_hash_type_vals,"Unknown hash type %s"));
   tvb_memcpy(tvb,(void *)value,data_offset+16,4);
-  value[4]=0;
+  value[4]='\0';
   proto_tree_add_string_format(zrtp_tree,hf_zrtp_msg_cipher,tvb,data_offset+16,4,value,"Cipher: %s",
 				  key_to_val(value,4,zrtp_cipher_type_vals,"Unknown cipher type %s"));
   tvb_memcpy(tvb,(void *)value,data_offset+20,4);
-  value[4]=0;
+  value[4]='\0';
   proto_tree_add_string_format(zrtp_tree,hf_zrtp_msg_at,tvb,data_offset+20,4,value,
 				  "Auth tag: %s",key_to_val(value,4,zrtp_auth_tag_vals,"Unknown auth tag %s"));
   tvb_memcpy(tvb,(void *)value,data_offset+24,4);
-  value[4]=0;
+  value[4]='\0';
   proto_tree_add_string_format(zrtp_tree,hf_zrtp_msg_keya,tvb,data_offset+24,4,value,
 				  "Key agreement: %s",key_to_val(value,4,zrtp_key_agreement_vals,"Unknown key agreement %s"));
 
@@ -570,7 +624,7 @@ dissect_Commit(tvbuff_t *tvb, packet_info *pinfo, proto_tree *zrtp_tree) {
     key_type = 2;
   }
   tvb_memcpy(tvb,(void *)value,data_offset+28,4);
-  value[4]=0;
+  value[4]='\0';
   proto_tree_add_string_format(zrtp_tree,hf_zrtp_msg_sas,tvb,data_offset+28,4,value,
 				  "SAS type: %s",key_to_val(value,4,zrtp_sas_type_vals,"Unknown SAS type %s"));
 
@@ -652,7 +706,7 @@ dissect_Hello(tvbuff_t *tvb, packet_info *pinfo, proto_tree *zrtp_tree) {
   run_offset = data_offset+4;
   for(i=0;i<vhc;i++){
     tvb_memcpy(tvb,(void *)value,run_offset,4);
-    value[4]=0;
+    value[4]='\0';
     proto_tree_add_string_format(tmp_tree,hf_zrtp_msg_hash,tvb,run_offset,4,value,
 				    "Hash[%d]: %s",i,key_to_val(value,4,zrtp_hash_type_vals,"Unknown hash type %s"));
     run_offset+=4;
@@ -661,7 +715,7 @@ dissect_Hello(tvbuff_t *tvb, packet_info *pinfo, proto_tree *zrtp_tree) {
   tmp_tree = proto_item_add_subtree(ti,ett_zrtp_msg_cc);
   for(i=0;i<vcc;i++){
     tvb_memcpy(tvb,(void *)value,run_offset,4);
-    value[4]=0;
+    value[4]='\0';
     proto_tree_add_string_format(tmp_tree,hf_zrtp_msg_cipher,tvb,run_offset,4,value,"Cipher[%d]: %s",i,
 				    key_to_val(value,4,zrtp_cipher_type_vals,"Unknown cipher type %s"));
     run_offset+=4;
@@ -670,7 +724,7 @@ dissect_Hello(tvbuff_t *tvb, packet_info *pinfo, proto_tree *zrtp_tree) {
   tmp_tree = proto_item_add_subtree(ti,ett_zrtp_msg_ac);  
   for(i=0;i<vac;i++){
     tvb_memcpy(tvb,(void *)value,run_offset,4);
-    value[4]=0;
+    value[4]='\0';
     proto_tree_add_string_format(tmp_tree,hf_zrtp_msg_at,tvb,run_offset,4,value,
 				    "Auth tag[%d]: %s",i,key_to_val(value,4,zrtp_auth_tag_vals,"Unknown auth tag %s"));
     run_offset+=4;
@@ -679,7 +733,7 @@ dissect_Hello(tvbuff_t *tvb, packet_info *pinfo, proto_tree *zrtp_tree) {
   tmp_tree = proto_item_add_subtree(ti,ett_zrtp_msg_kc);  
   for(i=0;i<vkc;i++){
     tvb_memcpy(tvb,(void *)value,run_offset,4);
-    value[4]=0;
+    value[4]='\0';
     proto_tree_add_string_format(tmp_tree,hf_zrtp_msg_keya,tvb,run_offset,4,value,
 				    "Key agreement[%d]: %s",i,key_to_val(value,4,zrtp_key_agreement_vals,"Unknown key agreement %s"));
     run_offset+=4;
@@ -688,7 +742,7 @@ dissect_Hello(tvbuff_t *tvb, packet_info *pinfo, proto_tree *zrtp_tree) {
   tmp_tree = proto_item_add_subtree(ti,ett_zrtp_msg_sc);  
   for(i=0;i<vsc;i++){
     tvb_memcpy(tvb,(void *)value,run_offset,4);
-    value[4]=0;
+    value[4]='\0';
     proto_tree_add_string_format(tmp_tree,hf_zrtp_msg_sas,tvb,run_offset,4,value,
 				    "SAS type[%d]: %s",i,key_to_val(value,4,zrtp_sas_type_vals,"Unknown SAS type %s"));
     run_offset+=4;
@@ -706,7 +760,7 @@ proto_register_zrtp(void)
        "RTP Version", "zrtp.rtpversion",
        FT_UINT8, BASE_DEC,
        NULL, 0xC0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -715,7 +769,7 @@ proto_register_zrtp(void)
        "RTP padding", "zrtp.rtppadding",
        FT_BOOLEAN, 8,
        NULL, 0x20,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -724,7 +778,7 @@ proto_register_zrtp(void)
        "RTP Extension", "zrtp.rtpextension",
        FT_BOOLEAN, 8,
        NULL, 0x10,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -733,7 +787,7 @@ proto_register_zrtp(void)
        "ID", "zrtp.id",
        FT_UINT8, BASE_HEX,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -742,7 +796,7 @@ proto_register_zrtp(void)
        "Sequence", "zrtp.sequence",
        FT_UINT16, BASE_DEC,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -751,7 +805,7 @@ proto_register_zrtp(void)
        "Magic Cookie", "zrtp.cookie",
        FT_STRING, BASE_NONE,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -760,7 +814,7 @@ proto_register_zrtp(void)
        "Source Identifier", "zrtp.source_id",
        FT_UINT32, BASE_HEX,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -772,7 +826,7 @@ proto_register_zrtp(void)
        "Signature", "zrtp.signature",
        FT_UINT16, BASE_HEX,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -781,7 +835,7 @@ proto_register_zrtp(void)
        "Length", "zrtp.length",
        FT_UINT16, BASE_DEC,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -790,15 +844,16 @@ proto_register_zrtp(void)
        "Type", "zrtp.type",
        FT_STRING, BASE_NONE,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
+
     {&hf_zrtp_msg_version,
      {
        "ZRTP protocol version", "zrtp.version",
        FT_STRING, BASE_NONE,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -807,7 +862,7 @@ proto_register_zrtp(void)
        "Client Identifier", "zrtp.client_source_id",
        FT_STRING, BASE_NONE,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -816,7 +871,7 @@ proto_register_zrtp(void)
        "Hash Image", "zrtp.hash_image",
        FT_BYTES, BASE_NONE,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -825,7 +880,7 @@ proto_register_zrtp(void)
        "ZID", "zrtp.zid",
        FT_BYTES, BASE_DEC,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -834,7 +889,7 @@ proto_register_zrtp(void)
        "MiTM", "zrtp.mitm",
        FT_BOOLEAN, 8,
        NULL, 0x20,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -843,7 +898,7 @@ proto_register_zrtp(void)
        "Passive", "zrtp.passive",
        FT_BOOLEAN, 8,
        NULL, 0x10,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -852,7 +907,7 @@ proto_register_zrtp(void)
        "Hash Count", "zrtp.hc",
        FT_UINT8, BASE_DEC,
        NULL, 0x0F,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -861,7 +916,7 @@ proto_register_zrtp(void)
        "Cipher Count", "zrtp.cc",
        FT_UINT8, BASE_DEC,
        NULL, 0xF0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -870,7 +925,7 @@ proto_register_zrtp(void)
        "Auth tag Count", "zrtp.ac",
        FT_UINT8, BASE_DEC,
        NULL, 0x0F,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -879,7 +934,7 @@ proto_register_zrtp(void)
        "Key Agreement Count", "zrtp.kc",
        FT_UINT8, BASE_DEC,
        NULL, 0xF0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -888,7 +943,7 @@ proto_register_zrtp(void)
        "SAS Count", "zrtp.sc",
        FT_UINT8, BASE_DEC,
        NULL, 0x0F,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -897,7 +952,7 @@ proto_register_zrtp(void)
        "Hash", "zrtp.hash",
        FT_STRING, BASE_NONE,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -906,7 +961,7 @@ proto_register_zrtp(void)
        "Cipher", "zrtp.cipher",
        FT_STRING, BASE_NONE,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -915,7 +970,7 @@ proto_register_zrtp(void)
        "AT", "zrtp.at",
        FT_STRING, BASE_NONE,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -924,7 +979,7 @@ proto_register_zrtp(void)
        "Key Agreement", "zrtp.keya",
        FT_STRING, BASE_NONE,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -933,7 +988,7 @@ proto_register_zrtp(void)
        "SAS", "zrtp.sas",
        FT_STRING, BASE_NONE,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -942,7 +997,7 @@ proto_register_zrtp(void)
        "rs1ID", "zrtp.rs1id",
        FT_BYTES, BASE_NONE,
        NULL, 0x0,
-       "", HFILL 
+       NULL, HFILL 
      }
     },
 
@@ -951,7 +1006,7 @@ proto_register_zrtp(void)
        "rs2ID", "zrtp.rs2id",
        FT_BYTES, BASE_NONE,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -960,7 +1015,7 @@ proto_register_zrtp(void)
        "auxs", "zrtp.auxs",
        FT_BYTES, BASE_NONE,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -969,7 +1024,7 @@ proto_register_zrtp(void)
        "pbxs", "zrtp.pbxs",
        FT_BYTES, BASE_NONE,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -978,7 +1033,7 @@ proto_register_zrtp(void)
        "HMAC", "zrtp.hmac",
        FT_BYTES, BASE_NONE,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -987,7 +1042,7 @@ proto_register_zrtp(void)
        "CFB", "zrtp.cfb",
        FT_BYTES, BASE_NONE,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -996,7 +1051,43 @@ proto_register_zrtp(void)
        "Error", "zrtp.error",
        FT_UINT32, BASE_DEC,
        VALS(zrtp_error_vals), 0x0,
-       "", HFILL
+       NULL, HFILL
+     }
+    },
+
+    {&hf_zrtp_msg_ping_version,
+     {
+       "Ping Version", "zrtp.ping_version",
+       FT_STRING, BASE_NONE,
+       NULL, 0x0,
+       NULL, HFILL
+     }
+    },
+
+    {&hf_zrtp_msg_ping_endpointhash,
+     {
+       "Ping Endpoint Hash", "zrtp.ping_endpointhash",
+       FT_UINT64, BASE_HEX,
+       NULL, 0x0,
+       NULL, HFILL
+     }
+    },
+
+    {&hf_zrtp_msg_pingack_endpointhash,
+     {
+       "PingAck Endpoint Hash", "zrtp.pingack_endpointhash",
+       FT_UINT64, BASE_HEX,
+       NULL, 0x0,
+       NULL, HFILL
+     }
+    },
+
+    {&hf_zrtp_msg_ping_ssrc,
+     {
+       "Ping SSRC", "zrtp.ping_ssrc",
+       FT_UINT32, BASE_HEX,
+       NULL, 0x0,
+       NULL, HFILL
      }
     },
 
@@ -1005,7 +1096,7 @@ proto_register_zrtp(void)
        "Checksum", "zrtp.checksum",
        FT_UINT32, BASE_HEX,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -1032,7 +1123,7 @@ proto_register_zrtp(void)
        "hvi", "zrtp.hvi",
        FT_BYTES, BASE_NONE,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -1041,7 +1132,7 @@ proto_register_zrtp(void)
        "nonce", "zrtp.nonce",
        FT_BYTES, BASE_NONE,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     },
 
@@ -1050,7 +1141,7 @@ proto_register_zrtp(void)
        "key ID", "zrtp.key_id",
        FT_BYTES, BASE_NONE,
        NULL, 0x0,
-       "", HFILL
+       NULL, HFILL
      }
     }
   };
@@ -1078,13 +1169,8 @@ proto_register_zrtp(void)
 void
 proto_reg_handoff_zrtp(void)
 {
-  static gboolean inited = FALSE;
+  dissector_handle_t zrtp_handle;
 
-  if (!inited){
-    dissector_handle_t zrtp_handle;
-
-    zrtp_handle = create_dissector_handle(dissect_zrtp, proto_zrtp);
-    dissector_add_handle("udp.port", zrtp_handle);
-    inited = TRUE;
-  }
+  zrtp_handle = find_dissector("zrtp");
+  dissector_add_handle("udp.port", zrtp_handle);
 }
