@@ -1,7 +1,7 @@
 /* etypes.h
  * Defines ethernet packet types, similar to tcpdump's ethertype.h
  *
- * $Id: etypes.h 27804 2009-03-20 11:06:20Z stig $
+ * $Id: etypes.h 28040 2009-04-13 18:32:24Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -302,10 +302,15 @@
 #define ETHERTYPE_EPL_V2        0x88AB
 #endif
 
+#ifndef ETHERTYPE_XIMETA
+#define ETHERTYPE_XIMETA       0x88AD /* XiMeta Technology Americas Inc. */
+#endif								  /* proprietary communication protocol */	
+
 #ifndef ETHERTYPE_BRDWALK
 #define ETHERTYPE_BRDWALK       0x88AE
 #endif
 
+
 #ifndef ETHERTYPE_IEEE802_OUI_EXTENDED
 #define ETHERTYPE_IEEE802_OUI_EXTENDED 0x88B7	/* IEEE 802a OUI Extended Ethertype */
 #endif
