@@ -3,7 +3,7 @@
  *
  * Implemented as a tap named "expert".
  *
- * $Id: expert.c 22387 2007-07-23 20:11:05Z ulfl $
+ * $Id: expert.c 28662 2009-06-08 15:37:46Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -36,8 +36,15 @@
 
 
 static int expert_tap = -1;
+static int proto_expert = -1;
 static int highest_severity = 0;
 
+static int ett_expert = -1;
+static int ett_subexpert = -1;
+
+static int hf_expert_msg = -1;
+static int hf_expert_group = -1;
+static int hf_expert_severity = -1;
 
 const value_string expert_group_vals[] = {
 	{ PI_CHECKSUM,		"Checksum" },
@@ -45,8 +52,9 @@ const value_string expert_group_vals[] = {
 	{ PI_RESPONSE_CODE,	"Response" },
 	{ PI_REQUEST_CODE,	"Request" },
 	{ PI_UNDECODED,		"Undecoded" },
-	{ PI_MALFORMED,		"Malformed" },
 	{ PI_REASSEMBLE,	"Reassemble" },
+	{ PI_MALFORMED,		"Malformed" },
+	{ PI_DEBUG,		"Debug" },
 /*	{ PI_SECURITY,		"Security" },*/
 	{ 0, NULL }
 };
@@ -65,10 +73,33 @@ const value_string expert_severity_vals[] = {
 void
 expert_init(void)
 {
+	static hf_register_info hf[] = {
+		{ &hf_expert_msg,
+			{ "Message", "expert.message", FT_STRING, BASE_NONE, NULL, 0, "Wireshark expert information", HFILL }
+		},
+		{ &hf_expert_group, 
+			{ "Group", "expert.group", FT_UINT32, BASE_NONE, VALS(expert_group_vals), 0, "Wireshark expert group", HFILL }
+		},
+		{ &hf_expert_severity, 
+			{ "Severity level", "expert.severity", FT_UINT32, BASE_NONE, VALS(expert_severity_vals), 0, "Wireshark expert severity level", HFILL }
+		}
+	};
+	static gint *ett[] = {
+		&ett_expert,
+		&ett_subexpert
+	};
+
 	if(expert_tap == -1) {
 		expert_tap = register_tap("expert");
 	}
 
+	if (proto_expert == -1) {
+		proto_expert = proto_register_protocol("Expert Info", "Expert", "expert");
+		proto_register_field_array(proto_expert, hf, array_length(hf));
+		proto_register_subtree_array(ett, array_length(ett));
+		proto_set_cant_toggle(proto_expert);
+	}
+
 	highest_severity = 0;
 }
 
@@ -100,14 +131,30 @@ expert_set_item_flags(proto_item *pi, int group, int severity)
 	}
 }
 
+static proto_tree*
+expert_create_tree(proto_item *pi, int group, int severity, const char *msg)
+{
+	proto_tree *tree;
+	proto_item *ti;
+
+	tree = proto_item_add_subtree(pi, ett_expert);
+	ti = proto_tree_add_protocol_format(tree, proto_expert, NULL, 0, 0, "Expert Info (%s/%s): %s", 
+		val_to_str(severity, expert_severity_vals, "?%u?"),
+		val_to_str(group, expert_group_vals, "?%u?"),
+		msg);
+	PROTO_ITEM_SET_GENERATED(ti);
+
+	return proto_item_add_subtree(ti, ett_subexpert);
+}
 
 static void
 expert_set_info_vformat(
 packet_info *pinfo, proto_item *pi, int group, int severity, const char *format, va_list ap)
 {
-	int				ret;	/*tmp return value */
 	char			formatted[300];
 	expert_info_t	*ei;
+	proto_tree	*tree;
+	proto_item	*ti;
 
 
 	/* if this packet isn't loaded because of a read filter, don't output anything */
@@ -120,9 +167,7 @@ packet_info *pinfo, proto_item *pi, int group, int severity, const char *format,
         }
 
 	/* XXX - use currently nonexistant se_vsnprintf instead */
-	ret = g_vsnprintf(formatted, sizeof(formatted), format, ap);
-	if ((ret == -1) || (ret >= (int)sizeof(formatted)))
-		formatted[sizeof(formatted) - 1] = '\0';
+	g_vsnprintf(formatted, sizeof(formatted), format, ap);
 
 	ei = ep_alloc(sizeof(expert_info_t));
 	ei->packet_num	= pinfo->fd->num;
@@ -132,6 +177,14 @@ packet_info *pinfo, proto_item *pi, int group, int severity, const char *format,
 	ei->summary		= ep_strdup(formatted);
 	ei->pitem       = NULL;
 
+	tree = expert_create_tree(pi, group, severity, formatted);
+	ti = proto_tree_add_string(tree, hf_expert_msg, NULL, 0, 0, formatted);
+	PROTO_ITEM_SET_GENERATED(ti);
+	ti = proto_tree_add_uint(tree, hf_expert_severity, NULL, 0, 0, severity);
+	PROTO_ITEM_SET_GENERATED(ti);
+	ti = proto_tree_add_uint(tree, hf_expert_group, NULL, 0, 0, group);
+	PROTO_ITEM_SET_GENERATED(ti);
+
 	/* if we have a proto_item (not a faked item), set expert attributes to it */
 	if(pi != NULL && pi->finfo != NULL) {	
         ei->pitem       = pi;
