@@ -1,7 +1,7 @@
 /* filesystem.c
  * Filesystem utility routines
  *
- * $Id: filesystem.c 27066 2008-12-20 00:12:54Z guy $
+ * $Id: filesystem.c 33935 2010-08-26 17:35:28Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,6 +26,13 @@
 # include "config.h"
 #endif
 
+/*
+ * Required with GNU libc to get dladdr().
+ * We define it here because <dlfcn.h> apparently gets included by
+ * one of the headers we include below.
+ */
+#define _GNU_SOURCE
+
 #ifdef HAVE_DIRENT_H
 #include <dirent.h>
 #endif
@@ -42,6 +49,10 @@
 #include <unistd.h>
 #endif
 
+#ifdef HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
+
 #ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
@@ -51,14 +62,20 @@
 #include <tchar.h>
 #include <shlobj.h>
 #include <wsutil/unicode-utils.h>
-#else
+#else /* _WIN32 */
+#ifdef DLADDR_FINDS_EXECUTABLE_PATH
+#include <dlfcn.h>
+#endif /* DLADDR_FINDS_EXECUTABLE_PATH */
 #include <pwd.h>
-#endif
+#endif /* _WIN32 */
 
 #include "filesystem.h"
+#include "report_err.h"
 #include <wsutil/privileges.h>
 #include <wsutil/file_util.h>
 
+#include <wiretap/wtap.h>	/* for WTAP_ERR_SHORT_WRITE */
+
 #define PROFILES_DIR    "profiles"
 #define U3_MY_CAPTURES  "\\My Captures"
 
@@ -239,6 +256,10 @@ init_progfile_dir(const char *arg0
 #ifdef _WIN32
 	_U_
 #endif
+, int (*main_addr)(int, char **)
+#if defined(_WIN32) || !defined(DLADDR_FINDS_EXECUTABLE_PATH)
+	_U_
+#endif
 )
 {
 	char *dir_end;
@@ -246,22 +267,22 @@ init_progfile_dir(const char *arg0
 #ifdef _WIN32
 	TCHAR prog_pathname_w[_MAX_PATH+2];
 	size_t progfile_dir_len;
-        char *prog_pathname;
-        DWORD error;
-        TCHAR *msg_w;
-        guchar *msg;
-        size_t msglen;
+	char *prog_pathname;
+	DWORD error;
+	TCHAR *msg_w;
+	guchar *msg;
+	size_t msglen;
 
 	/*
 	 * Attempt to get the full pathname of the currently running
 	 * program.
 	 */
-	if (GetModuleFileName(NULL, prog_pathname_w, sizeof prog_pathname_w) != 0) {
-                /*
-                 * XXX - Should we use g_utf16_to_utf8(), as in
-                 * getenv_utf8()?
-                 */
-                prog_pathname = utf_16to8(prog_pathname_w);
+	if (GetModuleFileName(NULL, prog_pathname_w, G_N_ELEMENTS(prog_pathname_w)) != 0 && GetLastError() != ERROR_INSUFFICIENT_BUFFER) {
+		/*
+		 * XXX - Should we use g_utf16_to_utf8(), as in
+		 * getenv_utf8()?
+		 */
+		prog_pathname = utf_16to8(prog_pathname_w);
 		/*
 		 * We got it; strip off the last component, which would be
 		 * the file name of the executable, giving us the pathname
@@ -327,6 +348,9 @@ init_progfile_dir(const char *arg0
 		    msg, error);
 	}
 #else
+#ifdef DLADDR_FINDS_EXECUTABLE_PATH
+	Dl_info info;
+#endif
 	char *prog_pathname;
 	char *curdir;
 	long path_max;
@@ -348,10 +372,24 @@ init_progfile_dir(const char *arg0
 	    && !started_with_special_privs())
 		running_in_build_directory_flag = TRUE;
 
+#ifdef DLADDR_FINDS_EXECUTABLE_PATH
+	/*
+	 * Try to use dladdr() to find the pathname of the executable.
+	 * dladdr() is not guaranteed to give you anything better than
+	 * argv[0] (i.e., it might not contain a / at all, much less
+	 * being an absolute path), and doesn't appear to do so on
+	 * Linux, but on other platforms it could give you an absolute
+	 * path and obviate the need for us to determine the absolute
+	 * path.
+	 */
+	if (dladdr((void *)main_addr, &info))
+		arg0 = info.dli_fname;
+#endif
 	/*
 	 * Try to figure out the directory in which the currently running
-	 * program resides, given the argv[0] it was started with.  That
-	 * might be the absolute path of the program, or a path relative
+	 * program resides, given something purporting to be the executable
+	 * name (from dladdr() or from the argv[0] it was started with.
+	 * That might be the absolute path of the program, or a path relative
 	 * to the current directory of the process that started it, or
 	 * just a name for the program if it was started from the command
 	 * line and was searched for in $PATH.  It's not guaranteed to be
@@ -805,9 +843,7 @@ char *getenv_utf8(const char *varname)
 void
 set_profile_name(const gchar *profilename)
 {
-	if (persconfprofile) {
-		g_free (persconfprofile);
-	}
+	g_free (persconfprofile);
 
 	if (profilename && strlen(profilename) > 0 &&
 	    strcmp(profilename, DEFAULT_PROFILE) != 0) {
@@ -927,10 +963,7 @@ get_profiles_dir(void)
 {
 	static char *profiles_dir = NULL;
 
-	if (profiles_dir) {
-		g_free (profiles_dir);
-	}
-
+	g_free (profiles_dir);
 	profiles_dir = g_strdup_printf ("%s%s%s", get_persconffile_dir_no_profile (),
 					G_DIR_SEPARATOR_S, PROFILES_DIR);
 
@@ -942,9 +975,7 @@ get_persconffile_dir(const gchar *profilename)
 {
 	static char *persconffile_profile_dir = NULL;
 
-	if (persconffile_profile_dir) {
-		g_free (persconffile_profile_dir);
-	}
+	g_free (persconffile_profile_dir);
 
 	if (profilename && strlen(profilename) > 0 &&
 	    strcmp(profilename, DEFAULT_PROFILE) != 0) {
@@ -1552,6 +1583,72 @@ files_identical(const char *fname1, const char *fname2)
 #endif
 }
 
+/*
+ * Copy a file in binary mode, for those operating systems that care about
+ * such things.  This should be OK for all files, even text files, as
+ * we'll copy the raw bytes, and we don't look at the bytes as we copy
+ * them.
+ *
+ * Returns TRUE on success, FALSE on failure. If a failure, it also
+ * displays a simple dialog window with the error message.
+ */
+gboolean
+copy_file_binary_mode(const char *from_filename, const char *to_filename)
+{
+  int           from_fd, to_fd, nread, nwritten, err;
+  guint8        pd[65536];
+
+  /* Copy the raw bytes of the file. */
+  from_fd = ws_open(from_filename, O_RDONLY | O_BINARY, 0000 /* no creation so don't matter */);
+  if (from_fd < 0) {
+    report_open_failure(from_filename, errno, FALSE);
+    goto done;
+  }
+
+  /* Use open() instead of creat() so that we can pass the O_BINARY
+     flag, which is relevant on Win32; it appears that "creat()"
+     may open the file in text mode, not binary mode, but we want
+     to copy the raw bytes of the file, so we need the output file
+     to be open in binary mode. */
+  to_fd = ws_open(to_filename, O_WRONLY | O_CREAT | O_TRUNC | O_BINARY, 0644);
+  if (to_fd < 0) {
+    report_open_failure(to_filename, errno, TRUE);
+    ws_close(from_fd);
+    goto done;
+  }
+
+  while ((nread = ws_read(from_fd, pd, sizeof pd)) > 0) {
+    nwritten = ws_write(to_fd, pd, nread);
+    if (nwritten < nread) {
+      if (nwritten < 0)
+	err = errno;
+      else
+	err = WTAP_ERR_SHORT_WRITE;
+      report_write_failure(to_filename, err);
+      ws_close(from_fd);
+      ws_close(to_fd);
+      goto done;
+    }
+  }
+  if (nread < 0) {
+    err = errno;
+    report_read_failure(from_filename, err);
+    ws_close(from_fd);
+    ws_close(to_fd);
+    goto done;
+  }
+  ws_close(from_fd);
+  if (ws_close(to_fd) < 0) {
+    report_write_failure(to_filename, errno);
+    goto done;
+  }
+
+  return TRUE;
+
+done:
+  return FALSE;
+}
+
 /*
  * Editor modelines
  *
@@ -1564,4 +1661,3 @@ files_identical(const char *fname1, const char *fname2)
  * ex: set shiftwidth=4 tabstop=4 noexpandtab
  * :indentSize=4:tabSize=4:noTabs=false:
  */
-
