@@ -1,6 +1,6 @@
 /* follow.c
  *
- * $Id: follow.c 31276 2009-12-15 19:34:33Z gerald $
+ * $Id: follow.c 31539 2010-01-16 01:02:51Z gerald $
  *
  * Copyright 1998 Mike Hall <mlh@io.com>
  *
@@ -297,7 +297,7 @@ reassemble_tcp( guint32 tcp_stream, gulong sequence, gulong acknowledgement,
   }
   else {
     /* out of order packet */
-    if(data_length > 0 && sequence > seq[src_index] ) {
+    if(data_length > 0 && ((glong)(sequence - seq[src_index]) > 0) ) {
       tmp_frag = (tcp_frag *)g_malloc( sizeof( tcp_frag ) );
       tmp_frag->data = (gchar *)g_malloc( data_length );
       tmp_frag->seq = sequence;
@@ -352,6 +352,11 @@ check_fragments( int index, tcp_stream_chunk *sc, gulong acknowledged ) {
           }
 
           seq[index] += (current->len - new_pos);
+        } 
+
+        /* Remove the fragment from the list as the "new" part of it
+         * has been processed or its data has been seen already in 
+         * another packet. */
           if( prev ) {
             prev->next = current->next;
           } else {
@@ -361,7 +366,6 @@ check_fragments( int index, tcp_stream_chunk *sc, gulong acknowledged ) {
           g_free( current );
           return 1;
         }
-      }
 
       if( current->seq == seq[index] ) {
         /* this fragment fits the stream */
