@@ -1,6 +1,6 @@
 /* follow.h
  *
- * $Id: follow.h 23346 2007-11-03 04:45:35Z sfisher $
+ * $Id: follow.h 31276 2009-12-15 19:34:33Z gerald $
  *
  * Copyright 1998 Mike Hall <mlh@io.com>
  *
@@ -42,8 +42,8 @@ typedef struct _tcp_stream_chunk {
 } tcp_stream_chunk;
 
 char* build_follow_filter( packet_info * );
-void reassemble_tcp( gulong, gulong, const char*, gulong, int,
-		     address *, address *, guint, guint );
+void reassemble_tcp( guint32, gulong, gulong, gulong, const char*, gulong,
+                     int, address *, address *, guint, guint );
 void  reset_tcp_reassembly( void );
 
 typedef struct {
