@@ -1,5 +1,5 @@
 /*
- * $Id: ftype-bytes.c 31605 2010-01-21 17:30:45Z gerald $
+ * $Id: ftype-bytes.c 33115 2010-06-06 22:13:16Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -696,7 +696,7 @@ ftype_register_bytes(void)
 
 	static ftype_t oid_type = {
 		FT_OID,			/* ftype */
-		"OID",			/* name */
+		"FT_OID",			/* name */
 		"OBJECT IDENTIFIER",			/* pretty_name */
 		0,			/* wire_size */
 		bytes_fvalue_new,		/* new_value */
