@@ -1,5 +1,5 @@
 /*
- * $Id: ftype-integer.c 20472 2007-01-18 11:02:26Z martinm $
+ * $Id: ftype-integer.c 28117 2009-04-22 03:07:37Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,22 +29,6 @@
 #include "ftypes-int.h"
 #include <epan/addr_resolv.h>
 
-#ifdef NEED_G_ASCII_STRTOULL_H
-#include "g_ascii_strtoull.h"
-#endif
-
-/*
- * GLib 1.2[.x] doesn't define G_MAXUINT32 or G_MAXUINT64; if they're
- * not defined, we define them as the maximum 32-bit and 32-bit
- * unsigned numbers.
- */
-#ifndef G_MAXUINT32
-#define G_MAXUINT32	((guint32)0xFFFFFFFFU)
-#endif
-#ifndef G_MAXUINT64
-#define G_MAXUINT64	((guint64)G_GINT64_CONSTANT(0xFFFFFFFFFFFFFFFFU))
-#endif
-
 static void
 int_fvalue_new(fvalue_t *fv)
 {
@@ -118,7 +102,7 @@ val_from_unparsed(fvalue_t *fv, char *s, gboolean allow_partial_value _U_, LogFu
 		return FALSE;
 	}
 
-	fv->value.uinteger = value;
+	fv->value.uinteger = (guint32)value;
 	return TRUE;
 }
 
@@ -321,7 +305,7 @@ integer64_repr_len(fvalue_t *fv _U_, ftrepr_t rtype _U_)
 static void
 integer64_to_repr(fvalue_t *fv, ftrepr_t rtype _U_, char *buf)
 {
-	sprintf(buf, "%" PRId64, fv->value.integer64);
+	sprintf(buf, "%" G_GINT64_MODIFIER "d", fv->value.integer64);
 }
 
 static int
@@ -333,7 +317,7 @@ uinteger64_repr_len(fvalue_t *fv _U_, ftrepr_t rtype _U_)
 static void
 uinteger64_to_repr(fvalue_t *fv, ftrepr_t rtype _U_, char *buf)
 {
-	sprintf(buf, "%" PRIu64, fv->value.integer64);
+	sprintf(buf, "%" G_GINT64_MODIFIER "u", fv->value.integer64);
 }
 
 static gboolean
