@@ -1,5 +1,5 @@
 /*
- * $Id: ftype-string.c 27720 2009-03-15 02:57:16Z guy $
+ * $Id: ftype-string.c 31605 2010-01-21 17:30:45Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,8 +27,10 @@
 #include <ftypes-int.h>
 #include <string.h>
 
+#if defined(HAVE_LIBPCRE) || GLIB_CHECK_VERSION(2,14,0)
 #ifdef HAVE_LIBPCRE
 #include <pcre.h>
+# endif
 #define CMP_MATCHES cmp_matches
 #else
 #define CMP_MATCHES NULL
@@ -285,7 +287,34 @@ cmp_matches(fvalue_t *fv_a, fvalue_t *fv_b)
 	}
 	return FALSE;
 }
-#endif
+#elif GLIB_CHECK_VERSION(2,14,0) /* GRegex */
+static gboolean
+cmp_matches(fvalue_t *fv_a, fvalue_t *fv_b)
+{
+	char *str = fv_a->value.string;
+	GRegex *regex = fv_b->value.re;
+
+	/* fv_b is always a FT_PCRE, otherwise the dfilter semcheck() would have
+	 * warned us. For the same reason (and because we're using g_malloc()),
+	 * fv_b->value.re is not NULL.
+	 */
+	if (strcmp(fv_b->ftype->name, "FT_PCRE") != 0) {
+		return FALSE;
+	}
+	if (! regex) {
+		return FALSE;
+	}
+	return g_regex_match_full(
+			regex,		/* Compiled PCRE */
+			str,		/* The data to check for the pattern... */
+			(int)strlen(str),	/* ... and its length */
+			0,		/* Start offset within data */
+			0,		/* GRegexMatchFlags */
+			NULL,		/* We are not interested in the match information */
+			NULL		/* We don't want error information */
+			);
+}
+#endif /* HAVE_LIBPCRE / GRegex */
 
 void
 ftype_register_string(void)
