@@ -1,7 +1,7 @@
 /* packet.c
  * Routines for packet disassembly
  *
- * $Id: packet.c 28662 2009-06-08 15:37:46Z gerald $
+ * $Id: packet.c 33716 2010-08-05 16:44:50Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -197,23 +197,39 @@ add_new_data_source(packet_info *pinfo, tvbuff_t *tvb, const char *name)
 
 	src = ep_alloc(sizeof (data_source));
 	src->tvb = tvb;
-	/*
-	 * XXX - if we require this argument to be a string constant,
-	 * we don't need to allocate a buffer for a copy and make a
-	 * copy, and wouldn't need to free the buffer, either.
-	 */
-	src->name = ep_strdup_printf("%s (%u bytes)", name, tvb_length(tvb));
+    src->name_initialized = FALSE;
+	src->name = name;
 	pinfo->data_src = g_slist_append(pinfo->data_src, src);
 }
 
+void
+packet_add_new_data_source(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, const char *name)
+{
+	if (tree && PTREE_DATA(tree)->visible)
+		add_new_data_source(pinfo, tvb, name);
+}
+
+const char*
+get_data_source_name(data_source *src)
+{
+	if (!src->name_initialized) {
+		src->name = ep_strdup_printf("%s (%u bytes)", src->name, tvb_length(src->tvb));
+		src->name_initialized = TRUE;
+	}
+
+	return src->name;
+}
+
 /*
  * Free up a frame's list of data sources.
  */
 void
 free_data_sources(packet_info *pinfo)
 {
-	g_slist_free(pinfo->data_src);
-	pinfo->data_src = NULL;
+	if (pinfo->data_src) {
+		g_slist_free(pinfo->data_src);
+		pinfo->data_src = NULL;
+	}
 }
 
 /* Allow dissectors to register a "final_registration" routine
@@ -322,12 +338,15 @@ dissect_packet(epan_dissect_t *edt, union wtap_pseudo_header *pseudo_header,
 	edt->pi.clnp_dstref = 0;
 	edt->pi.link_dir = LINK_DIR_UNKNOWN;
 
-    EP_CHECK_CANARY(("before dissecting frame %d",fd->num));
+	/* to enable decode as for ethertype=0x0000 (fix for bug 4721) */
+	edt->pi.ethertype = G_MAXINT;
+
+	EP_CHECK_CANARY(("before dissecting frame %d",fd->num));
     
 	TRY {
 		edt->tvb = tvb_new_real_data(pd, fd->cap_len, fd->pkt_len);
 		/* Add this tvbuffer into the data_src list */
-		add_new_data_source(&edt->pi, edt->tvb, "Frame");
+		packet_add_new_data_source(&edt->pi, edt->tree, edt->tvb, "Frame");
 
 		/* Even though dissect_frame() catches all the exceptions a
 		 * sub-dissector can throw, dissect_frame() itself may throw
