@@ -1,7 +1,7 @@
 /* range.c
  * Range routines
  *
- * $Id: range.c 27281 2009-01-20 23:33:38Z gerald $
+ * $Id: range.c 28145 2009-04-24 12:18:31Z wmeier $
  *
  * Dick Gooris <gooris@lucent.com>
  * Ulf Lamping <ulf.lamping@web.de>
@@ -295,21 +295,20 @@ range_convert_range(range_t *range)
 {
    guint32 i;
    gboolean prepend_comma = FALSE;
-   char *string, *str;
+   emem_strbuf_t *strbuf;
 
-   string=ep_alloc(128);
-   string[0]=0;
-   str=string;
+   strbuf=ep_strbuf_new(NULL);
 
    for (i=0; i < range->nranges; i++) {
-      if (range->ranges[i].low == range->ranges[i].high)
-	 str += g_snprintf(str, 128-(str-string), "%s%u", prepend_comma?",":"", range->ranges[i].low);
-      else
-	 str += g_snprintf(str, 128-(str-string), "%s%u-%u", prepend_comma?",":"", range->ranges[i].low, range->ranges[i].high);
+      if (range->ranges[i].low == range->ranges[i].high) {
+	 ep_strbuf_append_printf(strbuf, "%s%u", prepend_comma?",":"", range->ranges[i].low);
+      } else {
+	 ep_strbuf_append_printf(strbuf, "%s%u-%u", prepend_comma?",":"", range->ranges[i].low, range->ranges[i].high);
+      }
       prepend_comma = TRUE;
    }
 
-   return string;
+   return strbuf->str;
 }
 
 /* Create a copy of a range. */
