@@ -2,7 +2,7 @@
  * API for a counter tree for Wireshark
  * 2004, Luis E. G. Ontanon
  *
- * $Id: stats_tree.c 25717 2008-07-12 01:48:24Z morriss $
+ * $Id: stats_tree.c 27999 2009-04-08 16:50:20Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -98,7 +98,7 @@ stats_tree_branch_max_namelen(const stat_node *node, guint indent)
 		}
 	}
 	
-	len = strlen(node->name) + indent;
+	len = (guint) strlen(node->name) + indent;
 	maxlen = len > maxlen ? len : maxlen;
 	
 	return maxlen;
@@ -169,10 +169,8 @@ free_stat_node(stat_node *node)
 	
 	if (node->hash) g_hash_table_destroy(node->hash);
 
-	if (node->rng) g_free(node->rng);
-	
-	if (node->name) g_free(node->name);
-	
+	g_free(node->rng);
+	g_free(node->name);
 	g_free(node);
 }
 
@@ -261,9 +259,9 @@ stats_tree_reinit(void *p)
 
 /* register a new stats_tree */
 extern void
-stats_tree_register(const char *tapname, const char *abbr, const char *name,
+stats_tree_register_with_group(const char *tapname, const char *abbr, const char *name,
 		    stat_tree_packet_cb packet, stat_tree_init_cb init,
-		    stat_tree_cleanup_cb cleanup)
+		    stat_tree_cleanup_cb cleanup, register_stat_group_t stat_group)
 {
 	
 	stats_tree_cfg *cfg = g_malloc( sizeof(stats_tree_cfg) );
@@ -274,6 +272,7 @@ stats_tree_register(const char *tapname, const char *abbr, const char *name,
 	cfg->tapname = g_strdup(tapname);
 	cfg->abbr = g_strdup(abbr);
 	cfg->name = name ? g_strdup(name) : g_strdup(abbr);
+    cfg->stat_group = stat_group;
 	
 	cfg->packet = packet;
 	cfg->init = init;
@@ -295,6 +294,17 @@ stats_tree_register(const char *tapname, const char *abbr, const char *name,
 	
 }
 
+/* register a new stats_tree with default group REGISTER_STAT_GROUP_UNSORTED */
+extern void
+stats_tree_register(const char *tapname, const char *abbr, const char *name,
+		    stat_tree_packet_cb packet, stat_tree_init_cb init,
+		    stat_tree_cleanup_cb cleanup)
+{
+    stats_tree_register_with_group(tapname, abbr, name,
+		    packet, init,
+		    cleanup, REGISTER_STAT_GROUP_UNSORTED);
+}
+
 extern stats_tree*
 stats_tree_new(stats_tree_cfg *cfg, tree_pres *pr, char *filter)
 {
