@@ -1,7 +1,7 @@
 /* tap.c
  * packet tap interface   2002 Ronnie Sahlberg
  *
- * $Id: tap.c 20979 2007-03-06 00:35:35Z sfisher $
+ * $Id: tap.c 30720 2009-10-26 19:22:56Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -117,7 +117,13 @@ int
 register_tap(const char *name)
 {
 	tap_dissector_t *td, *tdl;
-	int i;
+	int i, tap_id;
+
+	if(tap_dissector_list){
+		tap_id=find_tap_id(name);
+		if (tap_id)
+			return tap_id;
+	}
 
 	td=g_malloc(sizeof(tap_dissector_t));
 	td->next=NULL;
@@ -186,6 +192,25 @@ tap_queue_packet(int tap_id, packet_info *pinfo, const void *tap_specific_data)
 /* **********************************************************************
  * Functions used by file.c to drive the tap subsystem
  * ********************************************************************** */
+
+void tap_build_interesting (epan_dissect_t *edt)
+{
+	tap_listener_t *tl;
+
+	/* nothing to do, just return */
+	if(!tap_listener_queue){
+		return;
+	}
+
+	/* loop over all tap listeners and build the list of all
+	   interesting hf_fields */
+	for(tl=(tap_listener_t *)tap_listener_queue;tl;tl=tl->next){
+		if(tl->code){
+			epan_dissect_prime_dfilter(edt, tl->code);
+		}
+	}
+}
+
 /* This function is used to delete/initialize the tap queue and prime an
    epan_dissect_t with all the filters for tap listeners.
    To free the tap queue, we just prepend the used queue to the free queue.
@@ -193,8 +218,6 @@ tap_queue_packet(int tap_id, packet_info *pinfo, const void *tap_specific_data)
 void
 tap_queue_init(epan_dissect_t *edt)
 {
-	tap_listener_t *tl;
-
 	/* nothing to do, just return */
 	if(!tap_listener_queue){
 		return;
@@ -204,13 +227,7 @@ tap_queue_init(epan_dissect_t *edt)
 
 	tap_packet_index=0;
 
-	/* loop over all tap listeners and build the list of all
-	   interesting hf_fields */
-	for(tl=(tap_listener_t *)tap_listener_queue;tl;tl=tl->next){
-		if(tl->code){
-			epan_dissect_prime_dfilter(edt, tl->code);
-		}
-	}
+	tap_build_interesting (edt);
 }
 
 /* this function is called after a packet has been fully dissected to push the tapped
@@ -379,7 +396,7 @@ register_tap_listener(const char *tapname, void *tapdata, const char *fstring, t
 	tap_id=find_tap_id(tapname);
 	if(!tap_id){
 		error_string = g_string_new("");
-		g_string_sprintf(error_string, "Tap %s not found", tapname);
+		g_string_printf(error_string, "Tap %s not found", tapname);
 		return error_string;
 	}
 
@@ -389,7 +406,7 @@ register_tap_listener(const char *tapname, void *tapdata, const char *fstring, t
 	if(fstring){
 		if(!dfilter_compile(fstring, &tl->code)){
 			error_string = g_string_new("");
-			g_string_sprintf(error_string,
+			g_string_printf(error_string,
 			    "Filter \"%s\" is invalid - %s",
 			    fstring, dfilter_error_msg);
 			g_free(tl);
@@ -411,6 +428,53 @@ register_tap_listener(const char *tapname, void *tapdata, const char *fstring, t
 	return NULL;
 }
 
+/* this function sets a new dfilter to a tap listener
+ */
+GString *
+set_tap_dfilter(void *tapdata, const char *fstring)
+{
+	tap_listener_t *tl=NULL,*tl2;
+	GString *error_string;
+
+	if(!tap_listener_queue){
+		return NULL;
+	}
+
+	if(tap_listener_queue->tapdata==tapdata){
+		tl=(tap_listener_t *)tap_listener_queue;
+	} else {
+		for(tl2=(tap_listener_t *)tap_listener_queue;tl2->next;tl2=tl2->next){
+			if(tl2->next->tapdata==tapdata){
+				tl=tl2->next;
+				break;
+			}
+			
+		}
+	}
+
+	if(tl){
+		if(tl->code){
+			dfilter_free(tl->code);
+			num_tap_filters--;
+			tl->code=NULL;
+		}
+		tl->needs_redraw=1;
+		if(fstring){
+			if(!dfilter_compile(fstring, &tl->code)){
+				error_string = g_string_new("");
+				g_string_printf(error_string,
+						 "Filter \"%s\" is invalid - %s",
+						 fstring, dfilter_error_msg);
+				return error_string;
+			} else {
+				num_tap_filters++;
+			}
+		}
+	}
+
+	return NULL;
+}
+
 /* this function removes a tap listener
  */
 void
