@@ -1,7 +1,7 @@
 /* tap.h
  * packet tap interface   2002 Ronnie Sahlberg
  *
- * $Id: tap.h 21442 2007-04-16 04:34:07Z morriss $
+ * $Id: tap.h 30720 2009-10-26 19:22:56Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,10 +27,6 @@
 
 #include "epan/epan.h"
 
-#ifdef INTTYPES_H_DEFINES_FORMATS
-#include <inttypes.h>
-#endif
-
 /* With MSVC and a libwireshark.dll, we need a 
  * special declaration of num_tap_filters.
  */
@@ -45,6 +41,7 @@ extern void tap_init(void);
 extern int register_tap(const char *name);
 extern int find_tap_id(const char *name);
 extern void tap_queue_packet(int tap_id, packet_info *pinfo, const void *tap_specific_data);
+extern void tap_build_interesting(epan_dissect_t *edt);
 extern void tap_queue_init(epan_dissect_t *edt);
 extern void tap_push_tapped_queue(epan_dissect_t *edt);
 extern void reset_tap_listeners(void);
@@ -52,6 +49,7 @@ extern void draw_tap_listeners(gboolean draw_all);
 extern GString *register_tap_listener(const char *tapname, void *tapdata,
     const char *fstring, tap_reset_cb tap_reset, tap_packet_cb tap_packet,
     tap_draw_cb tap_draw);
+extern GString *set_tap_dfilter(void *tapdata, const char *fstring);
 extern void remove_tap_listener(void *tapdata);
 extern gboolean have_tap_listeners(void);
 extern gboolean have_tap_listener(int tap_id);
