@@ -1,12 +1,12 @@
 /*
  *  uat.c
  *
- * $Id: uat.c 27989 2009-04-08 03:24:49Z gerald $
+ * $Id: uat.c 32223 2010-03-17 19:14:44Z gerald $
  *
  *  User Accessible Tables
  *  Mantain an array of user accessible data strucures
  *
- * (c) 2007, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
+ * (c) 2007, Luis E. Garcia Ontanon <luis@ontanon.org>
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -38,12 +38,15 @@
 #include <stdarg.h>
 
 #include <glib.h>
+
+#include <wsutil/file_util.h>
+#include <wsutil/str_util.h>
+
 #include <epan/emem.h>
 #include <epan/report_err.h>
 #include <epan/filesystem.h>
 #include <epan/packet.h>
 #include <epan/range.h>
-#include <wiretap/file_util.h>
 
 #include "uat-int.h"
 
@@ -64,17 +67,22 @@ uat_t* uat_new(const char* name,
 			   uat_copy_cb_t copy_cb,
 			   uat_update_cb_t update_cb,
 			   uat_free_cb_t free_cb,
+			   uat_post_update_cb_t post_update_cb,
 			   uat_field_t* flds_array) {
+	/* Create new uat */
 	uat_t* uat = g_malloc(sizeof(uat_t));
 	guint i;
 
+	/* Add to global array of uats */
 	if (!all_uats)
 		all_uats = g_ptr_array_new();
 
 	g_ptr_array_add(all_uats,uat);
 
+	/* Check params */
 	g_assert(name && size && filename && data_ptr && numitems_ptr);
 
+	/* Set uat values from inputs */
 	uat->name = g_strdup(name);
 	uat->record_size = size;
 	uat->filename = g_strdup(filename);
@@ -84,8 +92,9 @@ uat_t* uat_new(const char* name,
 	uat->copy_cb = copy_cb;
 	uat->update_cb = update_cb;
 	uat->free_cb = free_cb;
+	uat->post_update_cb = post_update_cb;
 	uat->fields = flds_array;
-	uat->user_data = g_array_new(FALSE,FALSE,uat->record_size);
+	uat->user_data = g_array_new(FALSE,FALSE,(guint)uat->record_size);
 	uat->changed = FALSE;
 	uat->loaded = FALSE;
 	uat->rep = NULL;
@@ -93,7 +102,7 @@ uat_t* uat_new(const char* name,
 	uat->help = help;
 	uat->category = category;
 
-	for (i=0;flds_array[i].name;i++) {
+	for (i=0;flds_array[i].title;i++) {
 		fld_data_t* f = g_malloc(sizeof(fld_data_t));
 
 		f->colnum = i+1;
@@ -105,7 +114,6 @@ uat_t* uat_new(const char* name,
 
 	uat->ncols = i;
 
-
 	*data_ptr = NULL;
 	*numitems_ptr = 0;
 
@@ -120,7 +128,7 @@ void* uat_add_record(uat_t* uat, const void* data) {
 	rec = uat->user_data->data + (uat->record_size * (uat->user_data->len-1));
 
 	if (uat->copy_cb) {
-		uat->copy_cb(rec, data, uat->record_size);
+		uat->copy_cb(rec, data, (unsigned int) uat->record_size);
 	}
 
 	UAT_UPDATE(uat);
@@ -129,7 +137,7 @@ void* uat_add_record(uat_t* uat, const void* data) {
 }
 
 void uat_swap(uat_t* uat, guint a, guint b) {
-	guint s = uat->record_size;
+	size_t s = uat->record_size;
 	void* tmp = ep_alloc(s);
 
 	g_assert( a < uat->user_data->len && b < uat->user_data->len );
@@ -240,7 +248,7 @@ gboolean uat_save(uat_t* uat, char** error) {
 
 	if (! fname ) return FALSE;
 
-	fp = eth_fopen(fname,"w");
+	fp = ws_fopen(fname,"w");
 
     if (!fp && errno == ENOENT) {
         /* Parent directory does not exist, try creating first */
@@ -250,18 +258,7 @@ gboolean uat_save(uat_t* uat, char** error) {
             g_free (pf_dir_path);
             return FALSE;
         }
-        fp = eth_fopen(fname,"w");
-    }
-
-    if (!fp && errno == ENOENT) {
-        /* Parent directory does not exist, try creating first */
-        gchar *pf_dir_path = NULL;
-        if (create_persconffile_dir(&pf_dir_path) != 0) {
-            *error = ep_strdup_printf("uat_save: error creating '%s'", pf_dir_path);
-            g_free (pf_dir_path);
-            return FALSE;
-        }
-        fp = eth_fopen(fname,"w");
+        fp = ws_fopen(fname,"w");
     }
 
 	if (!fp) {
@@ -270,6 +267,7 @@ gboolean uat_save(uat_t* uat, char** error) {
 	}
 
 	*error = NULL;
+	g_free (fname);
 
 	fprintf(fp,"# This file is automatically generated, DO NOT MODIFY.\n");
 
@@ -330,14 +328,14 @@ void uat_clear(uat_t* uat) {
 }
 
 void* uat_dup(uat_t* uat, guint* len_p) {
-	guint size = (uat->record_size * uat->user_data->len);
+	guint size = (guint) (uat->record_size * uat->user_data->len);
 	*len_p = size;
 	return size ? g_memdup(uat->user_data->data,size) : NULL ;
 }
 
 void* uat_se_dup(uat_t* uat, guint* len_p) {
-	guint size = (uat->record_size * uat->user_data->len);
-	*len_p = size;
+	guint size = (guint) (uat->record_size * uat->user_data->len);
+	*len_p = (guint) size;
 	return size ? se_memdup(uat->user_data->data,size) : NULL ;
 }
 
@@ -390,7 +388,7 @@ void uat_load_all(void) {
 }
 
 
-gboolean uat_fld_chk_str(void* u1 _U_, const char* strptr, unsigned len _U_, void* u2 _U_, void* u3 _U_, const char** err) {
+gboolean uat_fld_chk_str(void* u1 _U_, const char* strptr, unsigned len _U_, const void* u2 _U_, const void* u3 _U_, const char** err) {
 	if (strptr == NULL) {
 		*err = "NULL pointer";
 		return FALSE;
@@ -400,10 +398,10 @@ gboolean uat_fld_chk_str(void* u1 _U_, const char* strptr, unsigned len _U_, voi
 	return TRUE;
 }
 
-gboolean uat_fld_chk_proto(void* u1 _U_, const char* strptr, unsigned len, void* u2 _U_, void* u3 _U_, const char** err) {
+gboolean uat_fld_chk_proto(void* u1 _U_, const char* strptr, unsigned len, const void* u2 _U_, const void* u3 _U_, const char** err) {
 	if (len) {
 		char* name = ep_strndup(strptr,len);
-		g_strdown(name);
+		ascii_strdown_inplace(name);
 		g_strchug(name);
 
 		if (find_dissector(name)) {
@@ -419,36 +417,40 @@ gboolean uat_fld_chk_proto(void* u1 _U_, const char* strptr, unsigned len, void*
 	}
 }
 
-gboolean uat_fld_chk_num_dec(void* u1 _U_, const char* strptr, unsigned len, void* u2 _U_, void* u3 _U_, const char** err) {
-	char* str = ep_strndup(strptr,len);
-	long i = strtol(str,&str,10);
+gboolean uat_fld_chk_num_dec(void* u1 _U_, const char* strptr, unsigned len, const void* u2 _U_, const void* u3 _U_, const char** err) {
+    if (len > 0) {
+        char* str = ep_strndup(strptr,len);
+        long i = strtol(str,&str,10);
 
-	if ( ( i == 0) && (errno == ERANGE || errno == EINVAL) ) {
-		*err = strerror(errno);
-		return FALSE;
-	}
+        if ( ( i == 0) && (errno == ERANGE || errno == EINVAL) ) {
+            *err = strerror(errno);
+            return FALSE;
+        }
+    }
 
 	*err = NULL;
 	return TRUE;
 }
 
-gboolean uat_fld_chk_num_hex(void* u1 _U_, const char* strptr, unsigned len, void* u2 _U_, void* u3 _U_, const char** err) {
-	char* str = ep_strndup(strptr,len);
-	long i = strtol(str,&str,16);
+gboolean uat_fld_chk_num_hex(void* u1 _U_, const char* strptr, unsigned len, const void* u2 _U_, const void* u3 _U_, const char** err) {
+    if (len > 0) {
+        char* str = ep_strndup(strptr,len);
+        long i = strtol(str,&str,16);
 
-	if ( ( i == 0) && (errno == ERANGE || errno == EINVAL) ) {
-		*err = strerror(errno);
-		return FALSE;
-	}
+        if ( ( i == 0) && (errno == ERANGE || errno == EINVAL) ) {
+            *err = strerror(errno);
+            return FALSE;
+        }
+    }
 
 	*err = NULL;
 	return TRUE;
 }
 
-gboolean uat_fld_chk_enum(void* u1 _U_, const char* strptr, unsigned len, void* v, void* u3 _U_, const char** err) {
+gboolean uat_fld_chk_enum(void* u1 _U_, const char* strptr, unsigned len, const void* v, const void* u3 _U_, const char** err) {
 	char* str = ep_strndup(strptr,len);
 	guint i;
-	value_string* vs = v;
+	const value_string* vs = v;
 
 	for(i=0;vs[i].strptr;i++) {
 		if (g_str_equal(vs[i].strptr,str)) {
@@ -461,7 +463,7 @@ gboolean uat_fld_chk_enum(void* u1 _U_, const char* strptr, unsigned len, void*
 	return FALSE;
 }
 
-gboolean uat_fld_chk_range(void* u1 _U_, const char* strptr, unsigned len, void* v _U_, void* u3, const char** err) {
+gboolean uat_fld_chk_range(void* u1 _U_, const char* strptr, unsigned len, const void* v _U_, const void* u3, const char** err) {
 	char* str = ep_strndup(strptr,len);
 	range_t* r = NULL;
 	convert_ret_t ret = range_convert_str(&r, str,GPOINTER_TO_UINT(u3));
