@@ -1,7 +1,7 @@
 /* value_string.c
  * Routines for value_strings
  *
- * $Id: value_string.c 23149 2007-10-11 19:40:58Z jake $
+ * $Id: value_string.c 29826 2009-09-09 19:15:24Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -31,6 +31,7 @@
 #include "to_str.h"
 #include "emem.h"
 #include "value_string.h"
+#include <string.h>
 
 /* Tries to match val against each element in the value_string array vs.
    Returns the associated string ptr on a match.
@@ -48,6 +49,22 @@ val_to_str(guint32 val, const value_string *vs, const char *fmt) {
   return ep_strdup_printf(fmt, val);
 }
 
+/* Tries to match val against each element in the value_string array vs.
+   Returns the associated string ptr on a match.
+   Returns 'unknown_str', on failure. */
+const gchar*
+val_to_str_const(guint32 val, const value_string *vs, const char *unknown_str) {
+  const gchar *ret;
+
+  g_assert(unknown_str != NULL);
+
+  ret = match_strval(val, vs);
+  if (ret != NULL)
+    return ret;
+
+  return unknown_str;
+}
+
 /* Tries to match val against each element in the value_string array vs.
    Returns the associated string ptr, and sets "*idx" to the index in
    that table, on a match, and returns NULL, and sets "*idx" to -1,
@@ -77,6 +94,51 @@ match_strval(guint32 val, const value_string *vs) {
     return match_strval_idx(val, vs, &ignore_me);
 }
 
+/* Tries to match val against each element in the value_string array vs.
+   Returns the associated string ptr on a match.
+   Formats val with fmt, and returns the resulting string, on failure. */
+const gchar*
+str_to_str(const gchar *val, const string_string *vs, const char *fmt) {
+  const gchar *ret;
+
+  g_assert(fmt != NULL);
+
+  ret = match_strstr(val, vs);
+  if (ret != NULL)
+    return ret;
+
+  return ep_strdup_printf(fmt, val);
+}
+
+/* Tries to match val against each element in the value_string array vs.
+   Returns the associated string ptr, and sets "*idx" to the index in
+   that table, on a match, and returns NULL, and sets "*idx" to -1,
+   on failure. */
+const gchar*
+match_strstr_idx(const gchar *val, const string_string *vs, gint *idx) {
+  gint i = 0;
+
+  if(vs) {
+    while (vs[i].strptr) {
+      if (!strcmp(vs[i].value,val)) {
+        *idx = i;
+        return(vs[i].strptr);
+      }
+      i++;
+    }
+  }
+
+  *idx = -1;
+  return NULL;
+}
+
+/* Like match_strval_idx(), but doesn't return the index. */
+const gchar*
+match_strstr(const gchar *val, const string_string *vs) {
+    gint ignore_me;
+    return match_strstr_idx(val, vs, &ignore_me);
+}
+
 /* Generate a string describing an enumerated bitfield (an N-bit field
    with various specific values having particular names). */
 const char *
@@ -87,7 +149,7 @@ decode_enumerated_bitfield(guint32 val, guint32 mask, int width,
   char *p;
 
   p = decode_bitfield_value(buf, val, mask, width);
-  g_snprintf(p, 1024-(p-buf), fmt, val_to_str(val & mask, tab, "Unknown"));
+  g_snprintf(p, (gulong) (1024-(p-buf)), fmt, val_to_str(val & mask, tab, "Unknown"));
   return buf;
 }
 
@@ -108,7 +170,7 @@ decode_enumerated_bitfield_shifted(guint32 val, guint32 mask, int width,
     shift++;
 
   p = decode_bitfield_value(buf, val, mask, width);
-  g_snprintf(p, 1024-(p-buf), fmt, val_to_str((val & mask) >> shift, tab, "Unknown"));
+  g_snprintf(p, (gulong) (1024-(p-buf)), fmt, val_to_str((val & mask) >> shift, tab, "Unknown"));
   return buf;
 }
 
