@@ -1,11 +1,11 @@
 /*
- * packet-lua.c
+ * init_wslua.c
  *
  * Wireshark's interface to the Lua Programming Language
  *
- * (c) 2006, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
+ * (c) 2006, Luis E. Garcia Ontanon <luis@ontanon.org>
  *
- * $Id: init_wslua.c 24089 2008-01-14 16:40:23Z stig $
+ * $Id: init_wslua.c 28662 2009-06-08 15:37:46Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,12 +27,13 @@
  */
 
 #include "wslua.h"
+#include <epan/dissectors/packet-frame.h>
 #include <epan/nstime.h>
 #include <math.h>
 #include <epan/expert.h>
 #include <epan/ex-opt.h>
-#include <epan/privileges.h>
-#include <wiretap/file_util.h>
+#include <wsutil/privileges.h>
+#include <wsutil/file_util.h>
 
 static lua_State* L = NULL;
 
@@ -44,6 +45,14 @@ int lua_dissectors_table_ref;
 
 dissector_handle_t lua_data_handle;
 
+static void lua_frame_end(void)
+{
+    clear_outstanding_Tvb();
+    clear_outstanding_Pinfo();
+    clear_outstanding_Column();
+    clear_outstanding_Columns();
+    clear_outstanding_TreeItem();
+}
 
 static int wslua_not_register_menu(lua_State* LS) {
     luaL_error(LS,"too late to register a menu");
@@ -55,10 +64,11 @@ int dissect_lua(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree) {
     lua_pinfo = pinfo;
     lua_tvb = tvb;
 
-	lua_tree = ep_alloc(sizeof(struct _wslua_treeitem));
-	lua_tree->tree = tree;
-	lua_tree->item = proto_tree_add_text(tree,tvb,0,0,"lua fake item");
-	PROTO_ITEM_SET_HIDDEN(lua_tree->item);
+    lua_tree = g_malloc(sizeof(struct _wslua_treeitem));
+    lua_tree->tree = tree;
+    lua_tree->item = proto_tree_add_text(tree,tvb,0,0,"lua fake item");
+    lua_tree->expired = FALSE;
+    PROTO_ITEM_SET_HIDDEN(lua_tree->item);
 
     /*
      * almost equivalent to Lua:
@@ -85,27 +95,25 @@ int dissect_lua(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree) {
             const gchar* error = lua_tostring(L,-1);
 
             proto_item* pi = proto_tree_add_text(tree,tvb,0,0,"Lua Error: %s",error);
-            expert_add_info_format(pinfo, pi, PI_DEBUG, PI_ERROR ,"Lua Error");
+            expert_add_info_format(pinfo, pi, PI_UNDECODED, PI_ERROR ,"Lua Error");
         } else {
 
             /* if the Lua dissector reported the consumed bytes, pass it to our caller */
-            if (lua_isnumber(L, -1)) {
+            if (lua_isnumber(L, -1)) { 
+                /* we got the consumed bytes or the missing bytes as a negative number */
                 consumed_bytes = (int) lua_tonumber(L, -1);
-                lua_pop(L, 1);  /* pop returned value */
+                lua_pop(L, 1);
+            }
         }
-	}
-	
+
     } else {
         proto_item* pi = proto_tree_add_text(tree,tvb,0,0,"Lua Error: did not find the %s dissector"
                                              " in the dissectors table",pinfo->current_proto);
 
-        expert_add_info_format(pinfo, pi, PI_DEBUG, PI_ERROR ,"Lua Error");
+        expert_add_info_format(pinfo, pi, PI_UNDECODED, PI_ERROR ,"Lua Error");
     }
 
-    clear_outstanding_tvbs();
-    clear_outstanding_pinfos();
-    clear_outstanding_trees();
-
+    register_frame_end_routine(lua_frame_end);
 
     lua_pinfo = NULL;
     lua_tree = NULL;
@@ -160,7 +168,7 @@ static int init_error_handler(lua_State* LS) {
 
 
 static void wslua_init_routine(void) {
-	static gboolean initialized = FALSE;
+    static gboolean initialized = FALSE;
 
     if ( ! initialized ) {
         lua_prime_all_fields(NULL);
@@ -192,7 +200,7 @@ static int lua_main_error_handler(lua_State* LS) {
 void lua_load_script(const gchar* filename) {
     FILE* file;
 
-    if (! ( file = eth_fopen(filename,"r")) ) {
+    if (! ( file = ws_fopen(filename,"r")) ) {
         report_open_failure(filename,errno,FALSE);
         return;
     }
@@ -227,12 +235,12 @@ static void basic_logger(const gchar *log_domain _U_,
 }
 
 static int wslua_panic(lua_State* LS) {
-	g_error("LUA PANIC: %s",lua_tostring(LS,-1));
-	return 0;
+    g_error("LUA PANIC: %s",lua_tostring(LS,-1));
+    return 0;
 }
 
 int wslua_init(lua_State* LS) {
-    const gchar* filename;
+    gchar* filename;
     const funnel_ops_t* ops = funnel_get_funnel_ops();
     gboolean run_anyway = FALSE;
 
@@ -244,16 +252,16 @@ int wslua_init(lua_State* LS) {
                       G_LOG_LEVEL_DEBUG,
                       ops ? ops->logger : basic_logger, NULL);
 
-	if (!L) {
-		if (LS)
-			L = LS;
-		else
-			L = luaL_newstate();
-	}
+    if (!L) {
+        if (LS)
+            L = LS;
+        else
+            L = luaL_newstate();
+    }
 
-	WSLUA_INIT(L);
+    WSLUA_INIT(L);
 
-	lua_atpanic(L,wslua_panic);
+    lua_atpanic(L,wslua_panic);
 
     /* the init_routines table (accessible by the user) */
     lua_pushstring(L, WSLUA_INIT_ROUTINES);
@@ -265,7 +273,11 @@ int wslua_init(lua_State* LS) {
     lua_dissectors_table_ref = luaL_ref(L, LUA_REGISTRYINDEX);
 
     /* set running_superuser variable to it's propper value */
-	WSLUA_REG_GLOBAL_BOOL(L,"running_superuser",started_with_special_privs());
+    WSLUA_REG_GLOBAL_BOOL(L,"running_superuser",started_with_special_privs());
+    
+    /* special constant used by PDU reassembly handling */
+    /* see dissect_lua() for notes */
+    WSLUA_REG_GLOBAL_NUMBER(L,"DESEGMENT_ONE_MORE_SEGMENT",DESEGMENT_ONE_MORE_SEGMENT);
 
     /* load system's init.lua */
     filename = get_datafile_path("init.lua");
@@ -274,15 +286,18 @@ int wslua_init(lua_State* LS) {
         lua_load_script(filename);
     }
 
+    g_free(filename);
+    filename = NULL;
+
     /* check if lua is to be disabled */
     lua_pushstring(L,"disable_lua");
     lua_gettable(L, LUA_GLOBALSINDEX);
 
     if (lua_isboolean(L,-1) && lua_toboolean(L,-1)) {
-		/* disable lua */
-		lua_close(L);
-		L = NULL;
-		return 0;
+        /* disable lua */
+        lua_close(L);
+        L = NULL;
+        return 0;
     }
 
     /* check whether we should run other scripts even if running superuser */
@@ -300,9 +315,11 @@ int wslua_init(lua_State* LS) {
 
         if (( file_exists(filename))) {
             lua_load_script(filename);
+            g_free(filename);
+            filename = NULL;
         }
 
-        while((filename = ex_opt_get_next("lua_script"))) {
+        while((filename = (gchar *)ex_opt_get_next("lua_script"))) {
             lua_load_script(filename);
         }
     }
@@ -326,7 +343,7 @@ int wslua_init(lua_State* LS) {
     lua_data_handle = find_dissector("data");
     lua_malformed = proto_get_id_by_filter_name("malformed");
 
-	Proto_commit(L);
+    Proto_commit(L);
 
     return 0;
 }
