@@ -6,7 +6,7 @@
  * (c) 2006, Luis E. Garcia Ontanon <luis@ontanon.org>
  * (c) 2007, Tamas Regos <tamas.regos@ericsson.com>
  *
- * $Id: wslua_proto.c 31581 2010-01-20 01:02:36Z gerald $
+ * $Id: wslua_proto.c 32661 2010-05-04 19:13:29Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -842,8 +842,8 @@ PROTOFIELD_OTHER(oid,FT_OID)
 PROTOFIELD_OTHER(bool,FT_BOOLEAN)
 
 
-WSLUA_METAMETHOD ProtoField_tostring(lua_State* L) {
-	/* Returns a string w/ info about a protofiled (for debugging purposes) */
+WSLUA_METAMETHOD ProtoField__tostring(lua_State* L) {
+	/* Returns a string with info about a protofield (for debugging purposes) */
     ProtoField f = checkProtoField(L,1);
     gchar* s = g_strdup_printf("ProtoField(%i): %s %s %s %s %p %.8x %s",f->hfid,f->name,f->abbr,ftenum_to_string(f->type),base_to_string(f->base),f->vs,f->mask,f->blob);
     
@@ -908,8 +908,8 @@ static const luaL_reg ProtoField_methods[] = {
 };
 
 static const luaL_reg ProtoField_meta[] = {
+    {"__tostring", ProtoField__tostring },
     {"__gc", ProtoField_gc },
-    {"__tostring", ProtoField_tostring },
     { NULL, NULL }
 };
 
