@@ -1,7 +1,7 @@
 /* file.h
  * Definitions for file structures and routines
  *
- * $Id: file.h 21135 2007-03-22 23:44:48Z ulfl $
+ * $Id: file.h 33123 2010-06-07 01:58:57Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -60,16 +60,6 @@ typedef enum {
     cf_cb_file_closed,
     cf_cb_file_read_start,
     cf_cb_file_read_finished,
-#ifdef HAVE_LIBPCAP
-    cf_cb_live_capture_prepared,
-    cf_cb_live_capture_update_started,
-    cf_cb_live_capture_update_continue,
-    cf_cb_live_capture_update_finished,
-    cf_cb_live_capture_fixed_started,
-    cf_cb_live_capture_fixed_continue,
-    cf_cb_live_capture_fixed_finished,
-	cf_cb_live_capture_stopping,
-#endif
     cf_cb_packet_selected,
     cf_cb_packet_unselected,
     cf_cb_field_unselected,
@@ -81,9 +71,6 @@ typedef enum {
 
 typedef void (*cf_callback_t) (gint event, gpointer data, gpointer user_data);
 
-extern void
-cf_callback_invoke(int event, gpointer data);
-
 extern void
 cf_callback_add(cf_callback_t func, gpointer user_data);
 
@@ -144,6 +131,13 @@ cf_status_t cf_start_tail(capture_file *cf, const char *fname, gboolean is_tempf
  */
 cf_read_status_t cf_continue_tail(capture_file *cf, volatile int to_read, int *err);
 
+/**
+ * Fake reading packets from the "end" of a capture file.
+ *
+ * @param cf the capture file to be read from
+ */
+void cf_fake_continue_tail(capture_file *cf);
+
 /**
  * Finish reading from "end" of a capture file.
  * 
@@ -169,7 +163,7 @@ gboolean cf_can_save_as(capture_file *cf);
  * @param fname the filename to save to
  * @param range the range of packets to save
  * @param save_format the format of the file to save (libpcap, ...)
- * @param compressed wether to gzip compress the file
+ * @param compressed whether to gzip compress the file
  * @return one of cf_status_t
  */
 cf_status_t cf_save(capture_file * cf, const char *fname, packet_range_t *range, guint save_format, gboolean compressed);
@@ -182,6 +176,24 @@ cf_status_t cf_save(capture_file * cf, const char *fname, packet_range_t *range,
  */
 const gchar *cf_get_display_name(capture_file *cf);
 
+/**
+ * Set the source of the capture data for temporary files, e.g.
+ * "Interface eth0" or "Pipe from Pong"
+ *
+ * @param cf the capture file
+ * @param source the source description. this will be copied internally.
+ */
+void cf_set_tempfile_source(capture_file *cf, gchar *source);
+
+/**
+ * Get the source of the capture data for temporary files. Guaranteed to
+ * return a non-null value. The returned value should not be freed.
+ *
+ * @param cf the capture file
+ * @param source the source description. this will be copied internally.
+ */
+const gchar *cf_get_tempfile_source(capture_file *cf);
+
 /**
  * Get the number of packets in the capture file.
  * 
@@ -335,6 +347,15 @@ cf_print_status_t cf_write_psml_packets(capture_file *cf, print_args_t *print_ar
  */
 cf_print_status_t cf_write_csv_packets(capture_file *cf, print_args_t *print_args);
 
+/**
+ * Print (export) the capture file into C Arrays format.
+ *
+ * @param cf the capture file
+ * @param print_args the arguments what and how to export
+ * @return one of cf_print_status_t
+ */
+cf_print_status_t cf_write_carrays_packets(capture_file *cf, print_args_t *print_args);
+
 /**
  * Find Packet in protocol tree.
  * 
@@ -452,10 +473,10 @@ void cf_unmark_frame(capture_file *cf, frame_data *frame);
  * Convert error number and info to a complete message.
  *
  * @param err the error number
- * @param err_info the additional info about this error (e.g. filename)
+ * @param err_info a string with additional details about this error
  * @return statically allocated error message
  */
-char *cf_read_error_message(int err, const gchar *err_info);
+char *cf_read_error_message(int err, gchar *err_info);
 
 /**
  * Merge two (or more) capture files into one.
@@ -474,4 +495,8 @@ cf_status_t
 cf_merge_files(char **out_filename, int in_file_count,
                char *const *in_filenames, int file_type, gboolean do_append);
 
+#if defined(HAVE_HEIMDAL_KERBEROS) || defined(HAVE_MIT_KERBEROS)
+void read_keytab_file(const char *);
+#endif
+
 #endif /* file.h */
