@@ -1,7 +1,7 @@
 /* color_edit_dlg.c
  * Definitions for single color filter edit dialog boxes
  *
- * $Id: color_edit_dlg.c 23482 2007-11-18 04:20:14Z sfisher $
+ * $Id: color_edit_dlg.c 27800 2009-03-19 17:49:11Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -31,33 +31,26 @@
 #include <gtk/gtk.h>
 
 #include <epan/packet.h>
-#include "color.h"
-#include "colors.h"
-#include "color_filters.h"
 
-#include "dlg_utils.h"
-#include "gui_utils.h"
-#include "compat_macros.h"
-#include "filter_dlg.h"
-#include "dfilter_expr_dlg.h"
-#include "simple_dialog.h"
+#include "../color.h"
+#include "../color_filters.h"
+#include "../simple_dialog.h"
+
+#include "gtk/color_utils.h"
+#include "gtk/dlg_utils.h"
+#include "gtk/gui_utils.h"
+#include "gtk/stock_icons.h"
+#include "gtk/filter_dlg.h"
+#include "gtk/dfilter_expr_dlg.h"
+#include "gtk/color_edit_dlg.h"
+#include "gtk/filter_autocomplete.h"
 
-#include "color_edit_dlg.h"
 
-#if GTK_MAJOR_VERSION >= 2
 #define BUTTON_SIZE_X -1
 #define BUTTON_SIZE_Y -1
-#else
-#define BUTTON_SIZE_X 50
-#define BUTTON_SIZE_Y 20
-#endif
 
 
-#if GTK_MAJOR_VERSION < 2
-static void edit_color_filter_destroy_cb(GtkObject *object, gpointer user_data);
-#else
 static void edit_color_filter_destroy_cb(GObject *object, gpointer user_data);
-#endif
 static void edit_color_filter_fg_cb(GtkButton *button, gpointer user_data);
 static void edit_color_filter_bg_cb(GtkButton *button, gpointer user_data);
 /*
@@ -104,7 +97,7 @@ edit_color_filter_dialog(GtkWidget *color_filters,
     GtkWidget      *edit_dialog;
     GtkWidget      *dialog_vbox;
     GtkTooltips    *tooltips;
-    GtkStyle       *style;
+    GdkColor       bg_color, fg_color;
 
     GtkWidget *filter_fr;
     GtkWidget *filter_fr_vbox;
@@ -128,20 +121,14 @@ edit_color_filter_dialog(GtkWidget *color_filters,
     GtkWidget *edit_color_filter_ok;
     GtkWidget *edit_color_filter_cancel;
 
-#if GTK_MAJOR_VERSION >= 2
     GtkTreeModel     *model;
     GtkTreeIter       iter;
-#endif
 
-#if GTK_MAJOR_VERSION >= 2
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(color_filters));
 
     gtk_tree_model_iter_nth_child(model, &iter, NULL, row_selected);
     gtk_tree_model_get(model, &iter, 5, &colorf, -1);
 
-#else
-    colorf = gtk_clist_get_row_data(GTK_CLIST(color_filters), row_selected);
-#endif
     if (colorf->edit_dialog != NULL) {
         /* There's already an edit box open for this filter; reactivate it. */
         reactivate_window(colorf->edit_dialog);
@@ -151,9 +138,9 @@ edit_color_filter_dialog(GtkWidget *color_filters,
     tooltips = gtk_tooltips_new ();
 
     /* dialog window */
-    edit_dialog = dlg_window_new ("Wireshark: Edit Color Filter");
+    edit_dialog = dlg_conf_window_new ("Wireshark: Edit Color Filter");
     gtk_window_set_default_size(GTK_WINDOW(edit_dialog), 500, -1);
-    OBJECT_SET_DATA(edit_dialog, "edit_dialog", edit_dialog);
+    g_object_set_data(G_OBJECT(edit_dialog), "edit_dialog", edit_dialog);
     colorf->edit_dialog = edit_dialog;
 
     dialog_vbox = gtk_vbox_new (FALSE, 0);
@@ -178,14 +165,11 @@ edit_color_filter_dialog(GtkWidget *color_filters,
     filt_name_entry = gtk_entry_new ();
     gtk_entry_set_text(GTK_ENTRY(filt_name_entry), colorf->filter_name);
 
-    style = gtk_style_copy(gtk_widget_get_style(filt_name_entry));
-    color_t_to_gdkcolor(&style->base[GTK_STATE_NORMAL], &colorf->bg_color);
-#if GTK_MAJOR_VERSION < 2
-    color_t_to_gdkcolor(&style->fg[GTK_STATE_NORMAL], &colorf->fg_color);
-#else
-    color_t_to_gdkcolor(&style->text[GTK_STATE_NORMAL], &colorf->fg_color);
-#endif
-    gtk_widget_set_style(filt_name_entry, style);
+    color_t_to_gdkcolor(&bg_color, &colorf->bg_color);
+    color_t_to_gdkcolor(&fg_color, &colorf->fg_color);
+
+    gtk_widget_modify_base(filt_name_entry, GTK_STATE_NORMAL, &bg_color);
+    gtk_widget_modify_text(filt_name_entry, GTK_STATE_NORMAL, &fg_color);
 
     gtk_box_pack_start (GTK_BOX (filter_name_hbox), filt_name_entry, TRUE, TRUE, 0);
     gtk_tooltips_set_tip (tooltips, filt_name_entry, ("This is the editable name of the filter. (No @ characters allowed.)"), NULL);
@@ -199,17 +183,19 @@ edit_color_filter_dialog(GtkWidget *color_filters,
     gtk_box_pack_start (GTK_BOX (filter_string_hbox), color_filter_text, FALSE, FALSE, 0);
 
     filt_text_entry = gtk_entry_new ();
-    SIGNAL_CONNECT(filt_text_entry, "changed", filter_te_syntax_check_cb, NULL);
+    g_signal_connect(filt_text_entry, "changed", G_CALLBACK(filter_te_syntax_check_cb), NULL);
+    g_object_set_data(G_OBJECT(filter_string_hbox), E_FILT_AUTOCOMP_PTR_KEY, NULL);
+    g_signal_connect(filt_text_entry, "key-press-event", G_CALLBACK (filter_string_te_key_pressed_cb), NULL);
+    g_signal_connect(edit_dialog, "key-press-event", G_CALLBACK (filter_parent_dlg_key_pressed_cb), NULL);
     gtk_entry_set_text(GTK_ENTRY(filt_text_entry), colorf->filter_text);
 
-    gtk_style_unref(style);
     gtk_box_pack_start (GTK_BOX (filter_string_hbox), filt_text_entry, TRUE, TRUE, 0);
     gtk_tooltips_set_tip (tooltips, filt_text_entry, ("This is the editable text of the filter"), NULL);
 
     /* Create the "Add Expression..." button, to pop up a dialog
        for constructing filter comparison expressions. */
-    add_expression_bt = BUTTON_NEW_FROM_STOCK(WIRESHARK_STOCK_ADD_EXPRESSION);
-    SIGNAL_CONNECT(add_expression_bt, "clicked", filter_expr_cb, filt_text_entry);
+    add_expression_bt = gtk_button_new_from_stock(WIRESHARK_STOCK_ADD_EXPRESSION);
+    g_signal_connect(add_expression_bt, "clicked", G_CALLBACK(filter_expr_cb), filt_text_entry);
     gtk_box_pack_start (GTK_BOX(filter_string_hbox), add_expression_bt, FALSE, FALSE, 3);
     gtk_tooltips_set_tip (tooltips, add_expression_bt, ("Add an expression to the filter string"), NULL);
 
@@ -245,7 +231,7 @@ edit_color_filter_dialog(GtkWidget *color_filters,
     gtk_container_add(GTK_CONTAINER(status_fr), status_vbox);
 
     disabled_cb = gtk_check_button_new_with_label("Disabled");
-    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(disabled_cb), colorf->disabled);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(disabled_cb), colorf->disabled);
     gtk_box_pack_start (GTK_BOX (status_vbox), disabled_cb, TRUE, FALSE, 0);
     gtk_tooltips_set_tip (tooltips, disabled_cb, ("Color rule won't be checked if this box is selected"), NULL);
     
@@ -254,38 +240,38 @@ edit_color_filter_dialog(GtkWidget *color_filters,
 	gtk_box_pack_start(GTK_BOX(dialog_vbox), bbox, FALSE, FALSE, 0);
     gtk_container_set_border_width  (GTK_CONTAINER (bbox), 0);
 
-    edit_color_filter_ok = OBJECT_GET_DATA(bbox, GTK_STOCK_OK);
+    edit_color_filter_ok = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_OK);
     gtk_tooltips_set_tip (tooltips, edit_color_filter_ok, ("Accept filter color change"), NULL);
 
-    edit_color_filter_cancel = OBJECT_GET_DATA(bbox, GTK_STOCK_CANCEL);
+    edit_color_filter_cancel = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_CANCEL);
     gtk_tooltips_set_tip (tooltips, edit_color_filter_cancel, ("Reject filter color change"), NULL);
 
     gtk_widget_grab_default(edit_color_filter_ok);
 
     /* signals and such */
-    OBJECT_SET_DATA(edit_dialog, COLOR_FILTER, colorf);
-    SIGNAL_CONNECT(edit_dialog, "destroy", edit_color_filter_destroy_cb, NULL);
-    OBJECT_SET_DATA(colorize_filter_fg, COLOR_FILTER, colorf);
-    SIGNAL_CONNECT(colorize_filter_fg, "clicked", edit_color_filter_fg_cb, NULL);
-    OBJECT_SET_DATA(colorize_filter_bg, COLOR_FILTER, colorf);
-    SIGNAL_CONNECT(colorize_filter_bg, "clicked", edit_color_filter_bg_cb, NULL);
-    OBJECT_SET_DATA(disabled_cb, COLOR_FILTER, colorf);
-/*    SIGNAL_CONNECT(disabled_cb, "clicked", edit_disabled_cb_cb, NULL);*/
-    OBJECT_SET_DATA(edit_color_filter_ok, COLOR_FILTERS_CL, color_filters);
-    OBJECT_SET_DATA(edit_color_filter_ok, COLOR_FILTER, colorf);
-    SIGNAL_CONNECT(edit_color_filter_ok, "clicked", edit_color_filter_ok_cb, edit_dialog);
+    g_object_set_data(G_OBJECT(edit_dialog), COLOR_FILTER, colorf);
+    g_signal_connect(edit_dialog, "destroy", G_CALLBACK(edit_color_filter_destroy_cb), NULL);
+    g_object_set_data(G_OBJECT(colorize_filter_fg), COLOR_FILTER, colorf);
+    g_signal_connect(colorize_filter_fg, "clicked", G_CALLBACK(edit_color_filter_fg_cb), NULL);
+    g_object_set_data(G_OBJECT(colorize_filter_bg), COLOR_FILTER, colorf);
+    g_signal_connect(colorize_filter_bg, "clicked", G_CALLBACK(edit_color_filter_bg_cb), NULL);
+    g_object_set_data(G_OBJECT(disabled_cb), COLOR_FILTER, colorf);
+/*    g_signal_connect(disabled_cb, "clicked", edit_disabled_cb_cb, NULL);*/
+    g_object_set_data(G_OBJECT(edit_color_filter_ok), COLOR_FILTERS_CL, color_filters);
+    g_object_set_data(G_OBJECT(edit_color_filter_ok), COLOR_FILTER, colorf);
+    g_signal_connect(edit_color_filter_ok, "clicked", G_CALLBACK(edit_color_filter_ok_cb), edit_dialog);
 
     /* set callback to delete new filters if cancel chosen */
     if (is_new_filter)
     {
-        OBJECT_SET_DATA(edit_color_filter_cancel, COLOR_FILTERS_CL, color_filters);
-        SIGNAL_CONNECT(edit_color_filter_cancel, "clicked",
-                       edit_new_color_filter_cancel_cb, edit_dialog);
+        g_object_set_data(G_OBJECT(edit_color_filter_cancel), COLOR_FILTERS_CL, color_filters);
+        g_signal_connect(edit_color_filter_cancel, "clicked",
+                       G_CALLBACK(edit_new_color_filter_cancel_cb), edit_dialog);
     }
     /* escape will select cancel */
     window_set_cancel_button(edit_dialog, edit_color_filter_cancel, window_cancel_button_cb);
 
-    SIGNAL_CONNECT(edit_dialog, "delete_event", window_delete_event_cb, NULL);
+    g_signal_connect(edit_dialog, "delete_event", G_CALLBACK(window_delete_event_cb), NULL);
 
     gtk_widget_show_all(edit_dialog);
     window_present(edit_dialog);
@@ -294,25 +280,20 @@ edit_color_filter_dialog(GtkWidget *color_filters,
 /* Called when the dialog box is being destroyed; destroy any color
    selection dialogs opened from this dialog, and null out the pointer
    to this dialog. */
-#if GTK_MAJOR_VERSION < 2
-static void
-edit_color_filter_destroy_cb(GtkObject *object, gpointer user_data _U_)
-#else
 static void
 edit_color_filter_destroy_cb(GObject *object, gpointer user_data _U_)
-#endif
 {
   color_filter_t *colorf;
   GtkWidget *color_sel;
 
-  colorf = (color_filter_t *)OBJECT_GET_DATA(object, COLOR_FILTER);
+  colorf = (color_filter_t *)g_object_get_data(G_OBJECT(object), COLOR_FILTER);
   colorf->edit_dialog = NULL;
 
   /* Destroy any color selection dialogs this dialog had open. */
-  color_sel = (GtkWidget *)OBJECT_GET_DATA(object, COLOR_SELECTION_FG);
+  color_sel = (GtkWidget *)g_object_get_data(G_OBJECT(object), COLOR_SELECTION_FG);
   if (color_sel != NULL)
     window_destroy(color_sel);
-  color_sel = (GtkWidget *)OBJECT_GET_DATA(object, COLOR_SELECTION_BG);
+  color_sel = (GtkWidget *)g_object_get_data(G_OBJECT(object), COLOR_SELECTION_BG);
   if (color_sel != NULL)
     window_destroy(color_sel);
 }
@@ -324,9 +305,9 @@ edit_color_filter_fg_cb(GtkButton *button, gpointer user_data _U_)
   color_filter_t *colorf;
   GtkWidget *color_selection_fg;
 
-  colorf = (color_filter_t *)OBJECT_GET_DATA(button, COLOR_FILTER);
+  colorf = (color_filter_t *)g_object_get_data(G_OBJECT(button), COLOR_FILTER);
   /* Do we already have one open for this dialog? */
-  color_selection_fg = OBJECT_GET_DATA(colorf->edit_dialog, COLOR_SELECTION_FG);
+  color_selection_fg = g_object_get_data(G_OBJECT(colorf->edit_dialog), COLOR_SELECTION_FG);
   if (color_selection_fg != NULL) {
     /* Yes.  Just reactivate it. */
     reactivate_window(color_selection_fg);
@@ -334,8 +315,8 @@ edit_color_filter_fg_cb(GtkButton *button, gpointer user_data _U_)
     /* No.  Create a new color selection box, and associate it with
        this dialog. */
     color_selection_fg = color_sel_win_new(colorf, FALSE);
-    OBJECT_SET_DATA(colorf->edit_dialog, COLOR_SELECTION_FG, color_selection_fg);
-    OBJECT_SET_DATA(color_selection_fg, COLOR_SELECTION_PARENT, colorf->edit_dialog);
+    g_object_set_data(G_OBJECT(colorf->edit_dialog), COLOR_SELECTION_FG, color_selection_fg);
+    g_object_set_data(G_OBJECT(color_selection_fg), COLOR_SELECTION_PARENT, colorf->edit_dialog);
   }
 }
 
@@ -347,9 +328,9 @@ edit_color_filter_bg_cb                (GtkButton       *button,
   color_filter_t *colorf;
   GtkWidget *color_selection_bg;
 
-  colorf = (color_filter_t *)OBJECT_GET_DATA(button, COLOR_FILTER);
+  colorf = (color_filter_t *)g_object_get_data(G_OBJECT(button), COLOR_FILTER);
   /* Do we already have one open for this dialog? */
-  color_selection_bg = OBJECT_GET_DATA(colorf->edit_dialog, COLOR_SELECTION_BG);
+  color_selection_bg = g_object_get_data(G_OBJECT(colorf->edit_dialog), COLOR_SELECTION_BG);
   if (color_selection_bg != NULL) {
     /* Yes.  Just reactivate it. */
     reactivate_window(color_selection_bg);
@@ -357,8 +338,8 @@ edit_color_filter_bg_cb                (GtkButton       *button,
     /* No.  Create a new color selection box, and associate it with
        this dialog. */
     color_selection_bg = color_sel_win_new(colorf, TRUE);
-    OBJECT_SET_DATA(colorf->edit_dialog, COLOR_SELECTION_BG, color_selection_bg);
-    OBJECT_SET_DATA(color_selection_bg, COLOR_SELECTION_PARENT, colorf->edit_dialog);
+    g_object_set_data(G_OBJECT(colorf->edit_dialog), COLOR_SELECTION_BG, color_selection_bg);
+    g_object_set_data(G_OBJECT(color_selection_bg), COLOR_SELECTION_PARENT, colorf->edit_dialog);
   }
 }
 
@@ -370,7 +351,7 @@ edit_disabled_cb_cb 	               (GtkButton       *button,
 {
   color_filter_t *colorf;
 
-  colorf = (color_filter_t *)OBJECT_GET_DATA(button, COLOR_FILTER);
+  colorf = (color_filter_t *)g_object_get_data(G_OBJECT(button), COLOR_FILTER);
   colorf->disabled = GTK_TOGGLE_BUTTON (button)->active;
 
   printf("Colorfilter %s is now %s\n",colorf->filter_name,colorf->disabled?"disabled":"enabled");
@@ -392,11 +373,9 @@ edit_color_filter_ok_cb                (GtkButton       *button,
     color_filter_t *colorf;
     dfilter_t      *compiled_filter;
     GtkWidget      *color_filters;
-#if GTK_MAJOR_VERSION >= 2
     GtkTreeModel   *model;
     GtkTreeIter     iter;
     gchar           fg_str[14], bg_str[14];
-#endif
 
     dialog = (GtkWidget *)user_data;
 
@@ -423,50 +402,30 @@ edit_color_filter_ok_cb                (GtkButton       *button,
                       " Please try again. Filter unchanged.\n%s\n", filter_name,
                       dfilter_error_msg);
     } else {
-        color_filters = (GtkWidget *)OBJECT_GET_DATA(button, COLOR_FILTERS_CL);
-        colorf = (color_filter_t *)OBJECT_GET_DATA(button, COLOR_FILTER);
+        color_filters = (GtkWidget *)g_object_get_data(G_OBJECT(button), COLOR_FILTERS_CL);
+        colorf = (color_filter_t *)g_object_get_data(G_OBJECT(button), COLOR_FILTER);
 
-        if (colorf->filter_name != NULL)
-            g_free(colorf->filter_name);
+        g_free(colorf->filter_name);
         colorf->filter_name = filter_name;
-        if (colorf->filter_text != NULL)
-            g_free(colorf->filter_text);
+
+        g_free(colorf->filter_text);
         colorf->filter_text = filter_text;
+
 	colorf->disabled = filter_disabled;
         gdkcolor_to_color_t(&colorf->fg_color, &new_fg_color);
         gdkcolor_to_color_t(&colorf->bg_color, &new_bg_color);
-#if GTK_MAJOR_VERSION < 2
-
-	/* XXX Using light-gray on white for disabled coloring-rules is a
-	 * workaround to using strikethrough as I don't know how to set
-	 * text to strikethrough in GTK1. This needs to be changed to
-	 * keep the GTK1 and GTK2 version simular
-	 */
-	gtk_clist_set_foreground(GTK_CLIST(color_filters), row_selected,
-				filter_disabled ? &LTGREY : &new_fg_color);
-	gtk_clist_set_background(GTK_CLIST(color_filters), row_selected,
-				filter_disabled ? &WHITE : &new_bg_color);
-#else
-        g_snprintf(fg_str, 14, "#%04X%04X%04X",
+        g_snprintf(fg_str, sizeof(fg_str), "#%04X%04X%04X",
                 new_fg_color.red, new_fg_color.green, new_fg_color.blue);
-        g_snprintf(bg_str, 14, "#%04X%04X%04X",
+        g_snprintf(bg_str, sizeof(bg_str), "#%04X%04X%04X",
                 new_bg_color.red, new_bg_color.green, new_bg_color.blue);
         model = gtk_tree_view_get_model(GTK_TREE_VIEW(color_filters));
         gtk_tree_model_iter_nth_child(model, &iter, NULL, row_selected);
         gtk_list_store_set(GTK_LIST_STORE(model), &iter, 0, filter_name,
                            1, filter_text, 2, fg_str, 3, bg_str,
 			   4, filter_disabled, -1);
-#endif
         if(colorf->c_colorfilter != NULL)
             dfilter_free(colorf->c_colorfilter);
         colorf->c_colorfilter = compiled_filter;
-#if GTK_MAJOR_VERSION < 2
-        /* gtk_clist_set_text frees old text (if any) and allocates new space */
-        gtk_clist_set_text(GTK_CLIST(color_filters), row_selected, 0,
-                           filter_name);
-        gtk_clist_set_text(GTK_CLIST(color_filters), row_selected, 1,
-                           filter_text);
-#endif
 
         /* Destroy the dialog box. */
         window_destroy(dialog);
@@ -478,7 +437,7 @@ static void
 edit_new_color_filter_cancel_cb(GtkButton *button, gpointer user_data _U_)
 {
     /* Delete the entry. As a side effect this destroys the edit_dialog window. */
-    color_delete(num_of_filters-1, (GtkWidget*)OBJECT_GET_DATA(button, COLOR_FILTERS_CL));
+    color_delete(num_of_filters-1, (GtkWidget*)g_object_get_data(G_OBJECT(button), COLOR_FILTERS_CL));
 }
 
 static GtkWidget*
@@ -487,9 +446,7 @@ color_sel_win_new(color_filter_t *colorf, gboolean is_bg)
   gchar *title;
   GtkWidget *color_sel_win;
   color_t   *color;
-#if GTK_MAJOR_VERSION >= 2
   GdkColor   gcolor;
-#endif
   GtkWidget *color_sel_ok;
   GtkWidget *color_sel_cancel;
   GtkWidget *color_sel_help;
@@ -505,34 +462,22 @@ color_sel_win_new(color_filter_t *colorf, gboolean is_bg)
   }
   color_sel_win = gtk_color_selection_dialog_new(title);
   g_free(title);
-  OBJECT_SET_DATA(color_sel_win, "color_sel_win", color_sel_win);
+  g_object_set_data(G_OBJECT(color_sel_win), "color_sel_win", color_sel_win);
   gtk_container_set_border_width (GTK_CONTAINER (color_sel_win), 10);
 
   if (color != NULL) {
-#if GTK_MAJOR_VERSION < 2
-    gdouble cols[3];
-
-    cols[0] = (gdouble)color->red / 65536.0;
-    cols[1] = (gdouble)color->green / 65536.0;
-    cols[2] = (gdouble)color->blue / 65536.0;
-
-    gtk_color_selection_set_color(
-		    GTK_COLOR_SELECTION(
-			    GTK_COLOR_SELECTION_DIALOG(color_sel_win)->colorsel), cols);
-#else
     color_t_to_gdkcolor(&gcolor, color);
     gtk_color_selection_set_current_color(
 		    GTK_COLOR_SELECTION(
 			    GTK_COLOR_SELECTION_DIALOG(color_sel_win)->colorsel), &gcolor);
-#endif
   }
 
   color_sel_ok = GTK_COLOR_SELECTION_DIALOG (color_sel_win)->ok_button;
-  OBJECT_SET_DATA(color_sel_win, "color_sel_ok", color_sel_ok);
+  g_object_set_data(G_OBJECT(color_sel_win), "color_sel_ok", color_sel_ok);
   GTK_WIDGET_SET_FLAGS (color_sel_ok, GTK_CAN_DEFAULT);
 
   color_sel_cancel = GTK_COLOR_SELECTION_DIALOG (color_sel_win)->cancel_button;
-  OBJECT_SET_DATA(color_sel_win, "color_sel_cancel", color_sel_cancel);
+  g_object_set_data(G_OBJECT(color_sel_win), "color_sel_cancel", color_sel_cancel);
   GTK_WIDGET_SET_FLAGS (color_sel_cancel, GTK_CAN_DEFAULT);
   window_set_cancel_button(color_sel_win, color_sel_cancel, NULL); /* ensure esc does req'd local cxl action.    */
                                                                    /* esc as handled by the                      */
@@ -540,13 +485,13 @@ color_sel_win_new(color_filter_t *colorf, gboolean is_bg)
                                                                    /*  doesn't result in this happening.         */
 
   color_sel_help = GTK_COLOR_SELECTION_DIALOG (color_sel_win)->help_button;
-  OBJECT_SET_DATA(color_sel_win, "color_sel_help", color_sel_help);
+  g_object_set_data(G_OBJECT(color_sel_win), "color_sel_help", color_sel_help);
 
 
   GTK_WIDGET_SET_FLAGS (color_sel_help, GTK_CAN_DEFAULT);
 
-  SIGNAL_CONNECT(color_sel_ok, "clicked", color_sel_ok_cb, color_sel_win);
-  SIGNAL_CONNECT(color_sel_cancel, "clicked", color_sel_cancel_cb, color_sel_win);
+  g_signal_connect(color_sel_ok, "clicked", G_CALLBACK(color_sel_ok_cb), color_sel_win);
+  g_signal_connect(color_sel_cancel, "clicked", G_CALLBACK(color_sel_cancel_cb), color_sel_win);
 
   gtk_widget_show_all(color_sel_win);
   return color_sel_win;
@@ -559,20 +504,20 @@ color_sel_win_destroy(GtkWidget *sel_win)
   GtkWidget *color_selection_fg, *color_selection_bg;
 
   /* Find the "Edit color filter" dialog box with which this is associated. */
-  parent = (GtkWidget *)OBJECT_GET_DATA(sel_win, COLOR_SELECTION_PARENT);
+  parent = (GtkWidget *)g_object_get_data(G_OBJECT(sel_win), COLOR_SELECTION_PARENT);
 
   /* Find that dialog box's foreground and background color selection
      boxes, if any. */
-  color_selection_fg = OBJECT_GET_DATA(parent, COLOR_SELECTION_FG);
-  color_selection_bg = OBJECT_GET_DATA(parent, COLOR_SELECTION_BG);
+  color_selection_fg = g_object_get_data(G_OBJECT(parent), COLOR_SELECTION_FG);
+  color_selection_bg = g_object_get_data(G_OBJECT(parent), COLOR_SELECTION_BG);
 
   if (sel_win == color_selection_fg) {
     /* This was its foreground color selection box; it isn't, anymore. */
-    OBJECT_SET_DATA(parent, COLOR_SELECTION_FG, NULL);
+    g_object_set_data(G_OBJECT(parent), COLOR_SELECTION_FG, NULL);
   }
   if (sel_win == color_selection_bg) {
     /* This was its background color selection box; it isn't, anymore. */
-    OBJECT_SET_DATA(parent, COLOR_SELECTION_BG, NULL);
+    g_object_set_data(G_OBJECT(parent), COLOR_SELECTION_BG, NULL);
   }
 
   /* Now destroy it. */
@@ -585,28 +530,15 @@ color_sel_ok_cb                        (GtkButton       *button _U_,
                                         gpointer         user_data)
 {
   GdkColor new_color; /* Color from color selection dialog */
-#if GTK_MAJOR_VERSION < 2
-  gdouble new_colors[4];  /* red, green, blue, "opacity" */
-#endif
   GtkWidget *color_dialog;
-  GtkStyle  *style;
   GtkWidget *parent;
   GtkWidget *color_selection_fg, *color_selection_bg;
   gboolean is_bg;
 
   color_dialog = (GtkWidget *)user_data;
 
-#if GTK_MAJOR_VERSION < 2
-  gtk_color_selection_get_color(GTK_COLOR_SELECTION(
-   GTK_COLOR_SELECTION_DIALOG(color_dialog)->colorsel), new_colors);
-
-  new_color.red   = (guint16)(new_colors[0]*65535.0);
-  new_color.green = (guint16)(new_colors[1]*65535.0);
-  new_color.blue  = (guint16)(new_colors[2]*65535.0);
-#else
   gtk_color_selection_get_current_color(GTK_COLOR_SELECTION(
    GTK_COLOR_SELECTION_DIALOG(color_dialog)->colorsel), &new_color);
-#endif
 
   if ( ! get_color(&new_color) ){
 	simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
@@ -614,26 +546,21 @@ color_sel_ok_cb                        (GtkButton       *button _U_,
   } else {
 	/* Find the "Edit color filter" dialog box with which this is
 	   associated. */
-	parent = (GtkWidget *)OBJECT_GET_DATA(color_dialog, COLOR_SELECTION_PARENT);
+        parent = (GtkWidget *)g_object_get_data(G_OBJECT(color_dialog), COLOR_SELECTION_PARENT);
 
 	/* Find that dialog box's foreground and background color selection
 	   boxes, if any. */
-	color_selection_fg = OBJECT_GET_DATA(parent, COLOR_SELECTION_FG);
-	color_selection_bg = OBJECT_GET_DATA(parent, COLOR_SELECTION_BG);
+	color_selection_fg = g_object_get_data(G_OBJECT(parent), COLOR_SELECTION_FG);
+	color_selection_bg = g_object_get_data(G_OBJECT(parent), COLOR_SELECTION_BG);
 	is_bg = (color_dialog == color_selection_bg);
 
 	color_sel_win_destroy(color_dialog);
 
 	/* now apply the change to the fore/background */
-
-	style = gtk_style_copy(gtk_widget_get_style(filt_name_entry));
 	if (is_bg)
-	  style->base[GTK_STATE_NORMAL] = new_color;
+	  gtk_widget_modify_base(filt_name_entry, GTK_STATE_NORMAL, &new_color);
         else
-	  style->text[GTK_STATE_NORMAL] = new_color;
-
-	gtk_widget_set_style(filt_name_entry, style);
-	gtk_style_unref(style);
+	  gtk_widget_modify_text(filt_name_entry, GTK_STATE_NORMAL, &new_color);
   }
 }
 
