@@ -1,22 +1,22 @@
 /* dcerpc_stat.c
  * dcerpc_stat   2002 Ronnie Sahlberg
  *
- * $Id: dcerpc_stat.c 21975 2007-05-29 02:43:18Z standel $
+ * $Id: dcerpc_stat.c 29099 2009-07-15 00:10:08Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
@@ -39,21 +39,24 @@
 
 #include <epan/packet_info.h>
 #include <epan/epan.h>
-
 #include <epan/stat_cmd_args.h>
-#include "../stat_menu.h"
-#include "gui_stat_menu.h"
-#include "simple_dialog.h"
-#include "dlg_utils.h"
-#include "gui_utils.h"
 #include <epan/tap.h>
-#include "../register.h"
 #include <epan/dissectors/packet-dcerpc.h>
+
+#include "../stat_menu.h"
+#include "../simple_dialog.h"
+#include "../register.h"
 #include "../globals.h"
-#include "filter_dlg.h"
-#include "compat_macros.h"
-#include "service_response_time_table.h"
-#include "gtkglobals.h"
+
+#include "gtk/gui_stat_menu.h"
+#include "gtk/dlg_utils.h"
+#include "gtk/gui_utils.h"
+#include "gtk/filter_dlg.h"
+#include "gtk/stock_icons.h"
+#include "gtk/service_response_time_table.h"
+#include "gtk/gtkglobals.h"
+#include "gtk/main.h"
+#include "gtk/filter_autocomplete.h"
 
 
 /* used to keep track of the statistics for an entire program interface */
@@ -166,8 +169,6 @@ dcerpcstat_draw(void *rs_arg)
  *
  * there should not be any other critical regions in gtk2
  */
-void protect_thread_critical_region(void);
-void unprotect_thread_critical_region(void);
 static void
 win_destroy_cb(GtkWindow *win _U_, gpointer data)
 {
@@ -191,7 +192,7 @@ gtk_dcerpcstat_init(const char *optarg, void* userdata _U_)
 	rpcstat_t *rs;
 	guint32 i, max_procs;
 	char *title_string;
-	char filter_string[256];
+	char *filter_string;
 	GtkWidget *vbox;
 	GtkWidget *stat_label;
 	GtkWidget *filter_label;
@@ -262,7 +263,9 @@ gtk_dcerpcstat_init(const char *optarg, void* userdata _U_)
 	rs->uuid=uuid;
 	rs->ver=ver;
 
-	rs->win=window_new(GTK_WINDOW_TOPLEVEL, "dcerpc-stat");
+	rs->win = dlg_window_new("dcerpc-stat");  /* transient_for top_level */
+	gtk_window_set_destroy_with_parent (GTK_WINDOW(rs->win), TRUE);
+
 	dcerpcstat_set_title(rs);
 	gtk_window_set_default_size(GTK_WINDOW(rs->win), 550, 400);
 
@@ -275,8 +278,10 @@ gtk_dcerpcstat_init(const char *optarg, void* userdata _U_)
 	g_free(title_string);
 	gtk_box_pack_start(GTK_BOX(vbox), stat_label, FALSE, FALSE, 0);
 
-	g_snprintf(filter_string,255,"Filter:%s",filter?filter:"");
+	filter_string = g_strdup_printf("Filter: %s",filter ? filter : "");
 	filter_label=gtk_label_new(filter_string);
+	g_free(filter_string);
+	gtk_label_set_line_wrap(GTK_LABEL(filter_label), TRUE);
 	gtk_box_pack_start(GTK_BOX(vbox), filter_label, FALSE, FALSE, 0);
 
 	for(i=0,max_procs=0;procs[i].name;i++){
@@ -313,7 +318,7 @@ gtk_dcerpcstat_init(const char *optarg, void* userdata _U_)
 	error_string=register_tap_listener("dcerpc", rs, filter, dcerpcstat_reset, dcerpcstat_packet, dcerpcstat_draw);
 	if(error_string){
 		/* error, we failed to attach to the tap. clean up */
-		simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, error_string->str);
+		simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "%s", error_string->str);
 		g_string_free(error_string, TRUE);
 		free_srt_table_data(&rs->srt_table);
 		g_free(rs);
@@ -324,16 +329,17 @@ gtk_dcerpcstat_init(const char *optarg, void* userdata _U_)
 	bbox = dlg_button_row_new(GTK_STOCK_CLOSE, NULL);
 	gtk_box_pack_end(GTK_BOX(vbox), bbox, FALSE, FALSE, 0);
 
-	close_bt = OBJECT_GET_DATA(bbox, GTK_STOCK_CLOSE);
+	close_bt = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_CLOSE);
 	window_set_cancel_button(rs->win, close_bt, window_cancel_button_cb);
 
-	SIGNAL_CONNECT(rs->win, "delete_event", window_delete_event_cb, NULL);
-	SIGNAL_CONNECT(rs->win, "destroy", win_destroy_cb, rs);
+	g_signal_connect(rs->win, "delete_event", G_CALLBACK(window_delete_event_cb), NULL);
+	g_signal_connect(rs->win, "destroy", G_CALLBACK(win_destroy_cb), rs);
 
 	gtk_widget_show_all(rs->win);
 	window_present(rs->win);
 
 	cf_retap_packets(&cfile, FALSE);
+	gdk_window_raise(rs->win->window);
 }
 
 
@@ -357,7 +363,7 @@ dcerpcstat_start_button_clicked(GtkWidget *item _U_, gpointer data _U_)
 	const char *filter;
 
 	str = g_string_new("dcerpc,srt");
-	g_string_sprintfa(str,
+	g_string_append_printf(str,
 	    ",%08x-%04x-%04x-%02x%02x-%02x%02x%02x%02x%02x%02x,%u.%u",
 	    dcerpc_uuid_program->Data1, dcerpc_uuid_program->Data2,
 	    dcerpc_uuid_program->Data3,
@@ -368,7 +374,7 @@ dcerpcstat_start_button_clicked(GtkWidget *item _U_, gpointer data _U_)
 	    dcerpc_version, 0);
 	filter=gtk_entry_get_text(GTK_ENTRY(filter_entry));
 	if(filter[0]!=0){
-		g_string_sprintfa(str, ",%s", filter);
+		g_string_append_printf(str, ",%s", filter);
 	}
 
 	gtk_dcerpcstat_init(str->str,NULL);
@@ -398,12 +404,12 @@ dcerpcstat_find_vers(gpointer *key, gpointer *value _U_, gpointer *user_data _U_
 		return NULL;
 	}
 
-	g_snprintf(vs, 5, "%u",k->ver);
+	g_snprintf(vs, sizeof(vs), "%u",k->ver);
 	menu_item=gtk_menu_item_new_with_label(vs);
-	SIGNAL_CONNECT(menu_item, "activate", dcerpcstat_version_select,
-                       ((long)k->ver));
+	g_signal_connect(menu_item, "activate", G_CALLBACK(dcerpcstat_version_select),
+                       (gpointer)((long)k->ver));
 	gtk_widget_show(menu_item);
-	gtk_menu_append(GTK_MENU(vers_menu), menu_item);
+	gtk_menu_shell_append(GTK_MENU_SHELL(vers_menu), menu_item);
 
 	if(dcerpc_version==0xffff){
 		dcerpc_version=k->ver;
@@ -434,7 +440,7 @@ static GtkWidget *program_submenu_item;
 static GtkWidget *program_submenu_label;
 static int program_subitem_index;
 static const char *first_menu_name;
-static void 
+static void
 dcerpcstat_add_program_to_menu(dcerpc_uuid_key *k, dcerpc_uuid_value *v)
 {
 	GtkWidget *program_menu_item;
@@ -445,35 +451,35 @@ dcerpcstat_add_program_to_menu(dcerpc_uuid_key *k, dcerpc_uuid_value *v)
 	case 0:
 
 		first_menu_name=v->name;
-		g_snprintf(str,63,"%s ...",v->name);
+		g_snprintf(str,sizeof(str),"%s ...",v->name);
 		program_submenu_item=gtk_menu_item_new();
 		box=gtk_hbox_new(TRUE,0);
 		gtk_container_add(GTK_CONTAINER(program_submenu_item), box);
-		
+
 		program_submenu_label=gtk_label_new(str);
 		gtk_box_pack_start(GTK_BOX(box), program_submenu_label, TRUE, TRUE, 0);
 		gtk_widget_show(program_submenu_label);
 		gtk_widget_show(box);
 
-		gtk_menu_append(GTK_MENU(prog_menu), program_submenu_item);
+		gtk_menu_shell_append(GTK_MENU_SHELL(prog_menu), program_submenu_item);
 		gtk_widget_show(program_submenu_item);
 
 		program_submenu_menu=gtk_menu_new();
 		gtk_menu_item_set_submenu(GTK_MENU_ITEM(program_submenu_item), program_submenu_menu);
 		break;
 	case 14:
-		g_snprintf(str,63,"%s - %s",first_menu_name,v->name);
+		g_snprintf(str,sizeof(str),"%s - %s",first_menu_name,v->name);
 		gtk_label_set_text(GTK_LABEL(program_submenu_label), str);
 		break;
 /*qqq*/
 	}
-	program_subitem_index++;		
+	program_subitem_index++;
 
 	program_menu_item=gtk_menu_item_new_with_label(v->name);
-	SIGNAL_CONNECT(program_menu_item, "activate", dcerpcstat_program_select, k);
+	g_signal_connect(program_menu_item, "activate", G_CALLBACK(dcerpcstat_program_select), k);
 
 	gtk_widget_show(program_menu_item);
-	gtk_menu_append(GTK_MENU(program_submenu_menu), program_menu_item);
+	gtk_menu_shell_append(GTK_MENU_SHELL(program_submenu_menu), program_menu_item);
 
 	if(!dcerpc_uuid_program){
 		dcerpc_uuid_program=&k->uuid;
@@ -551,7 +557,7 @@ gtk_dcerpcstat_cb(GtkWidget *w _U_, gpointer d _U_)
 	  "Service Response Time Statistics Filter",
 	  FALSE,
 	  FALSE,
-      FALSE
+          FALSE
 	};
 
 	/* if the window is already open, bring it to front and
@@ -565,7 +571,7 @@ gtk_dcerpcstat_cb(GtkWidget *w _U_, gpointer d _U_)
 	gtk_window_set_default_size(GTK_WINDOW(dlg), 400, -1);
 
 	dlg_box=gtk_vbox_new(FALSE, 10);
-	gtk_container_border_width(GTK_CONTAINER(dlg_box), 10);
+	gtk_container_set_border_width(GTK_CONTAINER(dlg_box), 10);
 	gtk_container_add(GTK_CONTAINER(dlg), dlg_box);
 	gtk_widget_show(dlg_box);
 
@@ -624,40 +630,45 @@ gtk_dcerpcstat_cb(GtkWidget *w _U_, gpointer d _U_)
 	filter_box=gtk_hbox_new(FALSE, 3);
 
 	/* Filter label */
-	filter_bt=BUTTON_NEW_FROM_STOCK(WIRESHARK_STOCK_DISPLAY_FILTER_ENTRY);
-	SIGNAL_CONNECT(filter_bt, "clicked", display_filter_construct_cb, &args);
+	filter_bt=gtk_button_new_from_stock(WIRESHARK_STOCK_DISPLAY_FILTER_ENTRY);
+	g_signal_connect(filter_bt, "clicked", G_CALLBACK(display_filter_construct_cb), &args);
 	gtk_box_pack_start(GTK_BOX(filter_box), filter_bt, FALSE, FALSE, 0);
 	gtk_widget_show(filter_bt);
 
 	/* Filter entry */
 	filter_entry=gtk_entry_new();
-    SIGNAL_CONNECT(filter_entry, "changed", filter_te_syntax_check_cb, NULL);
+	g_signal_connect(filter_entry, "changed", G_CALLBACK(filter_te_syntax_check_cb), NULL);
+	g_object_set_data(G_OBJECT(filter_box), E_FILT_AUTOCOMP_PTR_KEY, NULL);
+	g_signal_connect(filter_entry, "key-press-event", G_CALLBACK (filter_string_te_key_pressed_cb), NULL);
+	g_signal_connect(dlg, "key-press-event", G_CALLBACK (filter_parent_dlg_key_pressed_cb), NULL);
 	gtk_box_pack_start(GTK_BOX(filter_box), filter_entry, TRUE, TRUE, 0);
 	filter=gtk_entry_get_text(GTK_ENTRY(main_display_filter_widget));
 	if(filter){
 		gtk_entry_set_text(GTK_ENTRY(filter_entry), filter);
+	} else {
+		colorize_filter_te_as_empty(filter_entry);
 	}
 	gtk_widget_show(filter_entry);
-	
+
 	gtk_box_pack_start(GTK_BOX(dlg_box), filter_box, TRUE, TRUE, 0);
 	gtk_widget_show(filter_box);
 
-	OBJECT_SET_DATA(filter_bt, E_FILT_TE_PTR_KEY, filter_entry);
+	g_object_set_data(G_OBJECT(filter_bt), E_FILT_TE_PTR_KEY, filter_entry);
 
 	/* button box */
-    bbox = dlg_button_row_new(WIRESHARK_STOCK_CREATE_STAT, GTK_STOCK_CANCEL, NULL);
+        bbox = dlg_button_row_new(WIRESHARK_STOCK_CREATE_STAT, GTK_STOCK_CANCEL, NULL);
 	gtk_box_pack_start(GTK_BOX(dlg_box), bbox, FALSE, FALSE, 0);
-    gtk_widget_show(bbox);
+        gtk_widget_show(bbox);
 
-    start_button = OBJECT_GET_DATA(bbox, WIRESHARK_STOCK_CREATE_STAT);
-	SIGNAL_CONNECT_OBJECT(start_button, "clicked", 
-                              dcerpcstat_start_button_clicked, NULL);
+        start_button = g_object_get_data(G_OBJECT(bbox), WIRESHARK_STOCK_CREATE_STAT);
+	g_signal_connect_swapped(start_button, "clicked",
+                              G_CALLBACK(dcerpcstat_start_button_clicked), NULL);
 
-    cancel_button = OBJECT_GET_DATA(bbox, GTK_STOCK_CANCEL);
-    window_set_cancel_button(dlg, cancel_button, window_cancel_button_cb);
+        cancel_button = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_CANCEL);
+        window_set_cancel_button(dlg, cancel_button, window_cancel_button_cb);
 
-    SIGNAL_CONNECT(dlg, "delete_event", window_delete_event_cb, NULL);
-	SIGNAL_CONNECT(dlg, "destroy", dlg_destroy_cb, NULL);
+        g_signal_connect(dlg, "delete_event", G_CALLBACK(window_delete_event_cb), NULL);
+	g_signal_connect(dlg, "destroy", dlg_destroy_cb, NULL);
 
 	/* Catch the "activate" signal on the filter text entry, so that
 	   if the user types Return there, we act as if the "Create Stat"
@@ -666,13 +677,13 @@ gtk_dcerpcstat_cb(GtkWidget *w _U_, gpointer d _U_)
 	   focus. */
 	dlg_set_activate(filter_entry, start_button);
 
-    gtk_widget_grab_default(start_button );
+        gtk_widget_grab_default(start_button );
 
 	/* Give the initial focus to the "Filter" entry box. */
 	gtk_widget_grab_focus(filter_entry);
 
 	gtk_widget_show_all(dlg);
-    window_present(dlg);
+        window_present(dlg);
 }
 
 void
