@@ -1,6 +1,6 @@
 /* decode_as_dlg.c
  *
- * $Id: decode_as_dlg.c 29106 2009-07-15 21:37:33Z gerald $
+ * $Id: decode_as_dlg.c 33115 2010-06-06 22:13:16Z gerald $
  *
  * Routines to modify dissector tables on the fly.
  *
@@ -1632,7 +1632,7 @@ decode_add_sctp_page (const gchar *prompt, const gchar *table_name)
 gboolean
 decode_as_ok(void)
 {
-    return cfile.edt->pi.ethertype || cfile.edt->pi.ipproto ||
+    return (cfile.edt->pi.ethertype != G_MAXINT) || cfile.edt->pi.ipproto ||
 	cfile.edt->pi.ptype == PT_TCP || cfile.edt->pi.ptype == PT_UDP || 
         cfile.edt->pi.mpls_label || 
         cfile.cd_t == WTAP_FILE_BER;
@@ -1659,7 +1659,7 @@ decode_add_notebook (GtkWidget *format_hb)
     g_object_set_data(G_OBJECT(decode_w), E_NOTEBOOK, notebook);
 
     /* Add link level selection page */
-    if (cfile.edt->pi.ethertype) {
+    if (cfile.edt->pi.ethertype != G_MAXINT) {
 	g_snprintf(buffer, sizeof(buffer), "Ethertype 0x%04x", cfile.edt->pi.ethertype);
 	page = decode_add_simple_page(buffer, "Link", "ethertype", cfile.edt->pi.ethertype);
 	label = gtk_label_new("Link");
