@@ -3,7 +3,7 @@
  *
  * Implemented as a tap listener to the "expert" tap.
  *
- * $Id: expert_dlg.c 26641 2008-10-31 09:53:56Z stig $
+ * $Id: expert_dlg.c 28709 2009-06-11 18:38:15Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -251,7 +251,7 @@ expert_dlg_draw(void *data)
 	if(etd->disp_events < 1000)
 		gtk_clist_columns_autosize(etd->table);
 	gtk_clist_moveto(etd->table,
-                     etd->disp_events - 1, -1, 1.0, 1.0);
+                     etd->disp_events - 1, -1, 1.0f, 1.0f);
 	gtk_clist_thaw(etd->table);
 
 	if(etd->label) {
@@ -499,7 +499,8 @@ expert_dlg_init(const char *optarg, void* userdata _U_)
 	etd->error_events = 0;
 	etd->severity_report_level = PI_CHAT;
 
-	etd->win=window_new(GTK_WINDOW_TOPLEVEL, "Wireshark: Expert Info");
+	etd->win=dlg_window_new("Wireshark: Expert Info");  /* transient_for top_level */
+	gtk_window_set_destroy_with_parent (GTK_WINDOW(etd->win), TRUE);
 	gtk_window_set_default_size(GTK_WINDOW(etd->win), 650, 600);
 
 	vbox=gtk_vbox_new(FALSE, 3);
@@ -510,7 +511,7 @@ expert_dlg_init(const char *optarg, void* userdata _U_)
 	gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 0);
 
 	etd->label=gtk_label_new("Please wait ...");
-	gtk_misc_set_alignment(GTK_MISC(etd->label), 0.0, 0.5);
+	gtk_misc_set_alignment(GTK_MISC(etd->label), 0.0f, 0.5f);
 	gtk_table_attach_defaults(GTK_TABLE(table), etd->label, 0, 1, 0, 1);
 
 	severity_box = gtk_hbox_new(FALSE, 0);
