@@ -2,7 +2,7 @@
  * Common routines for tracking & saving objects found in streams of data
  * Copyright 2007, Stephen Fisher <stephentfisher@yahoo.com>
  *
- * $Id: export_object.c 22455 2007-08-04 17:52:38Z sfisher $
+ * $Id: export_object.c 25834 2008-07-25 22:58:05Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,27 +28,8 @@
 # include "config.h"
 #endif
 
-#include <glib.h>
 #include <gtk/gtk.h>
 
-/* This feature has not been ported to GTK1 and uses some functions only
- * only available in GTK 2.4 and above. */
-#if GTK_CHECK_VERSION(2,4,0)
-
-#include <alert_box.h>
-#include <simple_dialog.h>
-
-#include <epan/packet_info.h>
-#include <epan/prefs.h>
-#include <epan/tap.h>
-#include <gtk/compat_macros.h>
-#include <gtk/dlg_utils.h>
-#include <gtk/file_dlg.h>
-#include <gtk/gui_utils.h>
-#include <gtk/help_dlg.h>
-#include <gtk/main.h>
-#include <wiretap/file_util.h>
-
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
@@ -57,7 +38,21 @@
 #include <unistd.h>
 #endif
 
-#include "export_object.h"
+#include <epan/packet_info.h>
+#include <epan/prefs.h>
+#include <epan/tap.h>
+
+#include <../alert_box.h>
+#include <../simple_dialog.h>
+#include <wsutil/file_util.h>
+
+#include <gtk/dlg_utils.h>
+#include <gtk/file_dlg.h>
+#include <gtk/gui_utils.h>
+#include <gtk/help_dlg.h>
+#include <gtk/main.h>
+#include <gtk/stock_icons.h>
+#include "gtk/export_object.h"
 
 enum {
 	EO_PKT_NUM_COLUMN,
@@ -109,6 +104,7 @@ eo_win_destroy_cb(GtkWindow *win _U_, gpointer data)
         remove_tap_listener(object_list);
         unprotect_thread_critical_region();
 
+	/* Free the GSList attributes */
 	while(slist) {
 		entry = slist->data;
 
@@ -121,6 +117,7 @@ eo_win_destroy_cb(GtkWindow *win _U_, gpointer data)
        		g_free(entry);
 	}
 
+	/* Free the GSList elements */
 	g_slist_free(object_list->entries);
    	g_free(object_list);
 }
@@ -130,7 +127,7 @@ eo_save_entry(gchar *save_as_filename, export_object_entry_t *entry, gboolean sh
 {
 	int to_fd;
 
-	to_fd = eth_open(save_as_filename, O_WRONLY | O_CREAT | O_EXCL |
+	to_fd = ws_open(save_as_filename, O_WRONLY | O_CREAT | O_EXCL |
 			 O_BINARY, 0644);
 	if(to_fd == -1) { /* An error occurred */
 		if (show_err)
@@ -139,15 +136,15 @@ eo_save_entry(gchar *save_as_filename, export_object_entry_t *entry, gboolean sh
 		return FALSE;
 	}
 
-	if(eth_write(to_fd, entry->payload_data, entry->payload_len) < 0) {
+	if(ws_write(to_fd, entry->payload_data, entry->payload_len) < 0) {
 		if (show_err)
 			write_failure_alert_box(save_as_filename, errno);
-		eth_close(to_fd);
+		ws_close(to_fd);
 		g_free(save_as_filename);
 		return FALSE;
 	}
 
-	if (eth_close(to_fd) < 0) {
+	if (ws_close(to_fd) < 0) {
 		if (show_err)
 			write_failure_alert_box(save_as_filename, errno);
 		g_free(save_as_filename);
@@ -245,6 +242,12 @@ eo_draw(void *tapdata)
 	GSList *slist = object_list->entries;
 	GtkTreeIter new_iter;
 
+	/*  Free the tree first, since we may get called more than once for the same capture 
+	    Not doing so caused duplicate entries and clicking them caused crashes.
+	*/
+
+	gtk_tree_store_clear(object_list->store);
+
 	while(slist) {
 		eo_entry = slist->data;
 
@@ -270,7 +273,7 @@ export_object_window(const gchar *tapname, const gchar *name, tap_packet_cb tap_
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 	GtkTreeSelection *selection;
-	GtkWidget *vbox, *bbox, *help_bt, *close_bt, *save_bt, *save_all_bt;
+	GtkWidget *vbox, *bbox, *help_bt, *cancel_bt, *save_bt, *save_all_bt;
 	GtkTooltips *button_bar_tips;
 	GString *error_msg;
 	export_object_list_t *object_list;
@@ -304,7 +307,7 @@ export_object_window(const gchar *tapname, const gchar *name, tap_packet_cb tap_
 
 	vbox = gtk_vbox_new(FALSE, 5);
 
-        gtk_container_border_width(GTK_CONTAINER(vbox), 5);
+        gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
         gtk_container_add(GTK_CONTAINER(object_list->dlg), vbox);
 
 	sw = scrolled_window_new(NULL, NULL);
@@ -319,6 +322,7 @@ export_object_window(const gchar *tapname, const gchar *name, tap_packet_cb tap_
 						 G_TYPE_STRING);
 
 	object_list->tree = tree_view_new(GTK_TREE_MODEL(object_list->store));
+	g_object_unref(G_OBJECT(object_list->store));
 
 	object_list->tree_view = GTK_TREE_VIEW(object_list->tree);
 
@@ -370,52 +374,47 @@ export_object_window(const gchar *tapname, const gchar *name, tap_packet_cb tap_
 	gtk_container_add(GTK_CONTAINER(sw), object_list->tree);
 
 	selection = gtk_tree_view_get_selection(object_list->tree_view);
-        SIGNAL_CONNECT(selection, "changed", eo_remember_row_num, object_list);
+        g_signal_connect(selection, "changed", G_CALLBACK(eo_remember_row_num), object_list);
 
 
- 	bbox = gtk_hbox_new(FALSE, 5);
+    bbox = dlg_button_row_new(GTK_STOCK_HELP, WIRESHARK_STOCK_SAVE_ALL, GTK_STOCK_SAVE_AS, GTK_STOCK_CANCEL, NULL);
 
 	/* Help button */
-	help_bt = BUTTON_NEW_FROM_STOCK(GTK_STOCK_HELP);
-	SIGNAL_CONNECT(help_bt, "clicked", topic_cb, HELP_EXPORT_OBJECT_LIST);
+    help_bt = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_HELP);
+	g_signal_connect(help_bt, "clicked", G_CALLBACK(topic_cb), (gpointer)HELP_EXPORT_OBJECT_LIST);
 	gtk_tooltips_set_tip(GTK_TOOLTIPS(button_bar_tips), help_bt,
 			     "Show help for this dialog.", NULL);
-	gtk_box_pack_start(GTK_BOX(bbox), help_bt, FALSE, FALSE, 0);
 
 	/* Save All button */
-	save_all_bt = gtk_button_new_with_mnemonic("Save A_ll");
-	SIGNAL_CONNECT(save_all_bt, "clicked", eo_save_all_clicked_cb,
+    save_all_bt = g_object_get_data(G_OBJECT(bbox), WIRESHARK_STOCK_SAVE_ALL);
+	g_signal_connect(save_all_bt, "clicked", G_CALLBACK(eo_save_all_clicked_cb),
 		       object_list);
 	gtk_tooltips_set_tip(GTK_TOOLTIPS(button_bar_tips), save_all_bt,
 			     "Save all listed objects with their displayed "
 			     "filenames.", NULL);
-	gtk_box_pack_end(GTK_BOX(bbox), save_all_bt, FALSE, FALSE, 0);
 
-	/* Save button */
-	save_bt = BUTTON_NEW_FROM_STOCK(GTK_STOCK_SAVE_AS);
-	SIGNAL_CONNECT(save_bt, "clicked", eo_save_clicked_cb, object_list);
+	/* Save As button */
+    save_bt = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_SAVE_AS);
+	g_signal_connect(save_bt, "clicked", G_CALLBACK(eo_save_clicked_cb), object_list);
 	gtk_tooltips_set_tip(GTK_TOOLTIPS(button_bar_tips), save_bt,
 			     "Saves the currently selected content to a file.",
 			     NULL);
-	gtk_box_pack_end(GTK_BOX(bbox), save_bt, FALSE, FALSE, 0);
 
-	/* Close button */
-        close_bt = BUTTON_NEW_FROM_STOCK(GTK_STOCK_CLOSE);
-        GTK_WIDGET_SET_FLAGS(close_bt, GTK_CAN_DEFAULT);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(button_bar_tips), close_bt,
-			     "Close this dialog.", NULL);
-	gtk_box_pack_end(GTK_BOX(bbox), close_bt, FALSE, FALSE, 0);
+	/* Cancel button */
+    cancel_bt = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_CANCEL);
+	gtk_tooltips_set_tip(GTK_TOOLTIPS(button_bar_tips), cancel_bt,
+			     "Cancel this dialog.", NULL);
+
 
 	/* Pack the buttons into the "button box" */
-        gtk_box_pack_end(GTK_BOX(vbox), bbox, FALSE, FALSE, 0);
-        gtk_widget_show(bbox);
+	gtk_box_pack_end(GTK_BOX(vbox), bbox, FALSE, FALSE, 0);
+	gtk_widget_show(bbox);
 
 	/* Setup cancel/delete/destroy signal handlers */
-        SIGNAL_CONNECT(object_list->dlg, "delete_event",
-		       window_delete_event_cb, NULL);
-	SIGNAL_CONNECT(object_list->dlg, "destroy",
-		       eo_win_destroy_cb, object_list);
-       	window_set_cancel_button(object_list->dlg, close_bt,
+        g_signal_connect(object_list->dlg, "delete_event", G_CALLBACK(window_delete_event_cb), NULL);
+	g_signal_connect(object_list->dlg, "destroy",
+		       G_CALLBACK(eo_win_destroy_cb), object_list);
+       	window_set_cancel_button(object_list->dlg, cancel_bt,
 				 window_cancel_button_cb);
 
 	/* Show the window */
@@ -424,5 +423,3 @@ export_object_window(const gchar *tapname, const gchar *name, tap_packet_cb tap_
 
 	cf_retap_packets(&cfile, FALSE);
 }
-
-#endif /* GTK_CHECK_VERSION(2,4,0) */
