@@ -1,7 +1,7 @@
 /* file_dlg.c
  * Utilities to use when constructing file selection dialogs
  *
- * $Id: file_dlg.c 27718 2009-03-13 22:06:48Z stig $
+ * $Id: file_dlg.c 28059 2009-04-15 21:35:51Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -121,7 +121,7 @@ gboolean
 file_selection_set_current_folder(GtkWidget *fs, const gchar *filename)
 {
     gboolean ret;
-    int filename_len = strlen(filename);
+    size_t filename_len = strlen(filename);
     gchar *new_filename;
 
     /* trim filename, so gtk_file_chooser_set_current_folder() likes it, see below */
@@ -189,7 +189,7 @@ file_selection_browse(GtkWidget *file_bt, GtkWidget *file_te, const char *label,
 
   /* Call a handler when the file selection box is destroyed, so we can inform
      our caller, if any, that it's been destroyed. */
-  g_signal_connect(fs, "destroy", GTK_SIGNAL_FUNC(file_selection_browse_destroy_cb), 
+  g_signal_connect(fs, "destroy", G_CALLBACK(file_selection_browse_destroy_cb), 
 		 file_te);
 
   if (gtk_dialog_run(GTK_DIALOG(fs)) == GTK_RESPONSE_ACCEPT)
@@ -224,7 +224,7 @@ file_selection_browse_destroy_cb(GtkWidget *win, GtkWidget* parent_te)
 void
 set_last_open_dir(char *dirname)
 {
-	int len;
+	size_t len;
 	gchar *new_last_open_dir;
 
 	if (dirname) {
