@@ -1,7 +1,7 @@
 /* find_dlg.c
  * Routines for "find frame" window
  *
- * $Id: find_dlg.c 27718 2009-03-13 22:06:48Z stig $
+ * $Id: find_dlg.c 28189 2009-04-28 03:00:40Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -102,8 +102,8 @@ static GtkWidget *filter_text_box;
  * Save the presskey handlers to be able to dissable the auto-completion 
  * feature for hex and string searches.
  */
-static int te_presskey_handler_id;
-static int win_presskey_handler_id;
+static gulong te_presskey_handler_id;
+static gulong win_presskey_handler_id;
 
 void
 find_frame_cb(GtkWidget *w _U_, gpointer d _U_)
@@ -282,7 +282,7 @@ find_frame_cb(GtkWidget *w _U_, gpointer d _U_)
 
   combo_lb = gtk_label_new("Character set:");
   gtk_container_add(GTK_CONTAINER(string_opt_vb), combo_lb);
-  gtk_misc_set_alignment(GTK_MISC(combo_lb), 0.0, 0.5);
+  gtk_misc_set_alignment(GTK_MISC(combo_lb), 0.0f, 0.5f);
   gtk_widget_show(combo_lb);
 
   /* Character Type Selection Dropdown Box
