@@ -1,7 +1,7 @@
 /* follow_ssl.c
  * SSL specific routines for following traffic streams
  *
- * $Id: follow_ssl.c 23860 2007-12-14 07:06:22Z jake $
+ * $Id: follow_ssl.c 28062 2009-04-16 00:45:26Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -23,10 +23,9 @@
  * USA.
  */
 
-#include "config.h"
-
-#include <gtk/gtk.h>
-
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
 #include <stdio.h>
 #include <string.h>
 
@@ -37,38 +36,39 @@
 
 #include <ctype.h>
 
-#include <color.h>
-#include <gtk/colors.h>
-#include <gtk/main.h>
+#include <gtk/gtk.h>
+
 #include <epan/follow.h>
-#include <gtk/dlg_utils.h>
-#include <gtk/file_dlg.h>
-#include <gtk/keys.h>
-#include <globals.h>
-#include <alert_box.h>
-#include <simple_dialog.h>
 #include <epan/dissectors/packet-ipv6.h>
 #include <epan/prefs.h>
 #include <epan/addr_resolv.h>
-#include <util.h>
-#include <gtk/gui_utils.h>
 #include <epan/epan_dissect.h>
 #include <epan/filesystem.h>
-#include <gtk/compat_macros.h>
 #include <epan/ipproto.h>
-#include <gtk/font_utils.h>
-#include <wiretap/file_util.h>
 #include <epan/tap.h>
 
+#include <../color.h>
+#include <../globals.h>
+#include <../alert_box.h>
+#include <../simple_dialog.h>
+#include <../util.h>
+
+#include <gtk/color_utils.h>
+#include <gtk/main.h>
+#include <gtk/dlg_utils.h>
+#include <gtk/file_dlg.h>
+#include <gtk/keys.h>
+#include <gtk/gui_utils.h>
+#include <gtk/font_utils.h>
+#include "gtk/follow_ssl.h"
+#include "gtk/follow_stream.h"
+
 #ifdef SSL_PLUGIN
 #include "packet-ssl-utils.h"
 #else
 #include <epan/dissectors/packet-ssl-utils.h>
 #endif
 
-#include "follow_ssl.h"
-
-#include "follow_stream.h"
 
 typedef struct {
     gboolean is_server;
@@ -86,7 +86,7 @@ ssl_queue_packet_data(void *tapdata, packet_info *pinfo, epan_dissect_t *edt _U_
     int proto_ssl = (long) ssl;
     SslPacketInfo* pi = p_get_proto_data(pinfo->fd, proto_ssl);
 
-    /* skip packet without decrypted data payload*/    
+    /* skip packet without decrypted data payload*/
     if (!pi || !pi->appl_data)
         return 0;
 
@@ -94,35 +94,34 @@ ssl_queue_packet_data(void *tapdata, packet_info *pinfo, epan_dissect_t *edt _U_
     total_len = 0;
     appl_data = pi->appl_data;
     do {
-      total_len += appl_data->plain_data.data_len; 
+      total_len += appl_data->plain_data.data_len;
       appl_data = appl_data->next;
     } while (appl_data);
-    
+
     /* compute packet direction */
     rec = g_malloc(sizeof(SslDecryptedRecord) + total_len);
 
     if (follow_info->client_port == 0) {
         follow_info->client_port = pinfo->srcport;
-        memcpy(follow_info->client_ip, pinfo->src.data, pinfo->src.len);
+        COPY_ADDRESS(&follow_info->client_ip, &pinfo->src);
     }
-    if (memcmp(follow_info->client_ip, pinfo->src.data, pinfo->src.len) == 0 &&
-        follow_info->client_port == pinfo->srcport) {
+    if (ADDRESSES_EQUAL(&follow_info->client_ip, &pinfo->src) &&
+        follow_info->client_port == pinfo->srcport)
         rec->is_server = 0;
-    }
-    else 
+    else
         rec->is_server = 1;
 
     /* update stream counter */
     follow_info->bytes_written[rec->is_server] += total_len;
-    
-    /* extract decrypted data and queue it locally */    
+
+    /* extract decrypted data and queue it locally */
     rec->data.data = (guchar*)(rec + 1);
     rec->data.data_len = total_len;
     appl_data = pi->appl_data;
     p = rec->data.data;
     do {
       memcpy(p, appl_data->plain_data.data, appl_data->plain_data.data_len);
-      p += appl_data->plain_data.data_len; 
+      p += appl_data->plain_data.data_len;
       appl_data = appl_data->next;
     } while (appl_data);
     follow_info->payload = g_list_append(
@@ -131,7 +130,7 @@ ssl_queue_packet_data(void *tapdata, packet_info *pinfo, epan_dissect_t *edt _U_
     return 0;
 }
 
-extern gboolean 
+extern gboolean
 packet_is_ssl(epan_dissect_t* edt);
 
 
@@ -174,11 +173,12 @@ follow_ssl_stream_cb(GtkWidget * w, gpointer data _U_)
         simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
                       "Error creating filter for this stream.\n"
                       "A network layer header is needed");
+	g_free(follow_info);
         return;
     }
 
     /* Set the display filter entry accordingly */
-    filter_te = OBJECT_GET_DATA(w, E_DFILTER_TE_KEY);
+    filter_te = g_object_get_data(G_OBJECT(w), E_DFILTER_TE_KEY);
 
     /* needed in follow_filter_out_stream(), is there a better way? */
     follow_info->filter_te = filter_te;
@@ -189,8 +189,8 @@ follow_ssl_stream_cb(GtkWidget * w, gpointer data _U_)
 
     /* allocate our new filter. API claims g_malloc terminates program on failure */
     /* my calc for max alloc needed is really +10 but when did a few extra bytes hurt ? */
-    previous_filter_len = previous_filter?strlen(previous_filter):0;
-    filter_out_filter_len = strlen(follow_filter) + previous_filter_len + 16;
+    previous_filter_len = previous_filter?(int)strlen(previous_filter):0;
+    filter_out_filter_len = (int)strlen(follow_filter) + previous_filter_len + 16;
     follow_info->filter_out_filter = (gchar *)g_malloc(filter_out_filter_len);
 
     /* append the negation */
@@ -209,6 +209,9 @@ follow_ssl_stream_cb(GtkWidget * w, gpointer data _U_)
     {
         simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
             "Can't register ssl tap: %s\n",msg->str);
+	g_free(follow_info->filter_out_filter);
+	g_free(follow_info);
+	g_free(follow_filter);
         return;
     }
     gtk_entry_set_text(GTK_ENTRY(filter_te), follow_filter);
@@ -238,28 +241,40 @@ follow_ssl_stream_cb(GtkWidget * w, gpointer data _U_)
 	    memcpy(&ipaddr, stats.ip_address[1], 4);
 	    hostname1 = get_hostname(ipaddr);
     }
-    
+
     port0 = get_tcp_port(stats.port[0]);
     port1 = get_tcp_port(stats.port[1]);
-    
+
     follow_info->is_ipv6 = stats.is_ipv6;
 
    /* Both Stream Directions */
     both_directions_string = g_strdup_printf("Entire conversation (%u bytes)", follow_info->bytes_written[0] + follow_info->bytes_written[1]);
-    
-    /* Host 0 --> Host 1 */
-    server_to_client_string =
-	    g_strdup_printf("%s:%s --> %s:%s (%u bytes)",
-			    hostname0, port0,
-			    hostname1, port1,
-			    follow_info->bytes_written[0]);
 
-    /* Host 1 --> Host 0 */
-    client_to_server_string =
-	    g_strdup_printf("%s:%s --> %s:%s (%u bytes)",
-			    hostname1, port1,
-			    hostname0, port0,
-			    follow_info->bytes_written[1]);
+    if(follow_info->client_port == stats.port[0]) {
+	    server_to_client_string =
+		    g_strdup_printf("%s:%s --> %s:%s (%u bytes)",
+				    hostname0, port0,
+				    hostname1, port1,
+				    follow_info->bytes_written[0]);
+
+	    client_to_server_string =
+		    g_strdup_printf("%s:%s --> %s:%s (%u bytes)",
+				    hostname1, port1,
+				    hostname0, port0,
+				    follow_info->bytes_written[1]);
+    } else {
+	    server_to_client_string =
+		    g_strdup_printf("%s:%s --> %s:%s (%u bytes)",
+				    hostname1, port1,
+				    hostname0, port0,
+				    follow_info->bytes_written[0]);
+
+	    client_to_server_string =
+		    g_strdup_printf("%s:%s --> %s:%s (%u bytes)",
+				    hostname0, port0,
+				    hostname1, port1,
+				    follow_info->bytes_written[1]);
+    }
 
     follow_stream("Follow SSL Stream", follow_info, both_directions_string,
 		  server_to_client_string, client_to_server_string);
@@ -295,13 +310,15 @@ follow_read_ssl_stream(follow_info_t *follow_info,
 {
     int			iplen;
     guint32		global_client_pos = 0, global_server_pos = 0;
+    guint32		server_packet_count = 0;
+    guint32		client_packet_count = 0;
     guint32		*global_pos;
     gboolean		skip;
     GList* cur;
     frs_return_t        frs_return;
 
     iplen = (follow_info->is_ipv6) ? 16 : 4;
-    
+
     for (cur = follow_info->payload; cur; cur = g_list_next(cur)) {
         SslDecryptedRecord* rec = cur->data;
 	skip = FALSE;
@@ -310,8 +327,7 @@ follow_read_ssl_stream(follow_info_t *follow_info,
 	    if (follow_info->show_stream == FROM_SERVER) {
 		skip = TRUE;
 	    }
-	}
-	else {
+	} else {
 	    global_pos = &global_server_pos;
 	    if (follow_info->show_stream == FROM_CLIENT) {
 		skip = TRUE;
@@ -320,10 +336,11 @@ follow_read_ssl_stream(follow_info_t *follow_info,
 
         if (!skip) {
             size_t nchars = rec->data.data_len;
-            gchar *buffer = g_memdup(rec->data.data, nchars);
-            
+            gchar *buffer = g_memdup(rec->data.data, (guint) nchars);
+
 	    frs_return = follow_show(follow_info, print_line, buffer, nchars,
-				     rec->is_server, arg, global_pos);
+				     rec->is_server, arg, global_pos,
+				     &server_packet_count, &client_packet_count);
 	    g_free(buffer);
 	    if(frs_return == FRS_PRINT_ERROR)
 		    return frs_return;
