@@ -1,7 +1,7 @@
 /* graph_analysis.c
  * Graphic Analysis addition for Wireshark
  *
- * $Id: graph_analysis.c 26641 2008-10-31 09:53:56Z stig $
+ * $Id: graph_analysis.c 29703 2009-09-04 21:35:02Z gerald $
  *
  * Copyright 2004, Verso Technologies Inc.
  * By Alejandro Vaquero <alejandrovaquero@yahoo.com>
@@ -50,11 +50,13 @@
 #include "../register.h"
 #include "../color.h"
 #include "../simple_dialog.h"
+#include "../alert_box.h"
 #include <wsutil/file_util.h>
 
 #include "gtk/gtkglobals.h"
 #include "gtk/file_dlg.h"
 #include "gtk/gui_utils.h"
+#include "gtk/dlg_utils.h"
 #include "gtk/main.h"
 #include "gtk/graph_analysis.h"
 
@@ -204,7 +206,7 @@ static void draw_arrow(GdkDrawable *pixmap, GdkGC *gc, gint x, gint y, gboolean
 
 static void enlarge_string(GString *gstr, guint32 length, char pad){
 
-	guint32 i;
+	gsize i;
 
 	for (i = gstr->len; i < length; i++){
 		g_string_append_c(gstr, pad);
@@ -219,7 +221,7 @@ static void enlarge_string(GString *gstr, guint32 length, char pad){
 
 static void overwrite (GString *gstr, char *text_to_insert, guint32 p1, guint32 p2){
 
-	guint32 len;
+	gsize len;
 	gsize pos;
 
 	if (p1 == p2)
@@ -238,12 +240,11 @@ static void overwrite (GString *gstr, char *text_to_insert, guint32 p1, guint32
 		len = strlen(text_to_insert);
 	}
 
-	/* ouch this is ugly but gtk1 needs it */
-	if ((guint32)pos > (guint32)gstr->len)
+	if (pos > gstr->len)
 		pos = gstr->len;
 
 	/* ouch this is ugly but gtk1 needs it */
-	if ((guint32)(pos + len) > (guint32)gstr->len)
+	if ((pos + len) > gstr->len)
 		g_string_truncate(gstr, pos);
 	else
 		g_string_erase(gstr, pos, len);
@@ -278,6 +279,7 @@ static gboolean dialog_graph_dump_to_file(graph_analysis_data_t* user_data)
 
 	of = ws_fopen(user_data->dlg.save_file,"w");
 	if (of==NULL){
+		open_failure_alert_box(user_data->dlg.save_file, errno, TRUE);
 		return FALSE;
 	}
 
@@ -320,7 +322,8 @@ static gboolean dialog_graph_dump_to_file(graph_analysis_data_t* user_data)
 	display_items = current_item;
 
 	/* if not items to display */
-	if (display_items == 0)	goto exit;
+	if (display_items == 0)
+		goto exit;
 
 	display_nodes = user_data->num_nodes;
 
@@ -376,7 +379,7 @@ static gboolean dialog_graph_dump_to_file(graph_analysis_data_t* user_data)
 
 	g_string_append_c(empty_line, '|');
 
-	enlarge_string(separator_line, empty_line->len + header_length, '-');
+	enlarge_string(separator_line, (guint32) empty_line->len + header_length, '-');
 
 	/*
 	 * Draw the items
@@ -419,7 +422,7 @@ static gboolean dialog_graph_dump_to_file(graph_analysis_data_t* user_data)
 
 		/* write the frame label */
 
-		g_string_append(tmp_str, empty_line->str);
+		g_string_printf(tmp_str, "%s", empty_line->str);
 		overwrite(tmp_str,user_data->dlg.items[current_item].frame_label,
 			start_position,
 			end_position
@@ -432,7 +435,7 @@ static gboolean dialog_graph_dump_to_file(graph_analysis_data_t* user_data)
 		/* write the arrow and frame label*/
 		fprintf(of, "%s", empty_header);
 
-		g_string_append(tmp_str, empty_line->str);
+		g_string_printf(tmp_str, "%s", empty_line->str);
 
 		g_string_truncate(tmp_str2, 0);
 
@@ -450,8 +453,8 @@ static gboolean dialog_graph_dump_to_file(graph_analysis_data_t* user_data)
 			end_position
 			);
 
-		g_snprintf(src_port,8,"(%i)", user_data->dlg.items[current_item].port_src);
-		g_snprintf(dst_port,8,"(%i)", user_data->dlg.items[current_item].port_dst);
+		g_snprintf(src_port,sizeof(src_port),"(%i)", user_data->dlg.items[current_item].port_src);
+		g_snprintf(dst_port,sizeof(dst_port),"(%i)", user_data->dlg.items[current_item].port_dst);
 
 		if (start_position<end_position){
 			overwrite(tmp_str,src_port,start_position-9,start_position-1);
@@ -489,7 +492,7 @@ static void save_to_file_destroy_cb(GtkWidget *win _U_, gpointer user_data _U_)
 
 /* first an auxiliary function in case we need an overwrite confirmation dialog */
 
-static void overwrite_existing_file_cb(gpointer dialog _U_, gint btn, gpointer user_data _U_)
+static void overwrite_existing_file_cb(gpointer dialog _U_, gint btn, gpointer user_data)
 {
 	graph_analysis_data_t *user_data_p;
 
@@ -509,75 +512,77 @@ static void overwrite_existing_file_cb(gpointer dialog _U_, gint btn, gpointer u
 
 /* and then the save in a file dialog itself */
 
-static void save_to_file_ok_cb(GtkWidget *ok_bt _U_, gpointer user_data _U_)
+static gboolean save_to_file_ok_cb(GtkWidget *ok_bt _U_, gpointer user_data)
 {
 	FILE *file_test;
-	gpointer dialog;
 	graph_analysis_data_t *user_data_p;
 
 	user_data_p = user_data;
 
-	user_data_p->dlg.save_file = g_strdup(gtk_file_selection_get_filename(GTK_FILE_SELECTION (save_to_file_w)));
+	user_data_p->dlg.save_file = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(save_to_file_w));
 
 	/* Perhaps the user specified a directory instead of a file.
-	Check whether they did. */
+	   Check whether they did. */
 	if (test_for_directory(user_data_p->dlg.save_file) == EISDIR) {
 		/* It's a directory - set the file selection box to display it. */
 		set_last_open_dir(user_data_p->dlg.save_file);
-		g_free(user_data_p->dlg.save_file);
 		file_selection_set_current_folder(save_to_file_w, get_last_open_dir());
-		return;
+		gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(save_to_file_w), "");
+		g_free(user_data_p->dlg.save_file);
+		return FALSE;  /* run the dialog again */
 	}
 
-
+	/* GtkFileChooserDialog/gtk_dialog_run is currently being used.         */
+	/*      So: Trying to leave the graph_analysis window up if graph_dump  */
+	/*          fails doesn't work well.                                    */
+	/*  (See comment under on_save_bt_clicked)                              */
+	/*                                                                      */
+	/* As a work-around:                                                    */
+	/*  We'll always destroy the window.                                    */
+       
 	/* check whether the file exists */
 	file_test = ws_fopen(user_data_p->dlg.save_file,"r");
 	if (file_test!=NULL){
-
+		gpointer dialog;
 		dialog = simple_dialog(ESD_TYPE_CONFIRMATION, ESD_BTNS_YES_NO,
 		  "%sFile: \"%s\" already exists!%s\n\n"
 		  "Do you want to overwrite it?",
 		  simple_dialog_primary_start(),user_data_p->dlg.save_file, simple_dialog_primary_end());
 		simple_dialog_set_cb(dialog, overwrite_existing_file_cb, user_data);
 		fclose(file_test);
+		return TRUE;
 	}
 
 	else{
-		if (!dialog_graph_dump_to_file(user_data))
-			return;
+		if (!dialog_graph_dump_to_file(user_data)) {
+			/* Couldn't open the file ?  */
+			g_free(user_data_p->dlg.save_file);
+			return TRUE;
+		}
 	}
-	window_destroy(GTK_WIDGET(save_to_file_w));
-
+	g_free(user_data_p->dlg.save_file);
+	return TRUE;
 }
 
 /****************************************************************************/
 static void
-on_save_bt_clicked                    (GtkButton       *button _U_,
-                                        gpointer         user_data _U_)
+on_save_bt_clicked                    (GtkWidget       *button _U_,
+                                        graph_analysis_data_t *user_data)
 {
-	GtkWidget *vertb;
-	GtkWidget *ok_bt;
-
+#if 0  /* XXX: GtkFileChooserDialog/gtk_dialog_run currently being used is effectively modal so this is not req'd */
 	if (save_to_file_w != NULL) {
 		/* There's already a Save to file dialog box; reactivate it. */
 		reactivate_window(save_to_file_w);
 		return;
 	}
-
-	save_to_file_w = gtk_file_selection_new("Wireshark: Save graph to plain text file");
-
-	/* Container for each row of widgets */
-	vertb = gtk_vbox_new(FALSE, 0);
-	gtk_container_set_border_width(GTK_CONTAINER(vertb), 5);
-	gtk_box_pack_start(GTK_BOX(GTK_FILE_SELECTION(save_to_file_w)->action_area),
-		vertb, FALSE, FALSE, 0);
-	gtk_widget_show (vertb);
-
-	ok_bt = GTK_FILE_SELECTION(save_to_file_w)->ok_button;
-	g_signal_connect(ok_bt, "clicked", G_CALLBACK(save_to_file_ok_cb), user_data);
-
-	window_set_cancel_button(save_to_file_w,
-	GTK_FILE_SELECTION(save_to_file_w)->cancel_button, window_cancel_button_cb);
+#endif
+	save_to_file_w = 
+		gtk_file_chooser_dialog_new("Wireshark: Save graph to plain text file",
+					    GTK_WINDOW(user_data->dlg.window),
+					    GTK_FILE_CHOOSER_ACTION_SAVE,
+					    GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+					    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					    NULL);
 
 	g_signal_connect(save_to_file_w, "delete_event", G_CALLBACK(window_delete_event_cb), NULL);
 	g_signal_connect(save_to_file_w, "destroy", G_CALLBACK(save_to_file_destroy_cb), NULL);
@@ -585,6 +590,25 @@ on_save_bt_clicked                    (GtkButton       *button _U_,
 	gtk_widget_show(save_to_file_w);
 	window_present(save_to_file_w);
 
+	/* "Run" the GtkFileChooserDialog.                                              */
+        /* Upon exit: If "Accept" run the OK callback.                                  */
+        /*            If the OK callback returns with a FALSE status, re-run the dialog.*/
+        /*            Destroy the window.                                               */
+        /* XXX: If the OK callback pops up an alert box (eg: for an error) it *must*    */
+        /*      return with a TRUE status so that the dialog window will be destroyed.  */
+	/*      Trying to re-run the dialog after popping up an alert box will not work */
+        /*       since the user will not be able to dismiss the alert box.              */
+	/*      The (somewhat unfriendly) effect: the user must re-invoke the           */
+	/*      GtkFileChooserDialog whenever the OK callback pops up an alert box.     */
+	/*                                                                              */
+        /*      ToDo: use GtkFileChooserWidget in a dialog window instead of            */
+	/*            GtkFileChooserDialog.                                             */
+	while (gtk_dialog_run(GTK_DIALOG(save_to_file_w)) == GTK_RESPONSE_ACCEPT) {
+		if (save_to_file_ok_cb(NULL, user_data)) {
+			break;  /* we're done */
+		}
+	}
+	window_destroy(save_to_file_w);
 }
 
 /****************************************************************************/
@@ -815,8 +839,7 @@ static void dialog_graph_draw(graph_analysis_data_t* user_data)
 	for (i=0; i<user_data->num_nodes; i++){
 		/* print the node identifiers */
 		/* XXX we assign 5 pixels per character in the node identity */
-		g_snprintf(label_string, NODE_WIDTH/5, "%s",
-			get_addr_name(&(user_data->nodes[i])));
+		g_strlcpy(label_string, get_addr_name(&(user_data->nodes[i])), NODE_WIDTH/5);
 		pango_layout_set_text(layout, label_string, -1);
 		pango_layout_get_pixel_size(layout, &label_width, &label_height);
 		if (GDK_IS_DRAWABLE(user_data->dlg.pixmap)) {
@@ -1472,11 +1495,8 @@ static void dialog_graph_create_window(graph_analysis_data_t* user_data)
 	win_name = g_strdup_printf("%s - Graph Analysis", title_name_ptr);
 
 	/* create the main window */
-	if (user_data->dlg.title)
-		user_data->dlg.window=window_new(GTK_WINDOW_TOPLEVEL, user_data->dlg.title);
-	else
-		user_data->dlg.window=window_new(GTK_WINDOW_TOPLEVEL, win_name);
-
+	user_data->dlg.window=dlg_window_new((user_data->dlg.title)?user_data->dlg.title:win_name);
+	gtk_window_set_destroy_with_parent(GTK_WINDOW(user_data->dlg.window), TRUE);
 
 	vbox=gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(user_data->dlg.window), vbox);
