@@ -3,7 +3,7 @@
  * and some with GUI-independent APIs, with this file containing the GTK+
  * implementations of them (declared in ui_util.h)
  *
- * $Id: gui_utils.c 27741 2009-03-16 18:01:25Z etxrab $
+ * $Id: gui_utils.c 33121 2010-06-07 01:13:14Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -482,6 +482,9 @@ window_destroy(GtkWidget *win)
   window_geometry_t geom;
   const gchar *name;
 
+  if (!win)
+    return;
+
   /* get_geometry must be done *before* destroy is running, as the window geometry
    * cannot be retrieved at destroy time (so don't use event "destroy" for this) */
   /* ...and don't do this at all, if we currently have no GdkWindow (e.g. if the
@@ -570,7 +573,7 @@ void main_window_update(void)
 /* exit the main window */
 void main_window_exit(void)
 {
-  gtk_exit(0);
+  exit(0);
 }
 
 #ifdef HAVE_LIBPCAP
