@@ -2,7 +2,7 @@
  * H.225 message counter for Wireshark
  * Copyright 2003 Lars Roland
  *
- * $Id: h225_counter.c 26641 2008-10-31 09:53:56Z stig $
+ * $Id: h225_counter.c 29099 2009-07-15 00:10:08Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -519,7 +519,9 @@ gtk_h225counter_init(const char *optarg, void *userdata _U_)
 
 	h225counter_reset(hs);
 
-	hs->win=window_new(GTK_WINDOW_TOPLEVEL, "Wireshark: H.225 counters");
+	hs->win = dlg_window_new("Wireshark: H.225 counters");  /* transient_for top_level */
+	gtk_window_set_destroy_with_parent (GTK_WINDOW(hs->win), TRUE);
+
 	gtk_window_set_default_size(GTK_WINDOW(hs->win), 400, 200);
 
 	hs->vbox=gtk_vbox_new(FALSE, 3);
