@@ -1,6 +1,6 @@
 /* help_dlg.c
  *
- * $Id: help_dlg.c 25725 2008-07-12 19:28:08Z stig $
+ * $Id: help_dlg.c 28440 2009-05-21 22:10:17Z stig $
  *
  * Laurent Deniel <laurent.deniel@free.fr>
  *
@@ -283,6 +283,12 @@ topic_action(topic_action_e action)
     case(HELP_STATS_IO_GRAPH_DIALOG):
         help_topic_html("ChStatIOGraphs.html");
         break;
+    case(HELP_STATS_COMPARE_FILES_DIALOG):
+        help_topic_html("ChStatCompareCaptureFiles.html");
+        break;
+    case(HELP_STATS_LTE_MAC_TRAFFIC_DIALOG):
+        help_topic_html("ChStatLTEMACTraffic.html");
+        break;
     case(HELP_STATS_WLAN_TRAFFIC_DIALOG):
         help_topic_html("ChStatWLANTraffic.html");
         break;
