@@ -1,7 +1,7 @@
 /* io_stat.c
  * io_stat   2002 Ronnie Sahlberg
  *
- * $Id: io_stat.c 32215 2010-03-16 23:22:42Z gerald $
+ * $Id: io_stat.c 33115 2010-06-06 22:13:16Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1573,7 +1573,9 @@ create_tick_interval_menu_items(io_stat_t *io)
 	combo_box = gtk_combo_box_new_text ();
 
 	for(i=0;i<MAX_TICK_VALUES;i++){
-            if(tick_interval_values[i]>=1000){
+           if(tick_interval_values[i]>=60000){
+                    g_snprintf(str, sizeof(str), "%u min", tick_interval_values[i]/60000);
+            } else if(tick_interval_values[i]>=1000){
                     g_snprintf(str, sizeof(str), "%u sec", tick_interval_values[i]/1000);
 		} else if(tick_interval_values[i]>=100){
                     g_snprintf(str, sizeof(str), "0.%1u sec", (tick_interval_values[i]/100)%10);
