@@ -2,7 +2,7 @@
  * Copyright 2009 Martin Mathieson
  * (originally based upon wlan_stat_dlg.c)
  *
- * $Id: mac_lte_stat_dlg.c 27776 2009-03-18 16:21:45Z martinm $
+ * $Id: mac_lte_stat_dlg.c 28459 2009-05-24 07:25:57Z martinm $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -15,7 +15,7 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
@@ -63,21 +63,16 @@
 
 /**********************************************/
 /* Table column identifiers and title strings */
-enum {
-    BCH_FRAMES_COLUMN,
-    BCH_BYTES_COLUMN,
-    PCH_FRAMES_COLUMN,
-    PCH_BYTES_COLUMN,
-    NUM_COMMON_COLUMNS
-};
 
 enum {
     RNTI_COLUMN,
     UL_FRAMES_COLUMN,
     UL_BYTES_COLUMN,
+    UL_CRC_ERRORS_COLUMN,
     UL_RETX_FRAMES_COLUMN,
     DL_FRAMES_COLUMN,
     DL_BYTES_COLUMN,
+    DL_CRC_ERRORS_COLUMN,
     DL_RETX_FRAMES_COLUMN,
     TABLE_COLUMN,
     NUM_UE_COLUMNS
@@ -100,8 +95,8 @@ enum {
 };
 
 static const gchar *ue_titles[] = { "RNTI",
-                                 "UL Frames", "UL Bytes", "UL ReTX Frames",
-                                 "DL Frames", "DL Bytes", "DL ReTX Frames"};
+                                 "UL Frames", "UL Bytes", "UL CRC Errors", "UL ReTX Frames",
+                                 "DL Frames", "DL Bytes", "DL CRC Errors", "DL ReTX Frames"};
 
 static const gchar *channel_titles[] = { "CCCH",
                                          "LCID 1", "LCID 2", "LCID 3", "LCID 4", "LCID 5",
@@ -118,10 +113,12 @@ typedef struct mac_lte_row_data {
 
     guint32 UL_frames;
     guint32 UL_total_bytes;
+    guint32 UL_CRC_errors;
     guint32 UL_retx_frames;
 
     guint32 DL_frames;
     guint32 DL_total_bytes;
+    guint32 DL_CRC_errors;
     guint32 DL_retx_frames;
 
     guint32 UL_bytes_for_lcid[11];
@@ -135,7 +132,6 @@ typedef struct mac_lte_row_data {
 typedef struct mac_lte_ep {
     struct mac_lte_ep* next;
     struct mac_lte_row_data stats;
-    guint32 number_of_packets;
     GtkTreeIter iter;
     gboolean iter_valid;
 } mac_lte_ep_t;
@@ -147,6 +143,8 @@ typedef struct mac_lte_common_stats {
     guint32 bch_bytes;
     guint32 pch_frames;
     guint32 pch_bytes;
+    guint32 rar_frames;
+    guint32 rar_entries;
 } mac_lte_common_stats;
 
 static const char * selected_ue_row_names[] = {"UL SDUs", "UL Bytes", "DL SDUs", "DL Bytes"};
@@ -157,6 +155,8 @@ static GtkWidget *mac_lte_common_bch_frames;
 static GtkWidget *mac_lte_common_bch_bytes;
 static GtkWidget *mac_lte_common_pch_frames;
 static GtkWidget *mac_lte_common_pch_bytes;
+static GtkWidget *mac_lte_common_rar_frames;
+static GtkWidget *mac_lte_common_rar_entries;
 
 /* Labels in selected UE 'table' */
 static GtkWidget *selected_ue_column_entry[NUM_CHANNEL_COLUMNS][5];
@@ -172,8 +172,6 @@ static GtkWidget  *mac_lte_stat_selected_ue_lb = NULL;
 /* Used to keep track of whole MAC LTE statistics window */
 typedef struct mac_lte_stat_t {
     GtkTreeView   *ue_table;
-    guint32       number_of_packets;
-    guint32       num_entries;
     mac_lte_ep_t* ep_list;
 } mac_lte_stat_t;
 
@@ -184,7 +182,7 @@ mac_lte_stat_reset(void *phs)
 {
     mac_lte_stat_t* mac_lte_stat = (mac_lte_stat_t *)phs;
     mac_lte_ep_t* list = mac_lte_stat->ep_list;
-    char title[256];
+    gchar title[256];
     GtkListStore *store;
     gint i, n;
 
@@ -195,7 +193,7 @@ mac_lte_stat_reset(void *phs)
         gtk_window_set_title(GTK_WINDOW(mac_lte_stat_dlg_w), title);
     }
 
-    g_snprintf(title, sizeof(title), "UL/DL-SCH data");
+    g_snprintf(title, sizeof(title), "UL/DL-SCH data (0 UEs)");
     gtk_frame_set_label(GTK_FRAME(mac_lte_stat_ues_lb), title);
 
     memset(&common_stats, 0, sizeof(common_stats));
@@ -209,7 +207,6 @@ mac_lte_stat_reset(void *phs)
     }
 
     mac_lte_stat->ep_list = NULL;
-    mac_lte_stat->number_of_packets = 0;
 
     /* Set all of the channel counters to 0 */
     for (n=1; n <=4; n++) {
@@ -235,7 +232,6 @@ static mac_lte_ep_t* alloc_mac_lte_ep(struct mac_lte_tap_info *si, packet_info *
     }
 
     /* Copy SI data into ep->stats */
-    ep->number_of_packets = 0;
     ep->stats.rnti = si->rnti;
 
     /* Counts for new UE are all 0 */
@@ -243,6 +239,8 @@ static mac_lte_ep_t* alloc_mac_lte_ep(struct mac_lte_tap_info *si, packet_info *
     ep->stats.DL_frames = 0;
     ep->stats.UL_total_bytes = 0;
     ep->stats.DL_total_bytes = 0;
+    ep->stats.UL_CRC_errors = 0;
+    ep->stats.DL_CRC_errors = 0;
     ep->stats.UL_retx_frames = 0;
     ep->stats.DL_retx_frames = 0;
 
@@ -280,10 +278,8 @@ mac_lte_stat_packet(void *phs, packet_info *pinfo, epan_dissect_t *edt _U_,
         return (0);
     }
 
-    hs->number_of_packets++;
-
     /* For common channels, just update global counters */
-    switch (si->rnti_type) {
+    switch (si->rntiType) {
         case P_RNTI:
             common_stats.pch_frames++;
             common_stats.pch_bytes += si->single_number_of_bytes;
@@ -293,19 +289,27 @@ mac_lte_stat_packet(void *phs, packet_info *pinfo, epan_dissect_t *edt _U_,
             common_stats.bch_frames++;
             common_stats.bch_bytes += si->single_number_of_bytes;
             return 1;
+        case RA_RNTI:
+            common_stats.rar_frames++;
+            common_stats.rar_entries += si->number_of_rars;
+            return 1;
+        case C_RNTI:
+            /* Drop through for per-UE update */
+            break;
 
         default:
-            break;
+            return 0;
     }
 
-
     /* For per-UE data, must create a new row if none already existing */
     if (!hs->ep_list) {
+        /* Allocate new list */
         hs->ep_list = alloc_mac_lte_ep(si, pinfo);
+        /* Make it the first/only entry */
         te = hs->ep_list;
     } else {
         /* Look among existing rows for this RNTI */
-        for (tmp = hs->ep_list; tmp; tmp = tmp->next) {
+        for (tmp = hs->ep_list;(tmp != NULL); tmp = tmp->next) {
             if (tmp->stats.rnti == si->rnti) {
                 te = tmp;
                 break;
@@ -313,7 +317,7 @@ mac_lte_stat_packet(void *phs, packet_info *pinfo, epan_dissect_t *edt _U_,
         }
 
         /* Not found among existing, so create a new one anyway */
-        if (!te) {
+        if (te == NULL) {
             if ((te = alloc_mac_lte_ep(si, pinfo))) {
                 /* New item is head of list */
                 te->next = hs->ep_list;
@@ -328,9 +332,18 @@ mac_lte_stat_packet(void *phs, packet_info *pinfo, epan_dissect_t *edt _U_,
     }
 
     /* Update entry with details from si */
-    te->number_of_packets++;
     te->stats.rnti = si->rnti;
-    te->stats.is_predefined_data = si->is_predefined_data;
+    te->stats.is_predefined_data = si->isPredefinedData;
+    if (si->crcStatusValid && !si->crcStatus) {
+        if (si->direction == DIRECTION_UPLINK) {
+            te->stats.UL_CRC_errors++;
+            return 1;
+        }
+        else {
+            te->stats.DL_CRC_errors++;
+            return 1;
+        }
+    }
 
     /* Uplink */
     if (si->direction == DIRECTION_UPLINK) {
@@ -340,7 +353,7 @@ mac_lte_stat_packet(void *phs, packet_info *pinfo, epan_dissect_t *edt _U_,
         }
         te->stats.UL_frames++;
 
-        if (si->is_predefined_data) {
+        if (si->isPredefinedData) {
             te->stats.UL_total_bytes += si->single_number_of_bytes;
         }
         else {
@@ -363,7 +376,7 @@ mac_lte_stat_packet(void *phs, packet_info *pinfo, epan_dissect_t *edt _U_,
 
         te->stats.DL_frames++;
 
-        if (si->is_predefined_data) {
+        if (si->isPredefinedData) {
             te->stats.DL_total_bytes += si->single_number_of_bytes;
         }
         else {
@@ -381,86 +394,86 @@ mac_lte_stat_packet(void *phs, packet_info *pinfo, epan_dissect_t *edt _U_,
 }
 
 
-static void invalidate_ues_iters(mac_lte_stat_t *hs)
-{
-    mac_lte_ep_t *ep = hs->ep_list;
-    mac_lte_ep_t *d_ep;
-
-    /* Set 'valid' pointer in each entry in list of FALSE */
-    while (ep) {
-        d_ep = ep;
-        while (d_ep) {
-            d_ep->iter_valid = FALSE;
-            d_ep = d_ep->next;
-        }
-        ep = ep->next;
-    }
-}
-
-
 /* Draw the UE details table according to the current UE selection */
 static void
-mac_lte_ue_details(mac_lte_stat_t *hs _U_, mac_lte_ep_t *mac_stat_ep _U_, gboolean clear _U_)
+mac_lte_ue_details(mac_lte_ep_t *mac_stat_ep)
 {
     int n;
     gchar buff[32];
 
-    /* Clear details if necessary */
-    if (clear) {
-        invalidate_ues_iters(hs);
-    }
-
-
     /**********************************/
     /* Set data one row at a time     */
 
     /* UL SDUs */
     for (n=0; n < PREDEFINED_COLUMN-1; n++) {
-        g_snprintf(buff, sizeof(buff), "%u", mac_stat_ep->stats.UL_sdus_for_lcid[n]);
+        g_snprintf(buff, sizeof(buff), "%u", mac_stat_ep ? mac_stat_ep->stats.UL_sdus_for_lcid[n] : 0);
          gtk_label_set_text(GTK_LABEL(selected_ue_column_entry[n+1][1]), buff);
     }
 
     /* Predefined */
-    g_snprintf(buff, sizeof(buff), "%u", mac_stat_ep->stats.is_predefined_data ?
-                                             mac_stat_ep->stats.UL_frames :
-                                             0);
+    if (mac_stat_ep) {
+        g_snprintf(buff, sizeof(buff), "%u", mac_stat_ep->stats.is_predefined_data ?
+                                                 mac_stat_ep->stats.UL_frames :
+                                                 0);
+    }
+    else {
+        g_snprintf(buff, sizeof(buff), "%u", 0);
+    }
     gtk_label_set_text(GTK_LABEL(selected_ue_column_entry[PREDEFINED_COLUMN][1]), buff);
 
 
     /* UL Bytes */
     for (n=0; n < PREDEFINED_COLUMN-1; n++) {
-        g_snprintf(buff, sizeof(buff), "%u", mac_stat_ep->stats.UL_bytes_for_lcid[n]);
-         gtk_label_set_text(GTK_LABEL(selected_ue_column_entry[n+1][2]), buff);
+        g_snprintf(buff, sizeof(buff), "%u",
+            (mac_stat_ep) ? mac_stat_ep->stats.UL_bytes_for_lcid[n] : 0);
+        gtk_label_set_text(GTK_LABEL(selected_ue_column_entry[n+1][2]), buff);
     }
 
     /* Predefined */
-    g_snprintf(buff, sizeof(buff), "%u", mac_stat_ep->stats.is_predefined_data ?
-                                             mac_stat_ep->stats.UL_total_bytes :
-                                             0);
+    if (mac_stat_ep) {
+        g_snprintf(buff, sizeof(buff), "%u", mac_stat_ep->stats.is_predefined_data ?
+                                                 mac_stat_ep->stats.UL_total_bytes :
+                                                 0);
+    }
+    else {
+        g_snprintf(buff, sizeof(buff), "%u", 0);
+    }
     gtk_label_set_text(GTK_LABEL(selected_ue_column_entry[PREDEFINED_COLUMN][2]), buff);
 
 
     /* DL SDUs */
     for (n=0; n < PREDEFINED_COLUMN-1; n++) {
-        g_snprintf(buff, sizeof(buff), "%u", mac_stat_ep->stats.DL_sdus_for_lcid[n]);
-         gtk_label_set_text(GTK_LABEL(selected_ue_column_entry[n+1][3]), buff);
+        g_snprintf(buff, sizeof(buff), "%u",
+                   mac_stat_ep ? mac_stat_ep->stats.DL_sdus_for_lcid[n] : 0);
+        gtk_label_set_text(GTK_LABEL(selected_ue_column_entry[n+1][3]), buff);
     }
     /* Predefined */
-    g_snprintf(buff, sizeof(buff), "%u", mac_stat_ep->stats.is_predefined_data ?
-                                             mac_stat_ep->stats.DL_frames :
-                                             0);
+    if (mac_stat_ep) {
+        g_snprintf(buff, sizeof(buff), "%u", mac_stat_ep->stats.is_predefined_data ?
+                                                 mac_stat_ep->stats.DL_frames :
+                                                 0);
+    }
+    else {
+        g_snprintf(buff, sizeof(buff), "%u", 0);
+    }
     gtk_label_set_text(GTK_LABEL(selected_ue_column_entry[PREDEFINED_COLUMN][3]), buff);
 
 
     /* DL Bytes */
     for (n=0; n < PREDEFINED_COLUMN-1; n++) {
-        g_snprintf(buff, sizeof(buff), "%u", mac_stat_ep->stats.DL_bytes_for_lcid[n]);
-         gtk_label_set_text(GTK_LABEL(selected_ue_column_entry[n+1][4]), buff);
+        g_snprintf(buff, sizeof(buff), "%u",
+                   mac_stat_ep ? mac_stat_ep->stats.DL_bytes_for_lcid[n] : 0);
+        gtk_label_set_text(GTK_LABEL(selected_ue_column_entry[n+1][4]), buff);
     }
     /* Predefined */
-    g_snprintf(buff, sizeof(buff), "%u", mac_stat_ep->stats.is_predefined_data ?
-                                             mac_stat_ep->stats.DL_total_bytes :
-                                             0);
+    if (mac_stat_ep) {
+        g_snprintf(buff, sizeof(buff), "%u", mac_stat_ep->stats.is_predefined_data ?
+                                                 mac_stat_ep->stats.DL_total_bytes :
+                                                 0);
+    }
+    else {
+        g_snprintf(buff, sizeof(buff), "%u", 0);
+    }
     gtk_label_set_text(GTK_LABEL(selected_ue_column_entry[PREDEFINED_COLUMN][4]), buff);
 }
 
@@ -470,7 +483,9 @@ mac_lte_ue_details(mac_lte_stat_t *hs _U_, mac_lte_ep_t *mac_stat_ep _U_, gboole
 static void
 mac_lte_stat_draw(void *phs)
 {
-    char buff[32];
+    gchar   buff[32];
+    guint16 number_of_ues = 0;
+    gchar title[256];
 
     /* Look up the statistics window */
     mac_lte_stat_t *hs = (mac_lte_stat_t *)phs;
@@ -483,21 +498,31 @@ mac_lte_stat_draw(void *phs)
 
     /* Common channel data */
     g_snprintf(buff, sizeof(buff), "BCH Frames: %u", common_stats.bch_frames);
-     gtk_label_set_text(GTK_LABEL(mac_lte_common_bch_frames), buff);
+    gtk_label_set_text(GTK_LABEL(mac_lte_common_bch_frames), buff);
     g_snprintf(buff, sizeof(buff), "BCH Bytes: %u", common_stats.bch_bytes);
-     gtk_label_set_text(GTK_LABEL(mac_lte_common_bch_bytes), buff);
+    gtk_label_set_text(GTK_LABEL(mac_lte_common_bch_bytes), buff);
     g_snprintf(buff, sizeof(buff), "PCH Frames: %u", common_stats.pch_frames);
-     gtk_label_set_text(GTK_LABEL(mac_lte_common_pch_frames), buff);
+    gtk_label_set_text(GTK_LABEL(mac_lte_common_pch_frames), buff);
     g_snprintf(buff, sizeof(buff), "PCH Bytes: %u", common_stats.pch_bytes);
-     gtk_label_set_text(GTK_LABEL(mac_lte_common_pch_bytes), buff);
+    gtk_label_set_text(GTK_LABEL(mac_lte_common_pch_bytes), buff);
+    g_snprintf(buff, sizeof(buff), "RAR Frames: %u", common_stats.rar_frames);
+    gtk_label_set_text(GTK_LABEL(mac_lte_common_rar_frames), buff);
+    g_snprintf(buff, sizeof(buff), "RAR Entries: %u", common_stats.rar_entries);
+    gtk_label_set_text(GTK_LABEL(mac_lte_common_rar_entries), buff);
+
 
     /* Per-UE table entries */
     ues_store = GTK_LIST_STORE(gtk_tree_view_get_model(hs->ue_table));
-    hs->num_entries = 0;
 
-    /* For each row/UE/C-RNTI */
+    /* Set title that shows how many UEs currently in table */
+    for (tmp = list; (tmp!=NULL); tmp=tmp->next, number_of_ues++);
+    g_snprintf(title, sizeof(title), "UL/DL-SCH data (%u UEs)", number_of_ues);
+    gtk_frame_set_label(GTK_FRAME(mac_lte_stat_ues_lb), title);
+
+    /* For each row/UE/C-RNTI in the model */
     for (tmp = list; tmp; tmp=tmp->next) {
         if (tmp->iter_valid != TRUE) {
+            /* Add to list control if not drawn this UE before */
             gtk_list_store_append(ues_store, &tmp->iter);
             tmp->iter_valid = TRUE;
         }
@@ -507,14 +532,14 @@ mac_lte_stat_draw(void *phs)
                            RNTI_COLUMN, tmp->stats.rnti,
                            UL_FRAMES_COLUMN, tmp->stats.UL_frames,
                            UL_BYTES_COLUMN, tmp->stats.UL_total_bytes,
+                           UL_CRC_ERRORS_COLUMN, tmp->stats.UL_CRC_errors,
                            UL_RETX_FRAMES_COLUMN, tmp->stats.UL_retx_frames,
                            DL_FRAMES_COLUMN, tmp->stats.DL_frames,
                            DL_BYTES_COLUMN, tmp->stats.DL_total_bytes,
+                           DL_CRC_ERRORS_COLUMN, tmp->stats.DL_CRC_errors,
                            DL_RETX_FRAMES_COLUMN, tmp->stats.DL_retx_frames,
                            TABLE_COLUMN, tmp,
                            -1);
-
-        hs->num_entries++;
     }
 
     /* If there is a UE selected, update its counters in details window */
@@ -523,15 +548,14 @@ mac_lte_stat_draw(void *phs)
         mac_lte_ep_t *ep;
 
         gtk_tree_model_get(model, &iter, TABLE_COLUMN, &ep, -1);
-        mac_lte_ue_details(hs, ep, FALSE);
+        mac_lte_ue_details(ep);
     }
 }
 
 
 /* What to do when a list item is selected/unselected */
-static void mac_lte_select_cb(GtkTreeSelection *sel, gpointer data)
+static void mac_lte_select_cb(GtkTreeSelection *sel, gpointer data _U_)
 {
-    mac_lte_stat_t *hs = (mac_lte_stat_t *)data;
     mac_lte_ep_t   *ep;
     GtkTreeModel   *model;
     GtkTreeIter    iter;
@@ -539,7 +563,10 @@ static void mac_lte_select_cb(GtkTreeSelection *sel, gpointer data)
     if (gtk_tree_selection_get_selected(sel, &model, &iter)) {
         /* Show details of selected UE */
         gtk_tree_model_get(model, &iter, TABLE_COLUMN, &ep, -1);
-        mac_lte_ue_details(hs, ep, TRUE);
+        mac_lte_ue_details(ep);
+    }
+    else {
+        mac_lte_ue_details(NULL);
     }
 }
 
@@ -588,14 +615,12 @@ static void mac_lte_stat_dlg_create(void)
     GtkCellRenderer   *renderer;
     GtkTreeViewColumn *column;
     GtkTreeSelection  *sel;
-    char title[256];
+    gchar title[256];
     gint i, n;
 
     /* Create dialog */
     hs = g_malloc(sizeof(mac_lte_stat_t));
-    hs->num_entries = 0;
     hs->ep_list = NULL;
-    hs->number_of_packets = 0;
 
     /* Set title */
     g_snprintf(title, sizeof(title), "Wireshark: LTE MAC Statistics: %s",
@@ -646,12 +671,21 @@ static void mac_lte_stat_dlg_create(void)
     gtk_container_add(GTK_CONTAINER(common_row_hbox), mac_lte_common_pch_bytes);
     gtk_widget_show(mac_lte_common_pch_bytes);
 
+    mac_lte_common_rar_frames = gtk_label_new("RAR Frames:");
+    gtk_misc_set_alignment(GTK_MISC(mac_lte_common_rar_frames), 0.0f, .5f);
+    gtk_container_add(GTK_CONTAINER(common_row_hbox), mac_lte_common_rar_frames);
+    gtk_widget_show(mac_lte_common_rar_frames);
+
+    mac_lte_common_rar_entries = gtk_label_new("RAR Entries:");
+    gtk_misc_set_alignment(GTK_MISC(mac_lte_common_rar_entries), 0.0f, .5f);
+    gtk_container_add(GTK_CONTAINER(common_row_hbox), mac_lte_common_rar_entries);
+    gtk_widget_show(mac_lte_common_rar_entries);
 
     /**********************************************/
     /* UL/DL-SCH data                             */
     /**********************************************/
 
-    mac_lte_stat_ues_lb = gtk_frame_new("UL/DL-SCH Data");
+    mac_lte_stat_ues_lb = gtk_frame_new("UL/DL-SCH Data (0 UEs)");
     ues_vb = gtk_vbox_new(FALSE, 0);
     gtk_container_add(GTK_CONTAINER(mac_lte_stat_ues_lb), ues_vb);
     gtk_container_set_border_width(GTK_CONTAINER(ues_vb), 5);
@@ -663,8 +697,8 @@ static void mac_lte_stat_dlg_create(void)
 
     /* Create the table of UE data */
     store = gtk_list_store_new(NUM_UE_COLUMNS, G_TYPE_INT,
-                               G_TYPE_INT, G_TYPE_INT, G_TYPE_INT,  /* UL */
-                               G_TYPE_INT, G_TYPE_INT, G_TYPE_INT,  /* DL */
+                               G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT,  /* UL */
+                               G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT,  /* DL */
                                G_TYPE_POINTER);
     hs->ue_table = GTK_TREE_VIEW(tree_view_new(GTK_TREE_MODEL(store)));
     gtk_container_add(GTK_CONTAINER (ues_scrolled_window), GTK_WIDGET(hs->ue_table));
