@@ -1,7 +1,7 @@
 /* proto_draw.c
  * Routines for GTK+ packet display
  *
- * $Id: main_proto_draw.c 28662 2009-06-08 15:37:46Z gerald $
+ * $Id: main_proto_draw.c 33715 2010-08-05 16:37:41Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -646,7 +646,7 @@ add_byte_views(epan_dissect_t *edt, GtkWidget *tree_view,
 	 */
 	for (src_le = edt->pi.data_src; src_le != NULL; src_le = src_le->next) {
 		src = src_le->data;
-		add_byte_tab(byte_nb_ptr, src->name, src->tvb, edt->tree,
+		add_byte_tab(byte_nb_ptr, get_data_source_name(src), src->tvb, edt->tree,
                              tree_view);
 	}
 
@@ -1032,7 +1032,7 @@ packet_hex_print_common(GtkWidget *bv, const guint8 *pd, int len, int bstart,
   unsigned int   use_digits;
   gboolean       reverse, newreverse;
   GtkTextView   *bv_text_view = GTK_TEXT_VIEW(bv);
-  GtkTextBuffer *buf = gtk_text_view_get_buffer(bv_text_view);
+  GtkTextBuffer *buf;
   GtkTextIter    iter;
   const char    *revstyle;
   GtkTextMark   *mark = NULL;
@@ -1045,10 +1045,28 @@ packet_hex_print_common(GtkWidget *bv, const guint8 *pd, int len, int bstart,
   int         progbar_nextstep;
   int         progbar_quantum;
 
+  buf = gtk_text_view_get_buffer(bv_text_view);
+  g_object_ref(buf);
+#if 0
+  gtk_text_view_set_buffer( bv_text_view, NULL);       /* XXX: Apparently not a good idea; If a progress_bar
+                                                        *      is displayed below in delayed_create_progress_dlg()
+                                                        *      there will then be a crash internally in the gtk library.
+                                                        *      (It appears that gtk_text_view_set_buffer
+                                                        *       queues a callback to be run when this
+                                                        *       thread is next idle. Unfortunately the call to
+                                                        *       gtk_main_iteration() in delayed_create_progress_dlg()
+                                                        *       causes the internal callback to be run which then 
+                                                        *       crashes (because the textview has no buffer ?))
+                                                        */  
+#endif
+  gtk_text_view_set_buffer( bv_text_view,
+                            gtk_text_buffer_new(NULL));/* attach a dummy buffer in place of the real buffer.
+                                                        * (XXX: Presumably this is done so there's no attempt
+                                                        *       to display the real buffer until it has been
+                                                        *       completely generated).
+                                                        */
   gtk_text_buffer_set_text(buf, "", 0);
   gtk_text_buffer_get_start_iter(buf, &iter);
-  g_object_ref(buf);
-  gtk_text_view_set_buffer( bv_text_view, NULL);
 
   /*
    * How many of the leading digits of the offset will we supply?
