@@ -1,6 +1,6 @@
 /* main_welcome.c
  *
- * $Id: main_welcome.c 31539 2010-01-16 01:02:51Z gerald $
+ * $Id: main_welcome.c 32223 2010-03-17 19:14:44Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -218,7 +218,7 @@ welcome_button(const gchar *stock_item,
 
     g_signal_connect(eb, "enter-notify-event", G_CALLBACK(welcome_item_enter_cb), NULL);
     g_signal_connect(eb, "leave-notify-event", G_CALLBACK(welcome_item_leave_cb), NULL);
-    g_signal_connect(eb, "button-press-event", G_CALLBACK(callback), callback_data);
+    g_signal_connect(eb, "button-release-event", G_CALLBACK(callback), callback_data);
 
     /* icon */
     w = gtk_image_new_from_stock(stock_item, GTK_ICON_SIZE_LARGE_TOOLBAR);
