@@ -2,7 +2,7 @@
  * mgcp-statistics for Wireshark
  * Copyright 2003 Lars Roland
  *
- * $Id: mgcp_stat.c 23715 2007-12-03 21:41:06Z gerald $
+ * $Id: mgcp_stat.c 29099 2009-07-15 00:10:08Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -38,24 +38,21 @@
 #include <epan/packet_info.h>
 #include <epan/epan.h>
 #include <epan/value_string.h>
-
 #include <epan/tap.h>
+#include "epan/dissectors/packet-mgcp.h"
+
 #include "../register.h"
-#include "../epan/dissectors/packet-mgcp.h"
 #include "../timestats.h"
-#include "gui_stat_util.h"
-#include "compat_macros.h"
 #include "../simple_dialog.h"
-#include "dlg_utils.h"
 #include "../file.h"
 #include "../globals.h"
 #include "../stat_menu.h"
-#include "../tap_dfilter_dlg.h"
-#include "gui_utils.h"
 
-#ifdef NEED_G_ASCII_STRCASECMP_H
-#include "../epan/g_ascii_strcasecmp.h"
-#endif
+#include "gtk/gui_stat_util.h"
+#include "gtk/dlg_utils.h"
+#include "gtk/tap_dfilter_dlg.h"
+#include "gtk/gui_utils.h"
+#include "gtk/main.h"
 
 
 #define NUM_TIMESTATS 10
@@ -118,6 +115,7 @@ mgcpstat_packet(void *pms, packet_info *pinfo, epan_dissect_t *edt _U_, const vo
 	mgcpstat_t *ms=(mgcpstat_t *)pms;
 	const mgcp_info_t *mi=pmi;
 	nstime_t delta;
+	int ret = 0;
 
 	switch (mi->mgcp_type) {
 
@@ -125,24 +123,20 @@ mgcpstat_packet(void *pms, packet_info *pinfo, epan_dissect_t *edt _U_, const vo
 		if(mi->is_duplicate){
 			/* Duplicate is ignored */
 			ms->req_dup_num++;
-			return 0;
 		}
 		else {
 			ms->open_req_num++;
-			return 0;
 		}
-	break;
+		break;
 
 	case MGCP_RESPONSE:
 		if(mi->is_duplicate){
 			/* Duplicate is ignored */
 			ms->rsp_dup_num++;
-			return 0;
 		}
 		else if (!mi->request_available) {
 			/* no request was seen */
 			ms->disc_rsp_num++;
-			return 0;
 		}
 		else {
 			ms->open_req_num--;
@@ -180,14 +174,15 @@ mgcpstat_packet(void *pms, packet_info *pinfo, epan_dissect_t *edt _U_, const vo
 				time_stat_update(&(ms->rtd[9]),&delta, pinfo);
 			}
 
-			return 1;
+			ret = 1;
 		}
-	break;
+		break;
 
 	default:
-		return 0;
-	break;
+		break;
 	}
+
+	return ret;
 }
 
 static void
@@ -195,7 +190,6 @@ mgcpstat_draw(void *pms)
 {
 	mgcpstat_t *ms=(mgcpstat_t *)pms;
 	int i;
-	/* gtk1 using a scrollable clist*/
 	char *str[7];
 
 	for(i=0;i<7;i++) {
@@ -211,13 +205,13 @@ mgcpstat_draw(void *pms)
 			continue;
 		}
 
-		g_snprintf(str[0], 256, "%s", val_to_str(i,mgcp_mesage_type,"Other"));
-		g_snprintf(str[1], 256, "%d", ms->rtd[i].num);
-		g_snprintf(str[2], 256, "%8.2f msec", nstime_to_msec(&(ms->rtd[i].min)));
-		g_snprintf(str[3], 256, "%8.2f msec", nstime_to_msec(&(ms->rtd[i].max)));
-		g_snprintf(str[4], 256, "%8.2f msec", get_average(&(ms->rtd[i].tot), ms->rtd[i].num));
-		g_snprintf(str[5], 256, "%6u", ms->rtd[i].min_num);
-		g_snprintf(str[6], 256, "%6u", ms->rtd[i].max_num);
+		g_snprintf(str[0], sizeof(char[256]), "%s", val_to_str(i,mgcp_mesage_type,"Other"));
+		g_snprintf(str[1], sizeof(char[256]), "%d", ms->rtd[i].num);
+		g_snprintf(str[2], sizeof(char[256]), "%8.2f msec", nstime_to_msec(&(ms->rtd[i].min)));
+		g_snprintf(str[3], sizeof(char[256]), "%8.2f msec", nstime_to_msec(&(ms->rtd[i].max)));
+		g_snprintf(str[4], sizeof(char[256]), "%8.2f msec", get_average(&(ms->rtd[i].tot), ms->rtd[i].num));
+		g_snprintf(str[5], sizeof(char[256]), "%6u", ms->rtd[i].min_num);
+		g_snprintf(str[6], sizeof(char[256]), "%6u", ms->rtd[i].max_num);
 		gtk_clist_append(ms->table, str);
 	}
 
@@ -227,8 +221,6 @@ mgcpstat_draw(void *pms)
 	}
 }
 
-void protect_thread_critical_region(void);
-void unprotect_thread_critical_region(void);
 static void
 win_destroy_cb(GtkWindow *win _U_, gpointer data)
 {
@@ -274,22 +266,23 @@ gtk_mgcpstat_init(const char *optarg, void *userdata _U_)
 
 	mgcpstat_reset(ms);
 
-	ms->win=window_new(GTK_WINDOW_TOPLEVEL, "MGCP SRT");
+	ms->win = dlg_window_new("MGCP SRT");  /* transient_for top_level */
+	gtk_window_set_destroy_with_parent (GTK_WINDOW(ms->win), TRUE);
+
 	gtk_window_set_default_size(GTK_WINDOW(ms->win), 550, 150);
 
 	ms->vbox=gtk_vbox_new(FALSE, 3);
 
 	init_main_stat_window(ms->win, ms->vbox, "MGCP Service Response Time (SRT) Statistics", filter);
 
-	/* GTK1 using a scrollable clist*/
-        /* init a scrolled window*/
+	/* init a scrolled window*/
 	ms->scrolled_window = scrolled_window_new(NULL, NULL);
 
 	ms->table = create_stat_table(ms->scrolled_window, ms->vbox, 7, titles);
 
 	error_string=register_tap_listener("mgcp", ms, filter, mgcpstat_reset, mgcpstat_packet, mgcpstat_draw);
 	if(error_string){
-		simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, error_string->str);
+		simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "%s", error_string->str);
 		g_string_free(error_string, TRUE);
 		g_free(ms->filter);
 		g_free(ms);
@@ -300,16 +293,17 @@ gtk_mgcpstat_init(const char *optarg, void *userdata _U_)
 	bbox = dlg_button_row_new(GTK_STOCK_CLOSE, NULL);
 	gtk_box_pack_start(GTK_BOX(ms->vbox), bbox, FALSE, FALSE, 0);
 
-	bt_close = OBJECT_GET_DATA(bbox, GTK_STOCK_CLOSE);
+	bt_close = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_CLOSE);
 	window_set_cancel_button(ms->win, bt_close, window_cancel_button_cb);
 
-	SIGNAL_CONNECT(ms->win, "delete_event", window_delete_event_cb, NULL);
-	SIGNAL_CONNECT(ms->win, "destroy", win_destroy_cb, ms);
+	g_signal_connect(ms->win, "delete_event", G_CALLBACK(window_delete_event_cb), NULL);
+	g_signal_connect(ms->win, "destroy", G_CALLBACK(win_destroy_cb), ms);
 
 	gtk_widget_show_all(ms->win);
 	window_present(ms->win);
-	
+
 	cf_retap_packets(&cfile, FALSE);
+	gdk_window_raise(ms->win->window);
 }
 
 static tap_dfilter_dlg mgcp_srt_dlg = {
