@@ -3,7 +3,7 @@
  *
  * Copyright 2000, Jeffrey C. Foster <jfoste@woodward.com>
  *
- * $Id: packet_win.c 24513 2008-03-01 10:23:57Z tuexen $
+ * $Id: packet_win.c 32655 2010-05-04 00:20:39Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -44,29 +44,28 @@
 #include <string.h>
 
 #include <epan/epan.h>
-#include "main.h"
 #include <epan/timestamp.h>
 #include <epan/packet.h>
-#include "summary.h"
-#include "file.h"
 #include <epan/prefs.h>
-#include "menu.h"
-#include "../menu.h"
 #include <epan/column.h>
-#include "print.h"
 #include <epan/addr_resolv.h>
-#include "packet_win.h"
-#include "simple_dialog.h"
-#include "proto_draw.h"
-#include "keys.h"
-#include "gtkglobals.h"
-#include "gui_utils.h"
 #include <epan/plugins.h>
 #include <epan/epan_dissect.h>
-#include "compat_macros.h"
 #include <epan/strutil.h>
 
+#include "../file.h"
+#include "../print.h"
+#include "../simple_dialog.h"
 #include "../ui_util.h"
+#include "../summary.h"
+
+#include "gtk/main.h"
+#include "gtk/packet_win.h"
+#include "gtk/main_proto_draw.h"
+#include "gtk/keys.h"
+#include "gtk/gtkglobals.h"
+#include "gtk/gui_utils.h"
+
 
 /* Data structure holding information about a packet-detail window. */
 struct PacketWinData {
@@ -84,20 +83,42 @@ struct PacketWinData {
 /* List of all the packet-detail windows popped up. */
 static GList *detail_windows;
 
-#if GTK_MAJOR_VERSION < 2
-static void new_tree_view_select_row_cb(GtkCTree *ctree, GList *node,
-                                        gint column, gpointer user_data);
-
-static void new_tree_view_unselect_row_cb( GtkCTree *ctree, GList *node,
-                                           gint column, gpointer user_data);
-#else
 static void new_tree_view_selection_changed_cb(GtkTreeSelection *sel,
                                                gpointer user_data);
 
-#endif
 
 static void destroy_new_window(GtkObject *object, gpointer user_data);
 
+static gint
+button_press_handler(GtkWidget *widget, GdkEvent *event, gpointer data _U_)
+{
+  if (widget == NULL || event == NULL) {
+    return FALSE;
+  }
+
+  tree_view_select(widget, (GdkEventButton *) event);
+
+  /* GDK_2BUTTON_PRESS is a doubleclick -> expand/collapse tree row */
+  if (event->type == GDK_2BUTTON_PRESS) {
+    GtkTreePath      *path;
+
+    if (gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(widget),
+				      (gint) (((GdkEventButton *)event)->x),
+				      (gint) (((GdkEventButton *)event)->y),
+				      &path, NULL, NULL, NULL))
+    {
+      if (gtk_tree_view_row_expanded(GTK_TREE_VIEW(widget), path)) {
+	gtk_tree_view_collapse_row(GTK_TREE_VIEW(widget), path);
+      }	else {
+	gtk_tree_view_expand_row(GTK_TREE_VIEW(widget), path, FALSE);
+      }
+      gtk_tree_path_free(path);
+    }
+  }
+
+  return FALSE;
+}
+
 void new_window_cb(GtkWidget *w _U_)
 {
 #define NewWinTitleLen 1000
@@ -110,6 +131,11 @@ void new_window_cb(GtkWidget *w _U_)
   struct PacketWinData *DataPtr;
   int i;
 
+  if (!cfile.current_frame) {
+    /* nothing has been captured so far */
+    return;
+  }
+
   /* Allocate data structure to represent this window. */
   DataPtr = (struct PacketWinData *) g_malloc(sizeof(struct PacketWinData));
 
@@ -139,27 +165,26 @@ void new_window_cb(GtkWidget *w _U_)
 
   /* Container for paned windows  */
   main_vbox = gtk_vbox_new(FALSE, 1);
-  gtk_container_border_width(GTK_CONTAINER(main_vbox), 1);
+  gtk_container_set_border_width(GTK_CONTAINER(main_vbox), 1);
   gtk_container_add(GTK_CONTAINER(main_w), main_vbox);
   gtk_widget_show(main_vbox);
 
   /* Panes for the tree and byte view */
   pane = gtk_vpaned_new();
-  gtk_paned_gutter_size(GTK_PANED(pane), (GTK_PANED(pane))->handle_size);
   gtk_container_add(GTK_CONTAINER(main_vbox), pane);
   gtk_widget_show(pane);
 
   /* Tree view */
   tv_scrollw = main_tree_view_new(&prefs, &tree_view);
   gtk_paned_pack1(GTK_PANED(pane), tv_scrollw, TRUE, TRUE);
-  WIDGET_SET_SIZE(tv_scrollw, -1, tv_size);
+  gtk_widget_set_size_request(tv_scrollw, -1, tv_size);
   gtk_widget_show(tv_scrollw);
   gtk_widget_show(tree_view);
 
   /* Byte view */
   bv_nb_ptr = byte_view_new();
   gtk_paned_pack2(GTK_PANED(pane), bv_nb_ptr, FALSE, FALSE);
-  WIDGET_SET_SIZE(bv_nb_ptr, -1, bv_size);
+  gtk_widget_set_size_request(bv_nb_ptr, -1, bv_size);
   gtk_widget_show(bv_nb_ptr);
 
   DataPtr->main = main_w;
@@ -169,18 +194,10 @@ void new_window_cb(GtkWidget *w _U_)
   detail_windows = g_list_append(detail_windows, DataPtr);
 
   /* load callback handlers */
-#if GTK_MAJOR_VERSION < 2
-  SIGNAL_CONNECT(tree_view, "tree-select-row", new_tree_view_select_row_cb,
-                 DataPtr);
-
-  SIGNAL_CONNECT(tree_view, "tree-unselect-row", new_tree_view_unselect_row_cb,
-                 DataPtr);
-#else
-  SIGNAL_CONNECT(gtk_tree_view_get_selection(GTK_TREE_VIEW(tree_view)),
-                 "changed", new_tree_view_selection_changed_cb, DataPtr);
-#endif
-
-  SIGNAL_CONNECT(main_w, "destroy", destroy_new_window, DataPtr);
+  g_signal_connect(gtk_tree_view_get_selection(GTK_TREE_VIEW(tree_view)),
+                 "changed", G_CALLBACK(new_tree_view_selection_changed_cb), DataPtr);
+  g_signal_connect(tree_view, "button_press_event", G_CALLBACK(button_press_handler), NULL);
+  g_signal_connect(main_w, "destroy", G_CALLBACK(destroy_new_window), DataPtr);
 
   /* draw the protocol tree & print hex data */
   add_byte_views(DataPtr->edt, tree_view, DataPtr->bv_nb_ptr);
@@ -201,60 +218,6 @@ destroy_new_window(GtkObject *object _U_, gpointer user_data)
   g_free(DataPtr);
 }
 
-#if GTK_MAJOR_VERSION < 2
-/* called when a tree row is selected in the popup packet window */
-static void
-new_tree_view_select_row_cb(GtkCTree *ctree, GList *node, gint column _U_,
-                            gpointer user_data)
-{
-	field_info *finfo;
-	GtkWidget *byte_view;
-	const guint8 *data;
-	guint len;
-
-	struct PacketWinData *DataPtr = (struct PacketWinData*)user_data;
-
-	g_assert(node);
-	finfo = gtk_ctree_node_get_row_data( ctree, GTK_CTREE_NODE(node) );
-	if (!finfo) return;
-
-	set_notebook_page(DataPtr->bv_nb_ptr, finfo->ds_tvb);
-	byte_view = get_notebook_bv_ptr(DataPtr->bv_nb_ptr);
-	if ( !byte_view)	/* exit if no hex window to write in */
-		return;
-
-	data = get_byte_view_data_and_length(byte_view, &len);
-	if (data == NULL) {
-                data = DataPtr->pd;
-                len =  DataPtr->frame->cap_len;
-        }
-
-	DataPtr->finfo_selected = finfo;
-	packet_hex_print(byte_view, data, DataPtr->frame, finfo, len);
-}
-
-/* called when a tree row is unselected in the popup packet window */
-static void
-new_tree_view_unselect_row_cb(GtkCTree *ctree _U_, GList *node _U_,
-                              gint column _U_, gpointer user_data)
-{
-	GtkWidget* byte_view;
-	const guint8* data;
-	guint len;
-
-	struct PacketWinData *DataPtr = (struct PacketWinData*)user_data;
-
-	DataPtr->finfo_selected = NULL;
-
-	byte_view = get_notebook_bv_ptr(DataPtr->bv_nb_ptr);
-	if ( !byte_view)	/* exit if no hex window to write in */
-		return;
-
-	data = get_byte_view_data_and_length(byte_view, &len);
-	g_assert(data != NULL);
-	packet_hex_reprint(byte_view);
-}
-#else
 /* called when a tree row is (un)selected in the popup packet window */
 static void
 new_tree_view_selection_changed_cb(GtkTreeSelection *sel, gpointer user_data)
@@ -301,7 +264,6 @@ new_tree_view_selection_changed_cb(GtkTreeSelection *sel, gpointer user_data)
         packet_hex_reprint(byte_view);
     }
 }
-#endif
 
 /* Functions called from elsewhere to act on all popup packet windows. */
 
