@@ -1,7 +1,7 @@
 /* layout_prefs.c
  * Dialog box for layout preferences
  *
- * $Id: prefs_layout.c 27718 2009-03-13 22:06:48Z stig $
+ * $Id: prefs_layout.c 28108 2009-04-21 16:57:52Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -85,7 +85,7 @@ static GtkWidget *layout_content_radio_vbox(GtkWidget *main_vb, GtkTooltips *too
 
     g_snprintf (buf, sizeof(buf), "Pane %d:", i);
     radio_lb = gtk_label_new(buf);
-    gtk_misc_set_alignment(GTK_MISC(radio_lb), 0.0, 0.5);
+    gtk_misc_set_alignment(GTK_MISC(radio_lb), 0.0f, 0.5f);
     gtk_container_add(GTK_CONTAINER(radio_vb), radio_lb);
 
     radio_none_rb = gtk_radio_button_new_with_mnemonic_from_widget(NULL, "None");
