@@ -1,8 +1,8 @@
 /* profile_dlg.h
  * Definitions for dialog box for profiles editing.
- * Stig Bjrlykke <stig@bjorlykke.org>, 2008
+ * Stig Bjorlykke <stig@bjorlykke.org>, 2008
  *
- * $Id: profile_dlg.h 24089 2008-01-14 16:40:23Z stig $
+ * $Id: profile_dlg.h 27677 2009-03-09 15:42:37Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -31,6 +31,12 @@
  * @ingroup dialog_group
  */
 
+/** User requested the "Configuration Profiles" popup menu.
+ *
+ * @param widget parent widget
+ * @param event button event
+ */
+gboolean profile_show_popup_cb(GtkWidget *w _U_, GdkEvent *event);
 
 /** User requested the "Configuration Profiles" dialog box by menu or toolbar.
  *
