@@ -2,7 +2,7 @@
  * Definitions for recent "preference" handling routines
  * Copyright 2004, Ulf Lamping <ulf.lamping@web.de>
  *
- * $Id: recent.h 25477 2008-06-18 18:23:47Z gerald $
+ * $Id: recent.h 25967 2008-08-09 16:12:41Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -39,6 +39,12 @@
 /** ???. */
 #define RECENT_KEY_DISPLAY_FILTER       "recent.display_filter"
 
+typedef struct _col_width_data {
+  gint   cfmt;
+  gchar *cfield;
+  gint   width;
+} col_width_data;
+
 /** Recent settings. */
 typedef struct recent_settings_tag {
     gboolean    main_toolbar_show;
@@ -59,17 +65,19 @@ typedef struct recent_settings_tag {
     gint        gui_geometry_main_width;
     gint        gui_geometry_main_height;
 
-    gboolean    gui_geometry_main_maximized;    /* this is valid in GTK2 only */
+    gboolean    gui_geometry_main_maximized;
 
     gboolean    has_gui_geometry_main_upper_pane;   /* gui_geometry_main_upper_pane is valid */
-    gint        gui_geometry_main_upper_pane;       /* this is autodetected in GTK2 only */
+    gint        gui_geometry_main_upper_pane;
     gboolean    has_gui_geometry_main_lower_pane;   /* gui_geometry_main_lower_pane is valid */
-    gint        gui_geometry_main_lower_pane;       /* this is autodetected in GTK2 only */
+    gint        gui_geometry_main_lower_pane;
     gboolean    has_gui_geometry_status_pane;       /* gui_geometry_status_pane is valid */
-    gint        gui_geometry_status_pane_left;      /* this is autodetected in GTK2 only */
-    gint        gui_geometry_status_pane_right;      /* this is autodetected in GTK2 only */
+    gint        gui_geometry_status_pane_left;
+    gint        gui_geometry_status_pane_right;
+    gint        gui_geometry_wlan_stats_pane;
     gboolean    privs_warn_if_elevated;
     gboolean    privs_warn_if_no_npf;
+    GList      *col_width_list;                     /* column widths */
 } recent_settings_t;
 
 /** Global recent settings. */
@@ -81,6 +89,12 @@ extern recent_settings_t recent;
  */
 extern gboolean write_recent(void);
 
+/** Write profile recent settings file.
+ *
+ * @return TRUE if succeeded, FALSE if failed
+ */
+extern gboolean write_profile_recent(void);
+
 /** Read recent settings file (static part).
  *
  * @param rf_path_return path to recent file if function failed
@@ -88,6 +102,13 @@ extern gboolean write_recent(void);
  */
 extern void recent_read_static(char **rf_path_return, int *rf_errno_return);
 
+/** Read profile recent settings file (static part).
+ *
+ * @param rf_path_return path to recent file if function failed
+ * @param rf_errno_return if failed
+ */
+extern void recent_read_profile_static(char **rf_path_return, int *rf_errno_return);
+
 /** Read recent settings file (dynamic part).
  *
  * @param rf_path_return path to recent file if function failed
@@ -114,4 +135,17 @@ extern void write_recent_geom(gpointer key, gpointer value, gpointer rf);
  */
 extern int recent_set_arg(char *prefarg);
 
+/** Get the column width for the given column
+ * 
+ * @param col column number
+ */
+extern gint recent_get_column_width(gint col);
+
+/** Set the column width for the given column
+ * 
+ * @param col column number
+ * @param width column width
+ */
+extern void recent_set_column_width(gint col, gint width);
+
 #endif /* recent.h */
