@@ -1,7 +1,7 @@
 /* 
  * Copyright 2004, Irene Ruengeler <i.ruengeler [AT] fh-muenster.de>
  *
- * $Id: sctp_assoc_analyse.c 21894 2007-05-22 21:16:30Z tuexen $
+ * $Id: sctp_assoc_analyse.c 30658 2009-10-22 00:15:46Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -25,23 +25,25 @@
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
+#include <string.h>
 
 #include <gtk/gtk.h>
-#include <string.h>  /* for memmove */
-#include "globals.h"
-#include "simple_dialog.h"
+
 #include <epan/epan_dissect.h>
 #include "epan/filesystem.h"
-#include "register.h"
-#include "../stat_menu.h"
-#include "gui_stat_menu.h"
-#include "dlg_utils.h"
-#include "gui_utils.h"
-#include "main.h"
-#include "compat_macros.h"
+#include <epan/strutil.h>
 
-#include "sctp_stat.h"
-#include "gtkglobals.h"
+#include "../globals.h"
+#include "../simple_dialog.h"
+#include "../stat_menu.h"
+#include "../register.h"
+
+#include "gtk/gui_stat_menu.h"
+#include "gtk/dlg_utils.h"
+#include "gtk/gui_utils.h"
+#include "gtk/main.h"
+#include "gtk/sctp_stat.h"
+#include "gtk/gtkglobals.h"
 
 static sctp_assoc_info_t static_assoc;
 
@@ -206,25 +208,25 @@ update_analyse_dlg(struct sctp_analyse* u_data)
 	}
 
 
-	g_snprintf(label_txt, 50,"Checksum Type: %s",u_data->assoc->checksum_type);
+	g_snprintf(label_txt, sizeof(label_txt),"Checksum Type: %s",u_data->assoc->checksum_type);
 	gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->checktype), label_txt);
-	g_snprintf(label_txt, 50,"Checksum Errors: %u",u_data->assoc->n_checksum_errors);
+	g_snprintf(label_txt, sizeof(label_txt),"Checksum Errors: %u",u_data->assoc->n_checksum_errors);
 	gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->checksum), label_txt);
-	g_snprintf(label_txt, 50,"Bundling Errors: %u",u_data->assoc->n_bundling_errors);
+	g_snprintf(label_txt, sizeof(label_txt),"Bundling Errors: %u",u_data->assoc->n_bundling_errors);
 	gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->bundling), label_txt);
-	g_snprintf(label_txt, 50,"Padding Errors: %u",u_data->assoc->n_padding_errors);
+	g_snprintf(label_txt, sizeof(label_txt),"Padding Errors: %u",u_data->assoc->n_padding_errors);
 	gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->padding), label_txt);
-	g_snprintf(label_txt, 50,"Length Errors: %u",u_data->assoc->n_length_errors);
+	g_snprintf(label_txt, sizeof(label_txt),"Length Errors: %u",u_data->assoc->n_length_errors);
 	gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->length), label_txt);
-	g_snprintf(label_txt, 50,"Value Errors: %u",u_data->assoc->n_value_errors);
+	g_snprintf(label_txt, sizeof(label_txt),"Value Errors: %u",u_data->assoc->n_value_errors);
 	gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->value), label_txt);
-	g_snprintf(label_txt, 50,"No of Data Chunks from EP1 to EP2: %u",u_data->assoc->n_data_chunks_ep1);
+	g_snprintf(label_txt, sizeof(label_txt),"No of Data Chunks from EP1 to EP2: %u",u_data->assoc->n_data_chunks_ep1);
 	gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->chunks_ep1), label_txt);
-	g_snprintf(label_txt, 50,"No of Data Bytes from EP1 to EP2: %u",u_data->assoc->n_data_bytes_ep1);
+	g_snprintf(label_txt, sizeof(label_txt),"No of Data Bytes from EP1 to EP2: %u",u_data->assoc->n_data_bytes_ep1);
 	gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->bytes_ep1), label_txt);
-	g_snprintf(label_txt, 50,"No of Data Chunks from EP2 to EP1: %u",u_data->assoc->n_data_chunks_ep2);
+	g_snprintf(label_txt, sizeof(label_txt),"No of Data Chunks from EP2 to EP1: %u",u_data->assoc->n_data_chunks_ep2);
 	gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->chunks_ep2), label_txt);
-	g_snprintf(label_txt, 50,"No of Data Bytes from EP2 to EP1: %u",u_data->assoc->n_data_bytes_ep2);
+	g_snprintf(label_txt, sizeof(label_txt),"No of Data Bytes from EP2 to EP1: %u",u_data->assoc->n_data_bytes_ep2);
 	gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->bytes_ep2), label_txt);
 
 	if (u_data->assoc->init == TRUE)
@@ -260,28 +262,28 @@ update_analyse_dlg(struct sctp_analyse* u_data)
 	{
 		return;
 	}
-	g_snprintf(label_txt, 50,"Port: %u",u_data->assoc->port1);
+	g_snprintf(label_txt, sizeof(label_txt),"Port: %u",u_data->assoc->port1);
 	gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->page2->port), label_txt);
-	g_snprintf(label_txt, 50,"Sent Verification Tag: 0x%x",u_data->assoc->verification_tag1);
+	g_snprintf(label_txt, sizeof(label_txt),"Sent Verification Tag: 0x%x",u_data->assoc->verification_tag1);
 	gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->page2->veritag), label_txt);
 
 	if (u_data->assoc->init == TRUE || (u_data->assoc->initack == TRUE && u_data->assoc->initack_dir == 1))
 	{
-		g_snprintf(label_txt, 50,"Requested Number of Inbound Streams: %u",u_data->assoc->instream1);
+		g_snprintf(label_txt, sizeof(label_txt),"Requested Number of Inbound Streams: %u",u_data->assoc->instream1);
 		gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->page2->max_in), label_txt);
-		g_snprintf(label_txt, 50,"Minimum Number of Inbound Streams: %u",((u_data->assoc->instream1>u_data->assoc->outstream2)?u_data->assoc->outstream2:u_data->assoc->instream1));
+		g_snprintf(label_txt, sizeof(label_txt),"Minimum Number of Inbound Streams: %u",((u_data->assoc->instream1>u_data->assoc->outstream2)?u_data->assoc->outstream2:u_data->assoc->instream1));
 		gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->page2->min_in), label_txt);
 
-		g_snprintf(label_txt, 50,"Provided Number of Outbound Streams: %u",u_data->assoc->outstream1);
+		g_snprintf(label_txt, sizeof(label_txt),"Provided Number of Outbound Streams: %u",u_data->assoc->outstream1);
 		gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->page2->max_out), label_txt);
-		g_snprintf(label_txt, 50,"Minimum Number of Outbound Streams: %u",((u_data->assoc->outstream1>u_data->assoc->instream2)?u_data->assoc->instream2:u_data->assoc->outstream1));
+		g_snprintf(label_txt, sizeof(label_txt),"Minimum Number of Outbound Streams: %u",((u_data->assoc->outstream1>u_data->assoc->instream2)?u_data->assoc->instream2:u_data->assoc->outstream1));
 		gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->page2->max_out), label_txt);
 	}
 	else
 	{
-		g_snprintf(label_txt, 50,"Used Number of Inbound Streams: %u",u_data->assoc->instream1);
+		g_snprintf(label_txt, sizeof(label_txt),"Used Number of Inbound Streams: %u",u_data->assoc->instream1);
 		gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->page2->max_in), label_txt);
-		g_snprintf(label_txt, 50,"Used Number of Outbound Streams: %u",u_data->assoc->outstream1);
+		g_snprintf(label_txt, sizeof(label_txt),"Used Number of Outbound Streams: %u",u_data->assoc->outstream1);
 		gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->page2->max_out), label_txt);
 	}
 
@@ -318,34 +320,34 @@ update_analyse_dlg(struct sctp_analyse* u_data)
 		return;
 	}
 
-	g_snprintf(label_txt, 50,"Port: %u",u_data->assoc->port2);
+	g_snprintf(label_txt, sizeof(label_txt),"Port: %u",u_data->assoc->port2);
 	gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->page3->port), label_txt);
-	g_snprintf(label_txt, 50,"Sent Verification Tag: 0x%x",u_data->assoc->verification_tag2);
+	g_snprintf(label_txt, sizeof(label_txt),"Sent Verification Tag: 0x%x",u_data->assoc->verification_tag2);
 	gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->page3->veritag), label_txt);
 
 	if (u_data->assoc->initack == TRUE)
 	{
-		g_snprintf(label_txt, 50,"Requested Number of Inbound Streams: %u",u_data->assoc->instream2);
+		g_snprintf(label_txt, sizeof(label_txt),"Requested Number of Inbound Streams: %u",u_data->assoc->instream2);
 		gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->page3->max_in), label_txt);
-		g_snprintf(label_txt, 50,"Minimum Number of Inbound Streams: %u",((u_data->assoc->instream2>u_data->assoc->outstream1)?u_data->assoc->outstream1:u_data->assoc->instream2));
+		g_snprintf(label_txt, sizeof(label_txt),"Minimum Number of Inbound Streams: %u",((u_data->assoc->instream2>u_data->assoc->outstream1)?u_data->assoc->outstream1:u_data->assoc->instream2));
 		gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->page3->min_in), label_txt);
 
-		g_snprintf(label_txt, 50,"Provided Number of Outbound Streams: %u",u_data->assoc->outstream2);
+		g_snprintf(label_txt, sizeof(label_txt),"Provided Number of Outbound Streams: %u",u_data->assoc->outstream2);
 		gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->page3->max_out), label_txt);
-		g_snprintf(label_txt, 50,"Minimum Number of Outbound Streams: %u",((u_data->assoc->outstream2>u_data->assoc->instream1)?u_data->assoc->instream1:u_data->assoc->outstream2));
+		g_snprintf(label_txt, sizeof(label_txt),"Minimum Number of Outbound Streams: %u",((u_data->assoc->outstream2>u_data->assoc->instream1)?u_data->assoc->instream1:u_data->assoc->outstream2));
 		gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->page3->min_out), label_txt);
 	}
 	else
 	{
-		g_snprintf(label_txt, 50,"Used Number of Inbound Streams: %u",u_data->assoc->instream2);
+		g_snprintf(label_txt, sizeof(label_txt),"Used Number of Inbound Streams: %u",u_data->assoc->instream2);
 		gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->page3->max_in), label_txt);
-		g_snprintf(label_txt, 50,"Used Number of Outbound Streams: %u",u_data->assoc->outstream2);
+		g_snprintf(label_txt, sizeof(label_txt),"Used Number of Outbound Streams: %u",u_data->assoc->outstream2);
 		gtk_label_set_text(GTK_LABEL(u_data->analyse_nb->page3->min_out), label_txt);
 	}
 }
 
 
-void
+static void
 sctp_set_filter (GtkButton *button _U_, struct sctp_analyse* u_data)
 {
 	gchar *f_string = NULL;
@@ -472,19 +474,19 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 	u_data->analyse_nb = g_malloc(sizeof(struct notes));
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
-	SIGNAL_CONNECT(window, "destroy", on_destroy,u_data);
+	g_signal_connect(window, "destroy", G_CALLBACK(on_destroy), u_data);
 
 	/* Container for each row of widgets */
 	main_vb = gtk_vbox_new(FALSE, 2);
-	gtk_container_border_width(GTK_CONTAINER(main_vb), 2);
+	gtk_container_set_border_width(GTK_CONTAINER(main_vb), 2);
 	gtk_container_add(GTK_CONTAINER(window), main_vb);
 	gtk_widget_show(main_vb);
 
 	/* Start a notebook for flipping between sets of changes */
 	notebook = gtk_notebook_new();
 	gtk_container_add(GTK_CONTAINER(main_vb), notebook);
-	OBJECT_SET_DATA(window, "notebook", notebook);
-	SIGNAL_CONNECT(notebook, "switch_page", on_notebook_switch_page,NULL);
+	g_object_set_data(G_OBJECT(window), "notebook", notebook);
+	g_signal_connect(notebook, "switch_page", G_CALLBACK(on_notebook_switch_page), NULL);
 
 	page1 = gtk_vbox_new(FALSE, 8);
 	gtk_container_set_border_width(GTK_CONTAINER(page1), 8);
@@ -532,24 +534,23 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 	gtk_box_pack_start(GTK_BOX(page1), hbox, FALSE, FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 10);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX (hbox), GTK_BUTTONBOX_SPREAD);
-	gtk_button_box_set_spacing(GTK_BUTTON_BOX (hbox), 0);
-	gtk_button_box_set_child_ipadding(GTK_BUTTON_BOX (hbox), 4, 0);
+	gtk_box_set_spacing(GTK_BOX (hbox), 0);
 	gtk_widget_show(hbox);
 
 	chunk_stat_bt = gtk_button_new_with_label ("Chunk Statistics");
 	gtk_box_pack_start(GTK_BOX(hbox), chunk_stat_bt, FALSE, FALSE, 0);
 	gtk_widget_show(chunk_stat_bt);
-	SIGNAL_CONNECT(chunk_stat_bt, "clicked", on_chunk_stat_bt, u_data);
+	g_signal_connect(chunk_stat_bt, "clicked", G_CALLBACK(on_chunk_stat_bt), u_data);
 
 	bt_filter = gtk_button_new_with_label ("Set filter");
 	gtk_box_pack_start(GTK_BOX(hbox), bt_filter, FALSE, FALSE, 0);
 	gtk_widget_show (bt_filter);
-	SIGNAL_CONNECT(bt_filter, "clicked", sctp_set_filter, u_data);
+	g_signal_connect(bt_filter, "clicked", G_CALLBACK(sctp_set_filter), u_data);
 
-	close_bt = BUTTON_NEW_FROM_STOCK(GTK_STOCK_CLOSE);
+	close_bt = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
 	gtk_box_pack_start(GTK_BOX(hbox), close_bt, FALSE, FALSE, 0);
 	gtk_widget_show(close_bt);
-	SIGNAL_CONNECT(close_bt, "clicked", on_close_dlg, u_data);
+	g_signal_connect(close_bt, "clicked", G_CALLBACK(on_close_dlg), u_data);
 
 	/* tab */
 	label = gtk_label_new(" Statistics ");
@@ -566,11 +567,11 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 	gtk_container_add(GTK_CONTAINER(page2), u_data->analyse_nb->page2->addr_frame);
 
 	addr_hb = gtk_hbox_new(FALSE, 3);
-	gtk_container_border_width(GTK_CONTAINER(addr_hb), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(addr_hb), 5);
 	gtk_container_add(GTK_CONTAINER(u_data->analyse_nb->page2->addr_frame), addr_hb);
 
 	u_data->analyse_nb->page2->scrolled_window = scrolled_window_new(NULL, NULL);
-	WIDGET_SET_SIZE(u_data->analyse_nb->page2->scrolled_window, 560, 100);
+	gtk_widget_set_size_request(u_data->analyse_nb->page2->scrolled_window, 560, 100);
 
 	u_data->analyse_nb->page2->clist = gtk_clist_new(1);
 	gtk_widget_show(u_data->analyse_nb->page2->clist);
@@ -587,7 +588,7 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 	gtk_container_add(GTK_CONTAINER(page2), stat_fr);
 
 	hbox = gtk_hbox_new(FALSE,3);
-	gtk_container_border_width(GTK_CONTAINER(hbox), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
 	gtk_container_add(GTK_CONTAINER(stat_fr), hbox);
 
 	vbox_l = gtk_vbox_new(FALSE, 3);
@@ -636,33 +637,32 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 	gtk_box_pack_start(GTK_BOX(page2), h_button_box, FALSE, FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(h_button_box), 10);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX (h_button_box), GTK_BUTTONBOX_SPREAD);
-	gtk_button_box_set_spacing(GTK_BUTTON_BOX (h_button_box), 0);
-	gtk_button_box_set_child_ipadding(GTK_BUTTON_BOX (h_button_box), 4, 0);
+	gtk_box_set_spacing(GTK_BOX (h_button_box), 0);
 	gtk_widget_show(h_button_box);
 	
 	chunk_bt1 = gtk_button_new_with_label("Chunk Statistics");
 	gtk_box_pack_start(GTK_BOX(h_button_box), chunk_bt1, FALSE, FALSE, 0);
 	gtk_widget_show(chunk_bt1);
-	SIGNAL_CONNECT(chunk_bt1, "clicked", on_chunk1_dlg,u_data);
+	g_signal_connect(chunk_bt1, "clicked", G_CALLBACK(on_chunk1_dlg), u_data);
 
 	graph_bt1 = gtk_button_new_with_label("Graph TSN");
 	gtk_box_pack_start(GTK_BOX(h_button_box), graph_bt1, FALSE, FALSE, 0);
 	gtk_widget_show(graph_bt1);
-	SIGNAL_CONNECT(graph_bt1, "clicked", on_graph1_dlg,u_data);
+	g_signal_connect(graph_bt1, "clicked", G_CALLBACK(on_graph1_dlg), u_data);
 
 	graph_bt2 = gtk_button_new_with_label("Graph Bytes");
 	gtk_box_pack_start(GTK_BOX(h_button_box), graph_bt2, FALSE, FALSE, 0);
 	gtk_widget_show(graph_bt2);
-	SIGNAL_CONNECT(graph_bt2, "clicked", on_graph_byte1_dlg,u_data);
+	g_signal_connect(graph_bt2, "clicked", G_CALLBACK(on_graph_byte1_dlg), u_data);
 	if (u_data->assoc->n_array_tsn1==0)
 	{
 		gtk_widget_set_sensitive(graph_bt1, FALSE);
 		gtk_widget_set_sensitive(graph_bt2, FALSE);
 	}
-	close_bt = BUTTON_NEW_FROM_STOCK(GTK_STOCK_CLOSE);
+	close_bt = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
 	gtk_box_pack_start(GTK_BOX(h_button_box), close_bt, FALSE, FALSE, 0);
 	gtk_widget_show(close_bt);
-	SIGNAL_CONNECT(close_bt, "clicked", on_close_dlg, u_data);
+	g_signal_connect(close_bt, "clicked", G_CALLBACK(on_close_dlg), u_data);
 
 	label = gtk_label_new(" Endpoint 1 ");
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), page2, label);
@@ -677,11 +677,11 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 	gtk_container_add(GTK_CONTAINER(page3), u_data->analyse_nb->page3->addr_frame);
 
 	addr_hb = gtk_hbox_new(FALSE, 3);
-	gtk_container_border_width(GTK_CONTAINER(addr_hb), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(addr_hb), 5);
 	gtk_container_add(GTK_CONTAINER(u_data->analyse_nb->page3->addr_frame), addr_hb);
 
 	u_data->analyse_nb->page3->scrolled_window = scrolled_window_new(NULL, NULL);
-	WIDGET_SET_SIZE(u_data->analyse_nb->page3->scrolled_window, 560, 100);
+	gtk_widget_set_size_request(u_data->analyse_nb->page3->scrolled_window, 560, 100);
 
 	u_data->analyse_nb->page3->clist = gtk_clist_new(1);
 	gtk_widget_show(u_data->analyse_nb->page3->clist);		
@@ -699,7 +699,7 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 	gtk_container_add(GTK_CONTAINER(page3), stat_fr);
 
 	hbox = gtk_hbox_new(FALSE,3);
-	gtk_container_border_width(GTK_CONTAINER(hbox), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
 	gtk_container_add(GTK_CONTAINER(stat_fr), hbox);
 
 	vbox_l = gtk_vbox_new(FALSE, 3);
@@ -744,32 +744,31 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 	gtk_box_pack_start(GTK_BOX(page3), h_button_box, FALSE, FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(h_button_box), 10);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX (h_button_box), GTK_BUTTONBOX_SPREAD);
-	gtk_button_box_set_spacing(GTK_BUTTON_BOX (h_button_box), 0);
-	gtk_button_box_set_child_ipadding(GTK_BUTTON_BOX (h_button_box), 4, 0);
+	gtk_box_set_spacing(GTK_BOX (h_button_box), 0);
 	gtk_widget_show(h_button_box);
 	
 	chunk_bt1 = gtk_button_new_with_label("Chunk Statistics");
 	gtk_box_pack_start(GTK_BOX(h_button_box), chunk_bt1, FALSE, FALSE, 0);
 	gtk_widget_show(chunk_bt1);
-	SIGNAL_CONNECT(chunk_bt1, "clicked", on_chunk2_dlg, u_data);
+	g_signal_connect(chunk_bt1, "clicked", G_CALLBACK(on_chunk2_dlg), u_data);
 	
 	graph_bt1 = gtk_button_new_with_label("Graph TSN");
 	gtk_box_pack_start(GTK_BOX(h_button_box), graph_bt1, FALSE, FALSE, 0);
 	gtk_widget_show(graph_bt1);
-	SIGNAL_CONNECT(graph_bt1, "clicked", on_graph2_dlg, u_data);
+	g_signal_connect(graph_bt1, "clicked", G_CALLBACK(on_graph2_dlg), u_data);
 	graph_bt2 = gtk_button_new_with_label("Graph Bytes");
 	gtk_box_pack_start(GTK_BOX(h_button_box), graph_bt2, FALSE, FALSE, 0);
 	gtk_widget_show(graph_bt2);
-	SIGNAL_CONNECT(graph_bt2, "clicked", on_graph_byte2_dlg,u_data);
+	g_signal_connect(graph_bt2, "clicked", G_CALLBACK(on_graph_byte2_dlg), u_data);
 	if (u_data->assoc->n_array_tsn2==0)
 	{
 		gtk_widget_set_sensitive(graph_bt1, FALSE);
 		gtk_widget_set_sensitive(graph_bt2, FALSE);
 	}
-	close_bt = BUTTON_NEW_FROM_STOCK(GTK_STOCK_CLOSE);
+	close_bt = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
 	gtk_box_pack_start(GTK_BOX(h_button_box), close_bt, FALSE, FALSE, 0);
 	gtk_widget_show(close_bt);
-	SIGNAL_CONNECT(close_bt, "clicked", on_close_dlg, u_data);
+	g_signal_connect(close_bt, "clicked", G_CALLBACK(on_close_dlg), u_data);
 
 	label = gtk_label_new(" Endpoint 2 ");
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), page3, label);
@@ -817,9 +816,7 @@ void assoc_analyse(sctp_assoc_info_t* assoc)
 
 static void sctp_analyse_cb(struct sctp_analyse* u_data, gboolean ext)
 {
-	guint8* ip_src;
 	guint16 srcport;
-	guint8* ip_dst;
 	guint16 dstport;
 	GList *list, *framelist;
 	dfilter_t *sfcode;
@@ -834,9 +831,9 @@ static void sctp_analyse_cb(struct sctp_analyse* u_data, gboolean ext)
 	int i;
 	guint32 *fn;
 
-	strcpy(filter_text,"sctp");
+	g_strlcpy(filter_text,"sctp",250);
 	if (!dfilter_compile(filter_text, &sfcode)) {
-		simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, dfilter_error_msg);
+		simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "%s", dfilter_error_msg);
 		return;
 	}
 
@@ -869,10 +866,6 @@ static void sctp_analyse_cb(struct sctp_analyse* u_data, gboolean ext)
 		return;
 	}
 
-	ip_src = g_malloc(edt->pi.net_src.len);
-	memcpy(ip_src, edt->pi.net_src.data, edt->pi.net_src.len);
-	ip_dst = g_malloc(edt->pi.net_dst.len);
-	memcpy(ip_dst, edt->pi.net_dst.data, edt->pi.net_dst.len);
 	srcport = edt->pi.srcport;
 	dstport = edt->pi.destport;
 	list = g_list_first(sctp_stat_get_info()->assoc_info_list);
