@@ -2,7 +2,7 @@
  * Copyright 2004, Irene Ruengeler <i.ruengeler [AT] fh-muenster.de>
  * Copyright 2009, Varun Notibala <nbvarun [AT] gmail.com>
  *
- * $Id: sctp_graph_dlg.c 28662 2009-06-08 15:37:46Z gerald $
+ * $Id: sctp_graph_dlg.c 29704 2009-09-04 22:17:02Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -144,22 +144,27 @@ static void draw_sack_graph(struct sctp_udata *u_data)
 {
 	tsn_t	*sack;
 	GList *list=NULL, *tlist;
-	guint16 gap_start=0, gap_end=0, i, j, nr;
+	guint16 gap_start=0, gap_end=0, i, j, nr, dup_nr;
 	guint8 type;
-	guint32 tsnumber;
+	guint32 tsnumber, dup;
 	gint xvalue, yvalue;
 	GdkColor red_color = {0, 65535, 0, 0};
 	GdkColor green_color = {0, 0, 65535, 0};
-	GdkGC *red_gc, *green_gc;
+	GdkColor cyan_color = {0, 0, 65535, 65535};
+	GdkGC *red_gc, *green_gc, *cyan_gc;
 	struct sack_chunk_header *sack_header;
 	struct gaps *gap;
 	guint32 max_num, diff;
+	guint32 *dup_list;
 
 	red_gc = gdk_gc_new(u_data->io->draw_area->window);
 	gdk_gc_set_rgb_fg_color(red_gc, &red_color);
 
 	green_gc = gdk_gc_new(u_data->io->draw_area->window);
 	gdk_gc_set_rgb_fg_color(green_gc, &green_color);
+	
+	cyan_gc = gdk_gc_new(u_data->io->draw_area->window);
+	gdk_gc_set_rgb_fg_color(cyan_gc, &cyan_color);
 
 	if (u_data->dir==2)
 	{
@@ -205,6 +210,7 @@ static void draw_sack_graph(struct sctp_udata *u_data)
 				sack_header =(struct sack_chunk_header *)tlist->data;
 				nr=g_ntohs(sack_header->nr_of_gaps);
 				tsnumber = g_ntohl(sack_header->cum_tsn_ack);
+				dup_nr=g_ntohs(sack_header->nr_of_dups);
 
 				if (sack->secs>=u_data->io->x1_tmp_sec)
 				{
@@ -226,12 +232,12 @@ static void draw_sack_graph(struct sctp_udata *u_data)
 								yvalue = (guint32)(u_data->io->pixmap_height-BOTTOM_BORDER-POINT_SIZE-u_data->io->offset-((SUB_32(j+tsnumber,min_tsn))*u_data->io->y_interval));
 								if (xvalue >= LEFT_BORDER+u_data->io->offset &&
 								    xvalue <= u_data->io->pixmap_width-RIGHT_BORDER+u_data->io->offset &&
-								    yvalue >= TOP_BORDER-u_data->io->offset &&
+								    yvalue >= TOP_BORDER-u_data->io->offset-POINT_SIZE &&
 								    yvalue <= u_data->io->pixmap_height-BOTTOM_BORDER-u_data->io->offset)
 									gdk_draw_arc(u_data->io->pixmap,green_gc,TRUE,
-								             	    xvalue,
-								                    yvalue,
-								             	    POINT_SIZE, POINT_SIZE,0, (64*360) );
+									             xvalue,
+									             yvalue,
+									             POINT_SIZE, POINT_SIZE,0, (64*360) );
 							}
 							if (i < nr-1)
 								gap++;
@@ -249,12 +255,39 @@ static void draw_sack_graph(struct sctp_udata *u_data)
 						yvalue = (guint32)(u_data->io->pixmap_height-BOTTOM_BORDER-POINT_SIZE -u_data->io->offset-((SUB_32(tsnumber,min_tsn))*u_data->io->y_interval));
 						if (xvalue >= LEFT_BORDER+u_data->io->offset && 
 						    xvalue <= u_data->io->pixmap_width-RIGHT_BORDER+u_data->io->offset &&
-						    yvalue >= TOP_BORDER-u_data->io->offset &&
+						    yvalue >= TOP_BORDER-u_data->io->offset-POINT_SIZE &&
 						    yvalue <= u_data->io->pixmap_height-BOTTOM_BORDER-u_data->io->offset)
+						    {
 							gdk_draw_arc(u_data->io->pixmap,red_gc,TRUE,
 								     xvalue,
 								     yvalue,
 								     POINT_SIZE, POINT_SIZE,0, (64*360) );
+							}
+					}
+					if (dup_nr > 0)
+					{
+						dup_list = (guint32 *)(((char *)&sack_header->nr_of_dups)+sizeof(guint16)+(nr*sizeof(struct gaps)));
+						for (i = 0; i < dup_nr; i++)
+						{
+							dup = g_ntohl(dup_list[i]);
+							if (dup >= min_tsn)
+							{
+								if (u_data->io->uoff)
+									diff = sack->secs - u_data->io->min_x;
+								else
+									diff=sack->secs*1000000+sack->usecs-u_data->io->min_x;
+								xvalue = (guint32)(LEFT_BORDER+u_data->io->offset+u_data->io->x_interval*diff);
+								yvalue = (guint32)(u_data->io->pixmap_height-BOTTOM_BORDER-POINT_SIZE -u_data->io->offset-((SUB_32(dup,min_tsn))*u_data->io->y_interval));
+								if (xvalue >= LEFT_BORDER+u_data->io->offset && 
+								    xvalue <= u_data->io->pixmap_width-RIGHT_BORDER+u_data->io->offset &&
+								    yvalue >= TOP_BORDER-u_data->io->offset-POINT_SIZE &&
+								    yvalue <= u_data->io->pixmap_height-BOTTOM_BORDER-u_data->io->offset)
+									gdk_draw_arc(u_data->io->pixmap,cyan_gc,TRUE,
+									             xvalue,
+									             yvalue,
+									             POINT_SIZE, POINT_SIZE,0, (64*360) );
+							}
+						}
 					}
 				}
 			}
@@ -368,7 +401,7 @@ static void draw_nr_sack_graph(struct sctp_udata *u_data)
 								yvalue = (guint32)(u_data->io->pixmap_height-BOTTOM_BORDER-POINT_SIZE-u_data->io->offset-((SUB_32(j+tsnumber,min_tsn))*u_data->io->y_interval));
 								if (xvalue >= LEFT_BORDER+u_data->io->offset &&
 								    xvalue <= u_data->io->pixmap_width-RIGHT_BORDER+u_data->io->offset &&
-								    yvalue >= TOP_BORDER-u_data->io->offset &&
+								    yvalue >= TOP_BORDER-u_data->io->offset-POINT_SIZE &&
 								    yvalue <= u_data->io->pixmap_height-BOTTOM_BORDER-u_data->io->offset)
 								{
 									/* Check if this is an GAP ACK or NR GAP ACK */
@@ -418,7 +451,7 @@ static void draw_nr_sack_graph(struct sctp_udata *u_data)
 						yvalue = (guint32)(u_data->io->pixmap_height-BOTTOM_BORDER-POINT_SIZE -u_data->io->offset-((SUB_32(tsnumber,min_tsn))*u_data->io->y_interval));
 						if (xvalue >= LEFT_BORDER+u_data->io->offset && 
 						    xvalue <= u_data->io->pixmap_width-RIGHT_BORDER+u_data->io->offset &&
-						    yvalue >= TOP_BORDER-u_data->io->offset &&
+						    yvalue >= TOP_BORDER-u_data->io->offset-POINT_SIZE &&
 						    yvalue <= u_data->io->pixmap_height-BOTTOM_BORDER-u_data->io->offset)
 							gdk_draw_arc(u_data->io->pixmap,red_gc,TRUE,
 								     xvalue,
@@ -493,7 +526,7 @@ static void draw_tsn_graph(struct sctp_udata *u_data)
 					yvalue = (guint32)(u_data->io->pixmap_height-BOTTOM_BORDER-POINT_SIZE-u_data->io->offset-((SUB_32(tsnumber,min_tsn))*u_data->io->y_interval));
 					if (xvalue >= LEFT_BORDER+u_data->io->offset && 
 					    xvalue <= u_data->io->pixmap_width-RIGHT_BORDER+u_data->io->offset &&
-					    yvalue >= TOP_BORDER-u_data->io->offset &&
+					    yvalue >= TOP_BORDER-u_data->io->offset-POINT_SIZE &&
 					    yvalue <= u_data->io->pixmap_height-BOTTOM_BORDER-u_data->io->offset)
 						gdk_draw_arc(u_data->io->pixmap,u_data->io->draw_area->style->black_gc,TRUE,
 							     xvalue,
@@ -1346,10 +1379,8 @@ static void init_sctp_graph_window(struct sctp_udata *u_data)
 	GtkTooltips *tooltip_in, *tooltip_out;
 
 	/* create the main window */
-
-	u_data->io->window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
-
-	gtk_widget_set_name(u_data->io->window, "SCTP Graphics");
+	u_data->io->window= dlg_window_new("WSCTP Graphics");  /* transient_for top_level */
+	gtk_window_set_destroy_with_parent (GTK_WINDOW(u_data->io->window), TRUE);
 
 	vbox=gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(u_data->io->window), vbox);
