@@ -1,7 +1,7 @@
 /* smb_stat.c
  * smb_stat   2003 Ronnie Sahlberg
  *
- * $Id: smb_stat.c 26641 2008-10-31 09:53:56Z stig $
+ * $Id: smb_stat.c 29099 2009-07-15 00:10:08Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -169,7 +169,8 @@ gtk_smbstat_init(const char *optarg, void *userdata _U_)
 
 	ss=g_malloc(sizeof(smbstat_t));
 
-	ss->win=window_new(GTK_WINDOW_TOPLEVEL, "smb-stat");
+	ss->win = dlg_window_new("smb-stat");  /* transient_for top_level */
+	gtk_window_set_destroy_with_parent (GTK_WINDOW(ss->win), TRUE);
 	gtk_window_set_default_size(GTK_WINDOW(ss->win), 550, 600);
 	smbstat_set_title(ss);
 
