@@ -1,7 +1,7 @@
 /* wsp_stat.c
  * wsp_stat   2003 Jean-Michel FAYARD
  *
- * $Id: wsp_stat.c 27800 2009-03-19 17:49:11Z wmeier $
+ * $Id: wsp_stat.c 29099 2009-07-15 00:10:08Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -323,7 +323,9 @@ gtk_wspstat_init(const char *optarg, void *userdata _U_)
 	}
 
 	sp = g_malloc( sizeof(wspstat_t) );
-	sp->win = window_new(GTK_WINDOW_TOPLEVEL, "wsp-stat");
+	sp->win = dlg_window_new("wsp-stat");  /* transient_for top_level */
+	gtk_window_set_destroy_with_parent (GTK_WINDOW(sp->win), TRUE);
+
 	sp->hash = g_hash_table_new( g_int_hash, g_int_equal);
 	for (i=0 ; vals_status[i].strptr ; i++ )
 	{
