@@ -2,7 +2,7 @@
  * Routines for Dynamic Service Addition Acknowledge dissection
  * Copyright 2002, Anand V. Narwani <anand[AT]narwani.org>
  *
- * $Id: packet-dsaack.c 23088 2007-10-07 23:46:44Z richardv $
+ * $Id: packet-dsaack.c 32655 2010-05-04 00:20:39Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -69,7 +69,7 @@ dissect_dsaack (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
       col_clear (pinfo->cinfo, COL_INFO);
       col_add_fstr (pinfo->cinfo, COL_INFO,
 		    "Dynamic Service Add Ack ID = %u (%s)", transid,
-		    val_to_str (response, docsis_conf_code, "%s"));
+		    val_to_str (response, docsis_conf_code, "%d"));
     }
 
   if (tree)
