@@ -2,7 +2,7 @@
  * Routines for Dynamic Service Addition Response dissection
  * Copyright 2002, Anand V. Narwani <anand[AT]narwani.org>
  *
- * $Id: packet-dsarsp.c 18231 2006-05-28 16:32:49Z etxrab $
+ * $Id: packet-dsarsp.c 32655 2010-05-04 00:20:39Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -69,7 +69,7 @@ dissect_dsarsp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
       col_clear (pinfo->cinfo, COL_INFO);
       col_add_fstr (pinfo->cinfo, COL_INFO,
 		    "Dynamic Service Add Response ID = %u (%s)", transid,
-		    val_to_str (response, docsis_conf_code, "%s"));
+		    val_to_str (response, docsis_conf_code, "%d"));
     }
 
   if (tree)
@@ -109,17 +109,17 @@ proto_register_docsis_dsarsp (void)
 /* Setup list of header fields  See Section 1.6.1 for details*/
   static hf_register_info hf[] = {
     {&hf_docsis_dsarsp,
-     {"Dynamic Service Add Request", "docsis.dsarsp",
+     {"Dynamic Service Add Request", "docsis_dsarsp",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Dynamic Service Add Request", HFILL}
      },
     {&hf_docsis_dsarsp_tranid,
-     {"Transaction Id", "docsis.dsarsp.tranid",
+     {"Transaction Id", "docsis_dsarsp.tranid",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "Service Identifier", HFILL}
      },
     {&hf_docsis_dsarsp_response,
-     {"Confirmation Code", "docsis.dsarsp.confcode",
+     {"Confirmation Code", "docsis_dsarsp.confcode",
       FT_UINT8, BASE_DEC, VALS (docsis_conf_code), 0x0,
       "Confirmation Code", HFILL}
      },
