@@ -1,7 +1,7 @@
 /* packet-ethercat-frame.c
  * Routines for ethercat packet disassembly
  *
- * $Id: packet-ethercat-frame.c 24566 2008-03-05 20:42:58Z etxrab $
+ * $Id: packet-ethercat-frame.c 26554 2008-10-25 20:24:31Z wmeier $
  *
  * Copyright (c) 2007 by Beckhoff Automation GmbH
  *
@@ -40,14 +40,11 @@
 
 #include <epan/packet.h>
 #include <epan/addr_resolv.h>
-#include <epan/prefs.h>
 #include <epan/strutil.h>
 #include <epan/etypes.h>
 
 #include "packet-ethercat-frame.h"
 
-void proto_reg_handoff_ethercat_frame(void);
-
 /* Define the Ethercat frame proto */
 static int proto_ethercat_frame = -1;
 
@@ -167,9 +164,9 @@ void proto_register_ethercat_frame(void)
 
 void proto_reg_handoff_ethercat_frame(void)
 {
-   static dissector_handle_t ethercat_frame_handle;
+   dissector_handle_t ethercat_frame_handle;
 
-   ethercat_frame_handle = create_dissector_handle(dissect_ethercat_frame, proto_ethercat_frame);
+   ethercat_frame_handle = find_dissector("ecatf");
    dissector_add("ethertype", ETHERTYPE_ECATF, ethercat_frame_handle);
    dissector_add("udp.port", ETHERTYPE_ECATF, ethercat_frame_handle);
    dissector_add("tcp.port", ETHERTYPE_ECATF, ethercat_frame_handle);
