@@ -1,7 +1,7 @@
 /* packet-ioraw.c
  * Routines for ethercat packet disassembly
  *
- * $Id: packet-ioraw.c 23188 2007-10-15 18:39:58Z etxrab $
+ * $Id: packet-ioraw.c 26554 2008-10-25 20:24:31Z wmeier $
  *
  * Copyright (c) 2007 by Beckhoff Automation GmbH
  *
@@ -40,13 +40,10 @@
 
 #include <epan/packet.h>
 #include <epan/addr_resolv.h>
-#include <epan/prefs.h>
 #include <epan/strutil.h>
 
 #include "packet-ioraw.h"
 
-void proto_reg_handoff_ioraw(void);
-
 /* Define the ioraw proto */
 int proto_ioraw  = -1;
 
@@ -128,7 +125,7 @@ void proto_register_ioraw(void)
 
 void proto_reg_handoff_ioraw(void)
 {
-   static dissector_handle_t ioraw_handle;
+   dissector_handle_t ioraw_handle;
 
    ioraw_handle = create_dissector_handle(dissect_ioraw, proto_ioraw);
    dissector_add("ecatf.type", 3, ioraw_handle);
