@@ -5,7 +5,7 @@
  *
  * Author: Lu Pan <lu.pan@intel.com>
  *
- * $Id: packet-m2m.c 27926 2009-04-01 22:09:53Z gerald $
+ * $Id: packet-m2m.c 28355 2009-05-13 19:44:44Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -37,7 +37,6 @@
 #include <string.h>
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/prefs.h>
 #include <epan/reassemble.h>
 #include <epan/etypes.h>
 #include <plugins/wimax/wimax_tlv.h>
@@ -60,7 +59,6 @@ guint g_frame_number = 0;
 
 /* Local Variables */
 static gint proto_m2m = -1;
-static dissector_handle_t m2m_handle = NULL;
 static dissector_handle_t wimax_fch_burst_handle = NULL;
 static dissector_handle_t wimax_cdma_code_burst_handle = NULL;
 static dissector_handle_t wimax_pdu_burst_handle = NULL;
@@ -369,31 +367,24 @@ m2m_defragment_init(void)
 /* Register Wimax Mac to Mac Protocol handler */
 void proto_reg_handoff_m2m(void)
 {
-	static int Initialized = FALSE;
+	dissector_handle_t m2m_handle;
 
-	if (!Initialized)
-	{
-		m2m_handle = create_dissector_handle(dissect_m2m, proto_m2m);
-		dissector_add("ethertype", ETHERTYPE_WMX_M2M, m2m_handle);
-	}
+	m2m_handle = create_dissector_handle(dissect_m2m, proto_m2m);
+	dissector_add("ethertype", ETHERTYPE_WMX_M2M, m2m_handle);
 }
 
 /* Register Wimax Mac to Mac Protocol */
 void proto_register_m2m(void)
 {
-	if (proto_m2m == -1)
-	{
-		proto_m2m = proto_register_protocol (
-							"WiMax Mac to Mac Packet", /* name */
-							"M2M  (m2m)", /* short name */
-							"m2m" /* abbrev */
-							);
+	proto_m2m = proto_register_protocol (
+		"WiMax Mac to Mac Packet", /* name */
+		"M2M  (m2m)", /* short name */
+		"m2m" /* abbrev */
+		);
 
-		proto_register_field_array(proto_m2m, hf, array_length(hf));
-		proto_register_field_array(proto_m2m, hf_tlv, array_length(hf_tlv));
-		proto_register_subtree_array(ett, array_length(ett));
-	}
-	prefs_register_protocol(proto_m2m, proto_reg_handoff_m2m);
+	proto_register_field_array(proto_m2m, hf, array_length(hf));
+	proto_register_field_array(proto_m2m, hf_tlv, array_length(hf_tlv));
+	proto_register_subtree_array(ett, array_length(ett));
 
 	/* init the PDU fragment table */
 	fragment_table_init(&pdu_frag_table);
@@ -693,9 +684,7 @@ static void pdu_burst_decoder(proto_tree *tree, tvbuff_t *tvb, gint offset, gint
 		{
 			pdu_length = pdu_frag->len;
 			/* create the new tvb for defraged frame */
-			pdu_tvb = tvb_new_real_data(pdu_frag->data, pdu_length, pdu_length);
-			/* attach the pdu_tvb to tvb so that it will be cleaned up when tvb is cleaned up */
-			tvb_set_child_real_data_tvbuff(tvb, pdu_tvb);
+			pdu_tvb = tvb_new_child_real_data(tvb, pdu_frag->data, pdu_length, pdu_length);
 			/* add the defragmented data to the data source list */
 			add_new_data_source(pinfo, pdu_tvb, "Reassembled WiMax PDU Frame");
 		}
