@@ -1,9 +1,9 @@
 /* mate_runtime.c
 * MATE -- Meta Analysis Tracing Engine
 *
-* Copyright 2004, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
+* Copyright 2004, Luis E. Garcia Ontanon <luis@ontanon.org>
 *
-* $Id: mate_runtime.c 21330 2007-04-03 21:17:13Z sfisher $
+* $Id: mate_runtime.c 27085 2008-12-22 15:24:18Z wmeier $
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
@@ -676,7 +676,7 @@ static void get_pdu_fields(gpointer k, gpointer v, gpointer p) {
 	gchar* s;
 		
 
-	fis = (GPtrArray*) g_hash_table_lookup(data->interesting,(gpointer) hfid);
+	fis = (GPtrArray*) g_hash_table_lookup(data->interesting,GINT_TO_POINTER(hfid));
 	
 	if (fis) {
 		for (i = 0; i < fis->len; i++) {
@@ -859,8 +859,8 @@ extern void mate_analyze_frame(packet_info *pinfo, proto_tree* tree) {
 			
 			cfg = g_ptr_array_index(mc->pducfglist,i);
 			
-			dbg_print (dbg_pdu,4,dbg_facility,"mate_analyze_frame: tryning to extract: %s",cfg->name);
-			protos = (GPtrArray*) g_hash_table_lookup(tree->tree_data->interesting_hfids,(gpointer) cfg->hfid_proto);
+			dbg_print (dbg_pdu,4,dbg_facility,"mate_analyze_frame: trying to extract: %s",cfg->name);
+			protos = (GPtrArray*) g_hash_table_lookup(tree->tree_data->interesting_hfids,GINT_TO_POINTER(cfg->hfid_proto));
 			
 			if (protos)  {
 				pdu = NULL;
