@@ -3,7 +3,7 @@
 *
 * Copyright 2004, Luis E. Garcia Ontanon <luis@ontanon.org>
 *
-* $Id: mate_setup.c 27864 2009-03-27 14:46:54Z wmeier $
+* $Id: mate_setup.c 32661 2010-05-04 19:13:29Z gerald $
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
@@ -136,6 +136,7 @@ extern mate_cfg_gog* new_gogcfg(gchar* name) {
 	cfg->hfid_gog_num_of_gops = -1;
 	cfg->hfid_gog_gop = -1;
 	cfg->hfid_gog_gopstart = -1;
+	cfg->hfid_gog_gopstop = -1;
 	
 	cfg->hfid_start_time = -1;
 	cfg->hfid_stop_time = -1;
@@ -218,10 +219,10 @@ extern gchar* add_ranges(gchar* range,GPtrArray* range_ptr_arr) {
 
 static void new_attr_hfri(gchar* item_name, GHashTable* hfids, gchar* name) {
 	int* p_id = g_malloc(sizeof(int));
-
 	hf_register_info hfri;
 
 	memset(&hfri, 0, sizeof hfri);
+	*p_id = -1;
 	hfri.p_id = p_id;
 	hfri.hfinfo.name = g_strdup(name);
 	hfri.hfinfo.abbrev = g_strdup_printf("mate.%s.%s",item_name,name);
@@ -603,6 +604,7 @@ extern mate_config* mate_make_config(const gchar* filename, int mate_hfid) {
 	matecfg->defaults.pdu.match_mode = AVPL_STRICT;
 	matecfg->defaults.pdu.replace_mode = AVPL_INSERT;
 	
+		/* gop prefs */
 	matecfg->defaults.gop.expiration = -1.0;
 	matecfg->defaults.gop.idle_timeout = -1.0;
 	matecfg->defaults.gop.lifetime = -1.0;
@@ -610,8 +612,9 @@ extern mate_config* mate_make_config(const gchar* filename, int mate_hfid) {
 	matecfg->defaults.gop.show_times = TRUE;
 	matecfg->defaults.gop.drop_unassigned = FALSE;
 	
-		/* gop prefs */
+		/* gog prefs */
 	matecfg->defaults.gog.expiration = 5.0;
+	matecfg->defaults.gog.show_times = TRUE;
 	matecfg->defaults.gog.gop_tree_mode = GOP_BASIC_TREE;
 
 	/* what to dbgprint */
