@@ -5,7 +5,7 @@
  *
  * Author: Lu Pan <lu.pan@intel.com>
  *
- * $Id: mac_hd_generic_decoder.c 23661 2007-11-28 23:22:38Z gerald $
+ * $Id: mac_hd_generic_decoder.c 28355 2009-05-13 19:44:44Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -46,7 +46,6 @@
 #include <string.h>
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/prefs.h>
 #include <epan/address.h>
 #include <epan/reassemble.h>
 #include "crc.h"
@@ -65,7 +64,7 @@ extern address bs_address;			/* declared in packet-wmx.c */
 extern guint max_logical_bands;			/* declared in wimax_compact_dlmap_ie_decoder.c */
 extern gboolean is_down_link(address *src_address);/* declared in packet-wmx.c */
 extern void proto_register_mac_mgmt_msg(void); /* defined in macmgmtmsgdecoder.c */
-extern void init_wimax_globals();		/* defined in msg_ulmap.c */
+extern void init_wimax_globals(void);		/* defined in msg_ulmap.c */
 
 extern void dissect_mac_mgmt_msg_decoder(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
 
@@ -1368,11 +1367,11 @@ void wimax_defragment_init(void)
 	cid_adj_array_size = 0;
 	/* Free the array memory. */
 	if (cid_adj_array) {
-		free(cid_adj_array);
+		g_free(cid_adj_array);
 	}
 	cid_adj_array = NULL;
 	if (frag_num_array) {
-		free(frag_num_array);
+		g_free(frag_num_array);
 	}
 	frag_num_array = NULL;
 
@@ -1812,9 +1811,9 @@ void dissect_mac_header_generic_decoder(tvbuff_t *tvb, packet_info *pinfo, proto
 			/* defragment first if it is fragmented */
 			if (frag_type == NO_FRAG)
 			{	/* not fragmented payload */
-				payload_tvb =  tvb_new_subset(tvb, offset, length, length);
-				payload_length = length;
-				new_payload_len = length;
+				payload_tvb =  tvb_new_subset(tvb, offset, frag_len, frag_len);
+				payload_length = frag_len;
+				new_payload_len = frag_len;
 			}
 			else	/* fragmented payload */
 			{	/* add the frag */
@@ -1897,9 +1896,7 @@ void dissect_mac_header_generic_decoder(tvbuff_t *tvb, packet_info *pinfo, proto
 				{	/* defragmented completely */
 					payload_length = payload_frag->len;
 					/* create the new tvb for defragmented frame */
-					payload_tvb = tvb_new_real_data(payload_frag->data, payload_length, payload_length);
-					/* attach the payload_tvb to tvb so that it will be cleaned up when tvb is cleaned up */
-					tvb_set_child_real_data_tvbuff(tvb, payload_tvb);
+					payload_tvb = tvb_new_child_real_data(tvb, payload_frag->data, payload_length, payload_length);
 					/* add the defragmented data to the data source list */
 					add_new_data_source(pinfo, payload_tvb, "Reassembled WiMax MAC payload");
 					/* save the tvb langth */
