@@ -5,7 +5,7 @@
  *
  * Author: Lu Pan <lu.pan@intel.com>
  *
- * $Id: mac_mgmt_msg_decoder.c 21960 2007-05-27 18:33:13Z guy $
+ * $Id: mac_mgmt_msg_decoder.c 26103 2008-08-29 01:40:32Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -36,7 +36,6 @@
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/prefs.h>
 #include "wimax_mac.h"
 
 extern gint proto_wimax;
@@ -118,7 +117,7 @@ static gint proto_mac_mgmt_msg_decoder = -1;
 static gint ett_mac_mgmt_msg_decoder = -1;
 
 /* WIMAX MAC Management message type info */
-char *mgt_msg_abbrv[MAC_MGMT_MSG_TYPE_MAX] = 
+char *mgt_msg_abbrv[MAC_MGMT_MSG_TYPE_MAX] =
 {
 	"UCD",		/* 0 */
 	"DCD",
@@ -204,7 +203,7 @@ static hf_register_info hf[] =
 	{
 		&hf_mac_mgmt_msg_values,
 		{
-			"Values", "wimax.values",
+			"Values", "wmx.values",
 			FT_BYTES, BASE_HEX, NULL, 0x0,
 			"", HFILL
 		}
@@ -212,7 +211,7 @@ static hf_register_info hf[] =
 	{
 		&hf_mac_mgmt_msg_unknown_type,
 		{
-			"Unknown MAC Message Type", "wimax.unknown_type",
+			"Unknown MAC Message Type", "wmx.unknown_type",
 			FT_BYTES, BASE_HEX, NULL, 0x0,
 			"", HFILL
 		}
@@ -229,7 +228,7 @@ void proto_register_mac_mgmt_msg(void)
 		proto_mac_mgmt_msg_decoder = proto_register_protocol (
 							"WiMax MAC Management Message", /* name */
 							"MGMT MSG", /* short name */
-							"mgmtmsg" /* abbrev */
+							"wmx.mgmtmsg" /* abbrev */
 							);
 #endif
 
@@ -237,7 +236,9 @@ void proto_register_mac_mgmt_msg(void)
 		proto_register_subtree_array(ett, array_length(ett));
 	}
 
-	proto_register_wimax_utility_decoders();
+	/* Register dissector by name */
+	register_dissector("wmx_mac_mgmt_msg_decoder", dissect_mac_mgmt_msg_decoder,
+	                   proto_mac_mgmt_msg_decoder);
 
 	proto_register_mac_mgmt_msg_dcd();
 	proto_register_mac_mgmt_msg_ucd();
@@ -267,6 +268,8 @@ void proto_register_mac_mgmt_msg(void)
 	proto_register_mac_mgmt_msg_rep();
 	proto_register_mac_mgmt_msg_clk_cmp();
 	proto_register_mac_mgmt_msg_dsx_rvd();
+
+	proto_register_wimax_utility_decoders();
 }
 
 void dissect_mac_mgmt_msg_decoder(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
