@@ -5,7 +5,7 @@
  *
  * Author: Lu Pan <lu.pan@intel.com>
  *
- * $Id: msg_dcd.c 21960 2007-05-27 18:33:13Z guy $
+ * $Id: msg_dcd.c 27192 2009-01-08 07:36:11Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -40,7 +40,6 @@
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/prefs.h>
 #include "wimax_tlv.h"
 #include "wimax_mac.h"
 
@@ -348,161 +347,161 @@ static hf_register_info hf[] =
 	{
 		&hf_dcd_message_type,
 		{
-			"MAC Management Message Type", "wimax.macmgtmsgtype.dcd",
+			"MAC Management Message Type", "wmx.macmgtmsgtype.dcd",
 			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_33_asr,
 		{
-			"ASR (Anchor Switch Report) Slot Length (M) and Switching Period (L)", "wimax.dcd.asr", 
+			"ASR (Anchor Switch Report) Slot Length (M) and Switching Period (L)", "wmx.dcd.asr",
 			FT_UINT8, BASE_HEX, NULL, 0x0, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_33_asr_l,
 		{
-			"ASR Switching Period (L)", "wimax.dcd.asr.l", 
+			"ASR Switching Period (L)", "wmx.dcd.asr.l",
 			FT_UINT8, BASE_DEC, NULL, 0x0f, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_33_asr_m,
 		{
-			"ASR Slot Length (M)", "wimax.dcd.asr.m", 
+			"ASR Slot Length (M)", "wmx.dcd.asr.m",
 			FT_UINT8, BASE_DEC, NULL, 0xf0, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_bs_eirp,
 		{
-			"BS EIRP", "wimax.dcd.bs_eirp",
+			"BS EIRP", "wmx.dcd.bs_eirp",
 			FT_INT16, BASE_DEC, NULL, 0x00, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_bs_id,
 		{
-			"Base Station ID", "wimax.dcd.bs_id", 
+			"Base Station ID", "wmx.dcd.bs_id",
 			FT_ETHER, BASE_HEX, NULL, 0x00, "", HFILL
 		}
 	},
         {
-		&hf_dcd_restart_count, 
+		&hf_dcd_restart_count,
 		{
-			"BS Restart Count", "wimax.dcd.bs_restart_count", 
+			"BS Restart Count", "wmx.dcd.bs_restart_count",
 			FT_UINT8, BASE_DEC, NULL, 0x00, "", HFILL
 		}
 	},
 	{
 		&hf_dl_burst_diuc,
 		{
-			"DIUC", "wimax.dcd.burst.diuc", 
+			"DIUC", "wmx.dcd.burst.diuc",
 			FT_UINT8, BASE_DEC, NULL, 0x0F, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_burst_diuc_entry_threshold,
 		{
-			"DIUC Minimum Entry Threshold (in 0.25 dB units)", "wimax.dcd.burst.diuc_entry_threshold", 
+			"DIUC Minimum Entry Threshold (in 0.25 dB units)", "wmx.dcd.burst.diuc_entry_threshold",
 			FT_FLOAT, BASE_DEC, NULL, 0x00, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_burst_diuc_exit_threshold,
 		{
-			"DIUC Mandatory Exit Threshold (in 0.25 dB units)", "wimax.dcd.burst.diuc_exit_threshold", 
+			"DIUC Mandatory Exit Threshold (in 0.25 dB units)", "wmx.dcd.burst.diuc_exit_threshold",
 			FT_FLOAT, BASE_DEC, NULL, 0x00, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_burst_fec,
 		{
-			"FEC Code Type", "wimax.dcd.burst.fec", 
+			"FEC Code Type", "wmx.dcd.burst.fec",
 			FT_UINT8, BASE_DEC, VALS(vals_dcd_burst_fec_ofdma), 0x00, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_burst_freq,
 		{
-			"Frequency", "wimax.dcd.burst.freq", 
+			"Frequency", "wmx.dcd.burst.freq",
 			FT_UINT8, BASE_DEC, NULL, 0x00, "", HFILL
 		}
 	},
 	{
 		&hf_dl_burst_reserved,
 		{
-			"Reserved", "wimax.dcd.burst.reserved", 
+			"Reserved", "wmx.dcd.burst.reserved",
 			FT_UINT8, BASE_HEX, NULL, 0xF0, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_burst_tcs,
 		{
-			"TCS", "wimax.dcd.burst.tcs", 
+			"TCS", "wmx.dcd.burst.tcs",
 			FT_UINT8, BASE_DEC, VALS(vals_dcd_burst_tcs), 0x00, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_channel_nr,
 		{
-			"Channel Nr", "wimax.dcd.channel_nr",
+			"Channel Nr", "wmx.dcd.channel_nr",
 			FT_UINT8, BASE_DEC, NULL, 0x00, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_config_change_count,
 		{
-			"Configuration Change Count", "wimax.dcd.config_change_count",
+			"Configuration Change Count", "wmx.dcd.config_change_count",
 			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_21_default_rssi_and_cinr_averaging_parameter_physical_cinr_measurements,
 		{
-			"Default Averaging Parameter for Physical CINR Measurements (in multiples of 1/16)", "wimax.dcd.default_physical_cinr_meas_averaging_parameter", 
+			"Default Averaging Parameter for Physical CINR Measurements (in multiples of 1/16)", "wmx.dcd.default_physical_cinr_meas_averaging_parameter",
 			FT_UINT8, BASE_HEX, NULL, 0xf0, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_21_default_rssi_and_cinr_averaging_parameter,
 		{
-			"Default RSSI and CINR Averaging Parameter", "wimax.dcd.default_rssi_and_cinr_averaging_parameter", 
+			"Default RSSI and CINR Averaging Parameter", "wmx.dcd.default_rssi_and_cinr_averaging_parameter",
 			FT_UINT8, BASE_HEX, NULL, 0x00, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_21_default_rssi_and_cinr_averaging_parameter_rssi_measurements,
 		{
-			"Default Averaging Parameter for RSSI Measurements (in multiples of 1/16)", "wimax.dcd.default_rssi_meas_averaging_parameter", 
+			"Default Averaging Parameter for RSSI Measurements (in multiples of 1/16)", "wmx.dcd.default_rssi_meas_averaging_parameter",
 			FT_UINT8, BASE_HEX, NULL, 0x0f, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_22_dl_amc_allocated_physical_bands_bitmap,
 		{
-			"DL AMC Allocated Physical Bands Bitmap", "wimax.dcd.dl_amc_allocated_phy_bands_bitmap", 
+			"DL AMC Allocated Physical Bands Bitmap", "wmx.dcd.dl_amc_allocated_phy_bands_bitmap",
 			FT_BYTES, BASE_HEX, NULL, 0x0, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_dl_burst_profile_diuc,
 		{
-			"DIUC", "wimax.dcd.dl_burst_profile_diuc",
+			"DIUC", "wmx.dcd.dl_burst_profile_diuc",
 			FT_UINT8, BASE_DEC, VALS(diuc_msgs), 0x0F, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_dl_burst_profile_rsv,
 		{
-			"Reserved", "wimax.dcd.dl_burst_profile_rsv",
+			"Reserved", "wmx.dcd.dl_burst_profile_rsv",
 			FT_UINT8, BASE_DEC, NULL, 0xF0, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_downlink_channel_id,
 		{
-			"Reserved", "wimax.dcd.dl_channel_id",
+			"Reserved", "wmx.dcd.dl_channel_id",
 			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
 		}
 	},
@@ -516,49 +515,49 @@ static hf_register_info hf[] =
         {
 		&hf_dcd_tlv_t_34_dl_region_definition,
 		{
-			"DL Region Definition", "wimax.dcd.dl_region_definition", 
+			"DL Region Definition", "wmx.dcd.dl_region_definition",
 			FT_BYTES, BASE_HEX, NULL, 0x00, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_34_dl_region_definition_num_region,
 		{
-			"Number of Regions", "wimax.dcd.dl_region_definition.num_region", 
+			"Number of Regions", "wmx.dcd.dl_region_definition.num_region",
 			FT_UINT8, BASE_DEC, NULL, 0xFC, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_34_dl_region_definition_num_subchannels,
 		{
-			"Number of Subchannels", "wimax.dcd.dl_region_definition.num_subchannels", 
+			"Number of Subchannels", "wmx.dcd.dl_region_definition.num_subchannels",
 			FT_UINT8, BASE_HEX, NULL, 0x00, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_34_dl_region_definition_num_symbols,
 		{
-			"Number of OFDMA Symbols", "wimax.dcd.dl_region_definition.num_symbols", 
+			"Number of OFDMA Symbols", "wmx.dcd.dl_region_definition.num_symbols",
 			FT_UINT8, BASE_HEX, NULL, 0x00, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_34_dl_region_definition_reserved,
 		{
-			"Reserved", "wimax.dcd.dl_region_definition.reserved", 
+			"Reserved", "wmx.dcd.dl_region_definition.reserved",
 			FT_UINT8, BASE_DEC, NULL, 0x03, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_34_dl_region_definition_subchannel_offset,
 		{
-			"Subchannel Offset", "wimax.dcd.dl_region_definition.subchannel_offset", 
+			"Subchannel Offset", "wmx.dcd.dl_region_definition.subchannel_offset",
 			FT_UINT8, BASE_HEX, NULL, 0x00, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_34_dl_region_definition_symbol_offset,
 		{
-			"OFDMA Symbol Offset", "wimax.dcd.dl_region_definition.symbol_offset", 
+			"OFDMA Symbol Offset", "wmx.dcd.dl_region_definition.symbol_offset",
 			FT_UINT8, BASE_HEX, NULL, 0x00, "", HFILL
 		}
 	},
@@ -566,7 +565,7 @@ static hf_register_info hf[] =
         {
 		&hf_dcd_eirxp,
 		{
-			"EIRXP (IR, max)", "wimax.dcd.eirxp", 
+			"EIRXP (IR, max)", "wmx.dcd.eirxp",
 			FT_INT16, BASE_DEC, NULL, 0x00, "", HFILL
 		}
 	},
@@ -574,35 +573,35 @@ static hf_register_info hf[] =
 	{
 		&hf_dcd_frame_duration,
 		{
-			"Frame Duration", "wimax.dcd.frame_duration",
+			"Frame Duration", "wmx.dcd.frame_duration",
 			FT_UINT32, BASE_HEX, NULL, 0x00, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_frame_duration_code,
 		{
-			"Frame Duration Code", "wimax.dcd.frame_duration_code", 
+			"Frame Duration Code", "wmx.dcd.frame_duration_code",
 			FT_UINT8, BASE_HEX, VALS(vals_dcd_frame_duration), 0x00, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_frame_nr,
 		{
-			"Frame Number", "wimax.dcd.frame_nr", 
+			"Frame Number", "wmx.dcd.frame_nr",
 			FT_UINT24, BASE_DEC, NULL, 0x00, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_frequency,
 		{
-			"Downlink Center Frequency", "wimax.dcd.frequency", 
+			"Downlink Center Frequency", "wmx.dcd.frequency",
 			FT_UINT32, BASE_DEC, NULL, 0x00, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_31_h_add_threshold,
 		{
-			"H_add Threshold", "wimax.dcd.h_add_threshold", 
+			"H_add Threshold", "wmx.dcd.h_add_threshold",
 			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
 		}
 	},
@@ -610,7 +609,7 @@ static hf_register_info hf[] =
 	{
 		&hf_dcd_h_arq_ack_delay,
 		{
-			"H-ARQ ACK Delay for DL Burst", "wimax.dcd.h_arq_ack_delay_dl_burst", 
+			"H-ARQ ACK Delay for DL Burst", "wmx.dcd.h_arq_ack_delay_dl_burst",
 			FT_UINT8, BASE_DEC, NULL, 0x00, "", HFILL
 		}
 	},
@@ -618,7 +617,7 @@ static hf_register_info hf[] =
         {
 		&hf_dcd_h_arq_ack_delay,
 		{
-			"H-ARQ ACK Delay for UL Burst", "wimax.dcd.h_arq_ack_delay_ul_burst", 
+			"H-ARQ ACK Delay for UL Burst", "wmx.dcd.h_arq_ack_delay_ul_burst",
 			FT_UINT8, BASE_DEC, NULL, 0x00, "", HFILL
 		}
 	},
@@ -626,126 +625,126 @@ static hf_register_info hf[] =
         {
 		&hf_dcd_tlv_t_32_h_delete_threshold,
 		{
-			"H_delete Threshold", "wimax.dcd.h_delete_threshold", 
+			"H_delete Threshold", "wmx.dcd.h_delete_threshold",
 			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_50_ho_type_support,
 		{
-			"HO Type Support", "wimax.dcd.ho_type_support", 
+			"HO Type Support", "wmx.dcd.ho_type_support",
 			FT_UINT8, BASE_HEX, NULL, 0x00, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_50_ho_type_support_fbss_ho,
 		{
-			"FBSS HO", "wimax.dcd.ho_type_support.fbss_ho", 
+			"FBSS HO", "wmx.dcd.ho_type_support.fbss_ho",
 			FT_UINT8, BASE_HEX, VALS(tfs_support), 0x20, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_50_ho_type_support_ho,
 		{
-			"HO", "wimax.dcd.ho_type_support.ho", 
+			"HO", "wmx.dcd.ho_type_support.ho",
 			FT_UINT8, BASE_HEX, VALS(tfs_support), 0x80, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_50_ho_type_support_mdho,
 		{
-			"MDHO", "wimax.dcd.ho_type_support.mdho", 
+			"MDHO", "wmx.dcd.ho_type_support.mdho",
 			FT_UINT8, BASE_HEX, VALS(tfs_support), 0x40, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_50_ho_type_support_reserved,
 		{
-			"Reserved", "wimax.dcd.ho_type_support.reserved", 
+			"Reserved", "wmx.dcd.ho_type_support.reserved",
 			FT_UINT8, BASE_HEX, NULL, 0x1f, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_51_hysteresis_margin,
 		{
-			"Hysteresis Margin", "wimax.dcd.hysteresis_margin", 
+			"Hysteresis Margin", "wmx.dcd.hysteresis_margin",
 			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_invalid_tlv,
 		{
-			"Invalid TLV", "wimax.dcd.invalid_tlv", 
+			"Invalid TLV", "wmx.dcd.invalid_tlv",
 			FT_BYTES, BASE_HEX, NULL, 0, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_mac_version,
 		{
-			"MAC Version", "wimax.dcd.mac_version", 
+			"MAC Version", "wmx.dcd.mac_version",
 			FT_UINT8, BASE_DEC, VALS(vals_dcd_mac_version), 0x00, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_20_maximum_retransmission,
 		{
-			"Maximum Retransmission", "wimax.dcd.maximum_retransmission", 
+			"Maximum Retransmission", "wmx.dcd.maximum_retransmission",
 			FT_UINT8, BASE_DEC, NULL, 0x00, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_60_noise_interference,
 		{
-			"Noise and Interference", "wimax.dcd.noise_interference", 
+			"Noise and Interference", "wmx.dcd.noise_interference",
 			FT_UINT8, BASE_HEX, NULL, 0x0, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_35_paging_group_id,
 		{
-			"Paging Group ID", "wimax.dcd.paging_group_id", 
+			"Paging Group ID", "wmx.dcd.paging_group_id",
 			FT_UINT16, BASE_HEX, NULL, 0x0, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_tlv_t_36_tusc1_permutation_active_subchannels_bitmap,
 		{
-			"TUSC1 permutation active subchannels bitmap", "wimax.dcd.tusc1",
+			"TUSC1 permutation active subchannels bitmap", "wmx.dcd.tusc1",
 			FT_UINT16, BASE_HEX, NULL, 0xFF80, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_tlv_t_37_tusc2_permutation_active_subchannels_bitmap,
 		{
-			"TUSC2 permutation active subchannels bitmap", "wimax.dcd.tusc2",
+			"TUSC2 permutation active subchannels bitmap", "wmx.dcd.tusc2",
 			FT_UINT16, BASE_HEX, NULL, 0xFFF8, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_45_paging_interval_length,
 		{
-			"Paging Interval Length", "wimax.dcd.paging_interval_length", 
+			"Paging Interval Length", "wmx.dcd.paging_interval_length",
 			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_19_permutation_type_for_broadcast_regions_in_harq_zone,
 		{
-			"Permutation Type for Broadcast Region in HARQ Zone", "wimax.dcd.permutation_type_broadcast_region_in_harq_zone", 
+			"Permutation Type for Broadcast Region in HARQ Zone", "wmx.dcd.permutation_type_broadcast_region_in_harq_zone",
 			FT_UINT8, BASE_DEC, VALS(vals_dcd_permutation_type), 0x00, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_phy_type,
 		{
-			"PHY Type", "wimax.dcd.phy_type",
+			"PHY Type", "wmx.dcd.phy_type",
 			FT_UINT8, BASE_HEX, NULL, 0x00, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_power_adjustment,
 		{
-			"Power Adjustment Rule", "wimax.dcd.power_adjustment",
+			"Power Adjustment Rule", "wmx.dcd.power_adjustment",
 			FT_UINT8, BASE_HEX, VALS(vals_dcd_power_adjustmnt), 0x00, "", HFILL
 		}
 	},
@@ -753,7 +752,7 @@ static hf_register_info hf[] =
 	{
 		&hf_dcd_rss,
 		{
-			"RSS (IR, max)", "wimax.dcd.rss", 
+			"RSS (IR, max)", "wmx.dcd.rss",
 			FT_INT16, BASE_DEC, NULL, 0x00, "", HFILL
 		}
 	},
@@ -761,7 +760,7 @@ static hf_register_info hf[] =
 	{
 		&hf_dcd_rtg,
 		{
-			"RTG", "wimax.dcd.rtg", 
+			"RTG", "wmx.dcd.rtg",
 			FT_UINT8, BASE_HEX, NULL, 0x00, "", HFILL
 		}
 	},
@@ -769,7 +768,7 @@ static hf_register_info hf[] =
 	{
 		&hf_dcd_size_cqich_id,
 		{
-			"Size of CQICH-ID Field", "wimax.dcd.size_cqich_id", 
+			"Size of CQICH-ID Field", "wmx.dcd.size_cqich_id",
 			FT_UINT8, BASE_DEC, VALS(vals_dcd_size_of_cqich_id), 0x00, "", HFILL
 		}
 	},
@@ -777,70 +776,70 @@ static hf_register_info hf[] =
 	{
 		&hf_dcd_channel_switch_frame_nr,
 		{
-			"Channel Switch Frame Number", "wimax.dcd.switch_frame", 
+			"Channel Switch Frame Number", "wmx.dcd.switch_frame",
 			FT_UINT24, BASE_DEC, NULL, 0x00, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_52_time_to_trigger_duration,
 		{
-			"Time to Trigger Duration", "wimax.dcd.time_trigger_duration", 
+			"Time to Trigger Duration", "wmx.dcd.time_trigger_duration",
 			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_543_trigger_averaging_duration,
 		{
-			"Trigger Averaging Duration", "wimax.dcd.trigger_averaging_duration", 
+			"Trigger Averaging Duration", "wmx.dcd.trigger_averaging_duration",
 			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_542_trigger_value,
 		{
-			"Trigger Value", "wimax.dcd.trigger_value", 
+			"Trigger Value", "wmx.dcd.trigger_value",
 			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_ttg,
 		{
-			"TTG", "wimax.dcd.ttg", 
+			"TTG", "wmx.dcd.ttg",
 			FT_UINT16, BASE_HEX, NULL, 0x00, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_541_type_function_action,
 		{
-			"Type/Function/Action", "wimax.dcd.type_function_action", 
+			"Type/Function/Action", "wmx.dcd.type_function_action",
 			FT_UINT8, BASE_HEX, NULL, 0x0, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_541_action,
 		{
-			"Action", "wimax.dcd.type_function_action.action", 
+			"Action", "wmx.dcd.type_function_action.action",
 			FT_UINT8, BASE_HEX, VALS(vals_dcd_action), 0x7, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_541_function,
 		{
-			"Function", "wimax.dcd.type_function_action.function", 
+			"Function", "wmx.dcd.type_function_action.function",
 			FT_UINT8, BASE_HEX, VALS(vals_dcd_function), 0x38, "", HFILL
 		}
 	},
         {
 		&hf_dcd_tlv_t_541_type,
 		{
-			"Type", "wimax.dcd.type_function_action.type", 
+			"Type", "wmx.dcd.type_function_action.type",
 			FT_UINT8, BASE_HEX, VALS(vals_dcd_type), 0xC0, "", HFILL
 		}
 	},
 	{
 		&hf_dcd_unknown_type,
 		{
-			"Unknown DCD Type", "wimax.dcd.unknown_tlv_value",
+			"Unknown DCD Type", "wmx.dcd.unknown_tlv_value",
 			FT_BYTES, BASE_HEX, NULL, 0x0, "", HFILL
 		}
 	}
@@ -854,7 +853,7 @@ void proto_register_mac_mgmt_msg_dcd(void)
 		proto_mac_mgmt_msg_dcd_decoder = proto_register_protocol (
 							"WiMax DCD/UCD Messages", /* name */
 							"WiMax DCD/UCD (cd)", /* short name */
-							"cd" /* abbrev */
+							"wmx.cd" /* abbrev */
 							);
 
 		proto_register_field_array(proto_mac_mgmt_msg_dcd_decoder, hf, array_length(hf));
@@ -918,7 +917,7 @@ void dissect_mac_mgmt_msg_dcd_decoder(tvbuff_t *tvb, packet_info *pinfo, proto_t
 			tlv_len = get_tlv_length(&tlv_info);
 			if(tlv_type == -1 || tlv_len > MAX_TLV_LEN || tlv_len < 1)
 			{	/* invalid tlv info */
-				if(pinfo->cinfo)
+				if(check_col(pinfo->cinfo, COL_INFO))
 				{
 					col_append_sep_str(pinfo->cinfo, COL_INFO, NULL, "DCD TLV error");
 				}
@@ -955,7 +954,7 @@ void dissect_mac_mgmt_msg_dcd_decoder(tvbuff_t *tvb, packet_info *pinfo, proto_t
 						length = get_tlv_length(&tlv_info);
 						if(tlv_type == -1 || length > MAX_TLV_LEN || length < 1)
 						{	/* invalid tlv info */
-							if(pinfo->cinfo)
+							if(check_col(pinfo->cinfo, COL_INFO))
 							{
 								col_append_sep_str(pinfo->cinfo, COL_INFO, NULL, "DL Burst Profile TLV error");
 							}
@@ -1243,7 +1242,7 @@ void dissect_mac_mgmt_msg_dcd_decoder(tvbuff_t *tvb, packet_info *pinfo, proto_t
 						length = get_tlv_length(&tlv_info);
 						if(tlv_type == -1 || length > MAX_TLV_LEN || length < 1)
 						{	/* invalid tlv info */
-							if(pinfo->cinfo)
+							if(check_col(pinfo->cinfo, COL_INFO))
 							{
 								col_append_sep_str(pinfo->cinfo, COL_INFO, NULL, "Trigger TLV error");
 							}
