@@ -5,7 +5,7 @@
  *
  * Author: Lu Pan <lu.pan@intel.com>
  *
- * $Id: msg_rep.c 23660 2007-11-28 22:56:27Z gerald $
+ * $Id: msg_rep.c 27192 2009-01-08 07:36:11Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -39,7 +39,6 @@
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/prefs.h>
 #include "wimax_tlv.h"
 #include "wimax_mac.h"
 #include "wimax_utils.h"
@@ -1027,7 +1026,7 @@ void dissect_mac_mgmt_msg_rep_req_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 			tlv_len = get_tlv_length(&tlv_info);
 			if(tlv_type == -1 || tlv_len > MAX_TLV_LEN || tlv_len < 1)
 			{	/* invalid tlv info */
-				if(pinfo->cinfo)
+				if(check_col(pinfo->cinfo, COL_INFO))
 				{
 					col_append_sep_str(pinfo->cinfo, COL_INFO, NULL, "REP-REQ TLV error");
 				}
@@ -1056,7 +1055,7 @@ void dissect_mac_mgmt_msg_rep_req_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 					length = get_tlv_length(&tlv_info);
 					if(tlv_type == -1 || length > MAX_TLV_LEN || length < 1)
 					{	/* invalid tlv info */
-						if(pinfo->cinfo)
+						if(check_col(pinfo->cinfo, COL_INFO))
 						{
 							col_append_sep_str(pinfo->cinfo, COL_INFO, NULL, "REP-REQ Report Request TLV error");
 						}
@@ -1201,7 +1200,7 @@ void dissect_mac_mgmt_msg_rep_rsp_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 			tlv_len = get_tlv_length(&tlv_info);
 			if(tlv_type == -1 || tlv_len > MAX_TLV_LEN || tlv_len < 1)
 			{	/* invalid tlv info */
-				if(pinfo->cinfo)
+				if(check_col(pinfo->cinfo, COL_INFO))
 				{
 					col_append_sep_str(pinfo->cinfo, COL_INFO, NULL, "REP-RSP TLV error");
 				}
@@ -1230,7 +1229,7 @@ void dissect_mac_mgmt_msg_rep_rsp_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 						length = get_tlv_length(&tlv_info);
 						if(tlv_type == -1 || length > MAX_TLV_LEN || length < 1)
 						{	/* invalid tlv info */
-							if(pinfo->cinfo)
+							if(check_col(pinfo->cinfo, COL_INFO))
 							{
 								col_append_sep_str(pinfo->cinfo, COL_INFO, NULL, "REP-RSP report subtype TLV error");
 							}
@@ -1308,7 +1307,7 @@ void dissect_mac_mgmt_msg_rep_rsp_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 						length = get_tlv_length(&tlv_info);
 						if(tlv_type == -1 || length > MAX_TLV_LEN || length < 1)
 						{	/* invalid tlv info */
-							if(pinfo->cinfo)
+							if(check_col(pinfo->cinfo, COL_INFO))
 							{
 								col_append_sep_str(pinfo->cinfo, COL_INFO, NULL, "REP-RSP channel subtype TLV error");
 							}
@@ -1360,7 +1359,7 @@ void dissect_mac_mgmt_msg_rep_rsp_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 						length = get_tlv_length(&tlv_info);
 						if(tlv_type == -1 || length > MAX_TLV_LEN || length < 1)
 						{	/* invalid tlv info */
-							if(pinfo->cinfo)
+							if(check_col(pinfo->cinfo, COL_INFO))
 							{
 								col_append_sep_str(pinfo->cinfo, COL_INFO, NULL, "REP-RSP zone-specific phy CINR report subtype TLV error");
 							}
@@ -1451,7 +1450,7 @@ void dissect_mac_mgmt_msg_rep_rsp_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 						length = get_tlv_length(&tlv_info);
 						if(tlv_type == -1 || length > MAX_TLV_LEN || length < 1)
 						{	/* invalid tlv info */
-							if(pinfo->cinfo)
+							if(check_col(pinfo->cinfo, COL_INFO))
 							{
 								col_append_sep_str(pinfo->cinfo, COL_INFO, NULL, "REP-RSP preamble physical CINR report subtype TLV error");
 							}
@@ -1499,7 +1498,7 @@ void dissect_mac_mgmt_msg_rep_rsp_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 						length = get_tlv_length(&tlv_info);
 						if(tlv_type == -1 || length > MAX_TLV_LEN || length < 1)
 						{	/* invalid tlv info */
-							if(pinfo->cinfo)
+							if(check_col(pinfo->cinfo, COL_INFO))
 							{
 								col_append_sep_str(pinfo->cinfo, COL_INFO, NULL, "REP-RSP zone-specific effective CINR report subtype TLV error");
 							}
@@ -1561,7 +1560,7 @@ void dissect_mac_mgmt_msg_rep_rsp_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 						length = get_tlv_length(&tlv_info);
 						if(tlv_type == -1 || length > MAX_TLV_LEN || length < 1)
 						{	/* invalid tlv info */
-							if(pinfo->cinfo)
+							if(check_col(pinfo->cinfo, COL_INFO))
 							{
 								col_append_sep_str(pinfo->cinfo, COL_INFO, NULL, "REP-RSP preamble effective CINR report subtype TLV error");
 							}
