@@ -5,7 +5,7 @@
  *
  * Author: Lu Pan <lu.pan@intel.com>
  *
- * $Id: msg_res_cmd.c 23660 2007-11-28 22:56:27Z gerald $
+ * $Id: msg_res_cmd.c 27192 2009-01-08 07:36:11Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -40,7 +40,6 @@
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/prefs.h>
 #include "wimax_tlv.h"
 #include "wimax_mac.h"
 #include "wimax_utils.h"
@@ -138,7 +137,7 @@ void dissect_mac_mgmt_msg_res_cmd_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 			tlv_len = get_tlv_length(&tlv_info);
 			if(tlv_type == -1 || tlv_len > MAX_TLV_LEN || tlv_len < 1)
 			{	/* invalid tlv info */
-				if(pinfo->cinfo)
+				if(check_col(pinfo->cinfo, COL_INFO))
 				{
 					col_append_sep_str(pinfo->cinfo, COL_INFO, NULL, "RES-CMD TLV error");
 				}
