@@ -5,7 +5,7 @@
  *
  * Author: Lu Pan <lu.pan@intel.com>
  *
- * $Id: msg_ucd.c 23660 2007-11-28 22:56:27Z gerald $
+ * $Id: msg_ucd.c 27192 2009-01-08 07:36:11Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -754,7 +754,7 @@ void dissect_mac_mgmt_msg_ucd_decoder(tvbuff_t *tvb, packet_info *pinfo, proto_t
 			tlv_len = get_tlv_length(&tlv_info);
 			if(tlv_type == -1 || tlv_len > MAX_TLV_LEN || tlv_len < 1)
 			{	/* invalid tlv info */
-				if(pinfo->cinfo)
+				if(check_col(pinfo->cinfo, COL_INFO))
 				{
 					col_append_sep_str(pinfo->cinfo, COL_INFO, NULL, "UCD TLV error");
 				}
@@ -840,7 +840,7 @@ void dissect_mac_mgmt_msg_ucd_decoder(tvbuff_t *tvb, packet_info *pinfo, proto_t
 						tlv_type = get_tlv_type(&tlv_info);
 						if(tlv_type == -1)
 						{	/* invalid tlv info */
-							if(pinfo->cinfo)
+							if(check_col(pinfo->cinfo, COL_INFO))
 							{
 								col_append_sep_str(pinfo->cinfo, COL_INFO, NULL, "UL Burst Profile error");
 							}
