@@ -5,7 +5,7 @@
  *
  * Author: Lu Pan <lu.pan@intel.com>
  *
- * $Id: wimax_compact_ulmap_ie_decoder.c 23661 2007-11-28 23:22:38Z gerald $
+ * $Id: wimax_compact_ulmap_ie_decoder.c 26103 2008-08-29 01:40:32Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,7 +34,6 @@
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/prefs.h>
 #include "crc.h"
 
 /* MASKs */
@@ -724,7 +723,7 @@ static hf_register_info hf_cdma_allocation[] =
 	},
 	{	/* display the BW Request Mandatory */
 		&hf_cdma_allocation_bw_req,
-		{"BW Request Mandatory", "wmx.cdma_allocation.bw_req", FT_UINT8, BASE_DEC, TFS(&tfs_yes_no_ie), CDMA_ALLOCATION_BW_REQUEST_MANDATORY_MASK, "", HFILL}
+		{"BW Request Mandatory", "wmx.cdma_allocation.bw_req", FT_BOOLEAN, 8, TFS(&tfs_yes_no_ie), CDMA_ALLOCATION_BW_REQUEST_MANDATORY_MASK, "", HFILL}
 	},
 	{	/* display the Duration */
 		&hf_cdma_allocation_duration_1,
@@ -756,7 +755,7 @@ static hf_register_info hf_cdma_allocation[] =
 	},
 	{	/* display the BW Request Mandatory */
 		&hf_cdma_allocation_bw_req_1,
-		{"BW Request Mandatory", "wmx.cdma_allocation.bw_req", FT_UINT32, BASE_DEC, TFS(&tfs_yes_no_ie), CDMA_ALLOCATION_BW_REQUEST_MANDATORY_MASK_1, "", HFILL}
+		{"BW Request Mandatory", "wmx.cdma_allocation.bw_req", FT_BOOLEAN, 32, TFS(&tfs_yes_no_ie), CDMA_ALLOCATION_BW_REQUEST_MANDATORY_MASK_1, "", HFILL}
 	}
 };
 
