@@ -1,7 +1,7 @@
 /* print.c
  * Routines for printing packet analysis trees.
  *
- * $Id: print.c 31691 2010-01-27 00:00:53Z gerald $
+ * $Id: print.c 33975 2010-08-27 23:54:04Z gerald $
  *
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
@@ -240,6 +240,10 @@ proto_tree_write_pdml(epan_dissect_t *edt, FILE *fh)
 	data.src_list = edt->pi.data_src;
 	data.edt = edt;
 
+	/* We shouldn't be called with a NULL pointer here because we've
+	 * created a visible protocol tree */
+	g_assert(data.src_list);
+
 	fprintf(fh, "<packet>\n");
 
 	/* Print a "geninfo" protocol as required by PDML */
@@ -780,11 +784,15 @@ print_hex_data(print_stream_t *stream, epan_dissect_t *edt)
 	GSList *src_le;
 	data_source *src;
 	tvbuff_t *tvb;
-	char *name;
+	const char *name;
 	char *line;
 	const guchar *cp;
 	guint length;
 
+	/* We shouldn't be called with a NULL pointer here because we've
+	 * created a visible protocol tree */
+	g_assert(edt->pi.data_src);
+
 	/*
 	 * Set "multiple_sources" iff this frame has more than one
 	 * data source; if it does, we need to print the name of
@@ -798,7 +806,7 @@ print_hex_data(print_stream_t *stream, epan_dissect_t *edt)
 		src = src_le->data;
 		tvb = src->tvb;
 		if (multiple_sources) {
-			name = src->name;
+			name = get_data_source_name(src);
 			print_line(stream, 0, "");
 			line = g_strdup_printf("%s:", name);
 			print_line(stream, 0, line);
@@ -926,6 +934,11 @@ void ps_clean_string(unsigned char *out, const unsigned char *in,
 	int rd, wr;
 	char c;
 
+	if (in == NULL) {
+		out[0] = '\0';
+		return;
+	}
+
 	for (rd = 0, wr = 0 ; wr < outbuf_size; rd++, wr++ ) {
 		c = in[rd];
 		switch (c) {
