@@ -1,7 +1,7 @@
 /* proto_hier_stats.c
  * Routines for calculating statistics based on protocol.
  *
- * $Id: proto_hier_stats.c 23672 2007-11-29 15:31:59Z gerald $
+ * $Id: proto_hier_stats.c 28108 2009-04-21 16:57:52Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -88,18 +88,24 @@ process_node(proto_node *ptree_node, GNode *parent_stat_node, ph_stats_t *ps, gu
 	finfo = PITEM_FINFO(ptree_node);
 	g_assert(finfo);
 
-	stat_node = find_stat_node(parent_stat_node, finfo->hfinfo);
+	/* If the field info isn't related to a protocol but to a field,
+	 * don't count them, as they don't belong to any protocol.
+	 * (happens e.g. for toplevel tree item of desegmentation "[Reassembled TCP Segments]") */
+	if (finfo->hfinfo->parent != -1) {
+		/* Skip this element, use parent status node */
+		stat_node = parent_stat_node;
+		stats = STAT_NODE_STATS(stat_node);
+	} else {
+		stat_node = find_stat_node(parent_stat_node, finfo->hfinfo);
 
-	stats = STAT_NODE_STATS(stat_node);
-	stats->num_pkts_total++;
-	stats->num_bytes_total += pkt_len;
+		stats = STAT_NODE_STATS(stat_node);
+		stats->num_pkts_total++;
+		stats->num_bytes_total += pkt_len;
+	}
 
 	proto_sibling_node = ptree_node->next;
 
-	/* If the field info isn't related to a protocol but to a field (parent != -1),
-	 * don't count them, as they don't belong to any protocol.
-	 * (happens e.g. for toplevel tree item of desegmentation "[Reassembled TCP Segments]") */
-	if (proto_sibling_node && proto_sibling_node->finfo->hfinfo->parent == -1) {
+	if (proto_sibling_node) {
 		/* If the name does not exist for this proto_sibling_node, then it is
 		 * not a normal protocol in the top-level tree.  It was instead
 		 * added as a normal tree such as IPv6's Hop-by-hop Option Header and
@@ -200,7 +206,7 @@ ph_stats_new(void)
 	/* Count of packets at which we've looked. */
 	count = 0;
 	/* Progress so far. */
-	progbar_val = 0.0;
+	progbar_val = 0.0f;
 
 	stop_flag = FALSE;
 	g_get_current_time(&start_time);
