@@ -1,7 +1,7 @@
 /* tap-radiusstat.c
  * Copyright 2006 Alejandro Vaquero <alejandrovaquero@yahoo.com>
  *
- * 
+ * $Id: tap-radiusstat.c 27026 2008-12-16 19:28:48Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -54,14 +54,15 @@ typedef struct _radiusstat_t {
 } radiusstat_t;
 
 static const value_string radius_message_code[] = {
-  {  0,	"Overall       "},
-  {  1,	"Access        "},
-  {  2,	"Accounting    "},
-  {  3,	"Access Passw  "},
+  {  0, "Overall       "},
+  {  1, "Access        "},
+  {  2, "Accounting    "},
+  {  3, "Access Passw  "},
   {  4, "Ascend Acce Ev"},
-  {  5, "Diconnect     "},
+  {  5, "Disconnect    "},
   {  6, "Change Filter "},
   {  7, "Other         "},
+  {  0, NULL}
 };
 
 static int
