@@ -1,7 +1,7 @@
 /* tap-rtp-common.c
  * RTP stream handler functions used by tshark and wireshark
  *
- * $Id: tap-rtp-common.c 27934 2009-04-02 17:34:30Z gerald $
+ * $Id: tap-rtp-common.c 31539 2010-01-16 01:02:51Z gerald $
  *
  * Copyright 2008, Ericsson AB
  * By Balint Reczey <balint.reczey@ericsson.com>
@@ -204,7 +204,7 @@ int rtpstream_packet(void *arg, packet_info *pinfo, epan_dissect_t *edt _U_, con
 	tmp_strinfo.info_payload_type_str = rtpinfo->info_payload_type_str;
 
 	if (tapinfo->mode == TAP_ANALYSE) {
-		/* check wether we already have a stream with these parameters in the list */
+		/* check whether we already have a stream with these parameters in the list */
 		list = g_list_first(tapinfo->strinfo_list);
 		while (list)
 		{
@@ -357,7 +357,7 @@ get_clock_rate(guint32 key)
 		if (clock_map[i].key == key)
 			return clock_map[i].value;
 	}
-	return 1;
+	return 0;
 }
 
 typedef struct _mimetype_and_clock {
@@ -399,7 +399,7 @@ static const mimetype_and_clock mimetype_and_clock_map[] = {
 	{"GSM-EFR",	8000},			/* [RFC3551] */
 	{"H263-1998",	90000},		/* [RFC2429],[RFC3555] */
 	{"H263-2000",	90000},		/* [RFC2429],[RFC3555] */
-	{"H264", 90000},            /* [RFC3984] */
+	{"H264",	90000},         /* [RFC3984] */
 	{"MP1S",	90000},			/* [RFC2250],[RFC3555] */
 	{"MP2P",	90000},			/* [RFC2250],[RFC3555] */
 	{"MP4V-ES",	90000},			/* [RFC3016] */
@@ -427,7 +427,7 @@ get_dyn_pt_clock_rate(gchar *payload_type_str)
 			return mimetype_and_clock_map[i].value;
 	}
 
-	return 1;
+	return 0;
 }
 
 /****************************************************************************/
@@ -437,132 +437,77 @@ int rtp_packet_analyse(tap_rtp_stat_t *statinfo,
 {
 	double current_time;
 	double current_jitter;
-	double current_diff;
+	double current_diff = 0;
+	double nominaltime;
+	double arrivaltime;		/* Time relative to start_time */
+	double expected_time;
+	double absskew;
 	guint32 clock_rate;
+	guint32 old_flags;
 
-	statinfo->flags = 0;
-	/* check payload type */
-	if (rtpinfo->info_payload_type == PT_CN
-		|| rtpinfo->info_payload_type == PT_CN_OLD)
-		statinfo->flags |= STAT_FLAG_PT_CN;
-	if (statinfo->pt == PT_CN
-		|| statinfo->pt == PT_CN_OLD)
-		statinfo->flags |= STAT_FLAG_FOLLOW_PT_CN;
-	if (rtpinfo->info_payload_type != statinfo->pt)
-		statinfo->flags |= STAT_FLAG_PT_CHANGE;
-	statinfo->pt = rtpinfo->info_payload_type;
-	/*
-	 * XXX - should "get_clock_rate()" return 0 for unknown
-	 * payload types, presumably meaning that we should
-	 * just ignore this packet?
-	 */
-	if (statinfo->pt < 96 ){
-		clock_rate = get_clock_rate(statinfo->pt);
-	}else{ /* dynamic PT */
-		if ( rtpinfo->info_payload_type_str != NULL )
-			clock_rate = get_dyn_pt_clock_rate(rtpinfo-> info_payload_type_str);
-		else
-			clock_rate = 1;
-	}
+	/* Store the current time */
+	current_time = nstime_to_msec(&pinfo->fd->rel_ts);
 
-	/* store the current time and calculate the current jitter */
-	current_time = nstime_to_sec(&pinfo->fd->rel_ts);
-	current_diff = fabs (current_time - (statinfo->time) - ((double)(rtpinfo->info_timestamp)-(double)(statinfo->timestamp))/clock_rate);
-	current_jitter = statinfo->jitter + ( current_diff - statinfo->jitter)/16;
-	statinfo->delta = current_time-(statinfo->time);
-	statinfo->jitter = current_jitter;
-	statinfo->diff = current_diff;
-
-	/* calculate the BW in Kbps adding the IP+UDP header to the RTP -> 20bytes(IP)+8bytes(UDP) = 28bytes */
-	statinfo->bw_history[statinfo->bw_index].bytes = rtpinfo->info_data_len + 28;
-	statinfo->bw_history[statinfo->bw_index].time = current_time;
-	/* check if there are more than 1sec in the history buffer to calculate BW in bps. If so, remove those for the calculation */
-	while ((statinfo->bw_history[statinfo->bw_start_index].time+1)<current_time){
-	 	statinfo->total_bytes -= statinfo->bw_history[statinfo->bw_start_index].bytes;
-		statinfo->bw_start_index++;
-		if (statinfo->bw_start_index == BUFF_BW) statinfo->bw_start_index=0;
-	};
-	statinfo->total_bytes += rtpinfo->info_data_len + 28;
-	statinfo->bandwidth = (double)(statinfo->total_bytes*8)/1000;
-	statinfo->bw_index++;
-	if (statinfo->bw_index == BUFF_BW) statinfo->bw_index = 0;
-
-
-	/*  is this the first packet we got in this direction? */
+	/*  Is this the first packet we got in this direction? */
 	if (statinfo->first_packet) {
 		statinfo->start_seq_nr = rtpinfo->info_seq_num;
+		statinfo->stop_seq_nr = rtpinfo->info_seq_num;
+		statinfo->seq_num = rtpinfo->info_seq_num;
 		statinfo->start_time = current_time;
+		statinfo->timestamp = rtpinfo->info_timestamp;
+		statinfo->first_timestamp = rtpinfo->info_timestamp;
+		statinfo->time = current_time;
+		statinfo->lastnominaltime = 0;
+		statinfo->pt = rtpinfo->info_payload_type;
+		statinfo->reg_pt = rtpinfo->info_payload_type;
+		statinfo->bw_history[statinfo->bw_index].bytes = rtpinfo->info_data_len + 28;
+		statinfo->bw_history[statinfo->bw_index].time = current_time;
+		statinfo->bw_index++;
+		statinfo->total_bytes += rtpinfo->info_data_len + 28;
+		statinfo->bandwidth = (double)(statinfo->total_bytes*8)/1000;
+		/* Not needed ? initialised to zero? */
 		statinfo->delta = 0;
 		statinfo->jitter = 0;
 		statinfo->diff = 0;
+
+		statinfo->total_nr++;
 		statinfo->flags |= STAT_FLAG_FIRST;
-		statinfo->first_packet = FALSE;
-	}
-	/* is it a packet with the mark bit set? */
-	if (rtpinfo->info_marker_set) {
-		statinfo->delta_timestamp = rtpinfo->info_timestamp - statinfo->timestamp;
-		if (rtpinfo->info_timestamp > statinfo->timestamp){
+		if (rtpinfo->info_marker_set) {
 			statinfo->flags |= STAT_FLAG_MARKER;
 		}
-		else{
-			statinfo->flags |= STAT_FLAG_WRONG_TIMESTAMP;
-		}
-	}
-	/* is it a regular packet? */
-	if (!(statinfo->flags & STAT_FLAG_FIRST)
-		&& !(statinfo->flags & STAT_FLAG_MARKER)
-		&& !(statinfo->flags & STAT_FLAG_PT_CN)
-		&& !(statinfo->flags & STAT_FLAG_WRONG_TIMESTAMP)
-		&& !(statinfo->flags & STAT_FLAG_FOLLOW_PT_CN)) {
-		/* include it in maximum delta calculation */
-		if (statinfo->delta > statinfo->max_delta) {
-			statinfo->max_delta = statinfo->delta;
-			statinfo->max_nr = pinfo->fd->num;
-		}
-		/* maximum and mean jitter calculation */
-		if (statinfo->jitter > statinfo->max_jitter) {
-			statinfo->max_jitter = statinfo->jitter;
-		}
-		statinfo->mean_jitter = (statinfo->mean_jitter*statinfo->total_nr + current_diff) / (statinfo->total_nr+1);
-	}
-	/* regular payload change? (CN ignored) */
-	if (!(statinfo->flags & STAT_FLAG_FIRST)
-		&& !(statinfo->flags & STAT_FLAG_PT_CN)) {
-		if ((statinfo->pt != statinfo->reg_pt)
-			&& (statinfo->reg_pt != PT_UNDEFINED)) {
-			statinfo->flags |= STAT_FLAG_REG_PT_CHANGE;
-		}
-	}
-
-	/* set regular payload*/
-	if (!(statinfo->flags & STAT_FLAG_PT_CN)) {
-		statinfo->reg_pt = statinfo->pt;
+		statinfo->first_packet = FALSE;
+		return 0;
 	}
 
+	/* Save old flags and reset flags */
+	old_flags = statinfo->flags;
+	statinfo->flags = 0;
 
 	/* When calculating expected rtp packets the seq number can wrap around
-	* so we have to count the number of cycles
-	* Variable cycles counts the wraps around in forwarding connection and
-	* under is flag that indicates where we are
-	*
-	* XXX how to determine number of cycles with all possible lost, late
-	* and duplicated packets without any doubt? It seems to me, that
-	* because of all possible combination of late, duplicated or lost
-	* packets, this can only be more or less good approximation
-	*
-	* There are some combinations (rare but theoretically possible),
-	* where below code won't work correctly - statistic may be wrong then.
-	*/
+	 * so we have to count the number of cycles
+	 * Variable cycles counts the wraps around in forwarding connection and
+	 * under is flag that indicates where we are
+	 *
+	 * XXX How to determine number of cycles with all possible lost, late
+	 * and duplicated packets without any doubt? It seems to me, that
+	 * because of all possible combination of late, duplicated or lost
+	 * packets, this can only be more or less good approximation
+	 *
+	 * There are some combinations (rare but theoretically possible),
+	 * where below code won't work correctly - statistic may be wrong then.
+	 */
 
-	/* so if the current sequence number is less than the start one
-	* we assume, that there is another cycle running */
+	/* So if the current sequence number is less than the start one
+	 * we assume, that there is another cycle running
+	 */
 	if ((rtpinfo->info_seq_num < statinfo->start_seq_nr) && (statinfo->under == FALSE)){
 		statinfo->cycles++;
 		statinfo->under = TRUE;
 	}
 	/* what if the start seq nr was 0? Then the above condition will never
-	* be true, so we add another condition. XXX The problem would arise
-	* if one of the packets with seq nr 0 or 65535 would be lost or late */
+	 * be true, so we add another condition. XXX The problem would arise
+	 * if one of the packets with seq nr 0 or 65535 would be lost or late
+	 */
 	else if ((rtpinfo->info_seq_num == 0) && (statinfo->stop_seq_nr == 65535) &&
 		(statinfo->under == FALSE)){
 		statinfo->cycles++;
@@ -574,26 +519,177 @@ int rtp_packet_analyse(tap_rtp_stat_t *statinfo,
 	}
 
 	/* Since it is difficult to count lost, duplicate or late packets separately,
-	* we would like to know at least how many times the sequence number was not ok */
+	 * we would like to know at least how many times the sequence number was not ok
+	 */
 
-	/* if the current seq number equals the last one or if we are here for
-	* the first time, then it is ok, we just store the current one as the last one */
+	/* If the current seq number equals the last one or if we are here for
+	 * the first time, then it is ok, we just store the current one as the last one
+	 */
 	if ( (statinfo->seq_num+1 == rtpinfo->info_seq_num) || (statinfo->flags & STAT_FLAG_FIRST) )
 		statinfo->seq_num = rtpinfo->info_seq_num;
-	/* if the first one is 65535. XXX same problem as above: if seq 65535 or 0 is lost... */
+	/* If the first one is 65535. XXX same problem as above: if seq 65535 or 0 is lost... */
 	else if ( (statinfo->seq_num == 65535) && (rtpinfo->info_seq_num == 0) )
 		statinfo->seq_num = rtpinfo->info_seq_num;
-	/* lost packets */
+	/* Lost packets */
 	else if (statinfo->seq_num+1 < rtpinfo->info_seq_num) {
 		statinfo->seq_num = rtpinfo->info_seq_num;
 		statinfo->sequence++;
 		statinfo->flags |= STAT_FLAG_WRONG_SEQ;
 	}
-	/* late or duplicated */
+	/* Late or duplicated */
 	else if (statinfo->seq_num+1 > rtpinfo->info_seq_num) {
 		statinfo->sequence++;
 		statinfo->flags |= STAT_FLAG_WRONG_SEQ;
 	}
+
+	/* Check payload type */
+	if (rtpinfo->info_payload_type == PT_CN
+		|| rtpinfo->info_payload_type == PT_CN_OLD)
+		statinfo->flags |= STAT_FLAG_PT_CN;
+	if (statinfo->pt == PT_CN
+		|| statinfo->pt == PT_CN_OLD)
+		statinfo->flags |= STAT_FLAG_FOLLOW_PT_CN;
+	if (rtpinfo->info_payload_type != statinfo->pt)
+		statinfo->flags |= STAT_FLAG_PT_CHANGE;
+	statinfo->pt = rtpinfo->info_payload_type;
+
+	/*
+	 * Return 0 for unknown payload types
+	 * Ignore jitter calculation for clockrate = 0
+	 */
+	if (statinfo->pt < 96 ){
+		clock_rate = get_clock_rate(statinfo->pt);
+	}else{ /* Dynamic PT */
+		if ( rtpinfo->info_payload_type_str != NULL ){
+			/* Is it a "telephone-event" ?
+			 * Timestamp is not increased for telepone-event packets inpacting
+			 * caluculation of Jitter Skew and clock drift.
+			 * see 2.2.1 of RFC 4733
+			 */
+			if (g_ascii_strncasecmp("telephone-event",rtpinfo->info_payload_type_str,(strlen("telephone-event")))==0){
+				clock_rate = 0;
+				statinfo->flags |= STAT_FLAG_PT_T_EVENT;
+			}else{
+				clock_rate = get_dyn_pt_clock_rate(rtpinfo-> info_payload_type_str);
+			}
+		}else{
+			clock_rate = 0;
+		}
+	}
+
+		/* Handle wraparound ? */
+	arrivaltime = current_time - statinfo->start_time;
+
+	if (statinfo->first_timestamp > rtpinfo->info_timestamp){
+		/* Handle wraparound */
+		nominaltime = (double)(rtpinfo->info_timestamp + 0xffffffff - statinfo->first_timestamp + 1);
+	}else{
+		nominaltime = (double)(rtpinfo->info_timestamp - statinfo->first_timestamp);
+	}
+
+	/* Can only analyze defined sampling rates */
+    if (clock_rate != 0) { 
+		statinfo->clock_rate = clock_rate;
+		/* Convert from sampling clock to ms */
+		nominaltime = nominaltime /(clock_rate/1000);
+
+		/* Calculate the current jitter(in ms) */
+		if (!statinfo->first_packet) {
+			expected_time = statinfo->time + (nominaltime - statinfo->lastnominaltime);
+			current_diff = fabs(current_time - expected_time);
+			current_jitter = (15 * statinfo->jitter + current_diff) / 16;
+
+			statinfo->delta = current_time-(statinfo->time);
+			statinfo->jitter = current_jitter;
+			statinfo->diff = current_diff;
+		}
+		statinfo->lastnominaltime = nominaltime;
+		/* Calculate skew, i.e. absolute jitter that also catches clock drift
+		 * Skew is positive if TS (nominal) is too fast
+		 */
+		statinfo->skew    = nominaltime - arrivaltime;
+		absskew = fabs(statinfo->skew);
+		if(absskew > fabs(statinfo->max_skew)){
+			statinfo->max_skew = statinfo->skew;
+		}
+		/* Gather data for calculation of average, minimum and maximum framerate based on timestamp */
+#if 0
+		if (numPackets > 0 && (!hardPayloadType || !alternatePayloadType)) { 
+			/* Skip first packet and possibly alternate payload type packets */
+			double dt;
+			dt     = nominaltime - statinfo->lastnominaltime;
+			sumdt += 1.0 * dt;
+			numdt += (dt != 0 ? 1 : 0);
+			mindt  = (dt < mindt ? dt : mindt);
+			maxdt  = (dt > maxdt ? dt : maxdt);
+		}
+#endif
+		/* Gather data for calculation of skew least square */
+		statinfo->sumt   += 1.0 * current_time;
+		statinfo->sumTS  += 1.0 * nominaltime;
+		statinfo->sumt2  += 1.0 * current_time * current_time;
+		statinfo->sumtTS += 1.0 * current_time * nominaltime;
+	}
+
+	/* Calculate the BW in Kbps adding the IP+UDP header to the RTP -> 20bytes(IP)+8bytes(UDP) = 28bytes */
+	statinfo->bw_history[statinfo->bw_index].bytes = rtpinfo->info_data_len + 28;
+	statinfo->bw_history[statinfo->bw_index].time = current_time;
+
+	/* Check if there are more than 1sec in the history buffer to calculate BW in bps. If so, remove those for the calculation */
+	while ((statinfo->bw_history[statinfo->bw_start_index].time+1000/* ms */)<current_time){
+	 	statinfo->total_bytes -= statinfo->bw_history[statinfo->bw_start_index].bytes;
+		statinfo->bw_start_index++;
+		if (statinfo->bw_start_index == BUFF_BW) statinfo->bw_start_index=0;
+	};
+	statinfo->total_bytes += rtpinfo->info_data_len + 28;
+	statinfo->bandwidth = (double)(statinfo->total_bytes*8)/1000;
+	statinfo->bw_index++;
+	if (statinfo->bw_index == BUFF_BW) statinfo->bw_index = 0;
+
+
+	/* Is it a packet with the mark bit set? */
+	if (rtpinfo->info_marker_set) {
+		statinfo->delta_timestamp = rtpinfo->info_timestamp - statinfo->timestamp;
+		if (rtpinfo->info_timestamp > statinfo->timestamp){
+			statinfo->flags |= STAT_FLAG_MARKER;
+		}
+		else{
+			statinfo->flags |= STAT_FLAG_WRONG_TIMESTAMP;
+		}
+	}
+	/* Is it a regular packet? */
+	if (!(statinfo->flags & STAT_FLAG_FIRST)
+		&& !(statinfo->flags & STAT_FLAG_MARKER)
+		&& !(statinfo->flags & STAT_FLAG_PT_CN)
+		&& !(statinfo->flags & STAT_FLAG_WRONG_TIMESTAMP)
+		&& !(statinfo->flags & STAT_FLAG_FOLLOW_PT_CN)) {
+		/* Include it in maximum delta calculation */
+		if (statinfo->delta > statinfo->max_delta) {
+			statinfo->max_delta = statinfo->delta;
+			statinfo->max_nr = pinfo->fd->num;
+		}
+		if (clock_rate != 0) { 
+			/* Maximum and mean jitter calculation */
+			if (statinfo->jitter > statinfo->max_jitter) {
+				statinfo->max_jitter = statinfo->jitter;
+			}
+			statinfo->mean_jitter = (statinfo->mean_jitter*statinfo->total_nr + current_diff) / (statinfo->total_nr+1);
+		}
+	}
+	/* Regular payload change? (CN ignored) */
+	if (!(statinfo->flags & STAT_FLAG_FIRST)
+		&& !(statinfo->flags & STAT_FLAG_PT_CN)) {
+		if ((statinfo->pt != statinfo->reg_pt)
+			&& (statinfo->reg_pt != PT_UNDEFINED)) {
+			statinfo->flags |= STAT_FLAG_REG_PT_CHANGE;
+		}
+	}
+
+	/* Set regular payload*/
+	if (!(statinfo->flags & STAT_FLAG_PT_CN)) {
+		statinfo->reg_pt = statinfo->pt;
+	}
+
 	statinfo->time = current_time;
 	statinfo->timestamp = rtpinfo->info_timestamp;
 	statinfo->stop_seq_nr = rtpinfo->info_seq_num;
