@@ -6,7 +6,7 @@
  *
  * (c) Copyright 2001 Ashok Narayanan <ashokn@cisco.com>
  *
- * $Id: text2pcap.c 24526 2008-03-01 20:39:31Z wmeier $
+ * $Id: text2pcap.c 28334 2009-05-12 16:06:14Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -93,11 +93,27 @@
 #  define _XOPEN_SOURCE
 #endif
 
+/*
+ * Defining _XOPEN_SOURCE is needed on some platforms, e.g. platforms
+ * using glibc, to expand the set of things system header files define.
+ *
+ * Unfortunately, on other platforms, such as some versions of Solaris
+ * (including Solaris 10), it *reduces* that set as well, causing
+ * strptime() not to be declared, presumably because the version of the
+ * X/Open spec that _XOPEN_SOURCE implies doesn't include strptime() and
+ * blah blah blah namespace pollution blah blah blah.
+ *
+ * So we define __EXTENSIONS__ so that "strptime()" is declared.
+ */
+#ifndef __EXTENSIONS__
+#  define __EXTENSIONS__
+#endif
+
 #include <ctype.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <wiretap/file_util.h>
+#include <wsutil/file_util.h>
 
 #include <time.h>
 #include <glib.h>
@@ -178,7 +194,7 @@ static unsigned long num_packets_read = 0;
 static unsigned long num_packets_written = 0;
 
 /* Time code of packet, derived from packet_preamble */
-static gint32 ts_sec  = 0;
+static time_t ts_sec  = 0;
 static guint32 ts_usec = 0;
 static char *ts_fmt = NULL;
 static struct tm timecode_default;
@@ -323,7 +339,7 @@ struct pcap_hdr {
 
 /* "libpcap" record header. */
 struct pcaprec_hdr {
-    gint32	ts_sec;		/* timestamp seconds */
+    guint32	ts_sec;		/* timestamp seconds */
     guint32	ts_usec;	/* timestamp microseconds */
     guint32	incl_len;	/* number of octets of packet saved in file */
     guint32	orig_len;	/* actual length of packet */
@@ -549,8 +565,8 @@ write_current_packet (void)
             }
         }
 
-        /* Write PCap header */
-        ph.ts_sec = ts_sec;
+        /* Write PCAP header */
+        ph.ts_sec = (guint32)ts_sec;
         ph.ts_usec = ts_usec;
         if (ts_fmt == NULL) { ts_usec++; }	/* fake packet counter */
         ph.incl_len = length;
@@ -704,12 +720,12 @@ append_to_preamble(char *str)
     if (toklen != 0) {
         if (packet_preamble_len + toklen > PACKET_PREAMBLE_MAX_LEN)
             return;	/* no room to add the token to the preamble */
-        strncpy(&packet_preamble[packet_preamble_len], str, PACKET_PREAMBLE_MAX_LEN - packet_preamble_len);
-        packet_preamble_len += toklen;
+        g_strlcpy(&packet_preamble[packet_preamble_len], str, PACKET_PREAMBLE_MAX_LEN);
+        packet_preamble_len += (int) toklen;
 	if (debug >= 2) {
 		char *c;
 		char xs[PACKET_PREAMBLE_MAX_LEN];
-		strncpy(xs, packet_preamble, PACKET_PREAMBLE_MAX_LEN);
+		g_strlcpy(xs, packet_preamble, PACKET_PREAMBLE_MAX_LEN);
 		while ((c = strchr(xs, '\r')) != NULL) *c=' ';
 		fprintf (stderr, "[[append_to_preamble: \"%s\"]]", xs);
 	}
@@ -758,7 +774,7 @@ parse_preamble (void)
 		if (subsecs != NULL) {
 			/* Get the long time from the tm structure */
                         /*  (will return -1 if failure)            */
-			ts_sec  = (gint32)mktime( &timecode );
+			ts_sec  = mktime( &timecode );
 		} else
 			ts_sec = -1;	/* we failed to parse it */
 
@@ -794,7 +810,7 @@ parse_preamble (void)
 				 * 10^-6 seconds, we multiply by
 				 * 10^(6-N).
 				 */
-				subseclen = p - subsecs;
+				subseclen = (int) (p - subsecs);
 				if (subseclen > 6) {
 					/*
 					 * *More* than 6 digits; 6-N is
@@ -814,7 +830,7 @@ parse_preamble (void)
 		char *c;
 		while ((c = strchr(packet_preamble, '\r')) != NULL) *c=' ';
 		fprintf(stderr, "[[parse_preamble: \"%s\"]]\n", packet_preamble);
-		fprintf(stderr, "Format(%s), time(%u), subsecs(%u)\n", ts_fmt, ts_sec, ts_usec);
+		fprintf(stderr, "Format(%s), time(%u), subsecs(%u)\n", ts_fmt, (guint32)ts_sec, ts_usec);
 	}
 
 
@@ -1018,15 +1034,15 @@ usage (void)
             "Generate a capture file from an ASCII hexdump of packets.\n"
             "See http://www.wireshark.org for more information.\n"
             "\n"
-            "Usage: text2pcap [options] <input-filename> <output-filename>\n"
+            "Usage: text2pcap [options] <infile> <outfile>\n"
             "\n"
-            "where  <input-filename> specifies input  filename (use - for standard input)\n"
-            "      <output-filename> specifies output filename (use - for standard output)\n"
+            "where  <infile> specifies input  filename (use - for standard input)\n"
+            "      <outfile> specifies output filename (use - for standard output)\n"
             "\n"
             "Input:\n"
-            "  -o hex|oct|dec         parse offsets as (h)ex, (o)ctal or (d)ecimal, default is hex\n"
-            "  -t <timefmt>           treats the text before the packet as a date/time code;\n"
-            "                         the specified argument is a format string of the sort \n"
+            "  -o hex|oct|dec         parse offsets as (h)ex, (o)ctal or (d)ecimal; default is hex.\n"
+            "  -t <timefmt>           treat the text before the packet as a date/time code;\n"
+            "                         the specified argument is a format string of the sort\n"
             "                         supported by strptime.\n"
             "                         Example: The time \"10:15:14.5476\" has the format code\n"
             "                         \"%%H:%%M:%%S.\"\n"
@@ -1037,40 +1053,44 @@ usage (void)
             "                         used as the default for unspecified fields.\n"
             "\n"
             "Output:\n"
-            "  -l <typenum>           link-layer type number. Default is 1 (Ethernet). \n"
+            "  -l <typenum>           link-layer type number; default is 1 (Ethernet).\n"
             "                         See the file net/bpf.h for list of numbers.\n"
-            "  -m <max-packet>        max packet length in output, default is %d\n"
+            "                         Use this option if your dump is a complete hex dump\n"
+            "                         of an encapsulated packet and you wish to specify\n"
+            "                         the exact type of encapsulation.\n"
+            "                         Example: -l 7 for ARCNet packets.\n"
+            "  -m <max-packet>        max packet length in output; default is %d\n"
             "\n"
             "Prepend dummy header:\n"
             "  -e <l3pid>             prepend dummy Ethernet II header with specified L3PID\n"
-            "                         (in HEX)\n"
-            "                         Example: -e 0x800\n"
+            "                         (in HEX).\n"
+            "                         Example: -e 0x806 to specify an ARP packet.\n"
             "  -i <proto>             prepend dummy IP header with specified IP protocol\n"
-            "                         (in DECIMAL). \n"
+            "                         (in DECIMAL).\n"
             "                         Automatically prepends Ethernet header as well.\n"
             "                         Example: -i 46\n"
             "  -u <srcp>,<destp>      prepend dummy UDP header with specified\n"
             "                         dest and source ports (in DECIMAL).\n"
-            "                         Automatically prepends Ethernet & IP headers as well\n"
-            "                         Example: -u 30,40\n"
-            "  -T <srcp>,<destp>      prepend dummy TCP header with specified \n"
+            "                         Automatically prepends Ethernet & IP headers as well.\n"
+            "                         Example: -u 1000 69 to make the packets look like TFTP/UDP packets.\n" 
+            "  -T <srcp>,<destp>      prepend dummy TCP header with specified\n"
             "                         dest and source ports (in DECIMAL).\n"
-            "                         Automatically prepends Ethernet & IP headers as well\n"
+            "                         Automatically prepends Ethernet & IP headers as well.\n"
             "                         Example: -T 50,60\n"
-            "  -s <srcp>,<dstp>,<tag> prepend dummy SCTP header with specified \n"
+            "  -s <srcp>,<dstp>,<tag> prepend dummy SCTP header with specified\n"
             "                         dest/source ports and verification tag (in DECIMAL).\n"
-            "                         Automatically prepends Ethernet & IP headers as well\n"
+            "                         Automatically prepends Ethernet & IP headers as well.\n"
             "                         Example: -s 30,40,34\n"
-            "  -S <srcp>,<dstp>,<ppi> prepend dummy SCTP header with specified \n"
-            "                         dest/source ports and verification tag 0. \n"
-            "                         It also prepends a dummy SCTP DATA \n"
+            "  -S <srcp>,<dstp>,<ppi> prepend dummy SCTP header with specified\n"
+            "                         dest/source ports and verification tag 0.\n"
+            "                         Automatically prepends a dummy SCTP DATA\n"
             "                         chunk header with payload protocol identifier ppi.\n"
             "                         Example: -S 30,40,34\n"
             "\n"
             "Miscellaneous:\n"
-            "  -h                     display this help and exit\n"
-            "  -d                     detailed debug of parser states \n"
-            "  -q                     generate no output at all (automatically turns off -d)\n"
+            "  -h                     display this help and exit.\n"
+            "  -d                     show detailed debug of parser states.\n"
+            "  -q                     generate no output at all (automatically turns off -d).\n"
             "",
             VERSION, MAX_PACKET);
 
@@ -1263,8 +1283,8 @@ parse_options (int argc, char *argv[])
     }
 
     if (strcmp(argv[optind], "-")) {
-        input_filename = strdup(argv[optind]);
-        input_file = eth_fopen(input_filename, "rb");
+        input_filename = g_strdup(argv[optind]);
+        input_file = ws_fopen(input_filename, "rb");
         if (!input_file) {
             fprintf(stderr, "Cannot open file [%s] for reading: %s\n",
                     input_filename, strerror(errno));
@@ -1276,8 +1296,8 @@ parse_options (int argc, char *argv[])
     }
 
     if (strcmp(argv[optind+1], "-")) {
-        output_filename = strdup(argv[optind+1]);
-        output_file = eth_fopen(output_filename, "wb");
+        output_filename = g_strdup(argv[optind+1]);
+        output_file = ws_fopen(output_filename, "wb");
         if (!output_file) {
             fprintf(stderr, "Cannot open file [%s] for writing: %s\n",
                     output_filename, strerror(errno));
@@ -1304,8 +1324,8 @@ parse_options (int argc, char *argv[])
         output_filename = "Standard output";
     }
 
-    ts_sec = (gint32) time(0);		/* initialize to current time */
-    timecode_default = *localtime((time_t *)&ts_sec);
+    ts_sec = time(0);		/* initialize to current time */
+    timecode_default = *localtime(&ts_sec);
 
     /* Display summary of our state */
     if (!quiet) {
