@@ -1,6 +1,6 @@
 #!/bin/bash
 #
-# $Id: fuzz-test.sh 24729 2008-03-25 22:23:10Z gerald $
+# $Id: fuzz-test.sh 25389 2008-05-28 15:36:29Z morriss $
 
 # Fuzz-testing script for TShark
 #
@@ -9,15 +9,13 @@
 # each fuzzed file and checks for errors.  The files are processed
 # repeatedly until an error is found.
 
-# Tweak the following to your liking.  Editcap must support "-E".
-TSHARK=./tshark
-EDITCAP=./editcap
-CAPINFOS=./capinfos
-
 # This needs to point to a 'date' that supports %s.
 DATE=/bin/date
 BASE_NAME=fuzz-`$DATE +%Y-%m-%d`-$$
 
+# Directory containing binaries.  Default current directory.
+BIN_DIR=.
+
 # Temporary file directory and names.
 # (had problems with this on cygwin, tried TMP_DIR=./ which worked)
 TMP_DIR=/tmp
@@ -43,14 +41,20 @@ WIRESHARK_ABORT_ON_DISSECTOR_BUG="True"
 
 
 # To do: add options for file names and limits
-while getopts ":d:p:" OPTCHAR ; do
+while getopts ":b:d:p:" OPTCHAR ; do
 	case $OPTCHAR in
+		b) BIN_DIR=$OPTARG ;;
 		d) TMP_DIR=$OPTARG ;;
 		p) MAX_PASSES=$OPTARG ;;
 	esac
 done
 shift $(($OPTIND - 1))
 
+# Tweak the following to your liking.  Editcap must support "-E".
+TSHARK="$BIN_DIR/tshark"
+EDITCAP="$BIN_DIR/editcap"
+CAPINFOS="$BIN_DIR/capinfos"
+
 # set some limits to the child processes, e.g. stop it if it's running longer then MAX_CPU_TIME seconds
 # (ulimit is not supported well on cygwin and probably other platforms, e.g. cygwin shows some warnings)
 ulimit -S -t $MAX_CPU_TIME -v $MAX_VMEM
@@ -122,10 +126,23 @@ while [ $PASS -lt $MAX_PASSES -o $MAX_PASSES -lt 1 ] ; do
         fi
 	echo -n "    $CF: "
 
-	"$CAPINFOS" "$CF" > /dev/null 2>&1
-	if [ $? -ne 0 ] ; then
+	"$CAPINFOS" "$CF" > /dev/null 2> $TMP_DIR/$ERR_FILE
+	RETVAL=$?
+	if [ $RETVAL -eq 0 ] ; then
+	    # have a valid file
+	    rm -f $TMP_DIR/$ERR_FILE
+	elif [ $RETVAL -eq 1 ] ; then
 	    echo "Not a valid capture file"
+	    rm -f $TMP_DIR/$ERR_FILE
 	    continue
+	else
+            echo ""
+	    echo " ERROR"
+	    echo -e "Processing failed.  Capture info follows:\n"
+	    echo "  Input file: $CF"
+	    echo -e "stderr follows:\n"
+	    cat $TMP_DIR/$ERR_FILE
+	    exit 1
 	fi
 
 	DISSECTOR_BUG=0
