@@ -1,7 +1,7 @@
 /* version_info.c
  * Routines to report version information for stuff used by Wireshark
  *
- * $Id: version_info.c 30658 2009-10-22 00:15:46Z gerald $
+ * $Id: version_info.c 32661 2010-05-04 19:13:29Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -41,10 +41,6 @@
 #include <pcre.h>	/* to get the libpcre version number */
 #endif /* HAVE_LIBPCRE */
 
-#if (defined(HAVE_LIBGCRYPT) || defined(HAVE_LIBGNUTLS)) && defined(_WIN32)
-#include <winposixtype.h>
-#endif
-
 #ifdef HAVE_LIBGCRYPT
 #include <gcrypt.h>
 #endif /* HAVE_LIBGCRYPT */
@@ -139,6 +135,11 @@ end_string(GString *str)
 void
 get_compiled_version_info(GString *str, void (*additional_info)(GString *))
 {
+	if (sizeof(str) == 4)
+		g_string_append(str, "(32-bit) ");
+	else
+		g_string_append(str, "(64-bit) ");
+
         /* GLIB */
 	g_string_append(str, "with ");
 	g_string_append_printf(str,
@@ -182,7 +183,7 @@ get_compiled_version_info(GString *str, void (*additional_info)(GString *))
 		(*additional_info)(str);
 	g_string_append(str, ".");
 
-#ifndef HAVE_LIBPCRE
+#if !defined(HAVE_LIBPCRE) && !GLIB_CHECK_VERSION(2,14,0)
 	g_string_append(str,
 	"\nNOTE: this build doesn't support the \"matches\" operator for Wireshark filter syntax");
 	g_string_append(str, ".");
@@ -612,7 +613,7 @@ const char *
 get_copyright_info(void)
 {
 	return
-"Copyright 1998-2009 Gerald Combs <gerald@wireshark.org> and contributors.\n"
+"Copyright 1998-2010 Gerald Combs <gerald@wireshark.org> and contributors.\n"
 "This is free software; see the source for copying conditions. There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n";
 }
