@@ -1,6 +1,6 @@
 /* cosine.c
  *
- * $Id: cosine.c 25254 2008-05-08 05:16:33Z etxrab $
+ * $Id: cosine.c 27638 2009-03-07 05:11:56Z guy $
  *
  * CoSine IPNOS L2 debug output parsing
  * Copyright (c) 2002 by Motonori Shindo <mshindo@mshindo.net>
@@ -248,7 +248,8 @@ static gint64 cosine_seek_next_packet(wtap *wth, int *err, char *hdr)
 static gboolean cosine_check_file_type(wtap *wth, int *err)
 {
 	char	buf[COSINE_LINE_LENGTH];
-	guint	reclen, line;
+	gsize	reclen;
+	guint	line;
 
 	buf[COSINE_LINE_LENGTH-1] = '\0';
 
