@@ -32,7 +32,7 @@
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: erf.c 25464 2008-06-16 23:59:40Z gerald $
+ * $Id: erf.c 29662 2009-09-01 22:36:30Z gerald $
  */
 
 /*
@@ -84,6 +84,8 @@ extern int erf_open(wtap *wth, int *err, gchar **err_info _U_)
   guint16 eth_hdr;
   guint32 packet_size;
   guint16 rlen,wlen;
+  guint64 erf_ext_header;
+  guint8 type;
   size_t r;
   gchar * buffer;
 
@@ -124,7 +126,6 @@ extern int erf_open(wtap *wth, int *err, gchar **err_info _U_)
 
     rlen=g_ntohs(header.rlen);
     wlen=g_ntohs(header.wlen);
-    packet_size = rlen - sizeof(header);
 
     /* fail on invalid record type, invalid rlen, timestamps decreasing, or incrementing too far */
     
@@ -133,16 +134,18 @@ extern int erf_open(wtap *wth, int *err, gchar **err_info _U_)
       return 0;
     }
     
+    packet_size = rlen - (guint32)sizeof(header);
     if (packet_size > WTAP_MAX_PACKET_SIZE) {
       /*
-       * Probably a corrupt capture file; don't blow up trying
+       * Probably a corrupt capture file or a file that's not an ERF file
+       * but that passed earlier tests; don't blow up trying
        * to allocate space for an immensely-large packet.
        */
       return 0;
     }
 
     /* Skip PAD records, timestamps may not be set */
-    if (header.type == ERF_TYPE_PAD) {
+    if ((header.type & 0x7F) == ERF_TYPE_PAD) {
       if (file_seek(wth->fh, packet_size, SEEK_CUR, err) == -1) {
 	return -1;
       }
@@ -151,12 +154,12 @@ extern int erf_open(wtap *wth, int *err, gchar **err_info _U_)
 
     /* fail on invalid record type, decreasing timestamps or non-zero pad-bits */
     /* Not all types within this range are decoded, but it is a first filter */
-    if (header.type == 0 || header.type > ERF_TYPE_MAX ) {
+    if ((header.type & 0x7F) == 0 || (header.type & 0x7F) > ERF_TYPE_MAX ) {
       return 0;
     }
     
-    /* The ERF_TYPE_MAX is the PAD record, but the last used type is ERF_TYPE_INFINIBAND */
-    if (header.type > ERF_TYPE_INFINIBAND) {
+    /* The ERF_TYPE_MAX is the PAD record, but the last used type is ERF_TYPE_RAW_LINK */
+    if ((header.type & 0x7F) > ERF_TYPE_RAW_LINK) {
       return 0;
     }
     
@@ -174,8 +177,20 @@ extern int erf_open(wtap *wth, int *err, gchar **err_info _U_)
     
     memcpy(&prevts, &ts, sizeof(prevts));
 
+    /* Read over the extension headers */
+    type = header.type;
+    while (type & 0x80){
+	    if (file_read(&erf_ext_header, 1, sizeof(erf_ext_header),wth->fh) != sizeof(erf_ext_header)) {
+		    *err = file_error(wth->fh);
+		    return -1;
+	    }
+	    packet_size -= (guint32)sizeof(erf_ext_header);
+	    memcpy(&type, &erf_ext_header, sizeof(type));
+    }
+    
+
     /* Read over MC or ETH subheader */
-    switch(header.type) {
+    switch(header.type & 0x7F) {
     case ERF_TYPE_MC_HDLC:
     case ERF_TYPE_MC_RAW:
     case ERF_TYPE_MC_ATM:
@@ -187,7 +202,7 @@ extern int erf_open(wtap *wth, int *err, gchar **err_info _U_)
 	*err = file_error(wth->fh);
 	return -1;
       }
-      packet_size -= sizeof(mc_hdr);
+      packet_size -= (guint32)sizeof(mc_hdr);
       break;
     case ERF_TYPE_ETH:
     case ERF_TYPE_COLOR_ETH:
@@ -196,7 +211,7 @@ extern int erf_open(wtap *wth, int *err, gchar **err_info _U_)
 	*err = file_error(wth->fh);
 	return -1;
       }
-      packet_size -= sizeof(eth_hdr);
+      packet_size -= (guint32)sizeof(eth_hdr);
       break;
     default:
       break;
@@ -204,6 +219,13 @@ extern int erf_open(wtap *wth, int *err, gchar **err_info _U_)
 
     /* The file_seek function do not return an error if the end of file
        is reached whereas the record is truncated */
+    if (packet_size > WTAP_MAX_PACKET_SIZE) {
+      /*
+       * Probably a corrupt capture file; don't blow up trying
+       * to allocate space for an immensely-large packet.
+       */
+      return 0;
+    }
     buffer=g_malloc(packet_size);
     r = file_read(buffer, 1, packet_size, wth->fh);
     g_free(buffer);
@@ -277,9 +299,11 @@ static gboolean erf_seek_read(wtap *wth, gint64 seek_off,
   if (file_seek(wth->random_fh, seek_off, SEEK_SET, err) == -1)
     return FALSE;
 
-  if (!erf_read_header(wth->random_fh, NULL, pseudo_header, &erf_header,
-		       err, err_info, NULL, &packet_size))
-    return FALSE;
+  do {
+    if (!erf_read_header(wth->random_fh, NULL, pseudo_header, &erf_header,
+			 err, err_info, NULL, &packet_size))
+      return FALSE;
+  } while ( erf_header.type == ERF_TYPE_PAD );
 
   wtap_file_read_expected_bytes(pd, (int)packet_size, wth->random_fh, err);
 
@@ -296,14 +320,19 @@ static int erf_read_header(FILE_T fh,
 			   guint32 *packet_size)
 {
   guint32 mc_hdr;
-  guint16 eth_hdr,skiplen=0;
+  guint8 erf_exhdr[8];
+  guint64 erf_exhdr_sw;
+  guint8 type = 0;
+  guint16 eth_hdr;
+  guint32 skiplen=0;
+  int i = 0 , max = sizeof(pseudo_header->erf.ehdr_list)/sizeof(struct erf_ehdr);
 
   wtap_file_read_expected_bytes(erf_header, sizeof(*erf_header), fh, err);
   if (bytes_read != NULL) {
     *bytes_read = sizeof(*erf_header);
   }
 
-  *packet_size =  g_ntohs(erf_header->rlen) - sizeof(*erf_header);
+  *packet_size =  g_ntohs(erf_header->rlen) - (guint32)sizeof(*erf_header);
 
   if (*packet_size > WTAP_MAX_PACKET_SIZE) {
     /*
@@ -322,7 +351,7 @@ static int erf_read_header(FILE_T fh,
     phdr->ts.secs = (long) (ts >> 32);
     ts = ((ts & 0xffffffff) * 1000 * 1000 * 1000);
     ts += (ts & 0x80000000) << 1; /* rounding */
-    phdr->ts.nsecs = ((long) (ts >> 32));
+    phdr->ts.nsecs = ((int) (ts >> 32));
     if (phdr->ts.nsecs >= 1000000000) {
       phdr->ts.nsecs -= 1000000000;
       phdr->ts.secs += 1;
@@ -337,8 +366,25 @@ static int erf_read_header(FILE_T fh,
   pseudo_header->erf.phdr.lctr = g_ntohs(erf_header->lctr);
   pseudo_header->erf.phdr.wlen = g_ntohs(erf_header->wlen);
 
-  switch (erf_header->type) {
-  
+  /* Copy the ERF extension header into the pseudo header */
+  type = erf_header->type;
+  while (type & 0x80){
+	  wtap_file_read_expected_bytes(&erf_exhdr, sizeof(erf_exhdr), fh, err);
+	  if (bytes_read != NULL)
+		  *bytes_read += (guint32)sizeof(erf_exhdr);
+	  *packet_size -=  (guint32)sizeof(erf_exhdr);
+	  skiplen += (guint32)sizeof(erf_exhdr);
+	  erf_exhdr_sw = pntohll((guint64*) &(erf_exhdr[0]));
+	  if (i < max)
+	    memcpy(&pseudo_header->erf.ehdr_list[i].ehdr, &erf_exhdr_sw, sizeof(erf_exhdr_sw));
+	  type = erf_exhdr[0];
+	  i++;
+  }
+
+  switch (erf_header->type & 0x7F) {
+  case ERF_TYPE_IPV4:
+  case ERF_TYPE_IPV6:
+  case ERF_TYPE_RAW_LINK:
   case ERF_TYPE_INFINIBAND:
     /***
     if (phdr != NULL) {
@@ -348,6 +394,7 @@ static int erf_read_header(FILE_T fh,
     return TRUE;
     ***/
     break;
+  case ERF_TYPE_PAD:
   case ERF_TYPE_HDLC_POS:
   case ERF_TYPE_COLOR_HDLC_POS:
   case ERF_TYPE_DSM_COLOR_HDLC_POS:
@@ -361,9 +408,9 @@ static int erf_read_header(FILE_T fh,
   case ERF_TYPE_DSM_COLOR_ETH:
     wtap_file_read_expected_bytes(&eth_hdr, sizeof(eth_hdr), fh, err);
     if (bytes_read != NULL)
-      *bytes_read += sizeof(eth_hdr);
-    *packet_size -=  sizeof(eth_hdr);
-    skiplen = sizeof(eth_hdr);
+      *bytes_read += (guint32)sizeof(eth_hdr);
+    *packet_size -=  (guint32)sizeof(eth_hdr);
+    skiplen += (guint32)sizeof(eth_hdr);
     pseudo_header->erf.subhdr.eth_hdr = g_htons(eth_hdr);
     break;
 
@@ -376,9 +423,9 @@ static int erf_read_header(FILE_T fh,
   case ERF_TYPE_COLOR_MC_HDLC_POS:
     wtap_file_read_expected_bytes(&mc_hdr, sizeof(mc_hdr), fh, err);
     if (bytes_read != NULL)
-      *bytes_read += sizeof(mc_hdr);
-    *packet_size -=  sizeof(mc_hdr);
-    skiplen = sizeof(mc_hdr);
+      *bytes_read += (guint32)sizeof(mc_hdr);
+    *packet_size -=  (guint32)sizeof(mc_hdr);
+    skiplen += (guint32)sizeof(mc_hdr);
     pseudo_header->erf.subhdr.mc_hdr = g_htonl(mc_hdr);
     break;
 
@@ -395,7 +442,7 @@ static int erf_read_header(FILE_T fh,
   if (phdr != NULL) {
     phdr->len = g_htons(erf_header->wlen);
     phdr->caplen = min( g_htons(erf_header->wlen),
-			g_htons(erf_header->rlen) - sizeof(*erf_header) - skiplen );
+			g_htons(erf_header->rlen) - (guint32)sizeof(*erf_header) - skiplen );
   }
   return TRUE;
 }
