@@ -1,6 +1,6 @@
 /* file_wrappers.h
  *
- * $Id: file_wrappers.h 26212 2008-09-15 21:50:50Z jake $
+ * $Id: file_wrappers.h 27684 2009-03-09 22:28:05Z gerald $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -33,7 +33,7 @@ extern int file_error(void *fh);
 extern FILE_T file_open(const char *path, const char *mode);
 #define filed_open gzdopen
 /* XX: gzread and gzwrite return number of *bytes* (not number of elements) */
-#define file_read(buf, bsize, count, file) gzread((file),(buf),((count)*(bsize)))
+#define file_read(buf, bsize, count, file) gzread((file),(buf),(unsigned)((count)*(bsize)))
 #define file_write(buf, bsize, count, file) gzwrite((file),(buf),((count)*(bsize)))
 #define file_close gzclose
 #define file_getc gzgetc
