@@ -1,6 +1,6 @@
 /* iptrace.c
  *
- * $Id: iptrace.c 19814 2006-11-05 22:46:44Z ulfl $
+ * $Id: iptrace.c 28117 2009-04-22 03:07:37Z guy $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -514,9 +514,9 @@ fill_in_pseudo_header(int encap, const guint8 *pd, guint32 len,
 		decimal = strchr(if_text, '.');
 		if (decimal) {
 			*decimal = '\0';
-			Vpi = strtoul(if_text, NULL, 10);
+			Vpi = (int)strtoul(if_text, NULL, 10);
 			decimal++;
-			Vci = strtoul(decimal, NULL, 10);
+			Vci = (int)strtoul(decimal, NULL, 10);
 		}
 
 		/*
