@@ -1,6 +1,6 @@
 /* netmon.c
  *
- * $Id: netmon.c 22050 2007-06-05 17:17:22Z guy $
+ * $Id: netmon.c 28662 2009-06-08 15:37:46Z gerald $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -256,7 +256,7 @@ int netmon_open(wtap *wth, int *err, gchar **err_info)
 	 * in it as the offsets of the frames.
 	 */
 	frame_table_length = pletohl(&hdr.frametablelength);
-	frame_table_size = frame_table_length / sizeof (guint32);
+	frame_table_size = frame_table_length / (guint32)sizeof (guint32);
 	if ((frame_table_size * sizeof (guint32)) != frame_table_length) {
 		*err = WTAP_ERR_UNSUPPORTED;
 		*err_info = g_strdup_printf("netmon: frame table length is %u, which is not a multiple of the size of an entry",
@@ -409,7 +409,7 @@ static gboolean netmon_read(wtap *wth, int *err, gchar **err_info,
 			 * have a pseudo-header.
 			 */
 			*err = WTAP_ERR_BAD_RECORD;
-			*err_info = g_strdup_printf("netmon: ATM file has a %u-byte packet, too small to have even an ATM pseudo-header\n",
+			*err_info = g_strdup_printf("netmon: ATM file has a %u-byte packet, too small to have even an ATM pseudo-header",
 			    packet_size);
 			return FALSE;
 		}
@@ -420,8 +420,8 @@ static gboolean netmon_read(wtap *wth, int *err, gchar **err_info,
 		/*
 		 * Don't count the pseudo-header as part of the packet.
 		 */
-		orig_size -= sizeof (struct netmon_atm_hdr);
-		packet_size -= sizeof (struct netmon_atm_hdr);
+		orig_size -= (guint)sizeof (struct netmon_atm_hdr);
+		packet_size -= (guint)sizeof (struct netmon_atm_hdr);
 		wth->data_offset += sizeof (struct netmon_atm_hdr);
 		break;
 
@@ -778,7 +778,7 @@ static gboolean netmon_dump(wtap_dumper *wdh, const struct wtap_pkthdr *phdr,
 	netmon->frame_table[netmon->frame_table_index] =
 	    htolel(netmon->frame_table_offset);
 	netmon->frame_table_index++;
-	netmon->frame_table_offset += hdr_size + phdr->caplen + atm_hdrsize;
+	netmon->frame_table_offset += (int) hdr_size + phdr->caplen + atm_hdrsize;
 
 	return TRUE;
 }
