@@ -1,6 +1,6 @@
 /* pcapng.c
  *
- * $Id: pcapng.c 29101 2009-07-15 18:39:09Z gerald $
+ * $Id: pcapng.c 32655 2010-05-04 00:20:39Z gerald $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -42,7 +42,7 @@
 #include "libpcap.h"
 #include "pcap-common.h"
 
-#if 1
+#if 0
 #define pcapng_debug0(str) g_warning(str)
 #define pcapng_debug1(str,p1) g_warning(str,p1)
 #define pcapng_debug2(str,p1,p2) g_warning(str,p1,p2)
@@ -54,7 +54,7 @@
 #define pcapng_debug3(str,p1,p2,p3)
 #endif
 
-static gboolean 
+static gboolean
 pcapng_read(wtap *wth, int *err, gchar **err_info,
     gint64 *data_offset);
 static gboolean
@@ -305,7 +305,7 @@ pcapng_read_option(FILE_T fh, pcapng_t *pn, pcapng_option_header_t *oh,
 
 	/* sanity check: option length */
 	if (oh->option_length > len) {
-		pcapng_debug2("pcapng_read_option: option_length %u larger than buffer (%u)", 
+		pcapng_debug2("pcapng_read_option: option_length %u larger than buffer (%u)",
 			      oh->option_length, len);
 		return 0;
 	}
@@ -338,8 +338,9 @@ pcapng_read_option(FILE_T fh, pcapng_t *pn, pcapng_option_header_t *oh,
 
 
 static int
-pcapng_read_section_header_block(FILE_T fh, pcapng_block_header_t *bh,
-				 pcapng_t *pn, wtapng_block_t *wblock, int *err,
+pcapng_read_section_header_block(FILE_T fh, gboolean first_block,
+				 pcapng_block_header_t *bh, pcapng_t *pn,
+				 wtapng_block_t *wblock, int *err,
 				 gchar **err_info)
 {
 	int	bytes_read;
@@ -355,10 +356,24 @@ pcapng_read_section_header_block(FILE_T fh, pcapng_block_header_t *bh,
 	bytes_read = file_read(&shb, 1, sizeof shb, fh);
 	if (bytes_read != sizeof shb) {
 		*err = file_error(fh);
-		if (*err != 0)
-			return -1;
+		if (*err == 0) {
+			if (first_block) {
+				/*
+				 * We're reading this as part of an open,
+				 * and this block is too short to be
+				 * an SHB, so the file is too short
+				 * to be a pcap-ng file.
+				 */
 		return 0;
 	}
+
+			/*
+			 * Otherwise, just report this as an error.
+			 */
+			*err = WTAP_ERR_SHORT_READ;
+		}
+		return -1;
+	}
 	block_read = bytes_read;
 
 	/* is the magic number one we expect? */
@@ -377,7 +392,7 @@ pcapng_read_section_header_block(FILE_T fh, pcapng_block_header_t *bh,
 		pn->byte_swapped		= TRUE;
 		pn->version_major		= BSWAP16(shb.version_major);
 		pn->version_minor		= BSWAP16(shb.version_minor);
-			
+
 		/* tweak the block length to meet current swapping that we know now */
 		bh->block_total_length	= BSWAP32(bh->block_total_length);
 
@@ -386,15 +401,25 @@ pcapng_read_section_header_block(FILE_T fh, pcapng_block_header_t *bh,
 		break;
 	    default:
 		/* Not a "pcapng" magic number we know about. */
-		pcapng_debug1("pcapng_read_section_header_block: unknown magic number %u (probably not an pcapng file)", shb.magic);
+		if (first_block) {
+			/* Not a pcap-ng file. */
+			return 0;
+		}
+
+		/* A bad block */
+		*err = WTAP_ERR_BAD_RECORD;
+		*err_info = g_strdup_printf("pcapng_read_section_header_block: unknown byte-order magic number 0x%08x", shb.magic);
 		return 0;
 	}
 
+	/* OK, at this point we assume it's a pcap-ng file. */
+
 	/* we currently only understand SHB V1.0 */
-	if (pn->version_major != 1 || pn->version_minor != 0) {
-		pcapng_debug2("pcapng_read_section_header_block: unknown SHB version %u.%u", 
-			      pn->version_major, pn->version_minor);
-		return 0;
+	if (pn->version_major != 1 || pn->version_minor > 0) {
+		*err = WTAP_ERR_UNSUPPORTED;
+		*err_info = g_strdup_printf("pcapng_read_section_header_block: unknown SHB version %u.%u",
+ 			      pn->version_major, pn->version_minor);
+		return -1;
 	}
 
 	/* 64bit section_length (currently unused) */
@@ -413,8 +438,8 @@ pcapng_read_section_header_block(FILE_T fh, pcapng_block_header_t *bh,
 	/* Options */
 	errno = WTAP_ERR_CANT_READ;
 	to_read = bh->block_total_length
-        - (int)sizeof(pcapng_block_header_t) 
-        - (int)sizeof (pcapng_section_header_block_t) 
+        - (int)sizeof(pcapng_block_header_t)
+        - (int)sizeof (pcapng_section_header_block_t)
         - (int)sizeof(bh->block_total_length);
 	while(to_read > 0) {
 		/* read option */
@@ -559,9 +584,9 @@ pcapng_read_if_descr_block(FILE_T fh, pcapng_block_header_t *bh, pcapng_t *pn,
 
 	/* Options */
 	errno = WTAP_ERR_CANT_READ;
-	to_read = bh->block_total_length 
-        - (int)sizeof(pcapng_block_header_t) 
-        - (int)sizeof (pcapng_interface_description_block_t) 
+	to_read = bh->block_total_length
+        - (int)sizeof(pcapng_block_header_t)
+        - (int)sizeof (pcapng_interface_description_block_t)
         - (int)sizeof(bh->block_total_length);
 	while (to_read > 0) {
 		/* read option */
@@ -612,7 +637,7 @@ pcapng_read_if_descr_block(FILE_T fh, pcapng_block_header_t *bh, pcapng_t *pn,
 				 *  char[] may not be aligned correctly.
 				 */
 				memcpy(&wblock->data.if_descr.if_speed, option_content, sizeof(guint64));
-				if(pn->byte_swapped) 
+				if(pn->byte_swapped)
 					wblock->data.if_descr.if_speed = BSWAP64(wblock->data.if_descr.if_speed);
 				pcapng_debug1("pcapng_read_if_descr_block: if_speed %" G_GINT64_MODIFIER "u (bps)", wblock->data.if_descr.if_speed);
 			} else {
@@ -690,7 +715,7 @@ pcapng_read_if_descr_block(FILE_T fh, pcapng_block_header_t *bh, pcapng_t *pn,
 }
 
 
-static int 
+static int
 pcapng_read_packet_block(FILE_T fh, pcapng_block_header_t *bh, pcapng_t *pn, wtapng_block_t *wblock, int *err, gchar **err_info _U_, gboolean enhanced)
 {
 	int bytes_read;
@@ -807,7 +832,7 @@ pcapng_read_packet_block(FILE_T fh, pcapng_block_header_t *bh, pcapng_t *pn, wta
 	bytes_read = file_read((guchar *) (wblock->frame_buffer), 1, wblock->data.packet.cap_len - pseudo_header_len, fh);
 	if (bytes_read != (int) (wblock->data.packet.cap_len - pseudo_header_len)) {
 		*err = file_error(fh);
-		pcapng_debug1("pcapng_read_packet_block: couldn't read %u bytes of captured data", 
+		pcapng_debug1("pcapng_read_packet_block: couldn't read %u bytes of captured data",
 			      wblock->data.packet.cap_len - pseudo_header_len);
 		if (*err == 0)
 			*err = WTAP_ERR_SHORT_READ;
@@ -841,8 +866,8 @@ pcapng_read_packet_block(FILE_T fh, pcapng_block_header_t *bh, pcapng_t *pn, wta
 
 	/* Options */
 	errno = WTAP_ERR_CANT_READ;
-	to_read = block_total_length 
-        - (int)sizeof(pcapng_block_header_t) 
+	to_read = block_total_length
+        - (int)sizeof(pcapng_block_header_t)
         - block_read    /* fixed and variable part, including padding */
         - (int)sizeof(bh->block_total_length);
 	while(to_read > 0) {
@@ -878,7 +903,7 @@ pcapng_read_packet_block(FILE_T fh, pcapng_block_header_t *bh, pcapng_t *pn, wta
 				 *  char[] may not be aligned correctly.
 				 */
 				memcpy(&wblock->data.packet.pack_flags, option_content, sizeof(guint32));
-				if(pn->byte_swapped) 
+				if(pn->byte_swapped)
 					wblock->data.packet.pack_flags = BSWAP32(wblock->data.packet.pack_flags);
 				pcapng_debug1("pcapng_read_if_descr_block: pack_flags %u (ignored)", wblock->data.packet.pack_flags);
 			} else {
@@ -895,7 +920,7 @@ pcapng_read_packet_block(FILE_T fh, pcapng_block_header_t *bh, pcapng_t *pn, wta
 }
 
 
-static int 
+static int
 pcapng_read_simple_packet_block(FILE_T fh, pcapng_block_header_t *bh, pcapng_t *pn, wtapng_block_t *wblock, int *err, gchar **err_info _U_)
 {
 	int bytes_read;
@@ -922,8 +947,8 @@ pcapng_read_simple_packet_block(FILE_T fh, pcapng_block_header_t *bh, pcapng_t *
 		wblock->data.simple_packet.packet_len	= spb.packet_len;
 	}
 
-	wblock->data.simple_packet.cap_len = bh->block_total_length 
-					     - (guint32)sizeof(pcapng_simple_packet_block_t) 
+	wblock->data.simple_packet.cap_len = bh->block_total_length
+					     - (guint32)sizeof(pcapng_simple_packet_block_t)
 					     - (guint32)sizeof(bh->block_total_length);
 
 	if (wblock->data.simple_packet.cap_len > WTAP_MAX_PACKET_SIZE) {
@@ -972,7 +997,7 @@ pcapng_read_simple_packet_block(FILE_T fh, pcapng_block_header_t *bh, pcapng_t *
 	bytes_read = file_read((guchar *) (wblock->frame_buffer), 1, wblock->data.simple_packet.cap_len, fh);
 	if (bytes_read != (int) wblock->data.simple_packet.cap_len) {
 		*err = file_error(fh);
-		pcapng_debug1("pcapng_read_simple_packet_block: couldn't read %u bytes of captured data", 
+		pcapng_debug1("pcapng_read_simple_packet_block: couldn't read %u bytes of captured data",
 			      wblock->data.simple_packet.cap_len);
 		if (*err == 0)
 			*err = WTAP_ERR_SHORT_READ;
@@ -994,7 +1019,7 @@ pcapng_read_simple_packet_block(FILE_T fh, pcapng_block_header_t *bh, pcapng_t *
 	return block_read;
 }
 
-static int 
+static int
 pcapng_read_interface_statistics_block(FILE_T fh, pcapng_block_header_t *bh, pcapng_t *pn, wtapng_block_t *wblock,int *err, gchar **err_info _U_)
 {
 	int bytes_read;
@@ -1033,8 +1058,8 @@ pcapng_read_interface_statistics_block(FILE_T fh, pcapng_block_header_t *bh, pca
 
 	/* Options */
 	errno = WTAP_ERR_CANT_READ;
-	to_read = bh->block_total_length 
-        - sizeof(pcapng_block_header_t) 
+	to_read = bh->block_total_length
+        - sizeof(pcapng_block_header_t)
         - block_read    /* fixed and variable part, including padding */
         - sizeof(bh->block_total_length);
 	while(to_read > 0) {
@@ -1070,7 +1095,7 @@ pcapng_read_interface_statistics_block(FILE_T fh, pcapng_block_header_t *bh, pca
 				 *  char[] may not be aligned correctly.
 				 */
 				memcpy(&wblock->data.if_stats.isb_ifrecv, option_content, sizeof(guint64));
-				if(pn->byte_swapped) 
+				if(pn->byte_swapped)
 					wblock->data.if_stats.isb_ifrecv = BSWAP64(wblock->data.if_stats.isb_ifrecv);
 				pcapng_debug1("pcapng_read_interface_statistics_block: isb_ifrecv %" G_GINT64_MODIFIER "u", wblock->data.if_stats.isb_ifrecv);
 			} else {
@@ -1083,7 +1108,7 @@ pcapng_read_interface_statistics_block(FILE_T fh, pcapng_block_header_t *bh, pca
 				 *  char[] may not be aligned correctly.
 				 */
 				memcpy(&wblock->data.if_stats.isb_ifdrop, option_content, sizeof(guint64));
-				if(pn->byte_swapped) 
+				if(pn->byte_swapped)
 					wblock->data.if_stats.isb_ifdrop = BSWAP64(wblock->data.if_stats.isb_ifdrop);
 				pcapng_debug1("pcapng_read_interface_statistics_block: isb_ifdrop %" G_GINT64_MODIFIER "u", wblock->data.if_stats.isb_ifdrop);
 			} else {
@@ -1100,7 +1125,7 @@ pcapng_read_interface_statistics_block(FILE_T fh, pcapng_block_header_t *bh, pca
 }
 
 
-static int 
+static int
 pcapng_read_unknown_block(FILE_T fh, pcapng_block_header_t *bh, pcapng_t *pn _U_, wtapng_block_t *wblock _U_,int *err, gchar **err_info _U_)
 {
 	int block_read;
@@ -1130,8 +1155,8 @@ pcapng_read_unknown_block(FILE_T fh, pcapng_block_header_t *bh, pcapng_t *pn _U_
 }
 
 
-static int 
-pcapng_read_block(FILE_T fh, pcapng_t *pn, wtapng_block_t *wblock, int *err, gchar **err_info)
+static int
+pcapng_read_block(FILE_T fh, gboolean first_block, pcapng_t *pn, wtapng_block_t *wblock, int *err, gchar **err_info)
 {
 	int block_read;
 	int bytes_read;
@@ -1143,7 +1168,7 @@ pcapng_read_block(FILE_T fh, pcapng_t *pn, wtapng_block_t *wblock, int *err, gch
 	errno = WTAP_ERR_CANT_READ;
 	bytes_read = file_read(&bh, 1, sizeof bh, fh);
 	if (bytes_read != sizeof bh) {
-		pcapng_debug0("pcapng_read_block: end of file");
+		pcapng_debug0("pcapng_read_block: end of file or error");
 		*err = file_error(fh);
 		if (*err != 0)
 			return -1;
@@ -1160,9 +1185,23 @@ pcapng_read_block(FILE_T fh, pcapng_t *pn, wtapng_block_t *wblock, int *err, gch
 
 	pcapng_debug1("pcapng_read_block: block_type 0x%x", bh.block_type);
 
+	if (first_block) {
+		/*
+		 * This is being read in by pcapng_open(), so this block
+		 * must be an SHB.  If it's not, this is not a pcap-ng
+		 * file.
+		 *
+		 * XXX - check for various forms of Windows <-> UN*X
+		 * mangling, and suggest that the file might be a
+		 * pcap-ng file that was damaged in transit?
+		 */
+		if (bh.block_type != BLOCK_TYPE_SHB)
+			return 0;	/* not a pcap-ng file */
+	}
+
 	switch(bh.block_type) {
 		case(BLOCK_TYPE_SHB):
-			bytes_read = pcapng_read_section_header_block(fh, &bh, pn, wblock, err, err_info);
+			bytes_read = pcapng_read_section_header_block(fh, first_block, &bh, pn, wblock, err, err_info);
 			break;
 		case(BLOCK_TYPE_IDB):
 			bytes_read = pcapng_read_if_descr_block(fh, &bh, pn, wblock, err, err_info);
@@ -1195,9 +1234,9 @@ pcapng_read_block(FILE_T fh, pcapng_t *pn, wtapng_block_t *wblock, int *err, gch
 	if (bytes_read != sizeof block_total_length) {
 		pcapng_debug0("pcapng_read_block: couldn't read second block length");
 		*err = file_error(fh);
-		if (*err != 0)
-			return -1;
-		return 0;
+		if (*err == 0)
+			*err = WTAP_ERR_SHORT_READ;
+ 			return -1;
 	}
 	block_read += bytes_read;
 
@@ -1205,9 +1244,10 @@ pcapng_read_block(FILE_T fh, pcapng_t *pn, wtapng_block_t *wblock, int *err, gch
 		block_total_length = BSWAP32(block_total_length);
 
 	if (!(block_total_length == bh.block_total_length)) {
-		pcapng_debug2("pcapng_read_block: total block lengths (first %u and second %u) don't match", 
-			      bh.block_total_length, block_total_length);
-		return 0;
+		*err = WTAP_ERR_BAD_RECORD;
+		*err_info = g_strdup_printf("pcapng_read_block: total block lengths (first %u and second %u) don't match", 
+ 			      bh.block_total_length, block_total_length);
+		return -1;
 	}
 
 	return block_read;
@@ -1215,7 +1255,7 @@ pcapng_read_block(FILE_T fh, pcapng_t *pn, wtapng_block_t *wblock, int *err, gch
 
 
 /* classic wtap: open capture file */
-int 
+int
 pcapng_open(wtap *wth, int *err, gchar **err_info)
 {
 	int bytes_read;
@@ -1239,7 +1279,7 @@ pcapng_open(wtap *wth, int *err, gchar **err_info)
 
 	pcapng_debug0("pcapng_open: opening file");
 	/* read first block */
-	bytes_read = pcapng_read_block(wth->fh, &pn, &wblock, err, err_info);
+	bytes_read = pcapng_read_block(wth->fh, TRUE, &pn, &wblock, err, err_info);
 	if (bytes_read <= 0) {
 		pcapng_debug0("pcapng_open: couldn't read first SHB");
 		*err = file_error(wth->fh);
@@ -1275,7 +1315,7 @@ pcapng_open(wtap *wth, int *err, gchar **err_info)
 
 
 /* classic wtap: read packet */
-static gboolean 
+static gboolean
 pcapng_read(wtap *wth, int *err, gchar **err_info, gint64 *data_offset)
 {
 	int bytes_read;
@@ -1303,7 +1343,7 @@ pcapng_read(wtap *wth, int *err, gchar **err_info, gint64 *data_offset)
 
 	/* read next block */
 	while (1) {
-		bytes_read = pcapng_read_block(wth->fh, wth->capture.pcapng, &wblock, err, err_info);
+		bytes_read = pcapng_read_block(wth->fh, FALSE, wth->capture.pcapng, &wblock, err, err_info);
 		if (bytes_read <= 0) {
 			pcapng_debug0("pcapng_read: couldn't read packet block");
 			return FALSE;
@@ -1329,7 +1369,7 @@ pcapng_read(wtap *wth, int *err, gchar **err_info, gint64 *data_offset)
 		interface_data_t int_data;
 		guint64 time_units_per_second;
 		gint id;
-		
+
 		id = (gint)wblock.data.packet.interface_id;
 		int_data = g_array_index(wth->capture.pcapng->interface_data, interface_data_t, id);
 		time_units_per_second = int_data.time_units_per_second;
@@ -1376,7 +1416,7 @@ pcapng_seek_read(wtap *wth, gint64 seek_off,
 	wblock.file_encap = &wth->file_encap;
 
 	/* read the block */
-	bytes_read = pcapng_read_block(wth->random_fh, wth->capture.pcapng, &wblock, err, err_info);
+	bytes_read = pcapng_read_block(wth->random_fh, FALSE, wth->capture.pcapng, &wblock, err, err_info);
 	if (bytes_read <= 0) {
 		*err = file_error(wth->random_fh);
 		pcapng_debug3("pcapng_seek_read: couldn't read packet block (err=%d, errno=%d, bytes_read=%d).",
@@ -1537,7 +1577,7 @@ pcapng_write_packet_block(wtap_dumper *wdh, wtapng_block_t *wblock, int *err)
 	const guint32 zero_pad = 0;
 	guint32 pad_len;
 	guint32 phdr_len;
-	
+
 	phdr_len = (guint32)pcap_get_phdr_size(wblock->data.packet.wtap_encap, wblock->pseudo_header);
 	if ((phdr_len + wblock->data.packet.cap_len) % 4) {
 		pad_len = 4 - ((phdr_len + wblock->data.packet.cap_len) % 4);
@@ -1648,7 +1688,7 @@ pcapng_lookup_interface_id_by_encap(int wtap_encap, wtap_dumper *wdh)
 {
 	gint i;
 	interface_data_t int_data;
-	
+
 	for(i = 0; i < (gint)wdh->dump.pcapng->number_of_interfaces; i++) {
 		int_data = g_array_index(wdh->dump.pcapng->interface_data, interface_data_t, i);
 		if (wtap_encap == int_data.wtap_encap) {
@@ -1683,13 +1723,13 @@ static gboolean pcapng_dump(wtap_dumper *wdh,
 		wblock.type                    = BLOCK_TYPE_IDB;
 		wblock.data.if_descr.link_type = wtap_wtap_encap_to_pcap_encap(phdr->pkt_encap);
 		wblock.data.if_descr.snap_len  = wdh->snaplen; /* XXX */
-	
+
 		/* XXX - options unused */
 		wblock.data.if_descr.if_speed   = -1;
 		wblock.data.if_descr.if_tsresol = 6;    /* default: usec */
 		wblock.data.if_descr.if_os      = NULL;
 		wblock.data.if_descr.if_fcslen  = -1;
-	
+
 		if (!pcapng_write_block(wdh, &wblock, err)) {
 			return FALSE;
 		}
@@ -1720,7 +1760,7 @@ static gboolean pcapng_dump(wtap_dumper *wdh,
 	/* Split the 64-bit timestamp into two 32-bit pieces */
         wblock.data.packet.ts_high      = (guint32)(ts >> 32);
         wblock.data.packet.ts_low       = (guint32)ts;
-	
+
 	wblock.data.packet.cap_len      = phdr->caplen;
 	wblock.data.packet.packet_len   = phdr->len;
 	wblock.data.packet.interface_id = interface_id;
@@ -1751,7 +1791,7 @@ static gboolean pcapng_dump_close(wtap_dumper *wdh, int *err _U_)
 
 /* Returns TRUE on success, FALSE on failure; sets "*err" to an error code on
    failure */
-gboolean 
+gboolean
 pcapng_dump_open(wtap_dumper *wdh, gboolean cant_seek _U_, int *err)
 {
 	wtapng_block_t wblock;
@@ -1795,7 +1835,7 @@ int pcapng_dump_can_write_encap(int wtap_encap)
 	pcapng_debug2("pcapng_dump_can_write_encap: encap = %d (%s)",
 	              wtap_encap,
 	              wtap_encap_string(wtap_encap));
-	
+
 	/* Per-packet encapsulations is supported. */
 	if (wtap_encap == WTAP_ENCAP_PER_PACKET)
 		return 0;
