@@ -2,7 +2,7 @@
  * File read and write routines for Visual Networks cap files.
  * Copyright (c) 2001, Tom Nisbet  tnisbet@visualnetworks.com
  *
- * $Id: visual.c 27685 2009-03-09 22:37:55Z gerald $
+ * $Id: visual.c 28117 2009-04-22 03:07:37Z guy $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -494,7 +494,7 @@ static gboolean visual_seek_read (wtap *wth, gint64 seek_off,
     /* If ATM capture, need to skip over visual ATM packet header too */
     if (wth->file_encap == WTAP_ENCAP_ATM_PDUS)
     {
-       header_size += sizeof(struct visual_atm_hdr);
+       header_size += (int)sizeof(struct visual_atm_hdr);
     }
     
     /* Seek to the packet header */
