@@ -1,6 +1,6 @@
 /* vms.c
  *
- * $Id: vms.c 15534 2005-08-25 21:29:54Z ulfl $
+ * $Id: vms.c 28146 2009-04-24 12:52:02Z wmeier $
  *
  * Wiretap Library
  * Copyright (c) 2001 by Marc Milgram <ethereal@mmilgram.NOSPAMmail.net>
@@ -144,8 +144,8 @@ to handle them.
 #define VMS_LINE_LENGTH              240
 
 static gboolean vms_read(wtap *wth, int *err, gchar **err_info,
-    long *data_offset);
-static gboolean vms_seek_read(wtap *wth, long seek_off,
+    gint64 *data_offset);
+static gboolean vms_seek_read(wtap *wth, gint64 seek_off,
     union wtap_pseudo_header *pseudo_header, guint8 *pd, int len,
     int *err, gchar **err_info);
 static gboolean parse_single_hex_dump_line(char* rec, guint8 *buf,
@@ -174,9 +174,8 @@ static long vms_seek_next_packet(wtap *wth, int *err)
       if (strstr(buf, VMS_REC_MAGIC_STR1) ||
 	  strstr(buf, VMS_REC_MAGIC_STR2) ||
 	  strstr(buf, VMS_REC_MAGIC_STR2)) {
-	strncpy(hdr, buf, VMS_LINE_LENGTH-1);
-	hdr[VMS_LINE_LENGTH-1] = '\0';
-	return cur_off;
+		  g_strlcpy(hdr, buf,VMS_LINE_LENGTH);
+		  return cur_off;
       }
     } else {
       if (file_eof(wth->fh)) {
@@ -210,7 +209,7 @@ static gboolean vms_check_file_type(wtap *wth, int *err)
 {
   char	buf[VMS_LINE_LENGTH];
   guint	reclen, line;
-  long mpos;
+  gint64 mpos;
   
   buf[VMS_LINE_LENGTH-1] = '\0';
   
@@ -223,7 +222,7 @@ static gboolean vms_check_file_type(wtap *wth, int *err)
     }
     if (file_gets(buf, VMS_LINE_LENGTH, wth->fh) != NULL) {
       
-      reclen = strlen(buf);
+      reclen = (guint) strlen(buf);
       if (reclen < strlen(VMS_HDR_MAGIC_STR1) ||
 	  reclen < strlen(VMS_HDR_MAGIC_STR2) || 
 	  reclen < strlen(VMS_HDR_MAGIC_STR3)) {
@@ -278,9 +277,9 @@ int vms_open(wtap *wth, int *err, gchar **err_info _U_)
 
 /* Find the next packet and parse it; called from wtap_read(). */
 static gboolean vms_read(wtap *wth, int *err, gchar **err_info,
-    long *data_offset)
+    gint64 *data_offset)
 {
-    long   offset = 0;
+    gint64   offset = 0;
     guint8    *buf;
     int    pkt_len;
 
@@ -313,7 +312,7 @@ static gboolean vms_read(wtap *wth, int *err, gchar **err_info,
 
 /* Used to read packets in random-access fashion */
 static gboolean
-vms_seek_read (wtap *wth, long seek_off,
+vms_seek_read (wtap *wth, gint64 seek_off,
     union wtap_pseudo_header *pseudo_header _U_,
     guint8 *pd, int len, int *err, gchar **err_info)
 {
@@ -373,7 +372,7 @@ parse_vms_rec_hdr(wtap *wth, FILE_T fh, int *err, gchar **err_info)
     struct tm tm;
     char mon[4] = {'J', 'A', 'N', 0};
     gchar *p;
-    static gchar months[] = "JANFEBMARAPRMAYJUNJULAUGSEPOCTNOVDEC";
+    static const gchar months[] = "JANFEBMARAPRMAYJUNJULAUGSEPOCTNOVDEC";
 
     tm.tm_year = 1970;
     tm.tm_hour = 1;
@@ -436,7 +435,7 @@ parse_vms_rec_hdr(wtap *wth, FILE_T fh, int *err, gchar **err_info)
     if (wth) {
         p = strstr(months, mon);
         if (p)
-            tm.tm_mon = (p - months) / 3;
+            tm.tm_mon = (int) (p - months) / 3;
         tm.tm_year -= 1900;
 
 	tm.tm_isdst = -1;
@@ -518,13 +517,13 @@ parse_single_hex_dump_line(char* rec, guint8 *buf, long byte_offset,
     int        i;
     char        *s;
     int        value;
-    static int offsets[16] = {39,37,35,33,28,26,24,22,17,15,13,11,6,4,2,0};
+    static const int offsets[16] = {39,37,35,33,28,26,24,22,17,15,13,11,6,4,2,0};
     char lbuf[3] = {0,0,0};
 
 
     /* Get the byte_offset directly from the record */
     s = rec;
-    value = strtoul(s + 45 + in_off, NULL, 16);
+    value = (int)strtoul(s + 45 + in_off, NULL, 16);	/* XXX - error check? */
 
     if (value != byte_offset) {
         return FALSE;
