@@ -1,6 +1,6 @@
 /* wtap.h
  *
- * $Id: wtap.h 27265 2009-01-18 21:07:06Z gerald $
+ * $Id: wtap.h 33115 2010-06-06 22:13:16Z gerald $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -27,10 +27,6 @@
 #include <sys/time.h>
 #endif
 
-#ifdef HAVE_WINSOCK2_H
-# include <winsock2.h>
-#endif
-
 #include <glib.h>
 #include <stdio.h>
 #include <time.h>
@@ -93,184 +89,191 @@ extern "C" {
  *	   what older versions of "libpcap" on Linux turn the Ethernet
  *	   header for loopback interfaces into (0.6.0 and later versions
  *	   leave the Ethernet header alone and make it DLT_EN10MB). */
-#define WTAP_ENCAP_PER_PACKET			-1
-#define WTAP_ENCAP_UNKNOWN			0
-#define WTAP_ENCAP_ETHERNET			1
-#define WTAP_ENCAP_TOKEN_RING			2
-#define WTAP_ENCAP_SLIP				3
-#define WTAP_ENCAP_PPP				4
-#define WTAP_ENCAP_FDDI				5
-#define WTAP_ENCAP_FDDI_BITSWAPPED		6
-#define WTAP_ENCAP_RAW_IP			7
-#define WTAP_ENCAP_ARCNET			8
-#define WTAP_ENCAP_ARCNET_LINUX			9
-#define WTAP_ENCAP_ATM_RFC1483			10
-#define WTAP_ENCAP_LINUX_ATM_CLIP		11
-#define WTAP_ENCAP_LAPB				12
-#define WTAP_ENCAP_ATM_PDUS			13
-#define WTAP_ENCAP_ATM_PDUS_UNTRUNCATED		14
-#define WTAP_ENCAP_NULL				15
-#define WTAP_ENCAP_ASCEND			16
-#define WTAP_ENCAP_ISDN				17
-#define WTAP_ENCAP_IP_OVER_FC			18
-#define WTAP_ENCAP_PPP_WITH_PHDR		19
-#define WTAP_ENCAP_IEEE_802_11			20
-#define WTAP_ENCAP_PRISM_HEADER			21
-#define WTAP_ENCAP_IEEE_802_11_WITH_RADIO	22
-#define WTAP_ENCAP_IEEE_802_11_WLAN_RADIOTAP	23
-#define WTAP_ENCAP_IEEE_802_11_WLAN_AVS		24
-#define WTAP_ENCAP_SLL				25
-#define WTAP_ENCAP_FRELAY			26
-#define WTAP_ENCAP_FRELAY_WITH_PHDR		27
-#define WTAP_ENCAP_CHDLC			28
-#define WTAP_ENCAP_CISCO_IOS			29
-#define WTAP_ENCAP_LOCALTALK			30
-#define WTAP_ENCAP_OLD_PFLOG			31
-#define WTAP_ENCAP_HHDLC			32
-#define WTAP_ENCAP_DOCSIS			33
-#define WTAP_ENCAP_COSINE			34
-#define WTAP_ENCAP_WFLEET_HDLC			35
-#define WTAP_ENCAP_SDLC				36
-#define WTAP_ENCAP_TZSP				37
-#define WTAP_ENCAP_ENC				38
-#define WTAP_ENCAP_PFLOG			39
-#define WTAP_ENCAP_CHDLC_WITH_PHDR		40
-#define WTAP_ENCAP_BLUETOOTH_H4			41
-#define WTAP_ENCAP_MTP2				42
-#define WTAP_ENCAP_MTP3				43
-#define WTAP_ENCAP_IRDA				44
-#define WTAP_ENCAP_USER0 			45
-#define WTAP_ENCAP_USER1 			46
-#define WTAP_ENCAP_USER2 			47
-#define WTAP_ENCAP_USER3 			48
-#define WTAP_ENCAP_USER4 			49
-#define WTAP_ENCAP_USER5 			50
-#define WTAP_ENCAP_USER6 			51
-#define WTAP_ENCAP_USER7 			52
-#define WTAP_ENCAP_USER8 			53
-#define WTAP_ENCAP_USER9 			54
-#define WTAP_ENCAP_USER10			55
-#define WTAP_ENCAP_USER11			56
-#define WTAP_ENCAP_USER12			57
-#define WTAP_ENCAP_USER13			58
-#define WTAP_ENCAP_USER14			59
-#define WTAP_ENCAP_USER15			60
-#define WTAP_ENCAP_SYMANTEC			61
-#define WTAP_ENCAP_APPLE_IP_OVER_IEEE1394	62
-#define WTAP_ENCAP_BACNET_MS_TP			63
-#define WTAP_ENCAP_NETTL_RAW_ICMP		64
-#define WTAP_ENCAP_NETTL_RAW_ICMPV6		65
-#define WTAP_ENCAP_GPRS_LLC			66
-#define WTAP_ENCAP_JUNIPER_ATM1			67
-#define WTAP_ENCAP_JUNIPER_ATM2			68
-#define WTAP_ENCAP_REDBACK			69
-#define WTAP_ENCAP_NETTL_RAW_IP			70
-#define WTAP_ENCAP_NETTL_ETHERNET		71
-#define WTAP_ENCAP_NETTL_TOKEN_RING		72
-#define WTAP_ENCAP_NETTL_FDDI			73
-#define WTAP_ENCAP_NETTL_UNKNOWN		74
-#define WTAP_ENCAP_MTP2_WITH_PHDR		75
-#define WTAP_ENCAP_JUNIPER_PPPOE		76
-#define WTAP_GCOM_TIE1				77
-#define WTAP_GCOM_SERIAL			78
-#define WTAP_ENCAP_NETTL_X25			79
-#define WTAP_ENCAP_K12				80
-#define WTAP_ENCAP_JUNIPER_MLPPP		81
-#define WTAP_ENCAP_JUNIPER_MLFR			82
-#define WTAP_ENCAP_JUNIPER_ETHER		83
-#define WTAP_ENCAP_JUNIPER_PPP			84
-#define WTAP_ENCAP_JUNIPER_FRELAY		85
-#define WTAP_ENCAP_JUNIPER_CHDLC		86
-#define WTAP_ENCAP_JUNIPER_GGSN			87
-#define WTAP_ENCAP_LINUX_LAPD			88
-#define WTAP_ENCAP_CATAPULT_DCT2000		89
-#define WTAP_ENCAP_BER				90
-#define WTAP_ENCAP_JUNIPER_VP			91
-#define WTAP_ENCAP_USB				92
-#define WTAP_ENCAP_IEEE802_16_MAC_CPS		93
-#define WTAP_ENCAP_NETTL_RAW_TELNET			94
-#define WTAP_ENCAP_USB_LINUX				95
-#define WTAP_ENCAP_MPEG						96
-#define WTAP_ENCAP_PPI						97
-#define WTAP_ENCAP_ERF						98
-#define WTAP_ENCAP_BLUETOOTH_H4_WITH_PHDR	99
-#define WTAP_ENCAP_SITA						100
-#define WTAP_ENCAP_SCCP						101
-#define WTAP_ENCAP_BLUETOOTH_HCI			102 /*raw packets without a transport layer header e.g. H4*/
-#define WTAP_ENCAP_IPMB						103
-#define WTAP_ENCAP_IEEE802_15_4				104
-#define WTAP_ENCAP_X2E_XORAYA			105
-#define WTAP_ENCAP_FLEXRAY			106
-#define WTAP_ENCAP_LIN				107
-#define WTAP_ENCAP_MOST				108
-#define WTAP_ENCAP_CAN20B			109
+#define WTAP_ENCAP_PER_PACKET                   -1
+#define WTAP_ENCAP_UNKNOWN                      0
+#define WTAP_ENCAP_ETHERNET                     1
+#define WTAP_ENCAP_TOKEN_RING                   2
+#define WTAP_ENCAP_SLIP                         3
+#define WTAP_ENCAP_PPP                          4
+#define WTAP_ENCAP_FDDI                         5
+#define WTAP_ENCAP_FDDI_BITSWAPPED              6
+#define WTAP_ENCAP_RAW_IP                       7
+#define WTAP_ENCAP_ARCNET                       8
+#define WTAP_ENCAP_ARCNET_LINUX                 9
+#define WTAP_ENCAP_ATM_RFC1483                  10
+#define WTAP_ENCAP_LINUX_ATM_CLIP               11
+#define WTAP_ENCAP_LAPB                         12
+#define WTAP_ENCAP_ATM_PDUS                     13
+#define WTAP_ENCAP_ATM_PDUS_UNTRUNCATED         14
+#define WTAP_ENCAP_NULL                         15
+#define WTAP_ENCAP_ASCEND                       16
+#define WTAP_ENCAP_ISDN                         17
+#define WTAP_ENCAP_IP_OVER_FC                   18
+#define WTAP_ENCAP_PPP_WITH_PHDR                19
+#define WTAP_ENCAP_IEEE_802_11                  20
+#define WTAP_ENCAP_PRISM_HEADER                 21
+#define WTAP_ENCAP_IEEE_802_11_WITH_RADIO       22
+#define WTAP_ENCAP_IEEE_802_11_WLAN_RADIOTAP    23
+#define WTAP_ENCAP_IEEE_802_11_WLAN_AVS         24
+#define WTAP_ENCAP_SLL                          25
+#define WTAP_ENCAP_FRELAY                       26
+#define WTAP_ENCAP_FRELAY_WITH_PHDR             27
+#define WTAP_ENCAP_CHDLC                        28
+#define WTAP_ENCAP_CISCO_IOS                    29
+#define WTAP_ENCAP_LOCALTALK                    30
+#define WTAP_ENCAP_OLD_PFLOG                    31
+#define WTAP_ENCAP_HHDLC                        32
+#define WTAP_ENCAP_DOCSIS                       33
+#define WTAP_ENCAP_COSINE                       34
+#define WTAP_ENCAP_WFLEET_HDLC                  35
+#define WTAP_ENCAP_SDLC                         36
+#define WTAP_ENCAP_TZSP                         37
+#define WTAP_ENCAP_ENC                          38
+#define WTAP_ENCAP_PFLOG                        39
+#define WTAP_ENCAP_CHDLC_WITH_PHDR              40
+#define WTAP_ENCAP_BLUETOOTH_H4                 41
+#define WTAP_ENCAP_MTP2                         42
+#define WTAP_ENCAP_MTP3                         43
+#define WTAP_ENCAP_IRDA                         44
+#define WTAP_ENCAP_USER0                        45
+#define WTAP_ENCAP_USER1                        46
+#define WTAP_ENCAP_USER2                        47
+#define WTAP_ENCAP_USER3                        48
+#define WTAP_ENCAP_USER4                        49
+#define WTAP_ENCAP_USER5                        50
+#define WTAP_ENCAP_USER6                        51
+#define WTAP_ENCAP_USER7                        52
+#define WTAP_ENCAP_USER8                        53
+#define WTAP_ENCAP_USER9                        54
+#define WTAP_ENCAP_USER10                       55
+#define WTAP_ENCAP_USER11                       56
+#define WTAP_ENCAP_USER12                       57
+#define WTAP_ENCAP_USER13                       58
+#define WTAP_ENCAP_USER14                       59
+#define WTAP_ENCAP_USER15                       60
+#define WTAP_ENCAP_SYMANTEC                     61
+#define WTAP_ENCAP_APPLE_IP_OVER_IEEE1394       62
+#define WTAP_ENCAP_BACNET_MS_TP                 63
+#define WTAP_ENCAP_NETTL_RAW_ICMP               64
+#define WTAP_ENCAP_NETTL_RAW_ICMPV6             65
+#define WTAP_ENCAP_GPRS_LLC                     66
+#define WTAP_ENCAP_JUNIPER_ATM1                 67
+#define WTAP_ENCAP_JUNIPER_ATM2                 68
+#define WTAP_ENCAP_REDBACK                      69
+#define WTAP_ENCAP_NETTL_RAW_IP                 70
+#define WTAP_ENCAP_NETTL_ETHERNET               71
+#define WTAP_ENCAP_NETTL_TOKEN_RING             72
+#define WTAP_ENCAP_NETTL_FDDI                   73
+#define WTAP_ENCAP_NETTL_UNKNOWN                74
+#define WTAP_ENCAP_MTP2_WITH_PHDR               75
+#define WTAP_ENCAP_JUNIPER_PPPOE                76
+#define WTAP_GCOM_TIE1                          77
+#define WTAP_GCOM_SERIAL                        78
+#define WTAP_ENCAP_NETTL_X25                    79
+#define WTAP_ENCAP_K12                          80
+#define WTAP_ENCAP_JUNIPER_MLPPP                81
+#define WTAP_ENCAP_JUNIPER_MLFR                 82
+#define WTAP_ENCAP_JUNIPER_ETHER                83
+#define WTAP_ENCAP_JUNIPER_PPP                  84
+#define WTAP_ENCAP_JUNIPER_FRELAY               85
+#define WTAP_ENCAP_JUNIPER_CHDLC                86
+#define WTAP_ENCAP_JUNIPER_GGSN                 87
+#define WTAP_ENCAP_LINUX_LAPD                   88
+#define WTAP_ENCAP_CATAPULT_DCT2000             89
+#define WTAP_ENCAP_BER                          90
+#define WTAP_ENCAP_JUNIPER_VP                   91
+#define WTAP_ENCAP_USB                          92
+#define WTAP_ENCAP_IEEE802_16_MAC_CPS           93
+#define WTAP_ENCAP_NETTL_RAW_TELNET             94
+#define WTAP_ENCAP_USB_LINUX                    95
+#define WTAP_ENCAP_MPEG                         96
+#define WTAP_ENCAP_PPI                          97
+#define WTAP_ENCAP_ERF                          98
+#define WTAP_ENCAP_BLUETOOTH_H4_WITH_PHDR       99
+#define WTAP_ENCAP_SITA                         100
+#define WTAP_ENCAP_SCCP                         101
+#define WTAP_ENCAP_BLUETOOTH_HCI                102 /*raw packets without a transport layer header e.g. H4*/
+#define WTAP_ENCAP_IPMB                         103
+#define WTAP_ENCAP_IEEE802_15_4                 104
+#define WTAP_ENCAP_X2E_XORAYA                   105
+#define WTAP_ENCAP_FLEXRAY                      106
+#define WTAP_ENCAP_LIN                          107
+#define WTAP_ENCAP_MOST                         108
+#define WTAP_ENCAP_CAN20B                       109
 #define WTAP_ENCAP_LAYER1_EVENT                 110
 #define WTAP_ENCAP_X2E_SERIAL                   111
 #define WTAP_ENCAP_I2C                          112
 #define WTAP_ENCAP_IEEE802_15_4_NONASK_PHY      113
 #define WTAP_ENCAP_TNEF                         114
 #define WTAP_ENCAP_USB_LINUX_MMAPPED            115
+#define WTAP_ENCAP_GSM_UM                       116
+#define WTAP_ENCAP_DPNSS                        117
+#define WTAP_ENCAP_PACKETLOGGER                 118
 
-#define WTAP_NUM_ENCAP_TYPES			wtap_get_num_encap_types()
+#define WTAP_NUM_ENCAP_TYPES                    wtap_get_num_encap_types()
 
 /* File types that can be read by wiretap.
    We support writing some many of these file types, too, so we
    distinguish between different versions of them. */
-#define WTAP_FILE_UNKNOWN			0
-#define WTAP_FILE_WTAP						1
-#define WTAP_FILE_PCAP						2
-#define WTAP_FILE_PCAP_NSEC					3
-#define WTAP_FILE_PCAP_AIX					4
-#define WTAP_FILE_PCAP_SS991029				5
-#define WTAP_FILE_PCAP_NOKIA				6
-#define WTAP_FILE_PCAP_SS990417				7
-#define WTAP_FILE_PCAP_SS990915				8
-#define WTAP_FILE_5VIEWS					9
-#define WTAP_FILE_IPTRACE_1_0				10
-#define WTAP_FILE_IPTRACE_2_0				11
-#define WTAP_FILE_BER						12
-#define WTAP_FILE_HCIDUMP					13
-#define WTAP_FILE_CATAPULT_DCT2000			14
-#define WTAP_FILE_NETXRAY_OLD				15
-#define WTAP_FILE_NETXRAY_1_0				16
-#define WTAP_FILE_COSINE					17
-#define WTAP_FILE_CSIDS						18
-#define WTAP_FILE_DBS_ETHERWATCH			19
-#define WTAP_FILE_ERF						20
-#define WTAP_FILE_EYESDN					21
-#define WTAP_FILE_NETTL						22
-#define WTAP_FILE_ISERIES					23
-#define WTAP_FILE_ISERIES_UNICODE			24
-#define WTAP_FILE_I4BTRACE					25
-#define WTAP_FILE_ASCEND					26
-#define WTAP_FILE_NETMON_1_x				27
-#define WTAP_FILE_NETMON_2_x				28
-#define WTAP_FILE_NGSNIFFER_UNCOMPRESSED	29
-#define WTAP_FILE_NGSNIFFER_COMPRESSED		30
-#define WTAP_FILE_NETXRAY_1_1				31
-#define WTAP_FILE_NETXRAY_2_00x				32
-#define WTAP_FILE_NETWORK_INSTRUMENTS_V9	33
-#define WTAP_FILE_LANALYZER					34
-#define WTAP_FILE_PPPDUMP					35
-#define WTAP_FILE_RADCOM					36
-#define WTAP_FILE_SNOOP						37
-#define WTAP_FILE_SHOMITI					38
-#define WTAP_FILE_VMS						39
-#define WTAP_FILE_K12						40
-#define WTAP_FILE_TOSHIBA					41
-#define WTAP_FILE_VISUAL_NETWORKS			42
-#define WTAP_FILE_ETHERPEEK_V56				43
-#define WTAP_FILE_ETHERPEEK_V7				44
-#define WTAP_FILE_AIROPEEK_V9				45
-#define WTAP_FILE_MPEG						46
-#define WTAP_FILE_K12TEXT					47
-#define WTAP_FILE_NETSCREEN					48
-#define WTAP_FILE_COMMVIEW					49
-#define WTAP_FILE_PCAPNG					50
-#define WTAP_FILE_BTSNOOP					51
-#define WTAP_FILE_X2E_XORAYA					52
+#define WTAP_FILE_UNKNOWN                       0
+#define WTAP_FILE_WTAP                          1
+#define WTAP_FILE_PCAP                          2
+#define WTAP_FILE_PCAP_NSEC                     3
+#define WTAP_FILE_PCAP_AIX                      4
+#define WTAP_FILE_PCAP_SS991029                 5
+#define WTAP_FILE_PCAP_NOKIA                    6
+#define WTAP_FILE_PCAP_SS990417                 7
+#define WTAP_FILE_PCAP_SS990915                 8
+#define WTAP_FILE_5VIEWS                        9
+#define WTAP_FILE_IPTRACE_1_0                   10
+#define WTAP_FILE_IPTRACE_2_0                   11
+#define WTAP_FILE_BER                           12
+#define WTAP_FILE_HCIDUMP                       13
+#define WTAP_FILE_CATAPULT_DCT2000              14
+#define WTAP_FILE_NETXRAY_OLD                   15
+#define WTAP_FILE_NETXRAY_1_0                   16
+#define WTAP_FILE_COSINE                        17
+#define WTAP_FILE_CSIDS                         18
+#define WTAP_FILE_DBS_ETHERWATCH                19
+#define WTAP_FILE_ERF                           20
+#define WTAP_FILE_EYESDN                        21
+#define WTAP_FILE_NETTL                         22
+#define WTAP_FILE_ISERIES                       23
+#define WTAP_FILE_ISERIES_UNICODE               24
+#define WTAP_FILE_I4BTRACE                      25
+#define WTAP_FILE_ASCEND                        26
+#define WTAP_FILE_NETMON_1_x                    27
+#define WTAP_FILE_NETMON_2_x                    28
+#define WTAP_FILE_NGSNIFFER_UNCOMPRESSED        29
+#define WTAP_FILE_NGSNIFFER_COMPRESSED          30
+#define WTAP_FILE_NETXRAY_1_1                   31
+#define WTAP_FILE_NETXRAY_2_00x                 32
+#define WTAP_FILE_NETWORK_INSTRUMENTS_V9        33
+#define WTAP_FILE_LANALYZER                     34
+#define WTAP_FILE_PPPDUMP                       35
+#define WTAP_FILE_RADCOM                        36
+#define WTAP_FILE_SNOOP                         37
+#define WTAP_FILE_SHOMITI                       38
+#define WTAP_FILE_VMS                           39
+#define WTAP_FILE_K12                           40
+#define WTAP_FILE_TOSHIBA                       41
+#define WTAP_FILE_VISUAL_NETWORKS               42
+#define WTAP_FILE_ETHERPEEK_V56                 43
+#define WTAP_FILE_ETHERPEEK_V7                  44
+#define WTAP_FILE_AIROPEEK_V9                   45
+#define WTAP_FILE_MPEG                          46
+#define WTAP_FILE_K12TEXT                       47
+#define WTAP_FILE_NETSCREEN                     48
+#define WTAP_FILE_COMMVIEW                      49
+#define WTAP_FILE_PCAPNG                        50
+#define WTAP_FILE_BTSNOOP                       51
+#define WTAP_FILE_X2E_XORAYA                    52
+#define WTAP_FILE_TNEF                          53
+#define WTAP_FILE_DCT3TRACE                     54
+#define WTAP_FILE_PACKETLOGGER                  55
+#define WTAP_FILE_DAINTREE_SNA                  56
 
-#define WTAP_NUM_FILE_TYPES			wtap_get_num_file_types()
+#define WTAP_NUM_FILE_TYPES                     wtap_get_num_file_types()
 
 /* timestamp precision (currently only these values are supported) */
 #define WTAP_FILE_TSPREC_SEC		0
@@ -427,9 +430,14 @@ struct ascend_phdr {
 	guint32	task;			/* Task number */
 };
 
+/* Also defined in epan/packet_info.h */
+#define P2P_DIR_UNKNOWN	-1
+#define P2P_DIR_SENT	0
+#define P2P_DIR_RECV	1
+
 /* Packet "pseudo-header" for point-to-point links with direction flags. */
 struct p2p_phdr {
-	gboolean	sent; /* TRUE=sent, FALSE=received */
+	int	sent; /* TRUE=sent, FALSE=received, -1=unknown*/
 };
 
 /*
@@ -550,7 +558,7 @@ struct k12_phdr {
 	const gchar* stack_file;
 	guint32 input_type;
 	k12_input_info_t input_info;
-	gchar* extra_info;
+	guchar* extra_info;
 	guint32 extra_length;
 	void* stuff;
 };
@@ -608,8 +616,8 @@ struct usb_device_setup_hdr {
 
 /*
  * Header prepended by Linux kernel to each USB event.
- * Followed by a struct usb_device_setup_hdr, although that header is valid
- * only if setup_flag is 0.
+ * Always followed by a struct usb_device_setup_hdr, although that header
+ * is valid only if setup_flag is 0; otherwise it's 8 bytes of junk.
  * (Setup flag is '-', 'D', 'Z', or 0.  Data flag is '<', '>', 'Z', or 0.)
  * See linux/Documentation/usb/usbmon.txt and libpcap/pcap/usb.h for details.
  *
@@ -631,6 +639,9 @@ struct linux_usb_phdr {
     guint32 data_len;       /* amount of urb data really present in this event */
 };
 
+#define LIBPCAP_BT_PHDR_SENT    0
+#define LIBPCAP_BT_PHDR_RECV    1
+
 /*
  * Header prepended by libpcap to each bluetooth hci h:4 frame.
  * Values in network byte order
@@ -651,12 +662,17 @@ struct erf_phdr {
   guint16 wlen;
 };
 
+struct erf_ehdr {
+  guint64 ehdr;
+};
+
 /*
  * ERF pseudo header with optional subheader
  * (Multichannel or Ethernet)
  */
 struct erf_mc_phdr {
   struct erf_phdr phdr;
+  struct erf_ehdr ehdr_list[8];
   union
   {
     guint16 eth_hdr;
@@ -738,6 +754,40 @@ struct bthci_phdr {
 #define BTHCI_CHANNEL_SCO     3
 #define BTHCI_CHANNEL_EVENT   4
 
+/* pseudo header for WTAP_ENCAP_LAYER1_EVENT */
+struct l1event_phdr {
+	gboolean uton;
+};
+
+/* * I2C pseudo header */
+struct i2c_phdr {
+	guint8 is_event;
+	guint8 bus;
+	guint32 flags;
+};
+
+/* pseudo header for WTAP_ENCAP_GSM_UM */
+struct gsm_um_phdr {
+	gboolean uplink;
+	guint8 channel;
+	/* The following are only populated for downlink */
+	guint8 bsic;
+	guint16 arfcn;
+	guint32 tdma_frame;
+	guint8 error;
+	guint16 timeshift;
+};
+
+#define GSM_UM_CHANNEL_UNKNOWN	0
+#define GSM_UM_CHANNEL_BCCH	1
+#define GSM_UM_CHANNEL_SDCCH	2
+#define GSM_UM_CHANNEL_SACCH	3
+#define GSM_UM_CHANNEL_FACCH	4
+#define GSM_UM_CHANNEL_CCCH	5
+#define GSM_UM_CHANNEL_RACH	6
+#define GSM_UM_CHANNEL_AGCH	7
+#define GSM_UM_CHANNEL_PCH	8
+  
 union wtap_pseudo_header {
 	struct eth_phdr		eth;
 	struct x25_phdr		x25;
@@ -757,6 +807,9 @@ union wtap_pseudo_header {
 	struct erf_mc_phdr      erf;
 	struct sita_phdr	sita;
 	struct bthci_phdr	bthci;
+	struct l1event_phdr	l1event;
+	struct i2c_phdr		i2c;
+	struct gsm_um_phdr	gsm_um;
 };
 
 struct wtap_nstime {
@@ -821,6 +874,13 @@ typedef int (*wtap_open_routine_t)(struct wtap*, int *, char **);
 struct wtap* wtap_open_offline(const char *filename, int *err,
     gchar **err_info, gboolean do_random);
 
+/*
+ * If we were compiled with zlib and we're at EOF, unset EOF so that
+ * wtap_read/gzread has a chance to succeed. This is necessary if
+ * we're tailing a file.
+ */
+void wtap_cleareof(wtap *wth);
+
 /* Returns TRUE if read was successful. FALSE if failure. data_offset is
  * set to the offset in the file where the data for the read packet is
  * located. */
