@@ -1,7 +1,7 @@
 /* unicode-utils.h
  * Unicode utility definitions
  *
- * $Id: unicode-utils.h 25640 2008-06-30 17:16:29Z morriss $
+ * $Id: unicode-utils.h 33935 2010-08-26 17:35:28Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,6 +26,9 @@
 #define __UNICODEUTIL_H__
 
 #ifdef _WIN32
+#include <windows.h>
+#include <tchar.h>
+#include <wchar.h>
 
 /**
  * @file Unicode convenience routines.
